Struct aws_sdk_codecommit::client::fluent_builders::AssociateApprovalRuleTemplateWithRepository[][src]

pub struct AssociateApprovalRuleTemplateWithRepository<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }
Fluent builder constructing a request to AssociateApprovalRuleTemplateWithRepository.

Creates an association between an approval rule template and a specified repository. Then, the next time a pull request is created in the repository where the destination reference (if specified) matches the destination reference (branch) for the pull request, an approval rule that matches the template conditions is automatically created for that pull request. If no destination references are specified in the template, an approval rule that matches the template contents is created for all pull requests in that repository.

Implementations

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

The name for the approval rule template.

The name for the approval rule template.

The name of the repository that you want to associate with the template.

The name of the repository that you want to associate with the template.