Struct aws_sdk_codecommit::client::fluent_builders::BatchAssociateApprovalRuleTemplateWithRepositories[][src]

pub struct BatchAssociateApprovalRuleTemplateWithRepositories<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }
Fluent builder constructing a request to BatchAssociateApprovalRuleTemplateWithRepositories.

Creates an association between an approval rule template and one or more specified repositories.

Implementations

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

The name of the template you want to associate with one or more repositories.

The name of the template you want to associate with one or more repositories.

Appends an item to repositoryNames.

To override the contents of this collection use set_repository_names.

The names of the repositories you want to associate with the template.

The length constraint limit is for each string in the array. The array itself can be empty.

The names of the repositories you want to associate with the template.

The length constraint limit is for each string in the array. The array itself can be empty.