Struct aws_sdk_codecommit::client::fluent_builders::BatchDisassociateApprovalRuleTemplateFromRepositories [−][src]
pub struct BatchDisassociateApprovalRuleTemplateFromRepositories<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to BatchDisassociateApprovalRuleTemplateFromRepositories.
Removes the association between an approval rule template and one or more specified repositories.
Implementations
impl<C, M, R> BatchDisassociateApprovalRuleTemplateFromRepositories<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> BatchDisassociateApprovalRuleTemplateFromRepositories<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<BatchDisassociateApprovalRuleTemplateFromRepositoriesOutput, SdkError<BatchDisassociateApprovalRuleTemplateFromRepositoriesError>> where
R::Policy: SmithyRetryPolicy<BatchDisassociateApprovalRuleTemplateFromRepositoriesInputOperationOutputAlias, BatchDisassociateApprovalRuleTemplateFromRepositoriesOutput, BatchDisassociateApprovalRuleTemplateFromRepositoriesError, BatchDisassociateApprovalRuleTemplateFromRepositoriesInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<BatchDisassociateApprovalRuleTemplateFromRepositoriesOutput, SdkError<BatchDisassociateApprovalRuleTemplateFromRepositoriesError>> where
R::Policy: SmithyRetryPolicy<BatchDisassociateApprovalRuleTemplateFromRepositoriesInputOperationOutputAlias, BatchDisassociateApprovalRuleTemplateFromRepositoriesOutput, BatchDisassociateApprovalRuleTemplateFromRepositoriesError, BatchDisassociateApprovalRuleTemplateFromRepositoriesInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The name of the template that you want to disassociate from one or more repositories.
The name of the template that you want to disassociate from one or more repositories.
Appends an item to repositoryNames.
To override the contents of this collection use set_repository_names.
The repository names that you want to disassociate from the approval rule template.
The length constraint limit is for each string in the array. The array itself can be empty.
The repository names that you want to disassociate from the approval rule template.
The length constraint limit is for each string in the array. The array itself can be empty.