Struct aws_sdk_codecommit::client::fluent_builders::CreateBranch[][src]

pub struct CreateBranch<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }
Fluent builder constructing a request to CreateBranch.

Creates a branch in a repository and points the branch to a commit.

Calling the create branch operation does not set a repository's default branch. To do this, call the update default branch operation.

Implementations

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

The name of the repository in which you want to create the new branch.

The name of the repository in which you want to create the new branch.

The name of the new branch to create.

The name of the new branch to create.

The ID of the commit to point the new branch to.

The ID of the commit to point the new branch to.