Struct aws_sdk_codecommit::client::fluent_builders::DeleteApprovalRuleTemplate [−][src]
pub struct DeleteApprovalRuleTemplate<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to DeleteApprovalRuleTemplate.
Deletes a specified approval rule template. Deleting a template does not remove approval rules on pull requests already created with the template.
Implementations
impl<C, M, R> DeleteApprovalRuleTemplate<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> DeleteApprovalRuleTemplate<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<DeleteApprovalRuleTemplateOutput, SdkError<DeleteApprovalRuleTemplateError>> where
R::Policy: SmithyRetryPolicy<DeleteApprovalRuleTemplateInputOperationOutputAlias, DeleteApprovalRuleTemplateOutput, DeleteApprovalRuleTemplateError, DeleteApprovalRuleTemplateInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<DeleteApprovalRuleTemplateOutput, SdkError<DeleteApprovalRuleTemplateError>> where
R::Policy: SmithyRetryPolicy<DeleteApprovalRuleTemplateInputOperationOutputAlias, DeleteApprovalRuleTemplateOutput, DeleteApprovalRuleTemplateError, DeleteApprovalRuleTemplateInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The name of the approval rule template to delete.
The name of the approval rule template to delete.