Struct aws_sdk_codecommit::client::fluent_builders::DeletePullRequestApprovalRule [−][src]
pub struct DeletePullRequestApprovalRule<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to DeletePullRequestApprovalRule.
Deletes an approval rule from a specified pull request. Approval rules can be deleted from a pull request only if the pull request is open, and if the approval rule was created specifically for a pull request and not generated from an approval rule template associated with the repository where the pull request was created. You cannot delete an approval rule from a merged or closed pull request.
Implementations
impl<C, M, R> DeletePullRequestApprovalRule<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> DeletePullRequestApprovalRule<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<DeletePullRequestApprovalRuleOutput, SdkError<DeletePullRequestApprovalRuleError>> where
R::Policy: SmithyRetryPolicy<DeletePullRequestApprovalRuleInputOperationOutputAlias, DeletePullRequestApprovalRuleOutput, DeletePullRequestApprovalRuleError, DeletePullRequestApprovalRuleInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<DeletePullRequestApprovalRuleOutput, SdkError<DeletePullRequestApprovalRuleError>> where
R::Policy: SmithyRetryPolicy<DeletePullRequestApprovalRuleInputOperationOutputAlias, DeletePullRequestApprovalRuleOutput, DeletePullRequestApprovalRuleError, DeletePullRequestApprovalRuleInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The system-generated ID of the pull request that contains the approval rule you want to delete.
The system-generated ID of the pull request that contains the approval rule you want to delete.
The name of the approval rule you want to delete.
The name of the approval rule you want to delete.