Struct aws_sdk_codecommit::client::fluent_builders::DescribePullRequestEvents [−][src]
pub struct DescribePullRequestEvents<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to DescribePullRequestEvents.
Returns information about one or more pull request events.
Implementations
impl<C, M, R> DescribePullRequestEvents<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> DescribePullRequestEvents<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<DescribePullRequestEventsOutput, SdkError<DescribePullRequestEventsError>> where
R::Policy: SmithyRetryPolicy<DescribePullRequestEventsInputOperationOutputAlias, DescribePullRequestEventsOutput, DescribePullRequestEventsError, DescribePullRequestEventsInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<DescribePullRequestEventsOutput, SdkError<DescribePullRequestEventsError>> where
R::Policy: SmithyRetryPolicy<DescribePullRequestEventsInputOperationOutputAlias, DescribePullRequestEventsOutput, DescribePullRequestEventsError, DescribePullRequestEventsInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
Optional. The pull request event type about which you want to return information.
Optional. The pull request event type about which you want to return information.
The Amazon Resource Name (ARN) of the user whose actions resulted in the event. Examples include updating the pull request with more commits or changing the status of a pull request.
The Amazon Resource Name (ARN) of the user whose actions resulted in the event. Examples include updating the pull request with more commits or changing the status of a pull request.
An enumeration token that, when provided in a request, returns the next batch of the results.
An enumeration token that, when provided in a request, returns the next batch of the results.
A non-zero, non-negative integer used to limit the number of returned results. The default is 100 events, which is also the maximum number of events that can be returned in a result.
A non-zero, non-negative integer used to limit the number of returned results. The default is 100 events, which is also the maximum number of events that can be returned in a result.