Struct aws_sdk_codecommit::client::fluent_builders::DisassociateApprovalRuleTemplateFromRepository[][src]

pub struct DisassociateApprovalRuleTemplateFromRepository<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }
Fluent builder constructing a request to DisassociateApprovalRuleTemplateFromRepository.

Removes the association between a template and a repository so that approval rules based on the template are not automatically created when pull requests are created in the specified repository. This does not delete any approval rules previously created for pull requests through the template association.

Implementations

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

The name of the approval rule template to disassociate from a specified repository.

The name of the approval rule template to disassociate from a specified repository.

The name of the repository you want to disassociate from the template.

The name of the repository you want to disassociate from the template.