Struct aws_sdk_codecommit::client::fluent_builders::GetApprovalRuleTemplate [−][src]
pub struct GetApprovalRuleTemplate<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to GetApprovalRuleTemplate.
Returns information about a specified approval rule template.
Implementations
impl<C, M, R> GetApprovalRuleTemplate<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> GetApprovalRuleTemplate<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<GetApprovalRuleTemplateOutput, SdkError<GetApprovalRuleTemplateError>> where
R::Policy: SmithyRetryPolicy<GetApprovalRuleTemplateInputOperationOutputAlias, GetApprovalRuleTemplateOutput, GetApprovalRuleTemplateError, GetApprovalRuleTemplateInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<GetApprovalRuleTemplateOutput, SdkError<GetApprovalRuleTemplateError>> where
R::Policy: SmithyRetryPolicy<GetApprovalRuleTemplateInputOperationOutputAlias, GetApprovalRuleTemplateOutput, GetApprovalRuleTemplateError, GetApprovalRuleTemplateInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The name of the approval rule template for which you want to get information.
The name of the approval rule template for which you want to get information.