Struct aws_sdk_codecommit::client::fluent_builders::GetBlob [−][src]
pub struct GetBlob<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to GetBlob.
Returns the base-64 encoded content of an individual blob in a repository.
Implementations
impl<C, M, R> GetBlob<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> GetBlob<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(self) -> Result<GetBlobOutput, SdkError<GetBlobError>> where
R::Policy: SmithyRetryPolicy<GetBlobInputOperationOutputAlias, GetBlobOutput, GetBlobError, GetBlobInputOperationRetryAlias>,
pub async fn send(self) -> Result<GetBlobOutput, SdkError<GetBlobError>> where
R::Policy: SmithyRetryPolicy<GetBlobInputOperationOutputAlias, GetBlobOutput, GetBlobError, GetBlobInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The name of the repository that contains the blob.
The name of the repository that contains the blob.
The ID of the blob, which is its SHA-1 pointer.
The ID of the blob, which is its SHA-1 pointer.