Struct aws_sdk_codecommit::client::fluent_builders::GetComment [−][src]
pub struct GetComment<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to GetComment.
Returns the content of a comment made on a change, file, or commit in a repository.
Reaction counts might include numbers from user identities who were deleted after the reaction was made. For a count of reactions from active identities, use GetCommentReactions.
Implementations
impl<C, M, R> GetComment<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> GetComment<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(self) -> Result<GetCommentOutput, SdkError<GetCommentError>> where
R::Policy: SmithyRetryPolicy<GetCommentInputOperationOutputAlias, GetCommentOutput, GetCommentError, GetCommentInputOperationRetryAlias>,
pub async fn send(self) -> Result<GetCommentOutput, SdkError<GetCommentError>> where
R::Policy: SmithyRetryPolicy<GetCommentInputOperationOutputAlias, GetCommentOutput, GetCommentError, GetCommentInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The unique, system-generated ID of the comment. To get this ID, use GetCommentsForComparedCommit or GetCommentsForPullRequest.
The unique, system-generated ID of the comment. To get this ID, use GetCommentsForComparedCommit or GetCommentsForPullRequest.