Struct aws_sdk_codecommit::client::fluent_builders::GetCommentReactions[][src]

pub struct GetCommentReactions<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }
Fluent builder constructing a request to GetCommentReactions.

Returns information about reactions to a specified comment ID. Reactions from users who have been deleted will not be included in the count.

Implementations

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

The ID of the comment for which you want to get reactions information.

The ID of the comment for which you want to get reactions information.

Optional. The Amazon Resource Name (ARN) of the user or identity for which you want to get reaction information.

Optional. The Amazon Resource Name (ARN) of the user or identity for which you want to get reaction information.

An enumeration token that, when provided in a request, returns the next batch of the results.

An enumeration token that, when provided in a request, returns the next batch of the results.

A non-zero, non-negative integer used to limit the number of returned results. The default is the same as the allowed maximum, 1,000.

A non-zero, non-negative integer used to limit the number of returned results. The default is the same as the allowed maximum, 1,000.