Struct aws_sdk_codecommit::client::fluent_builders::GetMergeConflicts [−][src]
pub struct GetMergeConflicts<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to GetMergeConflicts.
Returns information about merge conflicts between the before and after commit IDs for a pull request in a repository.
Implementations
impl<C, M, R> GetMergeConflicts<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> GetMergeConflicts<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<GetMergeConflictsOutput, SdkError<GetMergeConflictsError>> where
R::Policy: SmithyRetryPolicy<GetMergeConflictsInputOperationOutputAlias, GetMergeConflictsOutput, GetMergeConflictsError, GetMergeConflictsInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<GetMergeConflictsOutput, SdkError<GetMergeConflictsError>> where
R::Policy: SmithyRetryPolicy<GetMergeConflictsInputOperationOutputAlias, GetMergeConflictsOutput, GetMergeConflictsError, GetMergeConflictsInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The name of the repository where the pull request was created.
The name of the repository where the pull request was created.
The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
The merge option or strategy you want to use to merge the code.
The merge option or strategy you want to use to merge the code.
The level of conflict detail to use. If unspecified, the default FILE_LEVEL is used, which returns a not-mergeable result if the same file has differences in both branches. If LINE_LEVEL is specified, a conflict is considered not mergeable if the same file in both branches has differences on the same line.
The level of conflict detail to use. If unspecified, the default FILE_LEVEL is used, which returns a not-mergeable result if the same file has differences in both branches. If LINE_LEVEL is specified, a conflict is considered not mergeable if the same file in both branches has differences on the same line.
The maximum number of files to include in the output.
The maximum number of files to include in the output.
Specifies which branch to use when resolving conflicts, or whether to attempt automatically merging two versions of a file. The default is NONE, which requires any conflicts to be resolved manually before the merge operation is successful.
pub fn set_conflict_resolution_strategy(
self,
input: Option<ConflictResolutionStrategyTypeEnum>
) -> Self
pub fn set_conflict_resolution_strategy(
self,
input: Option<ConflictResolutionStrategyTypeEnum>
) -> Self
Specifies which branch to use when resolving conflicts, or whether to attempt automatically merging two versions of a file. The default is NONE, which requires any conflicts to be resolved manually before the merge operation is successful.
An enumeration token that, when provided in a request, returns the next batch of the results.
An enumeration token that, when provided in a request, returns the next batch of the results.