Struct aws_sdk_codecommit::client::fluent_builders::ListPullRequests [−][src]
pub struct ListPullRequests<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to ListPullRequests.
Returns a list of pull requests for a specified repository. The return list can be refined by pull request status or pull request author ARN.
Implementations
impl<C, M, R> ListPullRequests<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> ListPullRequests<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<ListPullRequestsOutput, SdkError<ListPullRequestsError>> where
R::Policy: SmithyRetryPolicy<ListPullRequestsInputOperationOutputAlias, ListPullRequestsOutput, ListPullRequestsError, ListPullRequestsInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<ListPullRequestsOutput, SdkError<ListPullRequestsError>> where
R::Policy: SmithyRetryPolicy<ListPullRequestsInputOperationOutputAlias, ListPullRequestsOutput, ListPullRequestsError, ListPullRequestsInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The name of the repository for which you want to list pull requests.
The name of the repository for which you want to list pull requests.
Optional. The Amazon Resource Name (ARN) of the user who created the pull request. If used, this filters the results to pull requests created by that user.
Optional. The Amazon Resource Name (ARN) of the user who created the pull request. If used, this filters the results to pull requests created by that user.
Optional. The status of the pull request. If used, this refines the results to the pull requests that match the specified status.
Optional. The status of the pull request. If used, this refines the results to the pull requests that match the specified status.
An enumeration token that, when provided in a request, returns the next batch of the results.
An enumeration token that, when provided in a request, returns the next batch of the results.
A non-zero, non-negative integer used to limit the number of returned results.
A non-zero, non-negative integer used to limit the number of returned results.