Struct aws_sdk_codecommit::client::fluent_builders::ListRepositories[][src]

pub struct ListRepositories<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }
Fluent builder constructing a request to ListRepositories.

Gets information about one or more repositories.

Implementations

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

An enumeration token that allows the operation to batch the results of the operation. Batch sizes are 1,000 for list repository operations. When the client sends the token back to AWS CodeCommit, another page of 1,000 records is retrieved.

An enumeration token that allows the operation to batch the results of the operation. Batch sizes are 1,000 for list repository operations. When the client sends the token back to AWS CodeCommit, another page of 1,000 records is retrieved.

The criteria used to sort the results of a list repositories operation.

The criteria used to sort the results of a list repositories operation.

The order in which to sort the results of a list repositories operation.

The order in which to sort the results of a list repositories operation.