Struct aws_sdk_codecommit::client::fluent_builders::ListRepositoriesForApprovalRuleTemplate [−][src]
pub struct ListRepositoriesForApprovalRuleTemplate<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to ListRepositoriesForApprovalRuleTemplate.
Lists all repositories associated with the specified approval rule template.
Implementations
impl<C, M, R> ListRepositoriesForApprovalRuleTemplate<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> ListRepositoriesForApprovalRuleTemplate<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<ListRepositoriesForApprovalRuleTemplateOutput, SdkError<ListRepositoriesForApprovalRuleTemplateError>> where
R::Policy: SmithyRetryPolicy<ListRepositoriesForApprovalRuleTemplateInputOperationOutputAlias, ListRepositoriesForApprovalRuleTemplateOutput, ListRepositoriesForApprovalRuleTemplateError, ListRepositoriesForApprovalRuleTemplateInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<ListRepositoriesForApprovalRuleTemplateOutput, SdkError<ListRepositoriesForApprovalRuleTemplateError>> where
R::Policy: SmithyRetryPolicy<ListRepositoriesForApprovalRuleTemplateInputOperationOutputAlias, ListRepositoriesForApprovalRuleTemplateOutput, ListRepositoriesForApprovalRuleTemplateError, ListRepositoriesForApprovalRuleTemplateInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The name of the approval rule template for which you want to list repositories that are associated with that template.
The name of the approval rule template for which you want to list repositories that are associated with that template.
An enumeration token that, when provided in a request, returns the next batch of the results.
An enumeration token that, when provided in a request, returns the next batch of the results.
A non-zero, non-negative integer used to limit the number of returned results.
A non-zero, non-negative integer used to limit the number of returned results.