Struct aws_sdk_codecommit::client::fluent_builders::MergeBranchesByFastForward [−][src]
pub struct MergeBranchesByFastForward<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to MergeBranchesByFastForward.
Merges two branches using the fast-forward merge strategy.
Implementations
impl<C, M, R> MergeBranchesByFastForward<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> MergeBranchesByFastForward<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<MergeBranchesByFastForwardOutput, SdkError<MergeBranchesByFastForwardError>> where
R::Policy: SmithyRetryPolicy<MergeBranchesByFastForwardInputOperationOutputAlias, MergeBranchesByFastForwardOutput, MergeBranchesByFastForwardError, MergeBranchesByFastForwardInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<MergeBranchesByFastForwardOutput, SdkError<MergeBranchesByFastForwardError>> where
R::Policy: SmithyRetryPolicy<MergeBranchesByFastForwardInputOperationOutputAlias, MergeBranchesByFastForwardOutput, MergeBranchesByFastForwardError, MergeBranchesByFastForwardInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The name of the repository where you want to merge two branches.
The name of the repository where you want to merge two branches.
The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
The branch where the merge is applied.
The branch where the merge is applied.