Struct aws_sdk_codecommit::client::fluent_builders::MergePullRequestByFastForward [−][src]
pub struct MergePullRequestByFastForward<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to MergePullRequestByFastForward.
Attempts to merge the source commit of a pull request into the specified destination branch for that pull request at the specified commit using the fast-forward merge strategy. If the merge is successful, it closes the pull request.
Implementations
impl<C, M, R> MergePullRequestByFastForward<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> MergePullRequestByFastForward<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<MergePullRequestByFastForwardOutput, SdkError<MergePullRequestByFastForwardError>> where
R::Policy: SmithyRetryPolicy<MergePullRequestByFastForwardInputOperationOutputAlias, MergePullRequestByFastForwardOutput, MergePullRequestByFastForwardError, MergePullRequestByFastForwardInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<MergePullRequestByFastForwardOutput, SdkError<MergePullRequestByFastForwardError>> where
R::Policy: SmithyRetryPolicy<MergePullRequestByFastForwardInputOperationOutputAlias, MergePullRequestByFastForwardOutput, MergePullRequestByFastForwardError, MergePullRequestByFastForwardInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
The name of the repository where the pull request was created.
The name of the repository where the pull request was created.
The full commit ID of the original or updated commit in the pull request source branch. Pass this value if you want an exception thrown if the current commit ID of the tip of the source branch does not match this commit ID.
The full commit ID of the original or updated commit in the pull request source branch. Pass this value if you want an exception thrown if the current commit ID of the tip of the source branch does not match this commit ID.