Struct aws_sdk_codecommit::client::fluent_builders::PostCommentForComparedCommit[][src]

pub struct PostCommentForComparedCommit<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }
Fluent builder constructing a request to PostCommentForComparedCommit.

Posts a comment on the comparison between two commits.

Implementations

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

The name of the repository where you want to post a comment on the comparison between commits.

The name of the repository where you want to post a comment on the comparison between commits.

To establish the directionality of the comparison, the full commit ID of the before commit. Required for commenting on any commit unless that commit is the initial commit.

To establish the directionality of the comparison, the full commit ID of the before commit. Required for commenting on any commit unless that commit is the initial commit.

To establish the directionality of the comparison, the full commit ID of the after commit.

To establish the directionality of the comparison, the full commit ID of the after commit.

The location of the comparison where you want to comment.

The location of the comparison where you want to comment.

The content of the comment you want to make.

The content of the comment you want to make.

A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.

A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.