Struct aws_sdk_codecommit::client::fluent_builders::UpdateApprovalRuleTemplateContent [−][src]
pub struct UpdateApprovalRuleTemplateContent<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to UpdateApprovalRuleTemplateContent.
Updates the content of an approval rule template. You can change the number of required approvals, the membership of the approval rule, and whether an approval pool is defined.
Implementations
impl<C, M, R> UpdateApprovalRuleTemplateContent<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> UpdateApprovalRuleTemplateContent<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<UpdateApprovalRuleTemplateContentOutput, SdkError<UpdateApprovalRuleTemplateContentError>> where
R::Policy: SmithyRetryPolicy<UpdateApprovalRuleTemplateContentInputOperationOutputAlias, UpdateApprovalRuleTemplateContentOutput, UpdateApprovalRuleTemplateContentError, UpdateApprovalRuleTemplateContentInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<UpdateApprovalRuleTemplateContentOutput, SdkError<UpdateApprovalRuleTemplateContentError>> where
R::Policy: SmithyRetryPolicy<UpdateApprovalRuleTemplateContentInputOperationOutputAlias, UpdateApprovalRuleTemplateContentOutput, UpdateApprovalRuleTemplateContentError, UpdateApprovalRuleTemplateContentInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The name of the approval rule template where you want to update the content of the rule.
The name of the approval rule template where you want to update the content of the rule.
The content that replaces the existing content of the rule. Content statements must be complete. You cannot provide only the changes.
The content that replaces the existing content of the rule. Content statements must be complete. You cannot provide only the changes.
The SHA-256 hash signature for the content of the approval rule. You can retrieve this information by using GetPullRequest.
The SHA-256 hash signature for the content of the approval rule. You can retrieve this information by using GetPullRequest.