Struct aws_sdk_codecommit::client::fluent_builders::UpdateApprovalRuleTemplateDescription [−][src]
pub struct UpdateApprovalRuleTemplateDescription<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to UpdateApprovalRuleTemplateDescription.
Updates the description for a specified approval rule template.
Implementations
impl<C, M, R> UpdateApprovalRuleTemplateDescription<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> UpdateApprovalRuleTemplateDescription<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<UpdateApprovalRuleTemplateDescriptionOutput, SdkError<UpdateApprovalRuleTemplateDescriptionError>> where
R::Policy: SmithyRetryPolicy<UpdateApprovalRuleTemplateDescriptionInputOperationOutputAlias, UpdateApprovalRuleTemplateDescriptionOutput, UpdateApprovalRuleTemplateDescriptionError, UpdateApprovalRuleTemplateDescriptionInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<UpdateApprovalRuleTemplateDescriptionOutput, SdkError<UpdateApprovalRuleTemplateDescriptionError>> where
R::Policy: SmithyRetryPolicy<UpdateApprovalRuleTemplateDescriptionInputOperationOutputAlias, UpdateApprovalRuleTemplateDescriptionOutput, UpdateApprovalRuleTemplateDescriptionError, UpdateApprovalRuleTemplateDescriptionInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The name of the template for which you want to update the description.
The name of the template for which you want to update the description.
The updated description of the approval rule template.
The updated description of the approval rule template.