Struct aws_sdk_codecommit::client::fluent_builders::UpdateApprovalRuleTemplateName [−][src]
pub struct UpdateApprovalRuleTemplateName<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to UpdateApprovalRuleTemplateName.
Updates the name of a specified approval rule template.
Implementations
impl<C, M, R> UpdateApprovalRuleTemplateName<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> UpdateApprovalRuleTemplateName<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<UpdateApprovalRuleTemplateNameOutput, SdkError<UpdateApprovalRuleTemplateNameError>> where
R::Policy: SmithyRetryPolicy<UpdateApprovalRuleTemplateNameInputOperationOutputAlias, UpdateApprovalRuleTemplateNameOutput, UpdateApprovalRuleTemplateNameError, UpdateApprovalRuleTemplateNameInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<UpdateApprovalRuleTemplateNameOutput, SdkError<UpdateApprovalRuleTemplateNameError>> where
R::Policy: SmithyRetryPolicy<UpdateApprovalRuleTemplateNameInputOperationOutputAlias, UpdateApprovalRuleTemplateNameOutput, UpdateApprovalRuleTemplateNameError, UpdateApprovalRuleTemplateNameInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The current name of the approval rule template.
The current name of the approval rule template.
The new name you want to apply to the approval rule template.
The new name you want to apply to the approval rule template.