Struct aws_sdk_codecommit::client::fluent_builders::UpdatePullRequestApprovalState[][src]

pub struct UpdatePullRequestApprovalState<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }
Fluent builder constructing a request to UpdatePullRequestApprovalState.

Updates the state of a user's approval on a pull request. The user is derived from the signed-in account when the request is made.

Implementations

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

The system-generated ID of the pull request.

The system-generated ID of the pull request.

The system-generated ID of the revision.

The system-generated ID of the revision.

The approval state to associate with the user on the pull request.

The approval state to associate with the user on the pull request.