Struct aws_sdk_codecommit::client::fluent_builders::UpdatePullRequestStatus [−][src]
pub struct UpdatePullRequestStatus<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to UpdatePullRequestStatus.
Updates the status of a pull request.
Implementations
impl<C, M, R> UpdatePullRequestStatus<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> UpdatePullRequestStatus<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<UpdatePullRequestStatusOutput, SdkError<UpdatePullRequestStatusError>> where
R::Policy: SmithyRetryPolicy<UpdatePullRequestStatusInputOperationOutputAlias, UpdatePullRequestStatusOutput, UpdatePullRequestStatusError, UpdatePullRequestStatusInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<UpdatePullRequestStatusOutput, SdkError<UpdatePullRequestStatusError>> where
R::Policy: SmithyRetryPolicy<UpdatePullRequestStatusInputOperationOutputAlias, UpdatePullRequestStatusOutput, UpdatePullRequestStatusError, UpdatePullRequestStatusInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
The status of the pull request. The only valid operations are to update the status
from OPEN to OPEN, OPEN to CLOSED or
from CLOSED to CLOSED.
The status of the pull request. The only valid operations are to update the status
from OPEN to OPEN, OPEN to CLOSED or
from CLOSED to CLOSED.