Enum aws_sdk_codecommit::Error [−][src]
#[non_exhaustive]
pub enum Error {
Show 186 variants
ActorDoesNotExistException(ActorDoesNotExistException),
ApprovalRuleContentRequiredException(ApprovalRuleContentRequiredException),
ApprovalRuleDoesNotExistException(ApprovalRuleDoesNotExistException),
ApprovalRuleNameAlreadyExistsException(ApprovalRuleNameAlreadyExistsException),
ApprovalRuleNameRequiredException(ApprovalRuleNameRequiredException),
ApprovalRuleTemplateContentRequiredException(ApprovalRuleTemplateContentRequiredException),
ApprovalRuleTemplateDoesNotExistException(ApprovalRuleTemplateDoesNotExistException),
ApprovalRuleTemplateInUseException(ApprovalRuleTemplateInUseException),
ApprovalRuleTemplateNameAlreadyExistsException(ApprovalRuleTemplateNameAlreadyExistsException),
ApprovalRuleTemplateNameRequiredException(ApprovalRuleTemplateNameRequiredException),
ApprovalStateRequiredException(ApprovalStateRequiredException),
AuthorDoesNotExistException(AuthorDoesNotExistException),
BeforeCommitIdAndAfterCommitIdAreSameException(BeforeCommitIdAndAfterCommitIdAreSameException),
BlobIdDoesNotExistException(BlobIdDoesNotExistException),
BlobIdRequiredException(BlobIdRequiredException),
BranchDoesNotExistException(BranchDoesNotExistException),
BranchNameExistsException(BranchNameExistsException),
BranchNameIsTagNameException(BranchNameIsTagNameException),
BranchNameRequiredException(BranchNameRequiredException),
CannotDeleteApprovalRuleFromTemplateException(CannotDeleteApprovalRuleFromTemplateException),
CannotModifyApprovalRuleFromTemplateException(CannotModifyApprovalRuleFromTemplateException),
ClientRequestTokenRequiredException(ClientRequestTokenRequiredException),
CommentContentRequiredException(CommentContentRequiredException),
CommentContentSizeLimitExceededException(CommentContentSizeLimitExceededException),
CommentDeletedException(CommentDeletedException),
CommentDoesNotExistException(CommentDoesNotExistException),
CommentIdRequiredException(CommentIdRequiredException),
CommentNotCreatedByCallerException(CommentNotCreatedByCallerException),
CommitDoesNotExistException(CommitDoesNotExistException),
CommitIdDoesNotExistException(CommitIdDoesNotExistException),
CommitIdRequiredException(CommitIdRequiredException),
CommitIdsLimitExceededException(CommitIdsLimitExceededException),
CommitIdsListRequiredException(CommitIdsListRequiredException),
CommitMessageLengthExceededException(CommitMessageLengthExceededException),
CommitRequiredException(CommitRequiredException),
ConcurrentReferenceUpdateException(ConcurrentReferenceUpdateException),
DefaultBranchCannotBeDeletedException(DefaultBranchCannotBeDeletedException),
DirectoryNameConflictsWithFileNameException(DirectoryNameConflictsWithFileNameException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
FileContentAndSourceFileSpecifiedException(FileContentAndSourceFileSpecifiedException),
FileContentRequiredException(FileContentRequiredException),
FileContentSizeLimitExceededException(FileContentSizeLimitExceededException),
FileDoesNotExistException(FileDoesNotExistException),
FileEntryRequiredException(FileEntryRequiredException),
FileModeRequiredException(FileModeRequiredException),
FileNameConflictsWithDirectoryNameException(FileNameConflictsWithDirectoryNameException),
FilePathConflictsWithSubmodulePathException(FilePathConflictsWithSubmodulePathException),
FileTooLargeException(FileTooLargeException),
FolderContentSizeLimitExceededException(FolderContentSizeLimitExceededException),
FolderDoesNotExistException(FolderDoesNotExistException),
IdempotencyParameterMismatchException(IdempotencyParameterMismatchException),
InvalidActorArnException(InvalidActorArnException),
InvalidApprovalRuleContentException(InvalidApprovalRuleContentException),
InvalidApprovalRuleNameException(InvalidApprovalRuleNameException),
InvalidApprovalRuleTemplateContentException(InvalidApprovalRuleTemplateContentException),
InvalidApprovalRuleTemplateDescriptionException(InvalidApprovalRuleTemplateDescriptionException),
InvalidApprovalRuleTemplateNameException(InvalidApprovalRuleTemplateNameException),
InvalidApprovalStateException(InvalidApprovalStateException),
InvalidAuthorArnException(InvalidAuthorArnException),
InvalidBlobIdException(InvalidBlobIdException),
InvalidBranchNameException(InvalidBranchNameException),
InvalidClientRequestTokenException(InvalidClientRequestTokenException),
InvalidCommentIdException(InvalidCommentIdException),
InvalidCommitException(InvalidCommitException),
InvalidCommitIdException(InvalidCommitIdException),
InvalidConflictDetailLevelException(InvalidConflictDetailLevelException),
InvalidConflictResolutionException(InvalidConflictResolutionException),
InvalidConflictResolutionStrategyException(InvalidConflictResolutionStrategyException),
InvalidContinuationTokenException(InvalidContinuationTokenException),
InvalidDeletionParameterException(InvalidDeletionParameterException),
InvalidDescriptionException(InvalidDescriptionException),
InvalidDestinationCommitSpecifierException(InvalidDestinationCommitSpecifierException),
InvalidEmailException(InvalidEmailException),
InvalidFileLocationException(InvalidFileLocationException),
InvalidFileModeException(InvalidFileModeException),
InvalidFilePositionException(InvalidFilePositionException),
InvalidMaxConflictFilesException(InvalidMaxConflictFilesException),
InvalidMaxMergeHunksException(InvalidMaxMergeHunksException),
InvalidMaxResultsException(InvalidMaxResultsException),
InvalidMergeOptionException(InvalidMergeOptionException),
InvalidOrderException(InvalidOrderException),
InvalidOverrideStatusException(InvalidOverrideStatusException),
InvalidParentCommitIdException(InvalidParentCommitIdException),
InvalidPathException(InvalidPathException),
InvalidPullRequestEventTypeException(InvalidPullRequestEventTypeException),
InvalidPullRequestIdException(InvalidPullRequestIdException),
InvalidPullRequestStatusException(InvalidPullRequestStatusException),
InvalidPullRequestStatusUpdateException(InvalidPullRequestStatusUpdateException),
InvalidReactionUserArnException(InvalidReactionUserArnException),
InvalidReactionValueException(InvalidReactionValueException),
InvalidReferenceNameException(InvalidReferenceNameException),
InvalidRelativeFileVersionEnumException(InvalidRelativeFileVersionEnumException),
InvalidReplacementContentException(InvalidReplacementContentException),
InvalidReplacementTypeException(InvalidReplacementTypeException),
InvalidRepositoryDescriptionException(InvalidRepositoryDescriptionException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
InvalidRepositoryTriggerBranchNameException(InvalidRepositoryTriggerBranchNameException),
InvalidRepositoryTriggerCustomDataException(InvalidRepositoryTriggerCustomDataException),
InvalidRepositoryTriggerDestinationArnException(InvalidRepositoryTriggerDestinationArnException),
InvalidRepositoryTriggerEventsException(InvalidRepositoryTriggerEventsException),
InvalidRepositoryTriggerNameException(InvalidRepositoryTriggerNameException),
InvalidRepositoryTriggerRegionException(InvalidRepositoryTriggerRegionException),
InvalidResourceArnException(InvalidResourceArnException),
InvalidRevisionIdException(InvalidRevisionIdException),
InvalidRuleContentSha256Exception(InvalidRuleContentSha256Exception),
InvalidSortByException(InvalidSortByException),
InvalidSourceCommitSpecifierException(InvalidSourceCommitSpecifierException),
InvalidSystemTagUsageException(InvalidSystemTagUsageException),
InvalidTagKeysListException(InvalidTagKeysListException),
InvalidTagsMapException(InvalidTagsMapException),
InvalidTargetBranchException(InvalidTargetBranchException),
InvalidTargetException(InvalidTargetException),
InvalidTargetsException(InvalidTargetsException),
InvalidTitleException(InvalidTitleException),
ManualMergeRequiredException(ManualMergeRequiredException),
MaximumBranchesExceededException(MaximumBranchesExceededException),
MaximumConflictResolutionEntriesExceededException(MaximumConflictResolutionEntriesExceededException),
MaximumFileContentToLoadExceededException(MaximumFileContentToLoadExceededException),
MaximumFileEntriesExceededException(MaximumFileEntriesExceededException),
MaximumItemsToCompareExceededException(MaximumItemsToCompareExceededException),
MaximumNumberOfApprovalsExceededException(MaximumNumberOfApprovalsExceededException),
MaximumOpenPullRequestsExceededException(MaximumOpenPullRequestsExceededException),
MaximumRepositoryNamesExceededException(MaximumRepositoryNamesExceededException),
MaximumRepositoryTriggersExceededException(MaximumRepositoryTriggersExceededException),
MaximumRuleTemplatesAssociatedWithRepositoryException(MaximumRuleTemplatesAssociatedWithRepositoryException),
MergeOptionRequiredException(MergeOptionRequiredException),
MultipleConflictResolutionEntriesException(MultipleConflictResolutionEntriesException),
MultipleRepositoriesInPullRequestException(MultipleRepositoriesInPullRequestException),
NameLengthExceededException(NameLengthExceededException),
NoChangeException(NoChangeException),
NumberOfRuleTemplatesExceededException(NumberOfRuleTemplatesExceededException),
NumberOfRulesExceededException(NumberOfRulesExceededException),
OverrideAlreadySetException(OverrideAlreadySetException),
OverrideStatusRequiredException(OverrideStatusRequiredException),
ParentCommitDoesNotExistException(ParentCommitDoesNotExistException),
ParentCommitIdOutdatedException(ParentCommitIdOutdatedException),
ParentCommitIdRequiredException(ParentCommitIdRequiredException),
PathDoesNotExistException(PathDoesNotExistException),
PathRequiredException(PathRequiredException),
PullRequestAlreadyClosedException(PullRequestAlreadyClosedException),
PullRequestApprovalRulesNotSatisfiedException(PullRequestApprovalRulesNotSatisfiedException),
PullRequestCannotBeApprovedByAuthorException(PullRequestCannotBeApprovedByAuthorException),
PullRequestDoesNotExistException(PullRequestDoesNotExistException),
PullRequestIdRequiredException(PullRequestIdRequiredException),
PullRequestStatusRequiredException(PullRequestStatusRequiredException),
PutFileEntryConflictException(PutFileEntryConflictException),
ReactionLimitExceededException(ReactionLimitExceededException),
ReactionValueRequiredException(ReactionValueRequiredException),
ReferenceDoesNotExistException(ReferenceDoesNotExistException),
ReferenceNameRequiredException(ReferenceNameRequiredException),
ReferenceTypeNotSupportedException(ReferenceTypeNotSupportedException),
ReplacementContentRequiredException(ReplacementContentRequiredException),
ReplacementTypeRequiredException(ReplacementTypeRequiredException),
RepositoryDoesNotExistException(RepositoryDoesNotExistException),
RepositoryLimitExceededException(RepositoryLimitExceededException),
RepositoryNameExistsException(RepositoryNameExistsException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
RepositoryNamesRequiredException(RepositoryNamesRequiredException),
RepositoryNotAssociatedWithPullRequestException(RepositoryNotAssociatedWithPullRequestException),
RepositoryTriggerBranchNameListRequiredException(RepositoryTriggerBranchNameListRequiredException),
RepositoryTriggerDestinationArnRequiredException(RepositoryTriggerDestinationArnRequiredException),
RepositoryTriggerEventsListRequiredException(RepositoryTriggerEventsListRequiredException),
RepositoryTriggerNameRequiredException(RepositoryTriggerNameRequiredException),
RepositoryTriggersListRequiredException(RepositoryTriggersListRequiredException),
ResourceArnRequiredException(ResourceArnRequiredException),
RestrictedSourceFileException(RestrictedSourceFileException),
RevisionIdRequiredException(RevisionIdRequiredException),
RevisionNotCurrentException(RevisionNotCurrentException),
SameFileContentException(SameFileContentException),
SamePathRequestException(SamePathRequestException),
SourceAndDestinationAreSameException(SourceAndDestinationAreSameException),
SourceFileOrContentRequiredException(SourceFileOrContentRequiredException),
TagKeysListRequiredException(TagKeysListRequiredException),
TagPolicyException(TagPolicyException),
TagsMapRequiredException(TagsMapRequiredException),
TargetRequiredException(TargetRequiredException),
TargetsRequiredException(TargetsRequiredException),
TipOfSourceReferenceIsDifferentException(TipOfSourceReferenceIsDifferentException),
TipsDivergenceExceededException(TipsDivergenceExceededException),
TitleRequiredException(TitleRequiredException),
TooManyTagsException(TooManyTagsException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
All possible error types for this service.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ActorDoesNotExistException(ActorDoesNotExistException)The specified Amazon Resource Name (ARN) does not exist in the AWS account.
Tuple Fields of ActorDoesNotExistException
ApprovalRuleContentRequiredException(ApprovalRuleContentRequiredException)The content for the approval rule is empty. You must provide some content for an approval rule. The content cannot be null.
Tuple Fields of ApprovalRuleContentRequiredException
ApprovalRuleDoesNotExistException(ApprovalRuleDoesNotExistException)The specified approval rule does not exist.
Tuple Fields of ApprovalRuleDoesNotExistException
ApprovalRuleNameAlreadyExistsException(ApprovalRuleNameAlreadyExistsException)An approval rule with that name already exists. Approval rule names must be unique within the scope of a pull request.
Tuple Fields of ApprovalRuleNameAlreadyExistsException
ApprovalRuleNameRequiredException(ApprovalRuleNameRequiredException)An approval rule name is required, but was not specified.
Tuple Fields of ApprovalRuleNameRequiredException
ApprovalRuleTemplateContentRequiredException(ApprovalRuleTemplateContentRequiredException)The content for the approval rule template is empty. You must provide some content for an approval rule template. The content cannot be null.
Tuple Fields of ApprovalRuleTemplateContentRequiredException
ApprovalRuleTemplateDoesNotExistException(ApprovalRuleTemplateDoesNotExistException)The specified approval rule template does not exist. Verify that the name is correct and that you are signed in to the AWS Region where the template was created, and then try again.
Tuple Fields of ApprovalRuleTemplateDoesNotExistException
ApprovalRuleTemplateInUseException(ApprovalRuleTemplateInUseException)The approval rule template is associated with one or more repositories. You cannot delete a template that is associated with a repository. Remove all associations, and then try again.
Tuple Fields of ApprovalRuleTemplateInUseException
ApprovalRuleTemplateNameAlreadyExistsException(ApprovalRuleTemplateNameAlreadyExistsException)You cannot create an approval rule template with that name because a template with that name already exists in this AWS Region for your AWS account. Approval rule template names must be unique.
Tuple Fields of ApprovalRuleTemplateNameAlreadyExistsException
ApprovalRuleTemplateNameRequiredException(ApprovalRuleTemplateNameRequiredException)An approval rule template name is required, but was not specified.
Tuple Fields of ApprovalRuleTemplateNameRequiredException
ApprovalStateRequiredException(ApprovalStateRequiredException)An approval state is required, but was not specified.
Tuple Fields of ApprovalStateRequiredException
AuthorDoesNotExistException(AuthorDoesNotExistException)The specified Amazon Resource Name (ARN) does not exist in the AWS account.
Tuple Fields of AuthorDoesNotExistException
BeforeCommitIdAndAfterCommitIdAreSameException(BeforeCommitIdAndAfterCommitIdAreSameException)The before commit ID and the after commit ID are the same, which is not valid. The before commit ID and the after commit ID must be different commit IDs.
Tuple Fields of BeforeCommitIdAndAfterCommitIdAreSameException
BlobIdDoesNotExistException(BlobIdDoesNotExistException)The specified blob does not exist.
Tuple Fields of BlobIdDoesNotExistException
BlobIdRequiredException(BlobIdRequiredException)A blob ID is required, but was not specified.
Tuple Fields of BlobIdRequiredException
BranchDoesNotExistException(BranchDoesNotExistException)The specified branch does not exist.
Tuple Fields of BranchDoesNotExistException
BranchNameExistsException(BranchNameExistsException)Cannot create the branch with the specified name because the commit conflicts with an existing branch with the same name. Branch names must be unique.
Tuple Fields of BranchNameExistsException
BranchNameIsTagNameException(BranchNameIsTagNameException)The specified branch name is not valid because it is a tag name. Enter the name of a branch in the repository. For a list of valid branch names, use ListBranches.
Tuple Fields of BranchNameIsTagNameException
BranchNameRequiredException(BranchNameRequiredException)A branch name is required, but was not specified.
Tuple Fields of BranchNameRequiredException
CannotDeleteApprovalRuleFromTemplateException(CannotDeleteApprovalRuleFromTemplateException)The approval rule cannot be deleted from the pull request because it was created by an approval rule template and applied to the pull request automatically.
Tuple Fields of CannotDeleteApprovalRuleFromTemplateException
CannotModifyApprovalRuleFromTemplateException(CannotModifyApprovalRuleFromTemplateException)The approval rule cannot be modified for the pull request because it was created by an approval rule template and applied to the pull request automatically.
Tuple Fields of CannotModifyApprovalRuleFromTemplateException
ClientRequestTokenRequiredException(ClientRequestTokenRequiredException)A client request token is required. A client request token is an unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
Tuple Fields of ClientRequestTokenRequiredException
CommentContentRequiredException(CommentContentRequiredException)The comment is empty. You must provide some content for a comment. The content cannot be null.
Tuple Fields of CommentContentRequiredException
CommentContentSizeLimitExceededException(CommentContentSizeLimitExceededException)The comment is too large. Comments are limited to 1,000 characters.
Tuple Fields of CommentContentSizeLimitExceededException
CommentDeletedException(CommentDeletedException)This comment has already been deleted. You cannot edit or delete a deleted comment.
Tuple Fields of CommentDeletedException
CommentDoesNotExistException(CommentDoesNotExistException)No comment exists with the provided ID. Verify that you have used the correct ID, and then try again.
Tuple Fields of CommentDoesNotExistException
CommentIdRequiredException(CommentIdRequiredException)The comment ID is missing or null. A comment ID is required.
Tuple Fields of CommentIdRequiredException
CommentNotCreatedByCallerException(CommentNotCreatedByCallerException)You cannot modify or delete this comment. Only comment authors can modify or delete their comments.
Tuple Fields of CommentNotCreatedByCallerException
CommitDoesNotExistException(CommitDoesNotExistException)The specified commit does not exist or no commit was specified, and the specified repository has no default branch.
Tuple Fields of CommitDoesNotExistException
CommitIdDoesNotExistException(CommitIdDoesNotExistException)The specified commit ID does not exist.
Tuple Fields of CommitIdDoesNotExistException
CommitIdRequiredException(CommitIdRequiredException)A commit ID was not specified.
Tuple Fields of CommitIdRequiredException
CommitIdsLimitExceededException(CommitIdsLimitExceededException)The maximum number of allowed commit IDs in a batch request is 100. Verify that your batch requests contains no more than 100 commit IDs, and then try again.
Tuple Fields of CommitIdsLimitExceededException
CommitIdsListRequiredException(CommitIdsListRequiredException)A list of commit IDs is required, but was either not specified or the list was empty.
Tuple Fields of CommitIdsListRequiredException
CommitMessageLengthExceededException(CommitMessageLengthExceededException)The commit message is too long. Provide a shorter string.
Tuple Fields of CommitMessageLengthExceededException
CommitRequiredException(CommitRequiredException)A commit was not specified.
Tuple Fields of CommitRequiredException
ConcurrentReferenceUpdateException(ConcurrentReferenceUpdateException)The merge cannot be completed because the target branch has been modified. Another user might have modified the target branch while the merge was in progress. Wait a few minutes, and then try again.
Tuple Fields of ConcurrentReferenceUpdateException
DefaultBranchCannotBeDeletedException(DefaultBranchCannotBeDeletedException)The specified branch is the default branch for the repository, and cannot be deleted. To delete this branch, you must first set another branch as the default branch.
Tuple Fields of DefaultBranchCannotBeDeletedException
DirectoryNameConflictsWithFileNameException(DirectoryNameConflictsWithFileNameException)A file cannot be added to the repository because the specified path name has the same name as a file that already exists in this repository. Either provide a different name for the file, or specify a different path for the file.
Tuple Fields of DirectoryNameConflictsWithFileNameException
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)An encryption integrity check failed.
Tuple Fields of EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)An encryption key could not be accessed.
Tuple Fields of EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)The encryption key is disabled.
Tuple Fields of EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)No encryption key was found.
Tuple Fields of EncryptionKeyNotFoundException
The encryption key is not available.
FileContentAndSourceFileSpecifiedException(FileContentAndSourceFileSpecifiedException)The commit cannot be created because both a source file and file content have been specified for the same file. You cannot provide both. Either specify a source file or provide the file content directly.
Tuple Fields of FileContentAndSourceFileSpecifiedException
FileContentRequiredException(FileContentRequiredException)The file cannot be added because it is empty. Empty files cannot be added to the repository with this API.
Tuple Fields of FileContentRequiredException
FileContentSizeLimitExceededException(FileContentSizeLimitExceededException)The file cannot be added because it is too large. The maximum file size is 6 MB, and the combined file content change size is 7 MB. Consider making these changes using a Git client.
Tuple Fields of FileContentSizeLimitExceededException
FileDoesNotExistException(FileDoesNotExistException)The specified file does not exist. Verify that you have used the correct file name, full path, and extension.
Tuple Fields of FileDoesNotExistException
FileEntryRequiredException(FileEntryRequiredException)The commit cannot be created because no files have been specified as added, updated, or changed (PutFile or DeleteFile) for the commit.
Tuple Fields of FileEntryRequiredException
FileModeRequiredException(FileModeRequiredException)The commit cannot be created because no file mode has been specified. A file mode is required to update mode permissions for a file.
Tuple Fields of FileModeRequiredException
FileNameConflictsWithDirectoryNameException(FileNameConflictsWithDirectoryNameException)A file cannot be added to the repository because the specified file name has the same name as a directory in this repository. Either provide another name for the file, or add the file in a directory that does not match the file name.
Tuple Fields of FileNameConflictsWithDirectoryNameException
FilePathConflictsWithSubmodulePathException(FilePathConflictsWithSubmodulePathException)The commit cannot be created because a specified file path points to a submodule. Verify that the destination files have valid file paths that do not point to a submodule.
Tuple Fields of FilePathConflictsWithSubmodulePathException
FileTooLargeException(FileTooLargeException)The specified file exceeds the file size limit for AWS CodeCommit. For more information about limits in AWS CodeCommit, see AWS CodeCommit User Guide.
Tuple Fields of FileTooLargeException
FolderContentSizeLimitExceededException(FolderContentSizeLimitExceededException)The commit cannot be created because at least one of the overall changes in the commit results in a folder whose contents exceed the limit of 6 MB. Either reduce the number and size of your changes, or split the changes across multiple folders.
Tuple Fields of FolderContentSizeLimitExceededException
FolderDoesNotExistException(FolderDoesNotExistException)The specified folder does not exist. Either the folder name is not correct, or you did not enter the full path to the folder.
Tuple Fields of FolderDoesNotExistException
IdempotencyParameterMismatchException(IdempotencyParameterMismatchException)The client request token is not valid. Either the token is not in a valid format, or the token has been used in a previous request and cannot be reused.
Tuple Fields of IdempotencyParameterMismatchException
InvalidActorArnException(InvalidActorArnException)The Amazon Resource Name (ARN) is not valid. Make sure that you have provided the full ARN for the user who initiated the change for the pull request, and then try again.
Tuple Fields of InvalidActorArnException
InvalidApprovalRuleContentException(InvalidApprovalRuleContentException)The content for the approval rule is not valid.
Tuple Fields of InvalidApprovalRuleContentException
InvalidApprovalRuleNameException(InvalidApprovalRuleNameException)The name for the approval rule is not valid.
Tuple Fields of InvalidApprovalRuleNameException
InvalidApprovalRuleTemplateContentException(InvalidApprovalRuleTemplateContentException)The content of the approval rule template is not valid.
Tuple Fields of InvalidApprovalRuleTemplateContentException
InvalidApprovalRuleTemplateDescriptionException(InvalidApprovalRuleTemplateDescriptionException)The description for the approval rule template is not valid because it exceeds the maximum characters allowed for a description. For more information about limits in AWS CodeCommit, see AWS CodeCommit User Guide.
Tuple Fields of InvalidApprovalRuleTemplateDescriptionException
InvalidApprovalRuleTemplateNameException(InvalidApprovalRuleTemplateNameException)The name of the approval rule template is not valid. Template names must be between 1 and 100 valid characters in length. For more information about limits in AWS CodeCommit, see AWS CodeCommit User Guide.
Tuple Fields of InvalidApprovalRuleTemplateNameException
InvalidApprovalStateException(InvalidApprovalStateException)The state for the approval is not valid. Valid values include APPROVE and REVOKE.
Tuple Fields of InvalidApprovalStateException
InvalidAuthorArnException(InvalidAuthorArnException)The Amazon Resource Name (ARN) is not valid. Make sure that you have provided the full ARN for the author of the pull request, and then try again.
Tuple Fields of InvalidAuthorArnException
InvalidBlobIdException(InvalidBlobIdException)The specified blob is not valid.
Tuple Fields of InvalidBlobIdException
InvalidBranchNameException(InvalidBranchNameException)The specified reference name is not valid.
Tuple Fields of InvalidBranchNameException
InvalidClientRequestTokenException(InvalidClientRequestTokenException)The client request token is not valid.
Tuple Fields of InvalidClientRequestTokenException
InvalidCommentIdException(InvalidCommentIdException)The comment ID is not in a valid format. Make sure that you have provided the full comment ID.
Tuple Fields of InvalidCommentIdException
InvalidCommitException(InvalidCommitException)The specified commit is not valid.
Tuple Fields of InvalidCommitException
InvalidCommitIdException(InvalidCommitIdException)The specified commit ID is not valid.
Tuple Fields of InvalidCommitIdException
InvalidConflictDetailLevelException(InvalidConflictDetailLevelException)The specified conflict detail level is not valid.
Tuple Fields of InvalidConflictDetailLevelException
InvalidConflictResolutionException(InvalidConflictResolutionException)The specified conflict resolution list is not valid.
Tuple Fields of InvalidConflictResolutionException
InvalidConflictResolutionStrategyException(InvalidConflictResolutionStrategyException)The specified conflict resolution strategy is not valid.
Tuple Fields of InvalidConflictResolutionStrategyException
InvalidContinuationTokenException(InvalidContinuationTokenException)The specified continuation token is not valid.
Tuple Fields of InvalidContinuationTokenException
InvalidDeletionParameterException(InvalidDeletionParameterException)The specified deletion parameter is not valid.
Tuple Fields of InvalidDeletionParameterException
InvalidDescriptionException(InvalidDescriptionException)The pull request description is not valid. Descriptions cannot be more than 1,000 characters.
Tuple Fields of InvalidDescriptionException
InvalidDestinationCommitSpecifierException(InvalidDestinationCommitSpecifierException)The destination commit specifier is not valid. You must provide a valid branch name, tag, or full commit ID.
Tuple Fields of InvalidDestinationCommitSpecifierException
InvalidEmailException(InvalidEmailException)The specified email address either contains one or more characters that are not allowed, or it exceeds the maximum number of characters allowed for an email address.
Tuple Fields of InvalidEmailException
InvalidFileLocationException(InvalidFileLocationException)The location of the file is not valid. Make sure that you include the file name and extension.
Tuple Fields of InvalidFileLocationException
InvalidFileModeException(InvalidFileModeException)The specified file mode permission is not valid. For a list of valid file mode permissions, see PutFile.
Tuple Fields of InvalidFileModeException
InvalidFilePositionException(InvalidFilePositionException)The position is not valid. Make sure that the line number exists in the version of the file you want to comment on.
Tuple Fields of InvalidFilePositionException
InvalidMaxConflictFilesException(InvalidMaxConflictFilesException)The specified value for the number of conflict files to return is not valid.
Tuple Fields of InvalidMaxConflictFilesException
InvalidMaxMergeHunksException(InvalidMaxMergeHunksException)The specified value for the number of merge hunks to return is not valid.
Tuple Fields of InvalidMaxMergeHunksException
InvalidMaxResultsException(InvalidMaxResultsException)The specified number of maximum results is not valid.
Tuple Fields of InvalidMaxResultsException
InvalidMergeOptionException(InvalidMergeOptionException)The specified merge option is not valid for this operation. Not all merge strategies are supported for all operations.
Tuple Fields of InvalidMergeOptionException
InvalidOrderException(InvalidOrderException)The specified sort order is not valid.
Tuple Fields of InvalidOrderException
InvalidOverrideStatusException(InvalidOverrideStatusException)The override status is not valid. Valid statuses are OVERRIDE and REVOKE.
Tuple Fields of InvalidOverrideStatusException
InvalidParentCommitIdException(InvalidParentCommitIdException)The parent commit ID is not valid. The commit ID cannot be empty, and must match the head commit ID for the branch of the repository where you want to add or update a file.
Tuple Fields of InvalidParentCommitIdException
InvalidPathException(InvalidPathException)The specified path is not valid.
Tuple Fields of InvalidPathException
InvalidPullRequestEventTypeException(InvalidPullRequestEventTypeException)The pull request event type is not valid.
Tuple Fields of InvalidPullRequestEventTypeException
InvalidPullRequestIdException(InvalidPullRequestIdException)The pull request ID is not valid. Make sure that you have provided the full ID and that the pull request is in the specified repository, and then try again.
Tuple Fields of InvalidPullRequestIdException
InvalidPullRequestStatusException(InvalidPullRequestStatusException)The pull request status is not valid. The only valid values are OPEN and CLOSED.
Tuple Fields of InvalidPullRequestStatusException
InvalidPullRequestStatusUpdateException(InvalidPullRequestStatusUpdateException)The pull request status update is not valid. The only valid update is from OPEN to CLOSED.
Tuple Fields of InvalidPullRequestStatusUpdateException
InvalidReactionUserArnException(InvalidReactionUserArnException)The Amazon Resource Name (ARN) of the user or identity is not valid.
Tuple Fields of InvalidReactionUserArnException
InvalidReactionValueException(InvalidReactionValueException)The value of the reaction is not valid. For more information, see the AWS CodeCommit User Guide.
Tuple Fields of InvalidReactionValueException
InvalidReferenceNameException(InvalidReferenceNameException)The specified reference name format is not valid. Reference names must conform to the Git references format (for example, refs/heads/master). For more information, see Git Internals - Git References or consult your Git documentation.
Tuple Fields of InvalidReferenceNameException
InvalidRelativeFileVersionEnumException(InvalidRelativeFileVersionEnumException)Either the enum is not in a valid format, or the specified file version enum is not valid in respect to the current file version.
Tuple Fields of InvalidRelativeFileVersionEnumException
InvalidReplacementContentException(InvalidReplacementContentException)Automerge was specified for resolving the conflict, but the replacement type is not valid or content is missing.
Tuple Fields of InvalidReplacementContentException
InvalidReplacementTypeException(InvalidReplacementTypeException)Automerge was specified for resolving the conflict, but the specified replacement type is not valid.
Tuple Fields of InvalidReplacementTypeException
InvalidRepositoryDescriptionException(InvalidRepositoryDescriptionException)The specified repository description is not valid.
Tuple Fields of InvalidRepositoryDescriptionException
InvalidRepositoryNameException(InvalidRepositoryNameException)A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
Tuple Fields of InvalidRepositoryNameException
InvalidRepositoryTriggerBranchNameException(InvalidRepositoryTriggerBranchNameException)One or more branch names specified for the trigger is not valid.
Tuple Fields of InvalidRepositoryTriggerBranchNameException
InvalidRepositoryTriggerCustomDataException(InvalidRepositoryTriggerCustomDataException)The custom data provided for the trigger is not valid.
Tuple Fields of InvalidRepositoryTriggerCustomDataException
InvalidRepositoryTriggerDestinationArnException(InvalidRepositoryTriggerDestinationArnException)The Amazon Resource Name (ARN) for the trigger is not valid for the specified destination. The most common reason for this error is that the ARN does not meet the requirements for the service type.
Tuple Fields of InvalidRepositoryTriggerDestinationArnException
InvalidRepositoryTriggerEventsException(InvalidRepositoryTriggerEventsException)One or more events specified for the trigger is not valid. Check to make sure that all events specified match the requirements for allowed events.
Tuple Fields of InvalidRepositoryTriggerEventsException
InvalidRepositoryTriggerNameException(InvalidRepositoryTriggerNameException)The name of the trigger is not valid.
Tuple Fields of InvalidRepositoryTriggerNameException
InvalidRepositoryTriggerRegionException(InvalidRepositoryTriggerRegionException)The AWS Region for the trigger target does not match the AWS Region for the repository. Triggers must be created in the same Region as the target for the trigger.
Tuple Fields of InvalidRepositoryTriggerRegionException
InvalidResourceArnException(InvalidResourceArnException)The value for the resource ARN is not valid. For more information about resources in AWS CodeCommit, see CodeCommit Resources and Operations in the AWS CodeCommit User Guide.
Tuple Fields of InvalidResourceArnException
InvalidRevisionIdException(InvalidRevisionIdException)The revision ID is not valid. Use GetPullRequest to determine the value.
Tuple Fields of InvalidRevisionIdException
InvalidRuleContentSha256Exception(InvalidRuleContentSha256Exception)The SHA-256 hash signature for the rule content is not valid.
Tuple Fields of InvalidRuleContentSha256Exception
InvalidSortByException(InvalidSortByException)The specified sort by value is not valid.
Tuple Fields of InvalidSortByException
InvalidSourceCommitSpecifierException(InvalidSourceCommitSpecifierException)The source commit specifier is not valid. You must provide a valid branch name, tag, or full commit ID.
Tuple Fields of InvalidSourceCommitSpecifierException
InvalidSystemTagUsageException(InvalidSystemTagUsageException)The specified tag is not valid. Key names cannot be prefixed with aws:.
Tuple Fields of InvalidSystemTagUsageException
InvalidTagKeysListException(InvalidTagKeysListException)The list of tags is not valid.
Tuple Fields of InvalidTagKeysListException
InvalidTagsMapException(InvalidTagsMapException)The map of tags is not valid.
Tuple Fields of InvalidTagsMapException
InvalidTargetBranchException(InvalidTargetBranchException)The specified target branch is not valid.
Tuple Fields of InvalidTargetBranchException
InvalidTargetException(InvalidTargetException)The target for the pull request is not valid. A target must contain the full values for the repository name, source branch, and destination branch for the pull request.
Tuple Fields of InvalidTargetException
InvalidTargetsException(InvalidTargetsException)The targets for the pull request is not valid or not in a valid format. Targets are a list of target objects. Each target object must contain the full values for the repository name, source branch, and destination branch for a pull request.
Tuple Fields of InvalidTargetsException
InvalidTitleException(InvalidTitleException)The title of the pull request is not valid. Pull request titles cannot exceed 100 characters in length.
Tuple Fields of InvalidTitleException
ManualMergeRequiredException(ManualMergeRequiredException)The pull request cannot be merged automatically into the destination branch. You must manually merge the branches and resolve any conflicts.
Tuple Fields of ManualMergeRequiredException
MaximumBranchesExceededException(MaximumBranchesExceededException)The number of branches for the trigger was exceeded.
Tuple Fields of MaximumBranchesExceededException
MaximumConflictResolutionEntriesExceededException(MaximumConflictResolutionEntriesExceededException)The number of allowed conflict resolution entries was exceeded.
Tuple Fields of MaximumConflictResolutionEntriesExceededException
MaximumFileContentToLoadExceededException(MaximumFileContentToLoadExceededException)The number of files to load exceeds the allowed limit.
Tuple Fields of MaximumFileContentToLoadExceededException
MaximumFileEntriesExceededException(MaximumFileEntriesExceededException)The number of specified files to change as part of this commit exceeds the maximum number of files that can be changed in a single commit. Consider using a Git client for these changes.
Tuple Fields of MaximumFileEntriesExceededException
MaximumItemsToCompareExceededException(MaximumItemsToCompareExceededException)The number of items to compare between the source or destination branches and the merge base has exceeded the maximum allowed.
Tuple Fields of MaximumItemsToCompareExceededException
MaximumNumberOfApprovalsExceededException(MaximumNumberOfApprovalsExceededException)The number of approvals required for the approval rule exceeds the maximum number allowed.
Tuple Fields of MaximumNumberOfApprovalsExceededException
MaximumOpenPullRequestsExceededException(MaximumOpenPullRequestsExceededException)You cannot create the pull request because the repository has too many open pull requests. The maximum number of open pull requests for a repository is 1,000. Close one or more open pull requests, and then try again.
Tuple Fields of MaximumOpenPullRequestsExceededException
MaximumRepositoryNamesExceededException(MaximumRepositoryNamesExceededException)The maximum number of allowed repository names was exceeded. Currently, this number is 100.
Tuple Fields of MaximumRepositoryNamesExceededException
MaximumRepositoryTriggersExceededException(MaximumRepositoryTriggersExceededException)The number of triggers allowed for the repository was exceeded.
Tuple Fields of MaximumRepositoryTriggersExceededException
MaximumRuleTemplatesAssociatedWithRepositoryException(MaximumRuleTemplatesAssociatedWithRepositoryException)The maximum number of approval rule templates for a repository has been exceeded. You cannot associate more than 25 approval rule templates with a repository.
Tuple Fields of MaximumRuleTemplatesAssociatedWithRepositoryException
MergeOptionRequiredException(MergeOptionRequiredException)A merge option or stategy is required, and none was provided.
Tuple Fields of MergeOptionRequiredException
MultipleConflictResolutionEntriesException(MultipleConflictResolutionEntriesException)More than one conflict resolution entries exists for the conflict. A conflict can have only one conflict resolution entry.
Tuple Fields of MultipleConflictResolutionEntriesException
MultipleRepositoriesInPullRequestException(MultipleRepositoriesInPullRequestException)You cannot include more than one repository in a pull request. Make sure you have specified only one repository name in your request, and then try again.
Tuple Fields of MultipleRepositoriesInPullRequestException
NameLengthExceededException(NameLengthExceededException)The user name is not valid because it has exceeded the character limit for author names.
Tuple Fields of NameLengthExceededException
NoChangeException(NoChangeException)The commit cannot be created because no changes will be made to the repository as a result of this commit. A commit must contain at least one change.
Tuple Fields of NoChangeException
NumberOfRuleTemplatesExceededException(NumberOfRuleTemplatesExceededException)The maximum number of approval rule templates has been exceeded for this AWS Region.
Tuple Fields of NumberOfRuleTemplatesExceededException
NumberOfRulesExceededException(NumberOfRulesExceededException)The approval rule cannot be added. The pull request has the maximum number of approval rules associated with it.
Tuple Fields of NumberOfRulesExceededException
OverrideAlreadySetException(OverrideAlreadySetException)The pull request has already had its approval rules set to override.
Tuple Fields of OverrideAlreadySetException
OverrideStatusRequiredException(OverrideStatusRequiredException)An override status is required, but no value was provided. Valid values include OVERRIDE and REVOKE.
Tuple Fields of OverrideStatusRequiredException
ParentCommitDoesNotExistException(ParentCommitDoesNotExistException)The parent commit ID is not valid because it does not exist. The specified parent commit ID does not exist in the specified branch of the repository.
Tuple Fields of ParentCommitDoesNotExistException
ParentCommitIdOutdatedException(ParentCommitIdOutdatedException)The file could not be added because the provided parent commit ID is not the current tip of the specified branch. To view the full commit ID of the current head of the branch, use GetBranch.
Tuple Fields of ParentCommitIdOutdatedException
ParentCommitIdRequiredException(ParentCommitIdRequiredException)A parent commit ID is required. To view the full commit ID of a branch in a repository, use GetBranch or a Git command (for example, git pull or git log).
Tuple Fields of ParentCommitIdRequiredException
PathDoesNotExistException(PathDoesNotExistException)The specified path does not exist.
Tuple Fields of PathDoesNotExistException
PathRequiredException(PathRequiredException)The folderPath for a location cannot be null.
Tuple Fields of PathRequiredException
PullRequestAlreadyClosedException(PullRequestAlreadyClosedException)The pull request status cannot be updated because it is already closed.
Tuple Fields of PullRequestAlreadyClosedException
PullRequestApprovalRulesNotSatisfiedException(PullRequestApprovalRulesNotSatisfiedException)The pull request cannot be merged because one or more approval rules applied to the pull request have conditions that have not been met.
Tuple Fields of PullRequestApprovalRulesNotSatisfiedException
PullRequestCannotBeApprovedByAuthorException(PullRequestCannotBeApprovedByAuthorException)The approval cannot be applied because the user approving the pull request matches the user who created the pull request. You cannot approve a pull request that you created.
Tuple Fields of PullRequestCannotBeApprovedByAuthorException
PullRequestDoesNotExistException(PullRequestDoesNotExistException)The pull request ID could not be found. Make sure that you have specified the correct repository name and pull request ID, and then try again.
Tuple Fields of PullRequestDoesNotExistException
PullRequestIdRequiredException(PullRequestIdRequiredException)A pull request ID is required, but none was provided.
Tuple Fields of PullRequestIdRequiredException
PullRequestStatusRequiredException(PullRequestStatusRequiredException)A pull request status is required, but none was provided.
Tuple Fields of PullRequestStatusRequiredException
PutFileEntryConflictException(PutFileEntryConflictException)The commit cannot be created because one or more files specified in the commit reference both a file and a folder.
Tuple Fields of PutFileEntryConflictException
ReactionLimitExceededException(ReactionLimitExceededException)The number of reactions has been exceeded. Reactions are limited to one reaction per user for each individual comment ID.
Tuple Fields of ReactionLimitExceededException
ReactionValueRequiredException(ReactionValueRequiredException)A reaction value is required.
Tuple Fields of ReactionValueRequiredException
ReferenceDoesNotExistException(ReferenceDoesNotExistException)The specified reference does not exist. You must provide a full commit ID.
Tuple Fields of ReferenceDoesNotExistException
ReferenceNameRequiredException(ReferenceNameRequiredException)A reference name is required, but none was provided.
Tuple Fields of ReferenceNameRequiredException
ReferenceTypeNotSupportedException(ReferenceTypeNotSupportedException)The specified reference is not a supported type.
Tuple Fields of ReferenceTypeNotSupportedException
ReplacementContentRequiredException(ReplacementContentRequiredException)USE_NEW_CONTENT was specified, but no replacement content has been provided.
Tuple Fields of ReplacementContentRequiredException
ReplacementTypeRequiredException(ReplacementTypeRequiredException)A replacement type is required.
Tuple Fields of ReplacementTypeRequiredException
RepositoryDoesNotExistException(RepositoryDoesNotExistException)The specified repository does not exist.
Tuple Fields of RepositoryDoesNotExistException
RepositoryLimitExceededException(RepositoryLimitExceededException)A repository resource limit was exceeded.
Tuple Fields of RepositoryLimitExceededException
RepositoryNameExistsException(RepositoryNameExistsException)The specified repository name already exists.
Tuple Fields of RepositoryNameExistsException
RepositoryNameRequiredException(RepositoryNameRequiredException)A repository name is required, but was not specified.
Tuple Fields of RepositoryNameRequiredException
RepositoryNamesRequiredException(RepositoryNamesRequiredException)At least one repository name object is required, but was not specified.
Tuple Fields of RepositoryNamesRequiredException
RepositoryNotAssociatedWithPullRequestException(RepositoryNotAssociatedWithPullRequestException)The repository does not contain any pull requests with that pull request ID. Use GetPullRequest to verify the correct repository name for the pull request ID.
Tuple Fields of RepositoryNotAssociatedWithPullRequestException
RepositoryTriggerBranchNameListRequiredException(RepositoryTriggerBranchNameListRequiredException)At least one branch name is required, but was not specified in the trigger configuration.
Tuple Fields of RepositoryTriggerBranchNameListRequiredException
RepositoryTriggerDestinationArnRequiredException(RepositoryTriggerDestinationArnRequiredException)A destination ARN for the target service for the trigger is required, but was not specified.
Tuple Fields of RepositoryTriggerDestinationArnRequiredException
RepositoryTriggerEventsListRequiredException(RepositoryTriggerEventsListRequiredException)At least one event for the trigger is required, but was not specified.
Tuple Fields of RepositoryTriggerEventsListRequiredException
RepositoryTriggerNameRequiredException(RepositoryTriggerNameRequiredException)A name for the trigger is required, but was not specified.
Tuple Fields of RepositoryTriggerNameRequiredException
RepositoryTriggersListRequiredException(RepositoryTriggersListRequiredException)The list of triggers for the repository is required, but was not specified.
Tuple Fields of RepositoryTriggersListRequiredException
ResourceArnRequiredException(ResourceArnRequiredException)A valid Amazon Resource Name (ARN) for an AWS CodeCommit resource is required. For a list of valid resources in AWS CodeCommit, see CodeCommit Resources and Operations in the AWS CodeCommit User Guide.
Tuple Fields of ResourceArnRequiredException
RestrictedSourceFileException(RestrictedSourceFileException)The commit cannot be created because one of the changes specifies copying or moving a .gitkeep file.
Tuple Fields of RestrictedSourceFileException
RevisionIdRequiredException(RevisionIdRequiredException)A revision ID is required, but was not provided.
Tuple Fields of RevisionIdRequiredException
RevisionNotCurrentException(RevisionNotCurrentException)The revision ID provided in the request does not match the current revision ID. Use GetPullRequest to retrieve the current revision ID.
Tuple Fields of RevisionNotCurrentException
SameFileContentException(SameFileContentException)The file was not added or updated because the content of the file is exactly the same as the content of that file in the repository and branch that you specified.
Tuple Fields of SameFileContentException
SamePathRequestException(SamePathRequestException)The commit cannot be created because one or more changes in this commit duplicate actions in the same file path. For example, you cannot make the same delete request to the same file in the same file path twice, or make a delete request and a move request to the same file as part of the same commit.
Tuple Fields of SamePathRequestException
SourceAndDestinationAreSameException(SourceAndDestinationAreSameException)The source branch and destination branch for the pull request are the same. You must specify different branches for the source and destination.
Tuple Fields of SourceAndDestinationAreSameException
SourceFileOrContentRequiredException(SourceFileOrContentRequiredException)The commit cannot be created because no source files or file content have been specified for the commit.
Tuple Fields of SourceFileOrContentRequiredException
TagKeysListRequiredException(TagKeysListRequiredException)A list of tag keys is required. The list cannot be empty or null.
Tuple Fields of TagKeysListRequiredException
TagPolicyException(TagPolicyException)The tag policy is not valid.
Tuple Fields of TagPolicyException
TagsMapRequiredException(TagsMapRequiredException)A map of tags is required.
Tuple Fields of TagsMapRequiredException
TargetRequiredException(TargetRequiredException)A pull request target is required. It cannot be empty or null. A pull request target must contain the full values for the repository name, source branch, and destination branch for the pull request.
Tuple Fields of TargetRequiredException
TargetsRequiredException(TargetsRequiredException)An array of target objects is required. It cannot be empty or null.
Tuple Fields of TargetsRequiredException
TipOfSourceReferenceIsDifferentException(TipOfSourceReferenceIsDifferentException)The tip of the source branch in the destination repository does not match the tip of the source branch specified in your request. The pull request might have been updated. Make sure that you have the latest changes.
Tuple Fields of TipOfSourceReferenceIsDifferentException
TipsDivergenceExceededException(TipsDivergenceExceededException)The divergence between the tips of the provided commit specifiers is too great to determine whether there might be
any merge conflicts. Locally compare the specifiers using git diff or a diff tool.
Tuple Fields of TipsDivergenceExceededException
TitleRequiredException(TitleRequiredException)A pull request title is required. It cannot be empty or null.
Tuple Fields of TitleRequiredException
TooManyTagsException(TooManyTagsException)The maximum number of tags for an AWS CodeCommit resource has been exceeded.
Tuple Fields of TooManyTagsException
An unhandled error occurred.