Enum aws_sdk_codecommit::error::AssociateApprovalRuleTemplateWithRepositoryErrorKind[][src]

#[non_exhaustive]
pub enum AssociateApprovalRuleTemplateWithRepositoryErrorKind {
Show 13 variants ApprovalRuleTemplateDoesNotExistException(ApprovalRuleTemplateDoesNotExistException), ApprovalRuleTemplateNameRequiredException(ApprovalRuleTemplateNameRequiredException), EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException), EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException), EncryptionKeyDisabledException(EncryptionKeyDisabledException), EncryptionKeyNotFoundException(EncryptionKeyNotFoundException), EncryptionKeyUnavailableException(EncryptionKeyUnavailableException), InvalidApprovalRuleTemplateNameException(InvalidApprovalRuleTemplateNameException), InvalidRepositoryNameException(InvalidRepositoryNameException), MaximumRuleTemplatesAssociatedWithRepositoryException(MaximumRuleTemplatesAssociatedWithRepositoryException), RepositoryDoesNotExistException(RepositoryDoesNotExistException), RepositoryNameRequiredException(RepositoryNameRequiredException), Unhandled(Box<dyn Error + Send + Sync + 'static>),
}
Types of errors that can occur for the AssociateApprovalRuleTemplateWithRepository operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ApprovalRuleTemplateDoesNotExistException(ApprovalRuleTemplateDoesNotExistException)

The specified approval rule template does not exist. Verify that the name is correct and that you are signed in to the AWS Region where the template was created, and then try again.

Tuple Fields of ApprovalRuleTemplateDoesNotExistException

0: ApprovalRuleTemplateDoesNotExistException
ApprovalRuleTemplateNameRequiredException(ApprovalRuleTemplateNameRequiredException)

An approval rule template name is required, but was not specified.

Tuple Fields of ApprovalRuleTemplateNameRequiredException

0: ApprovalRuleTemplateNameRequiredException
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)

An encryption integrity check failed.

Tuple Fields of EncryptionIntegrityChecksFailedException

0: EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)

An encryption key could not be accessed.

Tuple Fields of EncryptionKeyAccessDeniedException

0: EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)

The encryption key is disabled.

Tuple Fields of EncryptionKeyDisabledException

0: EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)

No encryption key was found.

Tuple Fields of EncryptionKeyNotFoundException

0: EncryptionKeyNotFoundException
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)

The encryption key is not available.

Tuple Fields of EncryptionKeyUnavailableException

0: EncryptionKeyUnavailableException
InvalidApprovalRuleTemplateNameException(InvalidApprovalRuleTemplateNameException)

The name of the approval rule template is not valid. Template names must be between 1 and 100 valid characters in length. For more information about limits in AWS CodeCommit, see AWS CodeCommit User Guide.

Tuple Fields of InvalidApprovalRuleTemplateNameException

0: InvalidApprovalRuleTemplateNameException
InvalidRepositoryNameException(InvalidRepositoryNameException)

A specified repository name is not valid.

This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.

Tuple Fields of InvalidRepositoryNameException

0: InvalidRepositoryNameException
MaximumRuleTemplatesAssociatedWithRepositoryException(MaximumRuleTemplatesAssociatedWithRepositoryException)

The maximum number of approval rule templates for a repository has been exceeded. You cannot associate more than 25 approval rule templates with a repository.

Tuple Fields of MaximumRuleTemplatesAssociatedWithRepositoryException

0: MaximumRuleTemplatesAssociatedWithRepositoryException
RepositoryDoesNotExistException(RepositoryDoesNotExistException)

The specified repository does not exist.

Tuple Fields of RepositoryDoesNotExistException

0: RepositoryDoesNotExistException
RepositoryNameRequiredException(RepositoryNameRequiredException)

A repository name is required, but was not specified.

Tuple Fields of RepositoryNameRequiredException

0: RepositoryNameRequiredException
Unhandled(Box<dyn Error + Send + Sync + 'static>)

An unexpected error, e.g. invalid JSON returned by the service or an unknown error code

Tuple Fields of Unhandled

0: Box<dyn Error + Send + Sync + 'static>