Enum aws_sdk_codecommit::error::BatchDescribeMergeConflictsErrorKind [−][src]
#[non_exhaustive]
pub enum BatchDescribeMergeConflictsErrorKind {
Show 22 variants
CommitDoesNotExistException(CommitDoesNotExistException),
CommitRequiredException(CommitRequiredException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidCommitException(InvalidCommitException),
InvalidConflictDetailLevelException(InvalidConflictDetailLevelException),
InvalidConflictResolutionStrategyException(InvalidConflictResolutionStrategyException),
InvalidContinuationTokenException(InvalidContinuationTokenException),
InvalidMaxConflictFilesException(InvalidMaxConflictFilesException),
InvalidMaxMergeHunksException(InvalidMaxMergeHunksException),
InvalidMergeOptionException(InvalidMergeOptionException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
MaximumFileContentToLoadExceededException(MaximumFileContentToLoadExceededException),
MaximumItemsToCompareExceededException(MaximumItemsToCompareExceededException),
MergeOptionRequiredException(MergeOptionRequiredException),
RepositoryDoesNotExistException(RepositoryDoesNotExistException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
TipsDivergenceExceededException(TipsDivergenceExceededException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the BatchDescribeMergeConflicts operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
CommitDoesNotExistException(CommitDoesNotExistException)The specified commit does not exist or no commit was specified, and the specified repository has no default branch.
Tuple Fields of CommitDoesNotExistException
CommitRequiredException(CommitRequiredException)A commit was not specified.
Tuple Fields of CommitRequiredException
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)An encryption integrity check failed.
Tuple Fields of EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)An encryption key could not be accessed.
Tuple Fields of EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)The encryption key is disabled.
Tuple Fields of EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)No encryption key was found.
Tuple Fields of EncryptionKeyNotFoundException
The encryption key is not available.
InvalidCommitException(InvalidCommitException)The specified commit is not valid.
Tuple Fields of InvalidCommitException
InvalidConflictDetailLevelException(InvalidConflictDetailLevelException)The specified conflict detail level is not valid.
Tuple Fields of InvalidConflictDetailLevelException
InvalidConflictResolutionStrategyException(InvalidConflictResolutionStrategyException)The specified conflict resolution strategy is not valid.
Tuple Fields of InvalidConflictResolutionStrategyException
InvalidContinuationTokenException(InvalidContinuationTokenException)The specified continuation token is not valid.
Tuple Fields of InvalidContinuationTokenException
InvalidMaxConflictFilesException(InvalidMaxConflictFilesException)The specified value for the number of conflict files to return is not valid.
Tuple Fields of InvalidMaxConflictFilesException
InvalidMaxMergeHunksException(InvalidMaxMergeHunksException)The specified value for the number of merge hunks to return is not valid.
Tuple Fields of InvalidMaxMergeHunksException
InvalidMergeOptionException(InvalidMergeOptionException)The specified merge option is not valid for this operation. Not all merge strategies are supported for all operations.
Tuple Fields of InvalidMergeOptionException
InvalidRepositoryNameException(InvalidRepositoryNameException)A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
Tuple Fields of InvalidRepositoryNameException
MaximumFileContentToLoadExceededException(MaximumFileContentToLoadExceededException)The number of files to load exceeds the allowed limit.
Tuple Fields of MaximumFileContentToLoadExceededException
MaximumItemsToCompareExceededException(MaximumItemsToCompareExceededException)The number of items to compare between the source or destination branches and the merge base has exceeded the maximum allowed.
Tuple Fields of MaximumItemsToCompareExceededException
MergeOptionRequiredException(MergeOptionRequiredException)A merge option or stategy is required, and none was provided.
Tuple Fields of MergeOptionRequiredException
RepositoryDoesNotExistException(RepositoryDoesNotExistException)The specified repository does not exist.
Tuple Fields of RepositoryDoesNotExistException
RepositoryNameRequiredException(RepositoryNameRequiredException)A repository name is required, but was not specified.
Tuple Fields of RepositoryNameRequiredException
TipsDivergenceExceededException(TipsDivergenceExceededException)The divergence between the tips of the provided commit specifiers is too great to determine whether there might be
any merge conflicts. Locally compare the specifiers using git diff or a diff tool.
Tuple Fields of TipsDivergenceExceededException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code