Enum aws_sdk_codecommit::error::CreateApprovalRuleTemplateErrorKind [−][src]
#[non_exhaustive]
pub enum CreateApprovalRuleTemplateErrorKind {
ApprovalRuleTemplateContentRequiredException(ApprovalRuleTemplateContentRequiredException),
ApprovalRuleTemplateNameAlreadyExistsException(ApprovalRuleTemplateNameAlreadyExistsException),
ApprovalRuleTemplateNameRequiredException(ApprovalRuleTemplateNameRequiredException),
InvalidApprovalRuleTemplateContentException(InvalidApprovalRuleTemplateContentException),
InvalidApprovalRuleTemplateDescriptionException(InvalidApprovalRuleTemplateDescriptionException),
InvalidApprovalRuleTemplateNameException(InvalidApprovalRuleTemplateNameException),
NumberOfRuleTemplatesExceededException(NumberOfRuleTemplatesExceededException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the CreateApprovalRuleTemplate operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ApprovalRuleTemplateContentRequiredException(ApprovalRuleTemplateContentRequiredException)The content for the approval rule template is empty. You must provide some content for an approval rule template. The content cannot be null.
Tuple Fields of ApprovalRuleTemplateContentRequiredException
ApprovalRuleTemplateNameAlreadyExistsException(ApprovalRuleTemplateNameAlreadyExistsException)You cannot create an approval rule template with that name because a template with that name already exists in this AWS Region for your AWS account. Approval rule template names must be unique.
Tuple Fields of ApprovalRuleTemplateNameAlreadyExistsException
ApprovalRuleTemplateNameRequiredException(ApprovalRuleTemplateNameRequiredException)An approval rule template name is required, but was not specified.
Tuple Fields of ApprovalRuleTemplateNameRequiredException
InvalidApprovalRuleTemplateContentException(InvalidApprovalRuleTemplateContentException)The content of the approval rule template is not valid.
Tuple Fields of InvalidApprovalRuleTemplateContentException
InvalidApprovalRuleTemplateDescriptionException(InvalidApprovalRuleTemplateDescriptionException)The description for the approval rule template is not valid because it exceeds the maximum characters allowed for a description. For more information about limits in AWS CodeCommit, see AWS CodeCommit User Guide.
Tuple Fields of InvalidApprovalRuleTemplateDescriptionException
InvalidApprovalRuleTemplateNameException(InvalidApprovalRuleTemplateNameException)The name of the approval rule template is not valid. Template names must be between 1 and 100 valid characters in length. For more information about limits in AWS CodeCommit, see AWS CodeCommit User Guide.
Tuple Fields of InvalidApprovalRuleTemplateNameException
NumberOfRuleTemplatesExceededException(NumberOfRuleTemplatesExceededException)The maximum number of approval rule templates has been exceeded for this AWS Region.
Tuple Fields of NumberOfRuleTemplatesExceededException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code