Enum aws_sdk_codecommit::error::CreateCommitErrorKind[][src]

#[non_exhaustive]
pub enum CreateCommitErrorKind {
Show 39 variants BranchDoesNotExistException(BranchDoesNotExistException), BranchNameIsTagNameException(BranchNameIsTagNameException), BranchNameRequiredException(BranchNameRequiredException), CommitMessageLengthExceededException(CommitMessageLengthExceededException), DirectoryNameConflictsWithFileNameException(DirectoryNameConflictsWithFileNameException), EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException), EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException), EncryptionKeyDisabledException(EncryptionKeyDisabledException), EncryptionKeyNotFoundException(EncryptionKeyNotFoundException), EncryptionKeyUnavailableException(EncryptionKeyUnavailableException), FileContentAndSourceFileSpecifiedException(FileContentAndSourceFileSpecifiedException), FileContentSizeLimitExceededException(FileContentSizeLimitExceededException), FileDoesNotExistException(FileDoesNotExistException), FileEntryRequiredException(FileEntryRequiredException), FileModeRequiredException(FileModeRequiredException), FileNameConflictsWithDirectoryNameException(FileNameConflictsWithDirectoryNameException), FilePathConflictsWithSubmodulePathException(FilePathConflictsWithSubmodulePathException), FolderContentSizeLimitExceededException(FolderContentSizeLimitExceededException), InvalidBranchNameException(InvalidBranchNameException), InvalidDeletionParameterException(InvalidDeletionParameterException), InvalidEmailException(InvalidEmailException), InvalidFileModeException(InvalidFileModeException), InvalidParentCommitIdException(InvalidParentCommitIdException), InvalidPathException(InvalidPathException), InvalidRepositoryNameException(InvalidRepositoryNameException), MaximumFileEntriesExceededException(MaximumFileEntriesExceededException), NameLengthExceededException(NameLengthExceededException), NoChangeException(NoChangeException), ParentCommitDoesNotExistException(ParentCommitDoesNotExistException), ParentCommitIdOutdatedException(ParentCommitIdOutdatedException), ParentCommitIdRequiredException(ParentCommitIdRequiredException), PathRequiredException(PathRequiredException), PutFileEntryConflictException(PutFileEntryConflictException), RepositoryDoesNotExistException(RepositoryDoesNotExistException), RepositoryNameRequiredException(RepositoryNameRequiredException), RestrictedSourceFileException(RestrictedSourceFileException), SamePathRequestException(SamePathRequestException), SourceFileOrContentRequiredException(SourceFileOrContentRequiredException), Unhandled(Box<dyn Error + Send + Sync + 'static>),
}
Types of errors that can occur for the CreateCommit operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BranchDoesNotExistException(BranchDoesNotExistException)

The specified branch does not exist.

Tuple Fields of BranchDoesNotExistException

0: BranchDoesNotExistException
BranchNameIsTagNameException(BranchNameIsTagNameException)

The specified branch name is not valid because it is a tag name. Enter the name of a branch in the repository. For a list of valid branch names, use ListBranches.

Tuple Fields of BranchNameIsTagNameException

0: BranchNameIsTagNameException
BranchNameRequiredException(BranchNameRequiredException)

A branch name is required, but was not specified.

Tuple Fields of BranchNameRequiredException

0: BranchNameRequiredException
CommitMessageLengthExceededException(CommitMessageLengthExceededException)

The commit message is too long. Provide a shorter string.

Tuple Fields of CommitMessageLengthExceededException

0: CommitMessageLengthExceededException
DirectoryNameConflictsWithFileNameException(DirectoryNameConflictsWithFileNameException)

A file cannot be added to the repository because the specified path name has the same name as a file that already exists in this repository. Either provide a different name for the file, or specify a different path for the file.

Tuple Fields of DirectoryNameConflictsWithFileNameException

0: DirectoryNameConflictsWithFileNameException
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)

An encryption integrity check failed.

Tuple Fields of EncryptionIntegrityChecksFailedException

0: EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)

An encryption key could not be accessed.

Tuple Fields of EncryptionKeyAccessDeniedException

0: EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)

The encryption key is disabled.

Tuple Fields of EncryptionKeyDisabledException

0: EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)

No encryption key was found.

Tuple Fields of EncryptionKeyNotFoundException

0: EncryptionKeyNotFoundException
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)

The encryption key is not available.

Tuple Fields of EncryptionKeyUnavailableException

0: EncryptionKeyUnavailableException
FileContentAndSourceFileSpecifiedException(FileContentAndSourceFileSpecifiedException)

The commit cannot be created because both a source file and file content have been specified for the same file. You cannot provide both. Either specify a source file or provide the file content directly.

Tuple Fields of FileContentAndSourceFileSpecifiedException

0: FileContentAndSourceFileSpecifiedException
FileContentSizeLimitExceededException(FileContentSizeLimitExceededException)

The file cannot be added because it is too large. The maximum file size is 6 MB, and the combined file content change size is 7 MB. Consider making these changes using a Git client.

Tuple Fields of FileContentSizeLimitExceededException

0: FileContentSizeLimitExceededException
FileDoesNotExistException(FileDoesNotExistException)

The specified file does not exist. Verify that you have used the correct file name, full path, and extension.

Tuple Fields of FileDoesNotExistException

0: FileDoesNotExistException
FileEntryRequiredException(FileEntryRequiredException)

The commit cannot be created because no files have been specified as added, updated, or changed (PutFile or DeleteFile) for the commit.

Tuple Fields of FileEntryRequiredException

0: FileEntryRequiredException
FileModeRequiredException(FileModeRequiredException)

The commit cannot be created because no file mode has been specified. A file mode is required to update mode permissions for a file.

Tuple Fields of FileModeRequiredException

0: FileModeRequiredException
FileNameConflictsWithDirectoryNameException(FileNameConflictsWithDirectoryNameException)

A file cannot be added to the repository because the specified file name has the same name as a directory in this repository. Either provide another name for the file, or add the file in a directory that does not match the file name.

Tuple Fields of FileNameConflictsWithDirectoryNameException

0: FileNameConflictsWithDirectoryNameException
FilePathConflictsWithSubmodulePathException(FilePathConflictsWithSubmodulePathException)

The commit cannot be created because a specified file path points to a submodule. Verify that the destination files have valid file paths that do not point to a submodule.

Tuple Fields of FilePathConflictsWithSubmodulePathException

0: FilePathConflictsWithSubmodulePathException
FolderContentSizeLimitExceededException(FolderContentSizeLimitExceededException)

The commit cannot be created because at least one of the overall changes in the commit results in a folder whose contents exceed the limit of 6 MB. Either reduce the number and size of your changes, or split the changes across multiple folders.

Tuple Fields of FolderContentSizeLimitExceededException

0: FolderContentSizeLimitExceededException
InvalidBranchNameException(InvalidBranchNameException)

The specified reference name is not valid.

Tuple Fields of InvalidBranchNameException

0: InvalidBranchNameException
InvalidDeletionParameterException(InvalidDeletionParameterException)

The specified deletion parameter is not valid.

Tuple Fields of InvalidDeletionParameterException

0: InvalidDeletionParameterException
InvalidEmailException(InvalidEmailException)

The specified email address either contains one or more characters that are not allowed, or it exceeds the maximum number of characters allowed for an email address.

Tuple Fields of InvalidEmailException

0: InvalidEmailException
InvalidFileModeException(InvalidFileModeException)

The specified file mode permission is not valid. For a list of valid file mode permissions, see PutFile.

Tuple Fields of InvalidFileModeException

0: InvalidFileModeException
InvalidParentCommitIdException(InvalidParentCommitIdException)

The parent commit ID is not valid. The commit ID cannot be empty, and must match the head commit ID for the branch of the repository where you want to add or update a file.

Tuple Fields of InvalidParentCommitIdException

0: InvalidParentCommitIdException
InvalidPathException(InvalidPathException)

The specified path is not valid.

Tuple Fields of InvalidPathException

0: InvalidPathException
InvalidRepositoryNameException(InvalidRepositoryNameException)

A specified repository name is not valid.

This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.

Tuple Fields of InvalidRepositoryNameException

0: InvalidRepositoryNameException
MaximumFileEntriesExceededException(MaximumFileEntriesExceededException)

The number of specified files to change as part of this commit exceeds the maximum number of files that can be changed in a single commit. Consider using a Git client for these changes.

Tuple Fields of MaximumFileEntriesExceededException

0: MaximumFileEntriesExceededException
NameLengthExceededException(NameLengthExceededException)

The user name is not valid because it has exceeded the character limit for author names.

Tuple Fields of NameLengthExceededException

0: NameLengthExceededException
NoChangeException(NoChangeException)

The commit cannot be created because no changes will be made to the repository as a result of this commit. A commit must contain at least one change.

Tuple Fields of NoChangeException

0: NoChangeException
ParentCommitDoesNotExistException(ParentCommitDoesNotExistException)

The parent commit ID is not valid because it does not exist. The specified parent commit ID does not exist in the specified branch of the repository.

Tuple Fields of ParentCommitDoesNotExistException

0: ParentCommitDoesNotExistException
ParentCommitIdOutdatedException(ParentCommitIdOutdatedException)

The file could not be added because the provided parent commit ID is not the current tip of the specified branch. To view the full commit ID of the current head of the branch, use GetBranch.

Tuple Fields of ParentCommitIdOutdatedException

0: ParentCommitIdOutdatedException
ParentCommitIdRequiredException(ParentCommitIdRequiredException)

A parent commit ID is required. To view the full commit ID of a branch in a repository, use GetBranch or a Git command (for example, git pull or git log).

Tuple Fields of ParentCommitIdRequiredException

0: ParentCommitIdRequiredException
PathRequiredException(PathRequiredException)

The folderPath for a location cannot be null.

Tuple Fields of PathRequiredException

0: PathRequiredException
PutFileEntryConflictException(PutFileEntryConflictException)

The commit cannot be created because one or more files specified in the commit reference both a file and a folder.

Tuple Fields of PutFileEntryConflictException

0: PutFileEntryConflictException
RepositoryDoesNotExistException(RepositoryDoesNotExistException)

The specified repository does not exist.

Tuple Fields of RepositoryDoesNotExistException

0: RepositoryDoesNotExistException
RepositoryNameRequiredException(RepositoryNameRequiredException)

A repository name is required, but was not specified.

Tuple Fields of RepositoryNameRequiredException

0: RepositoryNameRequiredException
RestrictedSourceFileException(RestrictedSourceFileException)

The commit cannot be created because one of the changes specifies copying or moving a .gitkeep file.

Tuple Fields of RestrictedSourceFileException

0: RestrictedSourceFileException
SamePathRequestException(SamePathRequestException)

The commit cannot be created because one or more changes in this commit duplicate actions in the same file path. For example, you cannot make the same delete request to the same file in the same file path twice, or make a delete request and a move request to the same file as part of the same commit.

Tuple Fields of SamePathRequestException

0: SamePathRequestException
SourceFileOrContentRequiredException(SourceFileOrContentRequiredException)

The commit cannot be created because no source files or file content have been specified for the commit.

Tuple Fields of SourceFileOrContentRequiredException

0: SourceFileOrContentRequiredException
Unhandled(Box<dyn Error + Send + Sync + 'static>)

An unexpected error, eg. invalid JSON returned by the service or an unknown error code

Tuple Fields of Unhandled

0: Box<dyn Error + Send + Sync + 'static>