Enum aws_sdk_codecommit::error::CreatePullRequestApprovalRuleErrorKind [−][src]
#[non_exhaustive]
pub enum CreatePullRequestApprovalRuleErrorKind {
Show 16 variants
ApprovalRuleContentRequiredException(ApprovalRuleContentRequiredException),
ApprovalRuleNameAlreadyExistsException(ApprovalRuleNameAlreadyExistsException),
ApprovalRuleNameRequiredException(ApprovalRuleNameRequiredException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidApprovalRuleContentException(InvalidApprovalRuleContentException),
InvalidApprovalRuleNameException(InvalidApprovalRuleNameException),
InvalidPullRequestIdException(InvalidPullRequestIdException),
NumberOfRulesExceededException(NumberOfRulesExceededException),
PullRequestAlreadyClosedException(PullRequestAlreadyClosedException),
PullRequestDoesNotExistException(PullRequestDoesNotExistException),
PullRequestIdRequiredException(PullRequestIdRequiredException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the CreatePullRequestApprovalRule operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ApprovalRuleContentRequiredException(ApprovalRuleContentRequiredException)
Tuple Fields
The content for the approval rule is empty. You must provide some content for an approval rule. The content cannot be null.
ApprovalRuleNameAlreadyExistsException(ApprovalRuleNameAlreadyExistsException)
Tuple Fields
An approval rule with that name already exists. Approval rule names must be unique within the scope of a pull request.
ApprovalRuleNameRequiredException(ApprovalRuleNameRequiredException)
Tuple Fields
An approval rule name is required, but was not specified.
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)
Tuple Fields
An encryption integrity check failed.
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)
Tuple Fields
An encryption key could not be accessed.
EncryptionKeyDisabledException(EncryptionKeyDisabledException)
Tuple Fields
The encryption key is disabled.
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)
Tuple Fields
No encryption key was found.
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)
The encryption key is not available.
InvalidApprovalRuleContentException(InvalidApprovalRuleContentException)
Tuple Fields
The content for the approval rule is not valid.
InvalidApprovalRuleNameException(InvalidApprovalRuleNameException)
Tuple Fields
The name for the approval rule is not valid.
InvalidPullRequestIdException(InvalidPullRequestIdException)
Tuple Fields
The pull request ID is not valid. Make sure that you have provided the full ID and that the pull request is in the specified repository, and then try again.
NumberOfRulesExceededException(NumberOfRulesExceededException)
Tuple Fields
The approval rule cannot be added. The pull request has the maximum number of approval rules associated with it.
PullRequestAlreadyClosedException(PullRequestAlreadyClosedException)
Tuple Fields
The pull request status cannot be updated because it is already closed.
PullRequestDoesNotExistException(PullRequestDoesNotExistException)
Tuple Fields
The pull request ID could not be found. Make sure that you have specified the correct repository name and pull request ID, and then try again.
PullRequestIdRequiredException(PullRequestIdRequiredException)
Tuple Fields
A pull request ID is required, but none was provided.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code