Enum aws_sdk_codecommit::error::CreatePullRequestErrorKind[][src]

#[non_exhaustive]
pub enum CreatePullRequestErrorKind {
Show 26 variants ClientRequestTokenRequiredException(ClientRequestTokenRequiredException), EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException), EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException), EncryptionKeyDisabledException(EncryptionKeyDisabledException), EncryptionKeyNotFoundException(EncryptionKeyNotFoundException), EncryptionKeyUnavailableException(EncryptionKeyUnavailableException), IdempotencyParameterMismatchException(IdempotencyParameterMismatchException), InvalidClientRequestTokenException(InvalidClientRequestTokenException), InvalidDescriptionException(InvalidDescriptionException), InvalidReferenceNameException(InvalidReferenceNameException), InvalidRepositoryNameException(InvalidRepositoryNameException), InvalidTargetException(InvalidTargetException), InvalidTargetsException(InvalidTargetsException), InvalidTitleException(InvalidTitleException), MaximumOpenPullRequestsExceededException(MaximumOpenPullRequestsExceededException), MultipleRepositoriesInPullRequestException(MultipleRepositoriesInPullRequestException), ReferenceDoesNotExistException(ReferenceDoesNotExistException), ReferenceNameRequiredException(ReferenceNameRequiredException), ReferenceTypeNotSupportedException(ReferenceTypeNotSupportedException), RepositoryDoesNotExistException(RepositoryDoesNotExistException), RepositoryNameRequiredException(RepositoryNameRequiredException), SourceAndDestinationAreSameException(SourceAndDestinationAreSameException), TargetRequiredException(TargetRequiredException), TargetsRequiredException(TargetsRequiredException), TitleRequiredException(TitleRequiredException), Unhandled(Box<dyn Error + Send + Sync + 'static>),
}
Types of errors that can occur for the CreatePullRequest operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ClientRequestTokenRequiredException(ClientRequestTokenRequiredException)

A client request token is required. A client request token is an unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.

Tuple Fields of ClientRequestTokenRequiredException

0: ClientRequestTokenRequiredException
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)

An encryption integrity check failed.

Tuple Fields of EncryptionIntegrityChecksFailedException

0: EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)

An encryption key could not be accessed.

Tuple Fields of EncryptionKeyAccessDeniedException

0: EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)

The encryption key is disabled.

Tuple Fields of EncryptionKeyDisabledException

0: EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)

No encryption key was found.

Tuple Fields of EncryptionKeyNotFoundException

0: EncryptionKeyNotFoundException
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)

The encryption key is not available.

Tuple Fields of EncryptionKeyUnavailableException

0: EncryptionKeyUnavailableException
IdempotencyParameterMismatchException(IdempotencyParameterMismatchException)

The client request token is not valid. Either the token is not in a valid format, or the token has been used in a previous request and cannot be reused.

Tuple Fields of IdempotencyParameterMismatchException

0: IdempotencyParameterMismatchException
InvalidClientRequestTokenException(InvalidClientRequestTokenException)

The client request token is not valid.

Tuple Fields of InvalidClientRequestTokenException

0: InvalidClientRequestTokenException
InvalidDescriptionException(InvalidDescriptionException)

The pull request description is not valid. Descriptions cannot be more than 1,000 characters.

Tuple Fields of InvalidDescriptionException

0: InvalidDescriptionException
InvalidReferenceNameException(InvalidReferenceNameException)

The specified reference name format is not valid. Reference names must conform to the Git references format (for example, refs/heads/master). For more information, see Git Internals - Git References or consult your Git documentation.

Tuple Fields of InvalidReferenceNameException

0: InvalidReferenceNameException
InvalidRepositoryNameException(InvalidRepositoryNameException)

A specified repository name is not valid.

This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.

Tuple Fields of InvalidRepositoryNameException

0: InvalidRepositoryNameException
InvalidTargetException(InvalidTargetException)

The target for the pull request is not valid. A target must contain the full values for the repository name, source branch, and destination branch for the pull request.

Tuple Fields of InvalidTargetException

0: InvalidTargetException
InvalidTargetsException(InvalidTargetsException)

The targets for the pull request is not valid or not in a valid format. Targets are a list of target objects. Each target object must contain the full values for the repository name, source branch, and destination branch for a pull request.

Tuple Fields of InvalidTargetsException

0: InvalidTargetsException
InvalidTitleException(InvalidTitleException)

The title of the pull request is not valid. Pull request titles cannot exceed 100 characters in length.

Tuple Fields of InvalidTitleException

0: InvalidTitleException
MaximumOpenPullRequestsExceededException(MaximumOpenPullRequestsExceededException)

You cannot create the pull request because the repository has too many open pull requests. The maximum number of open pull requests for a repository is 1,000. Close one or more open pull requests, and then try again.

Tuple Fields of MaximumOpenPullRequestsExceededException

0: MaximumOpenPullRequestsExceededException
MultipleRepositoriesInPullRequestException(MultipleRepositoriesInPullRequestException)

You cannot include more than one repository in a pull request. Make sure you have specified only one repository name in your request, and then try again.

Tuple Fields of MultipleRepositoriesInPullRequestException

0: MultipleRepositoriesInPullRequestException
ReferenceDoesNotExistException(ReferenceDoesNotExistException)

The specified reference does not exist. You must provide a full commit ID.

Tuple Fields of ReferenceDoesNotExistException

0: ReferenceDoesNotExistException
ReferenceNameRequiredException(ReferenceNameRequiredException)

A reference name is required, but none was provided.

Tuple Fields of ReferenceNameRequiredException

0: ReferenceNameRequiredException
ReferenceTypeNotSupportedException(ReferenceTypeNotSupportedException)

The specified reference is not a supported type.

Tuple Fields of ReferenceTypeNotSupportedException

0: ReferenceTypeNotSupportedException
RepositoryDoesNotExistException(RepositoryDoesNotExistException)

The specified repository does not exist.

Tuple Fields of RepositoryDoesNotExistException

0: RepositoryDoesNotExistException
RepositoryNameRequiredException(RepositoryNameRequiredException)

A repository name is required, but was not specified.

Tuple Fields of RepositoryNameRequiredException

0: RepositoryNameRequiredException
SourceAndDestinationAreSameException(SourceAndDestinationAreSameException)

The source branch and destination branch for the pull request are the same. You must specify different branches for the source and destination.

Tuple Fields of SourceAndDestinationAreSameException

0: SourceAndDestinationAreSameException
TargetRequiredException(TargetRequiredException)

A pull request target is required. It cannot be empty or null. A pull request target must contain the full values for the repository name, source branch, and destination branch for the pull request.

Tuple Fields of TargetRequiredException

0: TargetRequiredException
TargetsRequiredException(TargetsRequiredException)

An array of target objects is required. It cannot be empty or null.

Tuple Fields of TargetsRequiredException

0: TargetsRequiredException
TitleRequiredException(TitleRequiredException)

A pull request title is required. It cannot be empty or null.

Tuple Fields of TitleRequiredException

0: TitleRequiredException
Unhandled(Box<dyn Error + Send + Sync + 'static>)

An unexpected error, e.g. invalid JSON returned by the service or an unknown error code

Tuple Fields of Unhandled

0: Box<dyn Error + Send + Sync + 'static>