Enum aws_sdk_codecommit::error::CreateRepositoryErrorKind [−][src]
#[non_exhaustive]
pub enum CreateRepositoryErrorKind {
Show 15 variants
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidRepositoryDescriptionException(InvalidRepositoryDescriptionException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
InvalidSystemTagUsageException(InvalidSystemTagUsageException),
InvalidTagsMapException(InvalidTagsMapException),
RepositoryLimitExceededException(RepositoryLimitExceededException),
RepositoryNameExistsException(RepositoryNameExistsException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
TagPolicyException(TagPolicyException),
TooManyTagsException(TooManyTagsException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the CreateRepository operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)
Tuple Fields
An encryption integrity check failed.
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)
Tuple Fields
An encryption key could not be accessed.
EncryptionKeyDisabledException(EncryptionKeyDisabledException)
Tuple Fields
The encryption key is disabled.
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)
Tuple Fields
No encryption key was found.
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)
The encryption key is not available.
InvalidRepositoryDescriptionException(InvalidRepositoryDescriptionException)
Tuple Fields
The specified repository description is not valid.
InvalidRepositoryNameException(InvalidRepositoryNameException)
Tuple Fields
A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
InvalidSystemTagUsageException(InvalidSystemTagUsageException)
Tuple Fields
The specified tag is not valid. Key names cannot be prefixed with aws:.
InvalidTagsMapException(InvalidTagsMapException)
Tuple Fields
The map of tags is not valid.
RepositoryLimitExceededException(RepositoryLimitExceededException)
Tuple Fields
A repository resource limit was exceeded.
RepositoryNameExistsException(RepositoryNameExistsException)
Tuple Fields
The specified repository name already exists.
RepositoryNameRequiredException(RepositoryNameRequiredException)
Tuple Fields
A repository name is required, but was not specified.
TagPolicyException(TagPolicyException)
Tuple Fields
The tag policy is not valid.
TooManyTagsException(TooManyTagsException)
Tuple Fields
The maximum number of tags for an AWS CodeCommit resource has been exceeded.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code