#[non_exhaustive]
pub enum DeleteApprovalRuleTemplateErrorKind {
ApprovalRuleTemplateInUseException(ApprovalRuleTemplateInUseException),
ApprovalRuleTemplateNameRequiredException(ApprovalRuleTemplateNameRequiredException),
InvalidApprovalRuleTemplateNameException(InvalidApprovalRuleTemplateNameException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the DeleteApprovalRuleTemplate operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ApprovalRuleTemplateInUseException(ApprovalRuleTemplateInUseException)
The approval rule template is associated with one or more repositories. You cannot delete a template that is associated with a repository. Remove all associations, and then try again.
ApprovalRuleTemplateNameRequiredException(ApprovalRuleTemplateNameRequiredException)
An approval rule template name is required, but was not specified.
InvalidApprovalRuleTemplateNameException(InvalidApprovalRuleTemplateNameException)
The name of the approval rule template is not valid. Template names must be between 1 and 100 valid characters in length. For more information about limits in AWS CodeCommit, see AWS CodeCommit User Guide.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code