Enum aws_sdk_codecommit::error::DeleteBranchErrorKind [−][src]
#[non_exhaustive]
pub enum DeleteBranchErrorKind {
BranchNameRequiredException(BranchNameRequiredException),
DefaultBranchCannotBeDeletedException(DefaultBranchCannotBeDeletedException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidBranchNameException(InvalidBranchNameException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
RepositoryDoesNotExistException(RepositoryDoesNotExistException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the DeleteBranch operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BranchNameRequiredException(BranchNameRequiredException)
Tuple Fields
A branch name is required, but was not specified.
DefaultBranchCannotBeDeletedException(DefaultBranchCannotBeDeletedException)
Tuple Fields
The specified branch is the default branch for the repository, and cannot be deleted. To delete this branch, you must first set another branch as the default branch.
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)
Tuple Fields
An encryption integrity check failed.
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)
Tuple Fields
An encryption key could not be accessed.
EncryptionKeyDisabledException(EncryptionKeyDisabledException)
Tuple Fields
The encryption key is disabled.
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)
Tuple Fields
No encryption key was found.
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)
The encryption key is not available.
InvalidBranchNameException(InvalidBranchNameException)
Tuple Fields
The specified reference name is not valid.
InvalidRepositoryNameException(InvalidRepositoryNameException)
Tuple Fields
A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
RepositoryDoesNotExistException(RepositoryDoesNotExistException)
Tuple Fields
The specified repository does not exist.
RepositoryNameRequiredException(RepositoryNameRequiredException)
Tuple Fields
A repository name is required, but was not specified.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code