Enum aws_sdk_codecommit::error::DeleteFileErrorKind [−][src]
#[non_exhaustive]
pub enum DeleteFileErrorKind {
Show 23 variants
BranchDoesNotExistException(BranchDoesNotExistException),
BranchNameIsTagNameException(BranchNameIsTagNameException),
BranchNameRequiredException(BranchNameRequiredException),
CommitMessageLengthExceededException(CommitMessageLengthExceededException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
FileDoesNotExistException(FileDoesNotExistException),
InvalidBranchNameException(InvalidBranchNameException),
InvalidEmailException(InvalidEmailException),
InvalidParentCommitIdException(InvalidParentCommitIdException),
InvalidPathException(InvalidPathException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
NameLengthExceededException(NameLengthExceededException),
ParentCommitDoesNotExistException(ParentCommitDoesNotExistException),
ParentCommitIdOutdatedException(ParentCommitIdOutdatedException),
ParentCommitIdRequiredException(ParentCommitIdRequiredException),
PathRequiredException(PathRequiredException),
RepositoryDoesNotExistException(RepositoryDoesNotExistException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the DeleteFile operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BranchDoesNotExistException(BranchDoesNotExistException)
Tuple Fields
The specified branch does not exist.
BranchNameIsTagNameException(BranchNameIsTagNameException)
Tuple Fields
The specified branch name is not valid because it is a tag name. Enter the name of a branch in the repository. For a list of valid branch names, use ListBranches.
BranchNameRequiredException(BranchNameRequiredException)
Tuple Fields
A branch name is required, but was not specified.
CommitMessageLengthExceededException(CommitMessageLengthExceededException)
Tuple Fields
The commit message is too long. Provide a shorter string.
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)
Tuple Fields
An encryption integrity check failed.
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)
Tuple Fields
An encryption key could not be accessed.
EncryptionKeyDisabledException(EncryptionKeyDisabledException)
Tuple Fields
The encryption key is disabled.
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)
Tuple Fields
No encryption key was found.
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)
The encryption key is not available.
FileDoesNotExistException(FileDoesNotExistException)
Tuple Fields
The specified file does not exist. Verify that you have used the correct file name, full path, and extension.
InvalidBranchNameException(InvalidBranchNameException)
Tuple Fields
The specified reference name is not valid.
InvalidEmailException(InvalidEmailException)
Tuple Fields
The specified email address either contains one or more characters that are not allowed, or it exceeds the maximum number of characters allowed for an email address.
InvalidParentCommitIdException(InvalidParentCommitIdException)
Tuple Fields
The parent commit ID is not valid. The commit ID cannot be empty, and must match the head commit ID for the branch of the repository where you want to add or update a file.
InvalidPathException(InvalidPathException)
Tuple Fields
The specified path is not valid.
InvalidRepositoryNameException(InvalidRepositoryNameException)
Tuple Fields
A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
NameLengthExceededException(NameLengthExceededException)
Tuple Fields
The user name is not valid because it has exceeded the character limit for author names.
ParentCommitDoesNotExistException(ParentCommitDoesNotExistException)
Tuple Fields
The parent commit ID is not valid because it does not exist. The specified parent commit ID does not exist in the specified branch of the repository.
ParentCommitIdOutdatedException(ParentCommitIdOutdatedException)
Tuple Fields
The file could not be added because the provided parent commit ID is not the current tip of the specified branch. To view the full commit ID of the current head of the branch, use GetBranch.
ParentCommitIdRequiredException(ParentCommitIdRequiredException)
Tuple Fields
A parent commit ID is required. To view the full commit ID of a branch in a repository, use GetBranch or a Git command (for example, git pull or git log).
PathRequiredException(PathRequiredException)
Tuple Fields
The folderPath for a location cannot be null.
RepositoryDoesNotExistException(RepositoryDoesNotExistException)
Tuple Fields
The specified repository does not exist.
RepositoryNameRequiredException(RepositoryNameRequiredException)
Tuple Fields
A repository name is required, but was not specified.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code