Enum aws_sdk_codecommit::error::DeletePullRequestApprovalRuleErrorKind [−][src]
#[non_exhaustive]
pub enum DeletePullRequestApprovalRuleErrorKind {
Show 13 variants
ApprovalRuleNameRequiredException(ApprovalRuleNameRequiredException),
CannotDeleteApprovalRuleFromTemplateException(CannotDeleteApprovalRuleFromTemplateException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidApprovalRuleNameException(InvalidApprovalRuleNameException),
InvalidPullRequestIdException(InvalidPullRequestIdException),
PullRequestAlreadyClosedException(PullRequestAlreadyClosedException),
PullRequestDoesNotExistException(PullRequestDoesNotExistException),
PullRequestIdRequiredException(PullRequestIdRequiredException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the DeletePullRequestApprovalRule operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ApprovalRuleNameRequiredException(ApprovalRuleNameRequiredException)
Tuple Fields
An approval rule name is required, but was not specified.
CannotDeleteApprovalRuleFromTemplateException(CannotDeleteApprovalRuleFromTemplateException)
Tuple Fields
The approval rule cannot be deleted from the pull request because it was created by an approval rule template and applied to the pull request automatically.
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)
Tuple Fields
An encryption integrity check failed.
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)
Tuple Fields
An encryption key could not be accessed.
EncryptionKeyDisabledException(EncryptionKeyDisabledException)
Tuple Fields
The encryption key is disabled.
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)
Tuple Fields
No encryption key was found.
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)
The encryption key is not available.
InvalidApprovalRuleNameException(InvalidApprovalRuleNameException)
Tuple Fields
The name for the approval rule is not valid.
InvalidPullRequestIdException(InvalidPullRequestIdException)
Tuple Fields
The pull request ID is not valid. Make sure that you have provided the full ID and that the pull request is in the specified repository, and then try again.
PullRequestAlreadyClosedException(PullRequestAlreadyClosedException)
Tuple Fields
The pull request status cannot be updated because it is already closed.
PullRequestDoesNotExistException(PullRequestDoesNotExistException)
Tuple Fields
The pull request ID could not be found. Make sure that you have specified the correct repository name and pull request ID, and then try again.
PullRequestIdRequiredException(PullRequestIdRequiredException)
Tuple Fields
A pull request ID is required, but none was provided.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code