Enum aws_sdk_codecommit::error::DescribeMergeConflictsErrorKind [−][src]
#[non_exhaustive]
pub enum DescribeMergeConflictsErrorKind {
Show 24 variants
CommitDoesNotExistException(CommitDoesNotExistException),
CommitRequiredException(CommitRequiredException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
FileDoesNotExistException(FileDoesNotExistException),
InvalidCommitException(InvalidCommitException),
InvalidConflictDetailLevelException(InvalidConflictDetailLevelException),
InvalidConflictResolutionStrategyException(InvalidConflictResolutionStrategyException),
InvalidContinuationTokenException(InvalidContinuationTokenException),
InvalidMaxMergeHunksException(InvalidMaxMergeHunksException),
InvalidMergeOptionException(InvalidMergeOptionException),
InvalidPathException(InvalidPathException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
MaximumFileContentToLoadExceededException(MaximumFileContentToLoadExceededException),
MaximumItemsToCompareExceededException(MaximumItemsToCompareExceededException),
MergeOptionRequiredException(MergeOptionRequiredException),
PathRequiredException(PathRequiredException),
RepositoryDoesNotExistException(RepositoryDoesNotExistException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
TipsDivergenceExceededException(TipsDivergenceExceededException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the DescribeMergeConflicts operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
CommitDoesNotExistException(CommitDoesNotExistException)
Tuple Fields
The specified commit does not exist or no commit was specified, and the specified repository has no default branch.
CommitRequiredException(CommitRequiredException)
Tuple Fields
A commit was not specified.
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)
Tuple Fields
An encryption integrity check failed.
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)
Tuple Fields
An encryption key could not be accessed.
EncryptionKeyDisabledException(EncryptionKeyDisabledException)
Tuple Fields
The encryption key is disabled.
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)
Tuple Fields
No encryption key was found.
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)
The encryption key is not available.
FileDoesNotExistException(FileDoesNotExistException)
Tuple Fields
The specified file does not exist. Verify that you have used the correct file name, full path, and extension.
InvalidCommitException(InvalidCommitException)
Tuple Fields
The specified commit is not valid.
InvalidConflictDetailLevelException(InvalidConflictDetailLevelException)
Tuple Fields
The specified conflict detail level is not valid.
InvalidConflictResolutionStrategyException(InvalidConflictResolutionStrategyException)
Tuple Fields
The specified conflict resolution strategy is not valid.
InvalidContinuationTokenException(InvalidContinuationTokenException)
Tuple Fields
The specified continuation token is not valid.
InvalidMaxMergeHunksException(InvalidMaxMergeHunksException)
Tuple Fields
The specified value for the number of merge hunks to return is not valid.
InvalidMergeOptionException(InvalidMergeOptionException)
Tuple Fields
The specified merge option is not valid for this operation. Not all merge strategies are supported for all operations.
InvalidPathException(InvalidPathException)
Tuple Fields
The specified path is not valid.
InvalidRepositoryNameException(InvalidRepositoryNameException)
Tuple Fields
A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
MaximumFileContentToLoadExceededException(MaximumFileContentToLoadExceededException)
Tuple Fields
The number of files to load exceeds the allowed limit.
MaximumItemsToCompareExceededException(MaximumItemsToCompareExceededException)
Tuple Fields
The number of items to compare between the source or destination branches and the merge base has exceeded the maximum allowed.
MergeOptionRequiredException(MergeOptionRequiredException)
Tuple Fields
A merge option or stategy is required, and none was provided.
PathRequiredException(PathRequiredException)
Tuple Fields
The folderPath for a location cannot be null.
RepositoryDoesNotExistException(RepositoryDoesNotExistException)
Tuple Fields
The specified repository does not exist.
RepositoryNameRequiredException(RepositoryNameRequiredException)
Tuple Fields
A repository name is required, but was not specified.
TipsDivergenceExceededException(TipsDivergenceExceededException)
Tuple Fields
The divergence between the tips of the provided commit specifiers is too great to determine whether there might be
any merge conflicts. Locally compare the specifiers using git diff or a diff tool.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code