Enum aws_sdk_codecommit::error::DescribePullRequestEventsErrorKind [−][src]
#[non_exhaustive]
pub enum DescribePullRequestEventsErrorKind {
Show 14 variants
ActorDoesNotExistException(ActorDoesNotExistException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidActorArnException(InvalidActorArnException),
InvalidContinuationTokenException(InvalidContinuationTokenException),
InvalidMaxResultsException(InvalidMaxResultsException),
InvalidPullRequestEventTypeException(InvalidPullRequestEventTypeException),
InvalidPullRequestIdException(InvalidPullRequestIdException),
PullRequestDoesNotExistException(PullRequestDoesNotExistException),
PullRequestIdRequiredException(PullRequestIdRequiredException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the DescribePullRequestEvents operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ActorDoesNotExistException(ActorDoesNotExistException)
Tuple Fields
The specified Amazon Resource Name (ARN) does not exist in the AWS account.
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)
Tuple Fields
An encryption integrity check failed.
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)
Tuple Fields
An encryption key could not be accessed.
EncryptionKeyDisabledException(EncryptionKeyDisabledException)
Tuple Fields
The encryption key is disabled.
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)
Tuple Fields
No encryption key was found.
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)
The encryption key is not available.
InvalidActorArnException(InvalidActorArnException)
Tuple Fields
The Amazon Resource Name (ARN) is not valid. Make sure that you have provided the full ARN for the user who initiated the change for the pull request, and then try again.
InvalidContinuationTokenException(InvalidContinuationTokenException)
Tuple Fields
The specified continuation token is not valid.
InvalidMaxResultsException(InvalidMaxResultsException)
Tuple Fields
The specified number of maximum results is not valid.
InvalidPullRequestEventTypeException(InvalidPullRequestEventTypeException)
Tuple Fields
The pull request event type is not valid.
InvalidPullRequestIdException(InvalidPullRequestIdException)
Tuple Fields
The pull request ID is not valid. Make sure that you have provided the full ID and that the pull request is in the specified repository, and then try again.
PullRequestDoesNotExistException(PullRequestDoesNotExistException)
Tuple Fields
The pull request ID could not be found. Make sure that you have specified the correct repository name and pull request ID, and then try again.
PullRequestIdRequiredException(PullRequestIdRequiredException)
Tuple Fields
A pull request ID is required, but none was provided.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code