Enum aws_sdk_codecommit::error::EvaluatePullRequestApprovalRulesErrorKind [−][src]
#[non_exhaustive]
pub enum EvaluatePullRequestApprovalRulesErrorKind {
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidPullRequestIdException(InvalidPullRequestIdException),
InvalidRevisionIdException(InvalidRevisionIdException),
PullRequestDoesNotExistException(PullRequestDoesNotExistException),
PullRequestIdRequiredException(PullRequestIdRequiredException),
RevisionIdRequiredException(RevisionIdRequiredException),
RevisionNotCurrentException(RevisionNotCurrentException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the EvaluatePullRequestApprovalRules operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)
Tuple Fields
An encryption integrity check failed.
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)
Tuple Fields
An encryption key could not be accessed.
EncryptionKeyDisabledException(EncryptionKeyDisabledException)
Tuple Fields
The encryption key is disabled.
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)
Tuple Fields
No encryption key was found.
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)
The encryption key is not available.
InvalidPullRequestIdException(InvalidPullRequestIdException)
Tuple Fields
The pull request ID is not valid. Make sure that you have provided the full ID and that the pull request is in the specified repository, and then try again.
InvalidRevisionIdException(InvalidRevisionIdException)
Tuple Fields
The revision ID is not valid. Use GetPullRequest to determine the value.
PullRequestDoesNotExistException(PullRequestDoesNotExistException)
Tuple Fields
The pull request ID could not be found. Make sure that you have specified the correct repository name and pull request ID, and then try again.
PullRequestIdRequiredException(PullRequestIdRequiredException)
Tuple Fields
A pull request ID is required, but none was provided.
RevisionIdRequiredException(RevisionIdRequiredException)
Tuple Fields
A revision ID is required, but was not provided.
RevisionNotCurrentException(RevisionNotCurrentException)
Tuple Fields
The revision ID provided in the request does not match the current revision ID. Use GetPullRequest to retrieve the current revision ID.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code