Enum aws_sdk_codecommit::error::GetBlobErrorKind [−][src]
#[non_exhaustive]
pub enum GetBlobErrorKind {
Show 13 variants
BlobIdDoesNotExistException(BlobIdDoesNotExistException),
BlobIdRequiredException(BlobIdRequiredException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
FileTooLargeException(FileTooLargeException),
InvalidBlobIdException(InvalidBlobIdException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
RepositoryDoesNotExistException(RepositoryDoesNotExistException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the GetBlob operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BlobIdDoesNotExistException(BlobIdDoesNotExistException)The specified blob does not exist.
Tuple Fields of BlobIdDoesNotExistException
BlobIdRequiredException(BlobIdRequiredException)A blob ID is required, but was not specified.
Tuple Fields of BlobIdRequiredException
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)An encryption integrity check failed.
Tuple Fields of EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)An encryption key could not be accessed.
Tuple Fields of EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)The encryption key is disabled.
Tuple Fields of EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)No encryption key was found.
Tuple Fields of EncryptionKeyNotFoundException
The encryption key is not available.
FileTooLargeException(FileTooLargeException)The specified file exceeds the file size limit for AWS CodeCommit. For more information about limits in AWS CodeCommit, see AWS CodeCommit User Guide.
Tuple Fields of FileTooLargeException
InvalidBlobIdException(InvalidBlobIdException)The specified blob is not valid.
Tuple Fields of InvalidBlobIdException
InvalidRepositoryNameException(InvalidRepositoryNameException)A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
Tuple Fields of InvalidRepositoryNameException
RepositoryDoesNotExistException(RepositoryDoesNotExistException)The specified repository does not exist.
Tuple Fields of RepositoryDoesNotExistException
RepositoryNameRequiredException(RepositoryNameRequiredException)A repository name is required, but was not specified.
Tuple Fields of RepositoryNameRequiredException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code