Enum aws_sdk_codecommit::error::GetCommentErrorKind [−][src]
#[non_exhaustive]
pub enum GetCommentErrorKind {
CommentDeletedException(CommentDeletedException),
CommentDoesNotExistException(CommentDoesNotExistException),
CommentIdRequiredException(CommentIdRequiredException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidCommentIdException(InvalidCommentIdException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the GetComment operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
CommentDeletedException(CommentDeletedException)
Tuple Fields
This comment has already been deleted. You cannot edit or delete a deleted comment.
CommentDoesNotExistException(CommentDoesNotExistException)
Tuple Fields
No comment exists with the provided ID. Verify that you have used the correct ID, and then try again.
CommentIdRequiredException(CommentIdRequiredException)
Tuple Fields
The comment ID is missing or null. A comment ID is required.
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)
Tuple Fields
An encryption integrity check failed.
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)
Tuple Fields
An encryption key could not be accessed.
EncryptionKeyDisabledException(EncryptionKeyDisabledException)
Tuple Fields
The encryption key is disabled.
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)
Tuple Fields
No encryption key was found.
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)
The encryption key is not available.
InvalidCommentIdException(InvalidCommentIdException)
Tuple Fields
The comment ID is not in a valid format. Make sure that you have provided the full comment ID.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code