Enum aws_sdk_codecommit::error::GetCommentReactionsErrorKind [−][src]
#[non_exhaustive]
pub enum GetCommentReactionsErrorKind {
CommentDeletedException(CommentDeletedException),
CommentDoesNotExistException(CommentDoesNotExistException),
CommentIdRequiredException(CommentIdRequiredException),
InvalidCommentIdException(InvalidCommentIdException),
InvalidContinuationTokenException(InvalidContinuationTokenException),
InvalidMaxResultsException(InvalidMaxResultsException),
InvalidReactionUserArnException(InvalidReactionUserArnException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the GetCommentReactions operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
CommentDeletedException(CommentDeletedException)This comment has already been deleted. You cannot edit or delete a deleted comment.
Tuple Fields of CommentDeletedException
CommentDoesNotExistException(CommentDoesNotExistException)No comment exists with the provided ID. Verify that you have used the correct ID, and then try again.
Tuple Fields of CommentDoesNotExistException
CommentIdRequiredException(CommentIdRequiredException)The comment ID is missing or null. A comment ID is required.
Tuple Fields of CommentIdRequiredException
InvalidCommentIdException(InvalidCommentIdException)The comment ID is not in a valid format. Make sure that you have provided the full comment ID.
Tuple Fields of InvalidCommentIdException
InvalidContinuationTokenException(InvalidContinuationTokenException)The specified continuation token is not valid.
Tuple Fields of InvalidContinuationTokenException
InvalidMaxResultsException(InvalidMaxResultsException)The specified number of maximum results is not valid.
Tuple Fields of InvalidMaxResultsException
InvalidReactionUserArnException(InvalidReactionUserArnException)The Amazon Resource Name (ARN) of the user or identity is not valid.
Tuple Fields of InvalidReactionUserArnException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code