Enum aws_sdk_codecommit::error::GetDifferencesErrorKind [−][src]
#[non_exhaustive]
pub enum GetDifferencesErrorKind {
Show 17 variants
CommitDoesNotExistException(CommitDoesNotExistException),
CommitRequiredException(CommitRequiredException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidCommitException(InvalidCommitException),
InvalidCommitIdException(InvalidCommitIdException),
InvalidContinuationTokenException(InvalidContinuationTokenException),
InvalidMaxResultsException(InvalidMaxResultsException),
InvalidPathException(InvalidPathException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
PathDoesNotExistException(PathDoesNotExistException),
RepositoryDoesNotExistException(RepositoryDoesNotExistException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the GetDifferences operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
CommitDoesNotExistException(CommitDoesNotExistException)The specified commit does not exist or no commit was specified, and the specified repository has no default branch.
Tuple Fields of CommitDoesNotExistException
CommitRequiredException(CommitRequiredException)A commit was not specified.
Tuple Fields of CommitRequiredException
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)An encryption integrity check failed.
Tuple Fields of EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)An encryption key could not be accessed.
Tuple Fields of EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)The encryption key is disabled.
Tuple Fields of EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)No encryption key was found.
Tuple Fields of EncryptionKeyNotFoundException
The encryption key is not available.
InvalidCommitException(InvalidCommitException)The specified commit is not valid.
Tuple Fields of InvalidCommitException
InvalidCommitIdException(InvalidCommitIdException)The specified commit ID is not valid.
Tuple Fields of InvalidCommitIdException
InvalidContinuationTokenException(InvalidContinuationTokenException)The specified continuation token is not valid.
Tuple Fields of InvalidContinuationTokenException
InvalidMaxResultsException(InvalidMaxResultsException)The specified number of maximum results is not valid.
Tuple Fields of InvalidMaxResultsException
InvalidPathException(InvalidPathException)The specified path is not valid.
Tuple Fields of InvalidPathException
InvalidRepositoryNameException(InvalidRepositoryNameException)A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
Tuple Fields of InvalidRepositoryNameException
PathDoesNotExistException(PathDoesNotExistException)The specified path does not exist.
Tuple Fields of PathDoesNotExistException
RepositoryDoesNotExistException(RepositoryDoesNotExistException)The specified repository does not exist.
Tuple Fields of RepositoryDoesNotExistException
RepositoryNameRequiredException(RepositoryNameRequiredException)A repository name is required, but was not specified.
Tuple Fields of RepositoryNameRequiredException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code