Enum aws_sdk_codecommit::error::GetMergeConflictsErrorKind [−][src]
#[non_exhaustive]
pub enum GetMergeConflictsErrorKind {
Show 23 variants
CommitDoesNotExistException(CommitDoesNotExistException),
CommitRequiredException(CommitRequiredException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidCommitException(InvalidCommitException),
InvalidConflictDetailLevelException(InvalidConflictDetailLevelException),
InvalidConflictResolutionStrategyException(InvalidConflictResolutionStrategyException),
InvalidContinuationTokenException(InvalidContinuationTokenException),
InvalidDestinationCommitSpecifierException(InvalidDestinationCommitSpecifierException),
InvalidMaxConflictFilesException(InvalidMaxConflictFilesException),
InvalidMergeOptionException(InvalidMergeOptionException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
InvalidSourceCommitSpecifierException(InvalidSourceCommitSpecifierException),
MaximumFileContentToLoadExceededException(MaximumFileContentToLoadExceededException),
MaximumItemsToCompareExceededException(MaximumItemsToCompareExceededException),
MergeOptionRequiredException(MergeOptionRequiredException),
RepositoryDoesNotExistException(RepositoryDoesNotExistException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
TipsDivergenceExceededException(TipsDivergenceExceededException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the GetMergeConflicts operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
CommitDoesNotExistException(CommitDoesNotExistException)
Tuple Fields
The specified commit does not exist or no commit was specified, and the specified repository has no default branch.
CommitRequiredException(CommitRequiredException)
Tuple Fields
A commit was not specified.
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)
Tuple Fields
An encryption integrity check failed.
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)
Tuple Fields
An encryption key could not be accessed.
EncryptionKeyDisabledException(EncryptionKeyDisabledException)
Tuple Fields
The encryption key is disabled.
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)
Tuple Fields
No encryption key was found.
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)
The encryption key is not available.
InvalidCommitException(InvalidCommitException)
Tuple Fields
The specified commit is not valid.
InvalidConflictDetailLevelException(InvalidConflictDetailLevelException)
Tuple Fields
The specified conflict detail level is not valid.
InvalidConflictResolutionStrategyException(InvalidConflictResolutionStrategyException)
Tuple Fields
The specified conflict resolution strategy is not valid.
InvalidContinuationTokenException(InvalidContinuationTokenException)
Tuple Fields
The specified continuation token is not valid.
InvalidDestinationCommitSpecifierException(InvalidDestinationCommitSpecifierException)
Tuple Fields
The destination commit specifier is not valid. You must provide a valid branch name, tag, or full commit ID.
InvalidMaxConflictFilesException(InvalidMaxConflictFilesException)
Tuple Fields
The specified value for the number of conflict files to return is not valid.
InvalidMergeOptionException(InvalidMergeOptionException)
Tuple Fields
The specified merge option is not valid for this operation. Not all merge strategies are supported for all operations.
InvalidRepositoryNameException(InvalidRepositoryNameException)
Tuple Fields
A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
InvalidSourceCommitSpecifierException(InvalidSourceCommitSpecifierException)
Tuple Fields
The source commit specifier is not valid. You must provide a valid branch name, tag, or full commit ID.
MaximumFileContentToLoadExceededException(MaximumFileContentToLoadExceededException)
Tuple Fields
The number of files to load exceeds the allowed limit.
MaximumItemsToCompareExceededException(MaximumItemsToCompareExceededException)
Tuple Fields
The number of items to compare between the source or destination branches and the merge base has exceeded the maximum allowed.
MergeOptionRequiredException(MergeOptionRequiredException)
Tuple Fields
A merge option or stategy is required, and none was provided.
RepositoryDoesNotExistException(RepositoryDoesNotExistException)
Tuple Fields
The specified repository does not exist.
RepositoryNameRequiredException(RepositoryNameRequiredException)
Tuple Fields
A repository name is required, but was not specified.
TipsDivergenceExceededException(TipsDivergenceExceededException)
Tuple Fields
The divergence between the tips of the provided commit specifiers is too great to determine whether there might be
any merge conflicts. Locally compare the specifiers using git diff or a diff tool.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code