Enum aws_sdk_codecommit::error::GetMergeOptionsErrorKind[][src]

#[non_exhaustive]
pub enum GetMergeOptionsErrorKind {
Show 17 variants CommitDoesNotExistException(CommitDoesNotExistException), CommitRequiredException(CommitRequiredException), EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException), EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException), EncryptionKeyDisabledException(EncryptionKeyDisabledException), EncryptionKeyNotFoundException(EncryptionKeyNotFoundException), EncryptionKeyUnavailableException(EncryptionKeyUnavailableException), InvalidCommitException(InvalidCommitException), InvalidConflictDetailLevelException(InvalidConflictDetailLevelException), InvalidConflictResolutionStrategyException(InvalidConflictResolutionStrategyException), InvalidRepositoryNameException(InvalidRepositoryNameException), MaximumFileContentToLoadExceededException(MaximumFileContentToLoadExceededException), MaximumItemsToCompareExceededException(MaximumItemsToCompareExceededException), RepositoryDoesNotExistException(RepositoryDoesNotExistException), RepositoryNameRequiredException(RepositoryNameRequiredException), TipsDivergenceExceededException(TipsDivergenceExceededException), Unhandled(Box<dyn Error + Send + Sync + 'static>),
}
Types of errors that can occur for the GetMergeOptions operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CommitDoesNotExistException(CommitDoesNotExistException)

The specified commit does not exist or no commit was specified, and the specified repository has no default branch.

Tuple Fields of CommitDoesNotExistException

0: CommitDoesNotExistException
CommitRequiredException(CommitRequiredException)

A commit was not specified.

Tuple Fields of CommitRequiredException

0: CommitRequiredException
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)

An encryption integrity check failed.

Tuple Fields of EncryptionIntegrityChecksFailedException

0: EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)

An encryption key could not be accessed.

Tuple Fields of EncryptionKeyAccessDeniedException

0: EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)

The encryption key is disabled.

Tuple Fields of EncryptionKeyDisabledException

0: EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)

No encryption key was found.

Tuple Fields of EncryptionKeyNotFoundException

0: EncryptionKeyNotFoundException
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)

The encryption key is not available.

Tuple Fields of EncryptionKeyUnavailableException

0: EncryptionKeyUnavailableException
InvalidCommitException(InvalidCommitException)

The specified commit is not valid.

Tuple Fields of InvalidCommitException

0: InvalidCommitException
InvalidConflictDetailLevelException(InvalidConflictDetailLevelException)

The specified conflict detail level is not valid.

Tuple Fields of InvalidConflictDetailLevelException

0: InvalidConflictDetailLevelException
InvalidConflictResolutionStrategyException(InvalidConflictResolutionStrategyException)

The specified conflict resolution strategy is not valid.

Tuple Fields of InvalidConflictResolutionStrategyException

0: InvalidConflictResolutionStrategyException
InvalidRepositoryNameException(InvalidRepositoryNameException)

A specified repository name is not valid.

This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.

Tuple Fields of InvalidRepositoryNameException

0: InvalidRepositoryNameException
MaximumFileContentToLoadExceededException(MaximumFileContentToLoadExceededException)

The number of files to load exceeds the allowed limit.

Tuple Fields of MaximumFileContentToLoadExceededException

0: MaximumFileContentToLoadExceededException
MaximumItemsToCompareExceededException(MaximumItemsToCompareExceededException)

The number of items to compare between the source or destination branches and the merge base has exceeded the maximum allowed.

Tuple Fields of MaximumItemsToCompareExceededException

0: MaximumItemsToCompareExceededException
RepositoryDoesNotExistException(RepositoryDoesNotExistException)

The specified repository does not exist.

Tuple Fields of RepositoryDoesNotExistException

0: RepositoryDoesNotExistException
RepositoryNameRequiredException(RepositoryNameRequiredException)

A repository name is required, but was not specified.

Tuple Fields of RepositoryNameRequiredException

0: RepositoryNameRequiredException
TipsDivergenceExceededException(TipsDivergenceExceededException)

The divergence between the tips of the provided commit specifiers is too great to determine whether there might be any merge conflicts. Locally compare the specifiers using git diff or a diff tool.

Tuple Fields of TipsDivergenceExceededException

0: TipsDivergenceExceededException
Unhandled(Box<dyn Error + Send + Sync + 'static>)

An unexpected error, eg. invalid JSON returned by the service or an unknown error code

Tuple Fields of Unhandled

0: Box<dyn Error + Send + Sync + 'static>