Enum aws_sdk_codecommit::error::GetPullRequestErrorKind [−][src]
#[non_exhaustive]
pub enum GetPullRequestErrorKind {
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidPullRequestIdException(InvalidPullRequestIdException),
PullRequestDoesNotExistException(PullRequestDoesNotExistException),
PullRequestIdRequiredException(PullRequestIdRequiredException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the GetPullRequest operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)
Tuple Fields
An encryption integrity check failed.
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)
Tuple Fields
An encryption key could not be accessed.
EncryptionKeyDisabledException(EncryptionKeyDisabledException)
Tuple Fields
The encryption key is disabled.
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)
Tuple Fields
No encryption key was found.
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)
The encryption key is not available.
InvalidPullRequestIdException(InvalidPullRequestIdException)
Tuple Fields
The pull request ID is not valid. Make sure that you have provided the full ID and that the pull request is in the specified repository, and then try again.
PullRequestDoesNotExistException(PullRequestDoesNotExistException)
Tuple Fields
The pull request ID could not be found. Make sure that you have specified the correct repository name and pull request ID, and then try again.
PullRequestIdRequiredException(PullRequestIdRequiredException)
Tuple Fields
A pull request ID is required, but none was provided.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code