Enum aws_sdk_codecommit::error::GetPullRequestOverrideStateErrorKind [−][src]
#[non_exhaustive]
pub enum GetPullRequestOverrideStateErrorKind {
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidPullRequestIdException(InvalidPullRequestIdException),
InvalidRevisionIdException(InvalidRevisionIdException),
PullRequestDoesNotExistException(PullRequestDoesNotExistException),
PullRequestIdRequiredException(PullRequestIdRequiredException),
RevisionIdRequiredException(RevisionIdRequiredException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the GetPullRequestOverrideState operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)An encryption integrity check failed.
Tuple Fields of EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)An encryption key could not be accessed.
Tuple Fields of EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)The encryption key is disabled.
Tuple Fields of EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)No encryption key was found.
Tuple Fields of EncryptionKeyNotFoundException
The encryption key is not available.
InvalidPullRequestIdException(InvalidPullRequestIdException)The pull request ID is not valid. Make sure that you have provided the full ID and that the pull request is in the specified repository, and then try again.
Tuple Fields of InvalidPullRequestIdException
InvalidRevisionIdException(InvalidRevisionIdException)The revision ID is not valid. Use GetPullRequest to determine the value.
Tuple Fields of InvalidRevisionIdException
PullRequestDoesNotExistException(PullRequestDoesNotExistException)The pull request ID could not be found. Make sure that you have specified the correct repository name and pull request ID, and then try again.
Tuple Fields of PullRequestDoesNotExistException
PullRequestIdRequiredException(PullRequestIdRequiredException)A pull request ID is required, but none was provided.
Tuple Fields of PullRequestIdRequiredException
RevisionIdRequiredException(RevisionIdRequiredException)A revision ID is required, but was not provided.
Tuple Fields of RevisionIdRequiredException
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code