Enum aws_sdk_codecommit::error::ListRepositoriesErrorKind [−][src]
#[non_exhaustive]
pub enum ListRepositoriesErrorKind {
InvalidContinuationTokenException(InvalidContinuationTokenException),
InvalidOrderException(InvalidOrderException),
InvalidSortByException(InvalidSortByException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the ListRepositories operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidContinuationTokenException(InvalidContinuationTokenException)
Tuple Fields
The specified continuation token is not valid.
InvalidOrderException(InvalidOrderException)
Tuple Fields
The specified sort order is not valid.
InvalidSortByException(InvalidSortByException)
Tuple Fields
The specified sort by value is not valid.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code