Enum aws_sdk_codecommit::error::MergeBranchesByFastForwardErrorKind [−][src]
#[non_exhaustive]
pub enum MergeBranchesByFastForwardErrorKind {
Show 20 variants
BranchDoesNotExistException(BranchDoesNotExistException),
BranchNameIsTagNameException(BranchNameIsTagNameException),
BranchNameRequiredException(BranchNameRequiredException),
CommitDoesNotExistException(CommitDoesNotExistException),
CommitRequiredException(CommitRequiredException),
ConcurrentReferenceUpdateException(ConcurrentReferenceUpdateException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidBranchNameException(InvalidBranchNameException),
InvalidCommitException(InvalidCommitException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
InvalidTargetBranchException(InvalidTargetBranchException),
ManualMergeRequiredException(ManualMergeRequiredException),
RepositoryDoesNotExistException(RepositoryDoesNotExistException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
TipsDivergenceExceededException(TipsDivergenceExceededException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the MergeBranchesByFastForward operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BranchDoesNotExistException(BranchDoesNotExistException)
Tuple Fields
The specified branch does not exist.
BranchNameIsTagNameException(BranchNameIsTagNameException)
Tuple Fields
The specified branch name is not valid because it is a tag name. Enter the name of a branch in the repository. For a list of valid branch names, use ListBranches.
BranchNameRequiredException(BranchNameRequiredException)
Tuple Fields
A branch name is required, but was not specified.
CommitDoesNotExistException(CommitDoesNotExistException)
Tuple Fields
The specified commit does not exist or no commit was specified, and the specified repository has no default branch.
CommitRequiredException(CommitRequiredException)
Tuple Fields
A commit was not specified.
ConcurrentReferenceUpdateException(ConcurrentReferenceUpdateException)
Tuple Fields
The merge cannot be completed because the target branch has been modified. Another user might have modified the target branch while the merge was in progress. Wait a few minutes, and then try again.
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)
Tuple Fields
An encryption integrity check failed.
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)
Tuple Fields
An encryption key could not be accessed.
EncryptionKeyDisabledException(EncryptionKeyDisabledException)
Tuple Fields
The encryption key is disabled.
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)
Tuple Fields
No encryption key was found.
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)
The encryption key is not available.
InvalidBranchNameException(InvalidBranchNameException)
Tuple Fields
The specified reference name is not valid.
InvalidCommitException(InvalidCommitException)
Tuple Fields
The specified commit is not valid.
InvalidRepositoryNameException(InvalidRepositoryNameException)
Tuple Fields
A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
InvalidTargetBranchException(InvalidTargetBranchException)
Tuple Fields
The specified target branch is not valid.
ManualMergeRequiredException(ManualMergeRequiredException)
Tuple Fields
The pull request cannot be merged automatically into the destination branch. You must manually merge the branches and resolve any conflicts.
RepositoryDoesNotExistException(RepositoryDoesNotExistException)
Tuple Fields
The specified repository does not exist.
RepositoryNameRequiredException(RepositoryNameRequiredException)
Tuple Fields
A repository name is required, but was not specified.
TipsDivergenceExceededException(TipsDivergenceExceededException)
Tuple Fields
The divergence between the tips of the provided commit specifiers is too great to determine whether there might be
any merge conflicts. Locally compare the specifiers using git diff or a diff tool.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code