Enum aws_sdk_codecommit::error::MergeBranchesBySquashErrorKind[][src]

#[non_exhaustive]
pub enum MergeBranchesBySquashErrorKind {
Show 40 variants BranchDoesNotExistException(BranchDoesNotExistException), BranchNameIsTagNameException(BranchNameIsTagNameException), BranchNameRequiredException(BranchNameRequiredException), CommitDoesNotExistException(CommitDoesNotExistException), CommitMessageLengthExceededException(CommitMessageLengthExceededException), CommitRequiredException(CommitRequiredException), ConcurrentReferenceUpdateException(ConcurrentReferenceUpdateException), EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException), EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException), EncryptionKeyDisabledException(EncryptionKeyDisabledException), EncryptionKeyNotFoundException(EncryptionKeyNotFoundException), EncryptionKeyUnavailableException(EncryptionKeyUnavailableException), FileContentSizeLimitExceededException(FileContentSizeLimitExceededException), FileModeRequiredException(FileModeRequiredException), FolderContentSizeLimitExceededException(FolderContentSizeLimitExceededException), InvalidBranchNameException(InvalidBranchNameException), InvalidCommitException(InvalidCommitException), InvalidConflictDetailLevelException(InvalidConflictDetailLevelException), InvalidConflictResolutionException(InvalidConflictResolutionException), InvalidConflictResolutionStrategyException(InvalidConflictResolutionStrategyException), InvalidEmailException(InvalidEmailException), InvalidFileModeException(InvalidFileModeException), InvalidPathException(InvalidPathException), InvalidReplacementContentException(InvalidReplacementContentException), InvalidReplacementTypeException(InvalidReplacementTypeException), InvalidRepositoryNameException(InvalidRepositoryNameException), InvalidTargetBranchException(InvalidTargetBranchException), ManualMergeRequiredException(ManualMergeRequiredException), MaximumConflictResolutionEntriesExceededException(MaximumConflictResolutionEntriesExceededException), MaximumFileContentToLoadExceededException(MaximumFileContentToLoadExceededException), MaximumItemsToCompareExceededException(MaximumItemsToCompareExceededException), MultipleConflictResolutionEntriesException(MultipleConflictResolutionEntriesException), NameLengthExceededException(NameLengthExceededException), PathRequiredException(PathRequiredException), ReplacementContentRequiredException(ReplacementContentRequiredException), ReplacementTypeRequiredException(ReplacementTypeRequiredException), RepositoryDoesNotExistException(RepositoryDoesNotExistException), RepositoryNameRequiredException(RepositoryNameRequiredException), TipsDivergenceExceededException(TipsDivergenceExceededException), Unhandled(Box<dyn Error + Send + Sync + 'static>),
}
Types of errors that can occur for the MergeBranchesBySquash operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BranchDoesNotExistException(BranchDoesNotExistException)

The specified branch does not exist.

Tuple Fields of BranchDoesNotExistException

0: BranchDoesNotExistException
BranchNameIsTagNameException(BranchNameIsTagNameException)

The specified branch name is not valid because it is a tag name. Enter the name of a branch in the repository. For a list of valid branch names, use ListBranches.

Tuple Fields of BranchNameIsTagNameException

0: BranchNameIsTagNameException
BranchNameRequiredException(BranchNameRequiredException)

A branch name is required, but was not specified.

Tuple Fields of BranchNameRequiredException

0: BranchNameRequiredException
CommitDoesNotExistException(CommitDoesNotExistException)

The specified commit does not exist or no commit was specified, and the specified repository has no default branch.

Tuple Fields of CommitDoesNotExistException

0: CommitDoesNotExistException
CommitMessageLengthExceededException(CommitMessageLengthExceededException)

The commit message is too long. Provide a shorter string.

Tuple Fields of CommitMessageLengthExceededException

0: CommitMessageLengthExceededException
CommitRequiredException(CommitRequiredException)

A commit was not specified.

Tuple Fields of CommitRequiredException

0: CommitRequiredException
ConcurrentReferenceUpdateException(ConcurrentReferenceUpdateException)

The merge cannot be completed because the target branch has been modified. Another user might have modified the target branch while the merge was in progress. Wait a few minutes, and then try again.

Tuple Fields of ConcurrentReferenceUpdateException

0: ConcurrentReferenceUpdateException
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)

An encryption integrity check failed.

Tuple Fields of EncryptionIntegrityChecksFailedException

0: EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)

An encryption key could not be accessed.

Tuple Fields of EncryptionKeyAccessDeniedException

0: EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)

The encryption key is disabled.

Tuple Fields of EncryptionKeyDisabledException

0: EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)

No encryption key was found.

Tuple Fields of EncryptionKeyNotFoundException

0: EncryptionKeyNotFoundException
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)

The encryption key is not available.

Tuple Fields of EncryptionKeyUnavailableException

0: EncryptionKeyUnavailableException
FileContentSizeLimitExceededException(FileContentSizeLimitExceededException)

The file cannot be added because it is too large. The maximum file size is 6 MB, and the combined file content change size is 7 MB. Consider making these changes using a Git client.

Tuple Fields of FileContentSizeLimitExceededException

0: FileContentSizeLimitExceededException
FileModeRequiredException(FileModeRequiredException)

The commit cannot be created because no file mode has been specified. A file mode is required to update mode permissions for a file.

Tuple Fields of FileModeRequiredException

0: FileModeRequiredException
FolderContentSizeLimitExceededException(FolderContentSizeLimitExceededException)

The commit cannot be created because at least one of the overall changes in the commit results in a folder whose contents exceed the limit of 6 MB. Either reduce the number and size of your changes, or split the changes across multiple folders.

Tuple Fields of FolderContentSizeLimitExceededException

0: FolderContentSizeLimitExceededException
InvalidBranchNameException(InvalidBranchNameException)

The specified reference name is not valid.

Tuple Fields of InvalidBranchNameException

0: InvalidBranchNameException
InvalidCommitException(InvalidCommitException)

The specified commit is not valid.

Tuple Fields of InvalidCommitException

0: InvalidCommitException
InvalidConflictDetailLevelException(InvalidConflictDetailLevelException)

The specified conflict detail level is not valid.

Tuple Fields of InvalidConflictDetailLevelException

0: InvalidConflictDetailLevelException
InvalidConflictResolutionException(InvalidConflictResolutionException)

The specified conflict resolution list is not valid.

Tuple Fields of InvalidConflictResolutionException

0: InvalidConflictResolutionException
InvalidConflictResolutionStrategyException(InvalidConflictResolutionStrategyException)

The specified conflict resolution strategy is not valid.

Tuple Fields of InvalidConflictResolutionStrategyException

0: InvalidConflictResolutionStrategyException
InvalidEmailException(InvalidEmailException)

The specified email address either contains one or more characters that are not allowed, or it exceeds the maximum number of characters allowed for an email address.

Tuple Fields of InvalidEmailException

0: InvalidEmailException
InvalidFileModeException(InvalidFileModeException)

The specified file mode permission is not valid. For a list of valid file mode permissions, see PutFile.

Tuple Fields of InvalidFileModeException

0: InvalidFileModeException
InvalidPathException(InvalidPathException)

The specified path is not valid.

Tuple Fields of InvalidPathException

0: InvalidPathException
InvalidReplacementContentException(InvalidReplacementContentException)

Automerge was specified for resolving the conflict, but the replacement type is not valid or content is missing.

Tuple Fields of InvalidReplacementContentException

0: InvalidReplacementContentException
InvalidReplacementTypeException(InvalidReplacementTypeException)

Automerge was specified for resolving the conflict, but the specified replacement type is not valid.

Tuple Fields of InvalidReplacementTypeException

0: InvalidReplacementTypeException
InvalidRepositoryNameException(InvalidRepositoryNameException)

A specified repository name is not valid.

This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.

Tuple Fields of InvalidRepositoryNameException

0: InvalidRepositoryNameException
InvalidTargetBranchException(InvalidTargetBranchException)

The specified target branch is not valid.

Tuple Fields of InvalidTargetBranchException

0: InvalidTargetBranchException
ManualMergeRequiredException(ManualMergeRequiredException)

The pull request cannot be merged automatically into the destination branch. You must manually merge the branches and resolve any conflicts.

Tuple Fields of ManualMergeRequiredException

0: ManualMergeRequiredException
MaximumConflictResolutionEntriesExceededException(MaximumConflictResolutionEntriesExceededException)

The number of allowed conflict resolution entries was exceeded.

Tuple Fields of MaximumConflictResolutionEntriesExceededException

0: MaximumConflictResolutionEntriesExceededException
MaximumFileContentToLoadExceededException(MaximumFileContentToLoadExceededException)

The number of files to load exceeds the allowed limit.

Tuple Fields of MaximumFileContentToLoadExceededException

0: MaximumFileContentToLoadExceededException
MaximumItemsToCompareExceededException(MaximumItemsToCompareExceededException)

The number of items to compare between the source or destination branches and the merge base has exceeded the maximum allowed.

Tuple Fields of MaximumItemsToCompareExceededException

0: MaximumItemsToCompareExceededException
MultipleConflictResolutionEntriesException(MultipleConflictResolutionEntriesException)

More than one conflict resolution entries exists for the conflict. A conflict can have only one conflict resolution entry.

Tuple Fields of MultipleConflictResolutionEntriesException

0: MultipleConflictResolutionEntriesException
NameLengthExceededException(NameLengthExceededException)

The user name is not valid because it has exceeded the character limit for author names.

Tuple Fields of NameLengthExceededException

0: NameLengthExceededException
PathRequiredException(PathRequiredException)

The folderPath for a location cannot be null.

Tuple Fields of PathRequiredException

0: PathRequiredException
ReplacementContentRequiredException(ReplacementContentRequiredException)

USE_NEW_CONTENT was specified, but no replacement content has been provided.

Tuple Fields of ReplacementContentRequiredException

0: ReplacementContentRequiredException
ReplacementTypeRequiredException(ReplacementTypeRequiredException)

A replacement type is required.

Tuple Fields of ReplacementTypeRequiredException

0: ReplacementTypeRequiredException
RepositoryDoesNotExistException(RepositoryDoesNotExistException)

The specified repository does not exist.

Tuple Fields of RepositoryDoesNotExistException

0: RepositoryDoesNotExistException
RepositoryNameRequiredException(RepositoryNameRequiredException)

A repository name is required, but was not specified.

Tuple Fields of RepositoryNameRequiredException

0: RepositoryNameRequiredException
TipsDivergenceExceededException(TipsDivergenceExceededException)

The divergence between the tips of the provided commit specifiers is too great to determine whether there might be any merge conflicts. Locally compare the specifiers using git diff or a diff tool.

Tuple Fields of TipsDivergenceExceededException

0: TipsDivergenceExceededException
Unhandled(Box<dyn Error + Send + Sync + 'static>)

An unexpected error, eg. invalid JSON returned by the service or an unknown error code

Tuple Fields of Unhandled

0: Box<dyn Error + Send + Sync + 'static>