Enum aws_sdk_codecommit::error::MergeBranchesByThreeWayErrorKind [−][src]
#[non_exhaustive]
pub enum MergeBranchesByThreeWayErrorKind {
Show 40 variants
BranchDoesNotExistException(BranchDoesNotExistException),
BranchNameIsTagNameException(BranchNameIsTagNameException),
BranchNameRequiredException(BranchNameRequiredException),
CommitDoesNotExistException(CommitDoesNotExistException),
CommitMessageLengthExceededException(CommitMessageLengthExceededException),
CommitRequiredException(CommitRequiredException),
ConcurrentReferenceUpdateException(ConcurrentReferenceUpdateException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
FileContentSizeLimitExceededException(FileContentSizeLimitExceededException),
FileModeRequiredException(FileModeRequiredException),
FolderContentSizeLimitExceededException(FolderContentSizeLimitExceededException),
InvalidBranchNameException(InvalidBranchNameException),
InvalidCommitException(InvalidCommitException),
InvalidConflictDetailLevelException(InvalidConflictDetailLevelException),
InvalidConflictResolutionException(InvalidConflictResolutionException),
InvalidConflictResolutionStrategyException(InvalidConflictResolutionStrategyException),
InvalidEmailException(InvalidEmailException),
InvalidFileModeException(InvalidFileModeException),
InvalidPathException(InvalidPathException),
InvalidReplacementContentException(InvalidReplacementContentException),
InvalidReplacementTypeException(InvalidReplacementTypeException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
InvalidTargetBranchException(InvalidTargetBranchException),
ManualMergeRequiredException(ManualMergeRequiredException),
MaximumConflictResolutionEntriesExceededException(MaximumConflictResolutionEntriesExceededException),
MaximumFileContentToLoadExceededException(MaximumFileContentToLoadExceededException),
MaximumItemsToCompareExceededException(MaximumItemsToCompareExceededException),
MultipleConflictResolutionEntriesException(MultipleConflictResolutionEntriesException),
NameLengthExceededException(NameLengthExceededException),
PathRequiredException(PathRequiredException),
ReplacementContentRequiredException(ReplacementContentRequiredException),
ReplacementTypeRequiredException(ReplacementTypeRequiredException),
RepositoryDoesNotExistException(RepositoryDoesNotExistException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
TipsDivergenceExceededException(TipsDivergenceExceededException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the MergeBranchesByThreeWay operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BranchDoesNotExistException(BranchDoesNotExistException)
Tuple Fields
The specified branch does not exist.
BranchNameIsTagNameException(BranchNameIsTagNameException)
Tuple Fields
The specified branch name is not valid because it is a tag name. Enter the name of a branch in the repository. For a list of valid branch names, use ListBranches.
BranchNameRequiredException(BranchNameRequiredException)
Tuple Fields
A branch name is required, but was not specified.
CommitDoesNotExistException(CommitDoesNotExistException)
Tuple Fields
The specified commit does not exist or no commit was specified, and the specified repository has no default branch.
CommitMessageLengthExceededException(CommitMessageLengthExceededException)
Tuple Fields
The commit message is too long. Provide a shorter string.
CommitRequiredException(CommitRequiredException)
Tuple Fields
A commit was not specified.
ConcurrentReferenceUpdateException(ConcurrentReferenceUpdateException)
Tuple Fields
The merge cannot be completed because the target branch has been modified. Another user might have modified the target branch while the merge was in progress. Wait a few minutes, and then try again.
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)
Tuple Fields
An encryption integrity check failed.
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)
Tuple Fields
An encryption key could not be accessed.
EncryptionKeyDisabledException(EncryptionKeyDisabledException)
Tuple Fields
The encryption key is disabled.
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)
Tuple Fields
No encryption key was found.
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)
The encryption key is not available.
FileContentSizeLimitExceededException(FileContentSizeLimitExceededException)
Tuple Fields
The file cannot be added because it is too large. The maximum file size is 6 MB, and the combined file content change size is 7 MB. Consider making these changes using a Git client.
FileModeRequiredException(FileModeRequiredException)
Tuple Fields
The commit cannot be created because no file mode has been specified. A file mode is required to update mode permissions for a file.
FolderContentSizeLimitExceededException(FolderContentSizeLimitExceededException)
Tuple Fields
The commit cannot be created because at least one of the overall changes in the commit results in a folder whose contents exceed the limit of 6 MB. Either reduce the number and size of your changes, or split the changes across multiple folders.
InvalidBranchNameException(InvalidBranchNameException)
Tuple Fields
The specified reference name is not valid.
InvalidCommitException(InvalidCommitException)
Tuple Fields
The specified commit is not valid.
InvalidConflictDetailLevelException(InvalidConflictDetailLevelException)
Tuple Fields
The specified conflict detail level is not valid.
InvalidConflictResolutionException(InvalidConflictResolutionException)
Tuple Fields
The specified conflict resolution list is not valid.
InvalidConflictResolutionStrategyException(InvalidConflictResolutionStrategyException)
Tuple Fields
The specified conflict resolution strategy is not valid.
InvalidEmailException(InvalidEmailException)
Tuple Fields
The specified email address either contains one or more characters that are not allowed, or it exceeds the maximum number of characters allowed for an email address.
InvalidFileModeException(InvalidFileModeException)
Tuple Fields
The specified file mode permission is not valid. For a list of valid file mode permissions, see PutFile.
InvalidPathException(InvalidPathException)
Tuple Fields
The specified path is not valid.
InvalidReplacementContentException(InvalidReplacementContentException)
Tuple Fields
Automerge was specified for resolving the conflict, but the replacement type is not valid or content is missing.
InvalidReplacementTypeException(InvalidReplacementTypeException)
Tuple Fields
Automerge was specified for resolving the conflict, but the specified replacement type is not valid.
InvalidRepositoryNameException(InvalidRepositoryNameException)
Tuple Fields
A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
InvalidTargetBranchException(InvalidTargetBranchException)
Tuple Fields
The specified target branch is not valid.
ManualMergeRequiredException(ManualMergeRequiredException)
Tuple Fields
The pull request cannot be merged automatically into the destination branch. You must manually merge the branches and resolve any conflicts.
MaximumConflictResolutionEntriesExceededException(MaximumConflictResolutionEntriesExceededException)
Tuple Fields
The number of allowed conflict resolution entries was exceeded.
MaximumFileContentToLoadExceededException(MaximumFileContentToLoadExceededException)
Tuple Fields
The number of files to load exceeds the allowed limit.
MaximumItemsToCompareExceededException(MaximumItemsToCompareExceededException)
Tuple Fields
The number of items to compare between the source or destination branches and the merge base has exceeded the maximum allowed.
MultipleConflictResolutionEntriesException(MultipleConflictResolutionEntriesException)
Tuple Fields
More than one conflict resolution entries exists for the conflict. A conflict can have only one conflict resolution entry.
NameLengthExceededException(NameLengthExceededException)
Tuple Fields
The user name is not valid because it has exceeded the character limit for author names.
PathRequiredException(PathRequiredException)
Tuple Fields
The folderPath for a location cannot be null.
ReplacementContentRequiredException(ReplacementContentRequiredException)
Tuple Fields
USE_NEW_CONTENT was specified, but no replacement content has been provided.
ReplacementTypeRequiredException(ReplacementTypeRequiredException)
Tuple Fields
A replacement type is required.
RepositoryDoesNotExistException(RepositoryDoesNotExistException)
Tuple Fields
The specified repository does not exist.
RepositoryNameRequiredException(RepositoryNameRequiredException)
Tuple Fields
A repository name is required, but was not specified.
TipsDivergenceExceededException(TipsDivergenceExceededException)
Tuple Fields
The divergence between the tips of the provided commit specifiers is too great to determine whether there might be
any merge conflicts. Locally compare the specifiers using git diff or a diff tool.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code