Enum aws_sdk_codecommit::error::MergePullRequestByFastForwardErrorKind [−][src]
#[non_exhaustive]
pub enum MergePullRequestByFastForwardErrorKind {
Show 20 variants
ConcurrentReferenceUpdateException(ConcurrentReferenceUpdateException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidCommitIdException(InvalidCommitIdException),
InvalidPullRequestIdException(InvalidPullRequestIdException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
ManualMergeRequiredException(ManualMergeRequiredException),
PullRequestAlreadyClosedException(PullRequestAlreadyClosedException),
PullRequestApprovalRulesNotSatisfiedException(PullRequestApprovalRulesNotSatisfiedException),
PullRequestDoesNotExistException(PullRequestDoesNotExistException),
PullRequestIdRequiredException(PullRequestIdRequiredException),
ReferenceDoesNotExistException(ReferenceDoesNotExistException),
RepositoryDoesNotExistException(RepositoryDoesNotExistException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
RepositoryNotAssociatedWithPullRequestException(RepositoryNotAssociatedWithPullRequestException),
TipOfSourceReferenceIsDifferentException(TipOfSourceReferenceIsDifferentException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the MergePullRequestByFastForward operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ConcurrentReferenceUpdateException(ConcurrentReferenceUpdateException)
Tuple Fields
The merge cannot be completed because the target branch has been modified. Another user might have modified the target branch while the merge was in progress. Wait a few minutes, and then try again.
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)
Tuple Fields
An encryption integrity check failed.
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)
Tuple Fields
An encryption key could not be accessed.
EncryptionKeyDisabledException(EncryptionKeyDisabledException)
Tuple Fields
The encryption key is disabled.
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)
Tuple Fields
No encryption key was found.
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)
The encryption key is not available.
InvalidCommitIdException(InvalidCommitIdException)
Tuple Fields
The specified commit ID is not valid.
InvalidPullRequestIdException(InvalidPullRequestIdException)
Tuple Fields
The pull request ID is not valid. Make sure that you have provided the full ID and that the pull request is in the specified repository, and then try again.
InvalidRepositoryNameException(InvalidRepositoryNameException)
Tuple Fields
A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
ManualMergeRequiredException(ManualMergeRequiredException)
Tuple Fields
The pull request cannot be merged automatically into the destination branch. You must manually merge the branches and resolve any conflicts.
PullRequestAlreadyClosedException(PullRequestAlreadyClosedException)
Tuple Fields
The pull request status cannot be updated because it is already closed.
PullRequestApprovalRulesNotSatisfiedException(PullRequestApprovalRulesNotSatisfiedException)
Tuple Fields
The pull request cannot be merged because one or more approval rules applied to the pull request have conditions that have not been met.
PullRequestDoesNotExistException(PullRequestDoesNotExistException)
Tuple Fields
The pull request ID could not be found. Make sure that you have specified the correct repository name and pull request ID, and then try again.
PullRequestIdRequiredException(PullRequestIdRequiredException)
Tuple Fields
A pull request ID is required, but none was provided.
ReferenceDoesNotExistException(ReferenceDoesNotExistException)
Tuple Fields
The specified reference does not exist. You must provide a full commit ID.
RepositoryDoesNotExistException(RepositoryDoesNotExistException)
Tuple Fields
The specified repository does not exist.
RepositoryNameRequiredException(RepositoryNameRequiredException)
Tuple Fields
A repository name is required, but was not specified.
RepositoryNotAssociatedWithPullRequestException(RepositoryNotAssociatedWithPullRequestException)
Tuple Fields
The repository does not contain any pull requests with that pull request ID. Use GetPullRequest to verify the correct repository name for the pull request ID.
TipOfSourceReferenceIsDifferentException(TipOfSourceReferenceIsDifferentException)
Tuple Fields
The tip of the source branch in the destination repository does not match the tip of the source branch specified in your request. The pull request might have been updated. Make sure that you have the latest changes.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code