Enum aws_sdk_codecommit::error::PostCommentForComparedCommitErrorKind [−][src]
#[non_exhaustive]
pub enum PostCommentForComparedCommitErrorKind {
Show 24 variants
BeforeCommitIdAndAfterCommitIdAreSameException(BeforeCommitIdAndAfterCommitIdAreSameException),
ClientRequestTokenRequiredException(ClientRequestTokenRequiredException),
CommentContentRequiredException(CommentContentRequiredException),
CommentContentSizeLimitExceededException(CommentContentSizeLimitExceededException),
CommitDoesNotExistException(CommitDoesNotExistException),
CommitIdRequiredException(CommitIdRequiredException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
IdempotencyParameterMismatchException(IdempotencyParameterMismatchException),
InvalidClientRequestTokenException(InvalidClientRequestTokenException),
InvalidCommitIdException(InvalidCommitIdException),
InvalidFileLocationException(InvalidFileLocationException),
InvalidFilePositionException(InvalidFilePositionException),
InvalidPathException(InvalidPathException),
InvalidRelativeFileVersionEnumException(InvalidRelativeFileVersionEnumException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
PathDoesNotExistException(PathDoesNotExistException),
PathRequiredException(PathRequiredException),
RepositoryDoesNotExistException(RepositoryDoesNotExistException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the PostCommentForComparedCommit operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BeforeCommitIdAndAfterCommitIdAreSameException(BeforeCommitIdAndAfterCommitIdAreSameException)
Tuple Fields
The before commit ID and the after commit ID are the same, which is not valid. The before commit ID and the after commit ID must be different commit IDs.
ClientRequestTokenRequiredException(ClientRequestTokenRequiredException)
Tuple Fields
A client request token is required. A client request token is an unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
CommentContentRequiredException(CommentContentRequiredException)
Tuple Fields
The comment is empty. You must provide some content for a comment. The content cannot be null.
CommentContentSizeLimitExceededException(CommentContentSizeLimitExceededException)
Tuple Fields
The comment is too large. Comments are limited to 1,000 characters.
CommitDoesNotExistException(CommitDoesNotExistException)
Tuple Fields
The specified commit does not exist or no commit was specified, and the specified repository has no default branch.
CommitIdRequiredException(CommitIdRequiredException)
Tuple Fields
A commit ID was not specified.
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)
Tuple Fields
An encryption integrity check failed.
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)
Tuple Fields
An encryption key could not be accessed.
EncryptionKeyDisabledException(EncryptionKeyDisabledException)
Tuple Fields
The encryption key is disabled.
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)
Tuple Fields
No encryption key was found.
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)
The encryption key is not available.
IdempotencyParameterMismatchException(IdempotencyParameterMismatchException)
Tuple Fields
The client request token is not valid. Either the token is not in a valid format, or the token has been used in a previous request and cannot be reused.
InvalidClientRequestTokenException(InvalidClientRequestTokenException)
Tuple Fields
The client request token is not valid.
InvalidCommitIdException(InvalidCommitIdException)
Tuple Fields
The specified commit ID is not valid.
InvalidFileLocationException(InvalidFileLocationException)
Tuple Fields
The location of the file is not valid. Make sure that you include the file name and extension.
InvalidFilePositionException(InvalidFilePositionException)
Tuple Fields
The position is not valid. Make sure that the line number exists in the version of the file you want to comment on.
InvalidPathException(InvalidPathException)
Tuple Fields
The specified path is not valid.
InvalidRelativeFileVersionEnumException(InvalidRelativeFileVersionEnumException)
Tuple Fields
Either the enum is not in a valid format, or the specified file version enum is not valid in respect to the current file version.
InvalidRepositoryNameException(InvalidRepositoryNameException)
Tuple Fields
A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
PathDoesNotExistException(PathDoesNotExistException)
Tuple Fields
The specified path does not exist.
PathRequiredException(PathRequiredException)
Tuple Fields
The folderPath for a location cannot be null.
RepositoryDoesNotExistException(RepositoryDoesNotExistException)
Tuple Fields
The specified repository does not exist.
RepositoryNameRequiredException(RepositoryNameRequiredException)
Tuple Fields
A repository name is required, but was not specified.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code