Enum aws_sdk_codecommit::error::PutCommentReactionErrorKind [−][src]
#[non_exhaustive]
pub enum PutCommentReactionErrorKind {
CommentDeletedException(CommentDeletedException),
CommentDoesNotExistException(CommentDoesNotExistException),
CommentIdRequiredException(CommentIdRequiredException),
InvalidCommentIdException(InvalidCommentIdException),
InvalidReactionValueException(InvalidReactionValueException),
ReactionLimitExceededException(ReactionLimitExceededException),
ReactionValueRequiredException(ReactionValueRequiredException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the PutCommentReaction operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
CommentDeletedException(CommentDeletedException)
Tuple Fields
This comment has already been deleted. You cannot edit or delete a deleted comment.
CommentDoesNotExistException(CommentDoesNotExistException)
Tuple Fields
No comment exists with the provided ID. Verify that you have used the correct ID, and then try again.
CommentIdRequiredException(CommentIdRequiredException)
Tuple Fields
The comment ID is missing or null. A comment ID is required.
InvalidCommentIdException(InvalidCommentIdException)
Tuple Fields
The comment ID is not in a valid format. Make sure that you have provided the full comment ID.
InvalidReactionValueException(InvalidReactionValueException)
Tuple Fields
The value of the reaction is not valid. For more information, see the AWS CodeCommit User Guide.
ReactionLimitExceededException(ReactionLimitExceededException)
Tuple Fields
The number of reactions has been exceeded. Reactions are limited to one reaction per user for each individual comment ID.
ReactionValueRequiredException(ReactionValueRequiredException)
Tuple Fields
A reaction value is required.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code