Enum aws_sdk_codecommit::error::PutFileErrorKind [−][src]
#[non_exhaustive]
pub enum PutFileErrorKind {
Show 31 variants
BranchDoesNotExistException(BranchDoesNotExistException),
BranchNameIsTagNameException(BranchNameIsTagNameException),
BranchNameRequiredException(BranchNameRequiredException),
CommitMessageLengthExceededException(CommitMessageLengthExceededException),
DirectoryNameConflictsWithFileNameException(DirectoryNameConflictsWithFileNameException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
FileContentRequiredException(FileContentRequiredException),
FileContentSizeLimitExceededException(FileContentSizeLimitExceededException),
FileNameConflictsWithDirectoryNameException(FileNameConflictsWithDirectoryNameException),
FilePathConflictsWithSubmodulePathException(FilePathConflictsWithSubmodulePathException),
FolderContentSizeLimitExceededException(FolderContentSizeLimitExceededException),
InvalidBranchNameException(InvalidBranchNameException),
InvalidDeletionParameterException(InvalidDeletionParameterException),
InvalidEmailException(InvalidEmailException),
InvalidFileModeException(InvalidFileModeException),
InvalidParentCommitIdException(InvalidParentCommitIdException),
InvalidPathException(InvalidPathException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
NameLengthExceededException(NameLengthExceededException),
ParentCommitDoesNotExistException(ParentCommitDoesNotExistException),
ParentCommitIdOutdatedException(ParentCommitIdOutdatedException),
ParentCommitIdRequiredException(ParentCommitIdRequiredException),
PathRequiredException(PathRequiredException),
RepositoryDoesNotExistException(RepositoryDoesNotExistException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
SameFileContentException(SameFileContentException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the PutFile operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BranchDoesNotExistException(BranchDoesNotExistException)
Tuple Fields
The specified branch does not exist.
BranchNameIsTagNameException(BranchNameIsTagNameException)
Tuple Fields
The specified branch name is not valid because it is a tag name. Enter the name of a branch in the repository. For a list of valid branch names, use ListBranches.
BranchNameRequiredException(BranchNameRequiredException)
Tuple Fields
A branch name is required, but was not specified.
CommitMessageLengthExceededException(CommitMessageLengthExceededException)
Tuple Fields
The commit message is too long. Provide a shorter string.
DirectoryNameConflictsWithFileNameException(DirectoryNameConflictsWithFileNameException)
Tuple Fields
A file cannot be added to the repository because the specified path name has the same name as a file that already exists in this repository. Either provide a different name for the file, or specify a different path for the file.
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)
Tuple Fields
An encryption integrity check failed.
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)
Tuple Fields
An encryption key could not be accessed.
EncryptionKeyDisabledException(EncryptionKeyDisabledException)
Tuple Fields
The encryption key is disabled.
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)
Tuple Fields
No encryption key was found.
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)
The encryption key is not available.
FileContentRequiredException(FileContentRequiredException)
Tuple Fields
The file cannot be added because it is empty. Empty files cannot be added to the repository with this API.
FileContentSizeLimitExceededException(FileContentSizeLimitExceededException)
Tuple Fields
The file cannot be added because it is too large. The maximum file size is 6 MB, and the combined file content change size is 7 MB. Consider making these changes using a Git client.
FileNameConflictsWithDirectoryNameException(FileNameConflictsWithDirectoryNameException)
Tuple Fields
A file cannot be added to the repository because the specified file name has the same name as a directory in this repository. Either provide another name for the file, or add the file in a directory that does not match the file name.
FilePathConflictsWithSubmodulePathException(FilePathConflictsWithSubmodulePathException)
Tuple Fields
The commit cannot be created because a specified file path points to a submodule. Verify that the destination files have valid file paths that do not point to a submodule.
FolderContentSizeLimitExceededException(FolderContentSizeLimitExceededException)
Tuple Fields
The commit cannot be created because at least one of the overall changes in the commit results in a folder whose contents exceed the limit of 6 MB. Either reduce the number and size of your changes, or split the changes across multiple folders.
InvalidBranchNameException(InvalidBranchNameException)
Tuple Fields
The specified reference name is not valid.
InvalidDeletionParameterException(InvalidDeletionParameterException)
Tuple Fields
The specified deletion parameter is not valid.
InvalidEmailException(InvalidEmailException)
Tuple Fields
The specified email address either contains one or more characters that are not allowed, or it exceeds the maximum number of characters allowed for an email address.
InvalidFileModeException(InvalidFileModeException)
Tuple Fields
The specified file mode permission is not valid. For a list of valid file mode permissions, see PutFile.
InvalidParentCommitIdException(InvalidParentCommitIdException)
Tuple Fields
The parent commit ID is not valid. The commit ID cannot be empty, and must match the head commit ID for the branch of the repository where you want to add or update a file.
InvalidPathException(InvalidPathException)
Tuple Fields
The specified path is not valid.
InvalidRepositoryNameException(InvalidRepositoryNameException)
Tuple Fields
A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
NameLengthExceededException(NameLengthExceededException)
Tuple Fields
The user name is not valid because it has exceeded the character limit for author names.
ParentCommitDoesNotExistException(ParentCommitDoesNotExistException)
Tuple Fields
The parent commit ID is not valid because it does not exist. The specified parent commit ID does not exist in the specified branch of the repository.
ParentCommitIdOutdatedException(ParentCommitIdOutdatedException)
Tuple Fields
The file could not be added because the provided parent commit ID is not the current tip of the specified branch. To view the full commit ID of the current head of the branch, use GetBranch.
ParentCommitIdRequiredException(ParentCommitIdRequiredException)
Tuple Fields
A parent commit ID is required. To view the full commit ID of a branch in a repository, use GetBranch or a Git command (for example, git pull or git log).
PathRequiredException(PathRequiredException)
Tuple Fields
The folderPath for a location cannot be null.
RepositoryDoesNotExistException(RepositoryDoesNotExistException)
Tuple Fields
The specified repository does not exist.
RepositoryNameRequiredException(RepositoryNameRequiredException)
Tuple Fields
A repository name is required, but was not specified.
SameFileContentException(SameFileContentException)
Tuple Fields
The file was not added or updated because the content of the file is exactly the same as the content of that file in the repository and branch that you specified.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code