Enum aws_sdk_codecommit::error::PutRepositoryTriggersErrorKind[][src]

#[non_exhaustive]
pub enum PutRepositoryTriggersErrorKind {
Show 22 variants EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException), EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException), EncryptionKeyDisabledException(EncryptionKeyDisabledException), EncryptionKeyNotFoundException(EncryptionKeyNotFoundException), EncryptionKeyUnavailableException(EncryptionKeyUnavailableException), InvalidRepositoryNameException(InvalidRepositoryNameException), InvalidRepositoryTriggerBranchNameException(InvalidRepositoryTriggerBranchNameException), InvalidRepositoryTriggerCustomDataException(InvalidRepositoryTriggerCustomDataException), InvalidRepositoryTriggerDestinationArnException(InvalidRepositoryTriggerDestinationArnException), InvalidRepositoryTriggerEventsException(InvalidRepositoryTriggerEventsException), InvalidRepositoryTriggerNameException(InvalidRepositoryTriggerNameException), InvalidRepositoryTriggerRegionException(InvalidRepositoryTriggerRegionException), MaximumBranchesExceededException(MaximumBranchesExceededException), MaximumRepositoryTriggersExceededException(MaximumRepositoryTriggersExceededException), RepositoryDoesNotExistException(RepositoryDoesNotExistException), RepositoryNameRequiredException(RepositoryNameRequiredException), RepositoryTriggerBranchNameListRequiredException(RepositoryTriggerBranchNameListRequiredException), RepositoryTriggerDestinationArnRequiredException(RepositoryTriggerDestinationArnRequiredException), RepositoryTriggerEventsListRequiredException(RepositoryTriggerEventsListRequiredException), RepositoryTriggerNameRequiredException(RepositoryTriggerNameRequiredException), RepositoryTriggersListRequiredException(RepositoryTriggersListRequiredException), Unhandled(Box<dyn Error + Send + Sync + 'static>),
}
Types of errors that can occur for the PutRepositoryTriggers operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)

An encryption integrity check failed.

Tuple Fields of EncryptionIntegrityChecksFailedException

0: EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)

An encryption key could not be accessed.

Tuple Fields of EncryptionKeyAccessDeniedException

0: EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)

The encryption key is disabled.

Tuple Fields of EncryptionKeyDisabledException

0: EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)

No encryption key was found.

Tuple Fields of EncryptionKeyNotFoundException

0: EncryptionKeyNotFoundException
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)

The encryption key is not available.

Tuple Fields of EncryptionKeyUnavailableException

0: EncryptionKeyUnavailableException
InvalidRepositoryNameException(InvalidRepositoryNameException)

A specified repository name is not valid.

This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.

Tuple Fields of InvalidRepositoryNameException

0: InvalidRepositoryNameException
InvalidRepositoryTriggerBranchNameException(InvalidRepositoryTriggerBranchNameException)

One or more branch names specified for the trigger is not valid.

Tuple Fields of InvalidRepositoryTriggerBranchNameException

0: InvalidRepositoryTriggerBranchNameException
InvalidRepositoryTriggerCustomDataException(InvalidRepositoryTriggerCustomDataException)

The custom data provided for the trigger is not valid.

Tuple Fields of InvalidRepositoryTriggerCustomDataException

0: InvalidRepositoryTriggerCustomDataException
InvalidRepositoryTriggerDestinationArnException(InvalidRepositoryTriggerDestinationArnException)

The Amazon Resource Name (ARN) for the trigger is not valid for the specified destination. The most common reason for this error is that the ARN does not meet the requirements for the service type.

Tuple Fields of InvalidRepositoryTriggerDestinationArnException

0: InvalidRepositoryTriggerDestinationArnException
InvalidRepositoryTriggerEventsException(InvalidRepositoryTriggerEventsException)

One or more events specified for the trigger is not valid. Check to make sure that all events specified match the requirements for allowed events.

Tuple Fields of InvalidRepositoryTriggerEventsException

0: InvalidRepositoryTriggerEventsException
InvalidRepositoryTriggerNameException(InvalidRepositoryTriggerNameException)

The name of the trigger is not valid.

Tuple Fields of InvalidRepositoryTriggerNameException

0: InvalidRepositoryTriggerNameException
InvalidRepositoryTriggerRegionException(InvalidRepositoryTriggerRegionException)

The AWS Region for the trigger target does not match the AWS Region for the repository. Triggers must be created in the same Region as the target for the trigger.

Tuple Fields of InvalidRepositoryTriggerRegionException

0: InvalidRepositoryTriggerRegionException
MaximumBranchesExceededException(MaximumBranchesExceededException)

The number of branches for the trigger was exceeded.

Tuple Fields of MaximumBranchesExceededException

0: MaximumBranchesExceededException
MaximumRepositoryTriggersExceededException(MaximumRepositoryTriggersExceededException)

The number of triggers allowed for the repository was exceeded.

Tuple Fields of MaximumRepositoryTriggersExceededException

0: MaximumRepositoryTriggersExceededException
RepositoryDoesNotExistException(RepositoryDoesNotExistException)

The specified repository does not exist.

Tuple Fields of RepositoryDoesNotExistException

0: RepositoryDoesNotExistException
RepositoryNameRequiredException(RepositoryNameRequiredException)

A repository name is required, but was not specified.

Tuple Fields of RepositoryNameRequiredException

0: RepositoryNameRequiredException
RepositoryTriggerBranchNameListRequiredException(RepositoryTriggerBranchNameListRequiredException)

At least one branch name is required, but was not specified in the trigger configuration.

Tuple Fields of RepositoryTriggerBranchNameListRequiredException

0: RepositoryTriggerBranchNameListRequiredException
RepositoryTriggerDestinationArnRequiredException(RepositoryTriggerDestinationArnRequiredException)

A destination ARN for the target service for the trigger is required, but was not specified.

Tuple Fields of RepositoryTriggerDestinationArnRequiredException

0: RepositoryTriggerDestinationArnRequiredException
RepositoryTriggerEventsListRequiredException(RepositoryTriggerEventsListRequiredException)

At least one event for the trigger is required, but was not specified.

Tuple Fields of RepositoryTriggerEventsListRequiredException

0: RepositoryTriggerEventsListRequiredException
RepositoryTriggerNameRequiredException(RepositoryTriggerNameRequiredException)

A name for the trigger is required, but was not specified.

Tuple Fields of RepositoryTriggerNameRequiredException

0: RepositoryTriggerNameRequiredException
RepositoryTriggersListRequiredException(RepositoryTriggersListRequiredException)

The list of triggers for the repository is required, but was not specified.

Tuple Fields of RepositoryTriggersListRequiredException

0: RepositoryTriggersListRequiredException
Unhandled(Box<dyn Error + Send + Sync + 'static>)

An unexpected error, eg. invalid JSON returned by the service or an unknown error code

Tuple Fields of Unhandled

0: Box<dyn Error + Send + Sync + 'static>