Enum aws_sdk_codecommit::error::TestRepositoryTriggersErrorKind [−][src]
#[non_exhaustive]
pub enum TestRepositoryTriggersErrorKind {
Show 22 variants
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
InvalidRepositoryTriggerBranchNameException(InvalidRepositoryTriggerBranchNameException),
InvalidRepositoryTriggerCustomDataException(InvalidRepositoryTriggerCustomDataException),
InvalidRepositoryTriggerDestinationArnException(InvalidRepositoryTriggerDestinationArnException),
InvalidRepositoryTriggerEventsException(InvalidRepositoryTriggerEventsException),
InvalidRepositoryTriggerNameException(InvalidRepositoryTriggerNameException),
InvalidRepositoryTriggerRegionException(InvalidRepositoryTriggerRegionException),
MaximumBranchesExceededException(MaximumBranchesExceededException),
MaximumRepositoryTriggersExceededException(MaximumRepositoryTriggersExceededException),
RepositoryDoesNotExistException(RepositoryDoesNotExistException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
RepositoryTriggerBranchNameListRequiredException(RepositoryTriggerBranchNameListRequiredException),
RepositoryTriggerDestinationArnRequiredException(RepositoryTriggerDestinationArnRequiredException),
RepositoryTriggerEventsListRequiredException(RepositoryTriggerEventsListRequiredException),
RepositoryTriggerNameRequiredException(RepositoryTriggerNameRequiredException),
RepositoryTriggersListRequiredException(RepositoryTriggersListRequiredException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the TestRepositoryTriggers operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)
Tuple Fields
An encryption integrity check failed.
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)
Tuple Fields
An encryption key could not be accessed.
EncryptionKeyDisabledException(EncryptionKeyDisabledException)
Tuple Fields
The encryption key is disabled.
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)
Tuple Fields
No encryption key was found.
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)
The encryption key is not available.
InvalidRepositoryNameException(InvalidRepositoryNameException)
Tuple Fields
A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
InvalidRepositoryTriggerBranchNameException(InvalidRepositoryTriggerBranchNameException)
Tuple Fields
One or more branch names specified for the trigger is not valid.
InvalidRepositoryTriggerCustomDataException(InvalidRepositoryTriggerCustomDataException)
Tuple Fields
The custom data provided for the trigger is not valid.
InvalidRepositoryTriggerDestinationArnException(InvalidRepositoryTriggerDestinationArnException)
Tuple Fields
The Amazon Resource Name (ARN) for the trigger is not valid for the specified destination. The most common reason for this error is that the ARN does not meet the requirements for the service type.
InvalidRepositoryTriggerEventsException(InvalidRepositoryTriggerEventsException)
Tuple Fields
One or more events specified for the trigger is not valid. Check to make sure that all events specified match the requirements for allowed events.
InvalidRepositoryTriggerNameException(InvalidRepositoryTriggerNameException)
Tuple Fields
The name of the trigger is not valid.
InvalidRepositoryTriggerRegionException(InvalidRepositoryTriggerRegionException)
Tuple Fields
The AWS Region for the trigger target does not match the AWS Region for the repository. Triggers must be created in the same Region as the target for the trigger.
MaximumBranchesExceededException(MaximumBranchesExceededException)
Tuple Fields
The number of branches for the trigger was exceeded.
MaximumRepositoryTriggersExceededException(MaximumRepositoryTriggersExceededException)
Tuple Fields
The number of triggers allowed for the repository was exceeded.
RepositoryDoesNotExistException(RepositoryDoesNotExistException)
Tuple Fields
The specified repository does not exist.
RepositoryNameRequiredException(RepositoryNameRequiredException)
Tuple Fields
A repository name is required, but was not specified.
RepositoryTriggerBranchNameListRequiredException(RepositoryTriggerBranchNameListRequiredException)
Tuple Fields
At least one branch name is required, but was not specified in the trigger configuration.
RepositoryTriggerDestinationArnRequiredException(RepositoryTriggerDestinationArnRequiredException)
Tuple Fields
A destination ARN for the target service for the trigger is required, but was not specified.
RepositoryTriggerEventsListRequiredException(RepositoryTriggerEventsListRequiredException)
Tuple Fields
At least one event for the trigger is required, but was not specified.
RepositoryTriggerNameRequiredException(RepositoryTriggerNameRequiredException)
Tuple Fields
A name for the trigger is required, but was not specified.
RepositoryTriggersListRequiredException(RepositoryTriggersListRequiredException)
Tuple Fields
The list of triggers for the repository is required, but was not specified.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code