Enum aws_sdk_codecommit::error::UpdateApprovalRuleTemplateContentErrorKind [−][src]
#[non_exhaustive]
pub enum UpdateApprovalRuleTemplateContentErrorKind {
ApprovalRuleTemplateContentRequiredException(ApprovalRuleTemplateContentRequiredException),
ApprovalRuleTemplateDoesNotExistException(ApprovalRuleTemplateDoesNotExistException),
ApprovalRuleTemplateNameRequiredException(ApprovalRuleTemplateNameRequiredException),
InvalidApprovalRuleTemplateContentException(InvalidApprovalRuleTemplateContentException),
InvalidApprovalRuleTemplateNameException(InvalidApprovalRuleTemplateNameException),
InvalidRuleContentSha256Exception(InvalidRuleContentSha256Exception),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the UpdateApprovalRuleTemplateContent operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ApprovalRuleTemplateContentRequiredException(ApprovalRuleTemplateContentRequiredException)The content for the approval rule template is empty. You must provide some content for an approval rule template. The content cannot be null.
Tuple Fields of ApprovalRuleTemplateContentRequiredException
ApprovalRuleTemplateDoesNotExistException(ApprovalRuleTemplateDoesNotExistException)The specified approval rule template does not exist. Verify that the name is correct and that you are signed in to the AWS Region where the template was created, and then try again.
Tuple Fields of ApprovalRuleTemplateDoesNotExistException
ApprovalRuleTemplateNameRequiredException(ApprovalRuleTemplateNameRequiredException)An approval rule template name is required, but was not specified.
Tuple Fields of ApprovalRuleTemplateNameRequiredException
InvalidApprovalRuleTemplateContentException(InvalidApprovalRuleTemplateContentException)The content of the approval rule template is not valid.
Tuple Fields of InvalidApprovalRuleTemplateContentException
InvalidApprovalRuleTemplateNameException(InvalidApprovalRuleTemplateNameException)The name of the approval rule template is not valid. Template names must be between 1 and 100 valid characters in length. For more information about limits in AWS CodeCommit, see AWS CodeCommit User Guide.
Tuple Fields of InvalidApprovalRuleTemplateNameException
InvalidRuleContentSha256Exception(InvalidRuleContentSha256Exception)The SHA-256 hash signature for the rule content is not valid.
Tuple Fields of InvalidRuleContentSha256Exception
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code