Enum aws_sdk_codecommit::error::UpdateApprovalRuleTemplateDescriptionErrorKind [−][src]
#[non_exhaustive]
pub enum UpdateApprovalRuleTemplateDescriptionErrorKind {
ApprovalRuleTemplateDoesNotExistException(ApprovalRuleTemplateDoesNotExistException),
ApprovalRuleTemplateNameRequiredException(ApprovalRuleTemplateNameRequiredException),
InvalidApprovalRuleTemplateDescriptionException(InvalidApprovalRuleTemplateDescriptionException),
InvalidApprovalRuleTemplateNameException(InvalidApprovalRuleTemplateNameException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the UpdateApprovalRuleTemplateDescription operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ApprovalRuleTemplateDoesNotExistException(ApprovalRuleTemplateDoesNotExistException)The specified approval rule template does not exist. Verify that the name is correct and that you are signed in to the AWS Region where the template was created, and then try again.
Tuple Fields of ApprovalRuleTemplateDoesNotExistException
ApprovalRuleTemplateNameRequiredException(ApprovalRuleTemplateNameRequiredException)An approval rule template name is required, but was not specified.
Tuple Fields of ApprovalRuleTemplateNameRequiredException
InvalidApprovalRuleTemplateDescriptionException(InvalidApprovalRuleTemplateDescriptionException)The description for the approval rule template is not valid because it exceeds the maximum characters allowed for a description. For more information about limits in AWS CodeCommit, see AWS CodeCommit User Guide.
Tuple Fields of InvalidApprovalRuleTemplateDescriptionException
InvalidApprovalRuleTemplateNameException(InvalidApprovalRuleTemplateNameException)The name of the approval rule template is not valid. Template names must be between 1 and 100 valid characters in length. For more information about limits in AWS CodeCommit, see AWS CodeCommit User Guide.
Tuple Fields of InvalidApprovalRuleTemplateNameException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code