Enum aws_sdk_codecommit::error::UpdateApprovalRuleTemplateNameErrorKind [−][src]
#[non_exhaustive]
pub enum UpdateApprovalRuleTemplateNameErrorKind {
ApprovalRuleTemplateDoesNotExistException(ApprovalRuleTemplateDoesNotExistException),
ApprovalRuleTemplateNameAlreadyExistsException(ApprovalRuleTemplateNameAlreadyExistsException),
ApprovalRuleTemplateNameRequiredException(ApprovalRuleTemplateNameRequiredException),
InvalidApprovalRuleTemplateNameException(InvalidApprovalRuleTemplateNameException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the UpdateApprovalRuleTemplateName operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ApprovalRuleTemplateDoesNotExistException(ApprovalRuleTemplateDoesNotExistException)
Tuple Fields
The specified approval rule template does not exist. Verify that the name is correct and that you are signed in to the AWS Region where the template was created, and then try again.
ApprovalRuleTemplateNameAlreadyExistsException(ApprovalRuleTemplateNameAlreadyExistsException)
Tuple Fields
You cannot create an approval rule template with that name because a template with that name already exists in this AWS Region for your AWS account. Approval rule template names must be unique.
ApprovalRuleTemplateNameRequiredException(ApprovalRuleTemplateNameRequiredException)
Tuple Fields
An approval rule template name is required, but was not specified.
InvalidApprovalRuleTemplateNameException(InvalidApprovalRuleTemplateNameException)
Tuple Fields
The name of the approval rule template is not valid. Template names must be between 1 and 100 valid characters in length. For more information about limits in AWS CodeCommit, see AWS CodeCommit User Guide.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code