Enum aws_sdk_codecommit::error::UpdateCommentErrorKind [−][src]
#[non_exhaustive]
pub enum UpdateCommentErrorKind {
CommentContentRequiredException(CommentContentRequiredException),
CommentContentSizeLimitExceededException(CommentContentSizeLimitExceededException),
CommentDeletedException(CommentDeletedException),
CommentDoesNotExistException(CommentDoesNotExistException),
CommentIdRequiredException(CommentIdRequiredException),
CommentNotCreatedByCallerException(CommentNotCreatedByCallerException),
InvalidCommentIdException(InvalidCommentIdException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the UpdateComment operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
CommentContentRequiredException(CommentContentRequiredException)
Tuple Fields
The comment is empty. You must provide some content for a comment. The content cannot be null.
CommentContentSizeLimitExceededException(CommentContentSizeLimitExceededException)
Tuple Fields
The comment is too large. Comments are limited to 1,000 characters.
CommentDeletedException(CommentDeletedException)
Tuple Fields
This comment has already been deleted. You cannot edit or delete a deleted comment.
CommentDoesNotExistException(CommentDoesNotExistException)
Tuple Fields
No comment exists with the provided ID. Verify that you have used the correct ID, and then try again.
CommentIdRequiredException(CommentIdRequiredException)
Tuple Fields
The comment ID is missing or null. A comment ID is required.
CommentNotCreatedByCallerException(CommentNotCreatedByCallerException)
Tuple Fields
You cannot modify or delete this comment. Only comment authors can modify or delete their comments.
InvalidCommentIdException(InvalidCommentIdException)
Tuple Fields
The comment ID is not in a valid format. Make sure that you have provided the full comment ID.
Unhandled(Box<dyn Error + Send + Sync + 'static>)
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code