Enum aws_sdk_codecommit::error::UpdatePullRequestApprovalStateErrorKind [−][src]
#[non_exhaustive]
pub enum UpdatePullRequestApprovalStateErrorKind {
Show 17 variants
ApprovalStateRequiredException(ApprovalStateRequiredException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidApprovalStateException(InvalidApprovalStateException),
InvalidPullRequestIdException(InvalidPullRequestIdException),
InvalidRevisionIdException(InvalidRevisionIdException),
MaximumNumberOfApprovalsExceededException(MaximumNumberOfApprovalsExceededException),
PullRequestAlreadyClosedException(PullRequestAlreadyClosedException),
PullRequestCannotBeApprovedByAuthorException(PullRequestCannotBeApprovedByAuthorException),
PullRequestDoesNotExistException(PullRequestDoesNotExistException),
PullRequestIdRequiredException(PullRequestIdRequiredException),
RevisionIdRequiredException(RevisionIdRequiredException),
RevisionNotCurrentException(RevisionNotCurrentException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the UpdatePullRequestApprovalState operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ApprovalStateRequiredException(ApprovalStateRequiredException)An approval state is required, but was not specified.
Tuple Fields of ApprovalStateRequiredException
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)An encryption integrity check failed.
Tuple Fields of EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)An encryption key could not be accessed.
Tuple Fields of EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)The encryption key is disabled.
Tuple Fields of EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)No encryption key was found.
Tuple Fields of EncryptionKeyNotFoundException
The encryption key is not available.
InvalidApprovalStateException(InvalidApprovalStateException)The state for the approval is not valid. Valid values include APPROVE and REVOKE.
Tuple Fields of InvalidApprovalStateException
InvalidPullRequestIdException(InvalidPullRequestIdException)The pull request ID is not valid. Make sure that you have provided the full ID and that the pull request is in the specified repository, and then try again.
Tuple Fields of InvalidPullRequestIdException
InvalidRevisionIdException(InvalidRevisionIdException)The revision ID is not valid. Use GetPullRequest to determine the value.
Tuple Fields of InvalidRevisionIdException
MaximumNumberOfApprovalsExceededException(MaximumNumberOfApprovalsExceededException)The number of approvals required for the approval rule exceeds the maximum number allowed.
Tuple Fields of MaximumNumberOfApprovalsExceededException
PullRequestAlreadyClosedException(PullRequestAlreadyClosedException)The pull request status cannot be updated because it is already closed.
Tuple Fields of PullRequestAlreadyClosedException
PullRequestCannotBeApprovedByAuthorException(PullRequestCannotBeApprovedByAuthorException)The approval cannot be applied because the user approving the pull request matches the user who created the pull request. You cannot approve a pull request that you created.
Tuple Fields of PullRequestCannotBeApprovedByAuthorException
PullRequestDoesNotExistException(PullRequestDoesNotExistException)The pull request ID could not be found. Make sure that you have specified the correct repository name and pull request ID, and then try again.
Tuple Fields of PullRequestDoesNotExistException
PullRequestIdRequiredException(PullRequestIdRequiredException)A pull request ID is required, but none was provided.
Tuple Fields of PullRequestIdRequiredException
RevisionIdRequiredException(RevisionIdRequiredException)A revision ID is required, but was not provided.
Tuple Fields of RevisionIdRequiredException
RevisionNotCurrentException(RevisionNotCurrentException)The revision ID provided in the request does not match the current revision ID. Use GetPullRequest to retrieve the current revision ID.
Tuple Fields of RevisionNotCurrentException
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code