Enum aws_sdk_codecommit::error::UpdatePullRequestDescriptionErrorKind [−][src]
#[non_exhaustive]
pub enum UpdatePullRequestDescriptionErrorKind {
InvalidDescriptionException(InvalidDescriptionException),
InvalidPullRequestIdException(InvalidPullRequestIdException),
PullRequestAlreadyClosedException(PullRequestAlreadyClosedException),
PullRequestDoesNotExistException(PullRequestDoesNotExistException),
PullRequestIdRequiredException(PullRequestIdRequiredException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the UpdatePullRequestDescription operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InvalidDescriptionException(InvalidDescriptionException)The pull request description is not valid. Descriptions cannot be more than 1,000 characters.
Tuple Fields of InvalidDescriptionException
InvalidPullRequestIdException(InvalidPullRequestIdException)The pull request ID is not valid. Make sure that you have provided the full ID and that the pull request is in the specified repository, and then try again.
Tuple Fields of InvalidPullRequestIdException
PullRequestAlreadyClosedException(PullRequestAlreadyClosedException)The pull request status cannot be updated because it is already closed.
Tuple Fields of PullRequestAlreadyClosedException
PullRequestDoesNotExistException(PullRequestDoesNotExistException)The pull request ID could not be found. Make sure that you have specified the correct repository name and pull request ID, and then try again.
Tuple Fields of PullRequestDoesNotExistException
PullRequestIdRequiredException(PullRequestIdRequiredException)A pull request ID is required, but none was provided.
Tuple Fields of PullRequestIdRequiredException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code