Enum aws_sdk_codecommit::error::UpdatePullRequestTitleErrorKind [−][src]
#[non_exhaustive]
pub enum UpdatePullRequestTitleErrorKind {
InvalidPullRequestIdException(InvalidPullRequestIdException),
InvalidTitleException(InvalidTitleException),
PullRequestAlreadyClosedException(PullRequestAlreadyClosedException),
PullRequestDoesNotExistException(PullRequestDoesNotExistException),
PullRequestIdRequiredException(PullRequestIdRequiredException),
TitleRequiredException(TitleRequiredException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the UpdatePullRequestTitle operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InvalidPullRequestIdException(InvalidPullRequestIdException)The pull request ID is not valid. Make sure that you have provided the full ID and that the pull request is in the specified repository, and then try again.
Tuple Fields of InvalidPullRequestIdException
InvalidTitleException(InvalidTitleException)The title of the pull request is not valid. Pull request titles cannot exceed 100 characters in length.
Tuple Fields of InvalidTitleException
PullRequestAlreadyClosedException(PullRequestAlreadyClosedException)The pull request status cannot be updated because it is already closed.
Tuple Fields of PullRequestAlreadyClosedException
PullRequestDoesNotExistException(PullRequestDoesNotExistException)The pull request ID could not be found. Make sure that you have specified the correct repository name and pull request ID, and then try again.
Tuple Fields of PullRequestDoesNotExistException
PullRequestIdRequiredException(PullRequestIdRequiredException)A pull request ID is required, but none was provided.
Tuple Fields of PullRequestIdRequiredException
TitleRequiredException(TitleRequiredException)A pull request title is required. It cannot be empty or null.
Tuple Fields of TitleRequiredException
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code