Enum aws_sdk_codecommit::error::UpdateRepositoryNameErrorKind [−][src]
#[non_exhaustive]
pub enum UpdateRepositoryNameErrorKind {
InvalidRepositoryNameException(InvalidRepositoryNameException),
RepositoryDoesNotExistException(RepositoryDoesNotExistException),
RepositoryNameExistsException(RepositoryNameExistsException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the UpdateRepositoryName operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InvalidRepositoryNameException(InvalidRepositoryNameException)A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
Tuple Fields of InvalidRepositoryNameException
RepositoryDoesNotExistException(RepositoryDoesNotExistException)The specified repository does not exist.
Tuple Fields of RepositoryDoesNotExistException
RepositoryNameExistsException(RepositoryNameExistsException)The specified repository name already exists.
Tuple Fields of RepositoryNameExistsException
RepositoryNameRequiredException(RepositoryNameRequiredException)A repository name is required, but was not specified.
Tuple Fields of RepositoryNameRequiredException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code