Struct aws_sdk_codecommit::error::InvalidEmailException [−][src]
The specified email address either contains one or more characters that are not allowed, or it exceeds the maximum number of characters allowed for an email address.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.message: Option<String>Any message associated with the exception.
Implementations
Creates a new builder-style object to manufacture InvalidEmailException