Struct aws_sdk_codecommit::error::InvalidRepositoryTriggerDestinationArnException [−][src]
#[non_exhaustive]pub struct InvalidRepositoryTriggerDestinationArnException {
pub message: Option<String>,
}Expand description
The Amazon Resource Name (ARN) for the trigger is not valid for the specified destination. The most common reason for this error is that the ARN does not meet the requirements for the service type.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.message: Option<String>Any message associated with the exception.
Implementations
Creates a new builder-style object to manufacture InvalidRepositoryTriggerDestinationArnException