Struct aws_sdk_codecommit::error::InvalidTargetException [−][src]
The target for the pull request is not valid. A target must contain the full values for the repository name, source branch, and destination branch for the pull request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.message: Option<String>Any message associated with the exception.
Implementations
Creates a new builder-style object to manufacture InvalidTargetException