Struct aws_sdk_codecommit::error::ParentCommitIdOutdatedException [−][src]
The file could not be added because the provided parent commit ID is not the current tip of the specified branch. To view the full commit ID of the current head of the branch, use GetBranch.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.message: Option<String>Any message associated with the exception.
Implementations
Creates a new builder-style object to manufacture ParentCommitIdOutdatedException