Struct aws_sdk_codecommit::error::PutFileEntryConflictException [−][src]
The commit cannot be created because one or more files specified in the commit reference both a file and a folder.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.message: Option<String>Any message associated with the exception.
Implementations
Creates a new builder-style object to manufacture PutFileEntryConflictException