Struct aws_sdk_codecommit::error::SamePathRequestException [−][src]
The commit cannot be created because one or more changes in this commit duplicate actions in the same file path. For example, you cannot make the same delete request to the same file in the same file path twice, or make a delete request and a move request to the same file as part of the same commit.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.message: Option<String>Any message associated with the exception.
Implementations
Creates a new builder-style object to manufacture SamePathRequestException