Struct aws_sdk_codecommit::input::batch_get_commits_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for BatchGetCommitsInput
Implementations
Appends an item to commit_ids.
To override the contents of this collection use set_commit_ids.
The full commit IDs of the commits to get information about.
You must supply the full SHA IDs of each commit. You cannot use shortened SHA IDs.
The full commit IDs of the commits to get information about.
You must supply the full SHA IDs of each commit. You cannot use shortened SHA IDs.
The name of the repository that contains the commits.
The name of the repository that contains the commits.
Consumes the builder and constructs a BatchGetCommitsInput