Struct aws_sdk_codecommit::input::create_branch_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for CreateBranchInput
Implementations
The name of the repository in which you want to create the new branch.
The name of the repository in which you want to create the new branch.
The name of the new branch to create.
The name of the new branch to create.
The ID of the commit to point the new branch to.
The ID of the commit to point the new branch to.
Consumes the builder and constructs a CreateBranchInput