Struct aws_sdk_codecommit::input::create_commit_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for CreateCommitInput
Implementations
The name of the repository where you create the commit.
The name of the repository where you create the commit.
The name of the branch where you create the commit.
The name of the branch where you create the commit.
The ID of the commit that is the parent of the commit you create. Not required if this is an empty repository.
The ID of the commit that is the parent of the commit you create. Not required if this is an empty repository.
The name of the author who created the commit. This information is used as both the author and committer for the commit.
The name of the author who created the commit. This information is used as both the author and committer for the commit.
The email address of the person who created the commit.
The email address of the person who created the commit.
The commit message you want to include in the commit. Commit messages are limited to 256 KB. If no message is specified, a default message is used.
The commit message you want to include in the commit. Commit messages are limited to 256 KB. If no message is specified, a default message is used.
If the commit contains deletions, whether to keep a folder or folder structure if the changes leave the folders empty. If true, a ..gitkeep file is created for empty folders. The default is false.
If the commit contains deletions, whether to keep a folder or folder structure if the changes leave the folders empty. If true, a ..gitkeep file is created for empty folders. The default is false.
Appends an item to put_files.
To override the contents of this collection use set_put_files.
The files to add or update in this commit.
The files to add or update in this commit.
Appends an item to delete_files.
To override the contents of this collection use set_delete_files.
The files to delete in this commit. These files still exist in earlier commits.
The files to delete in this commit. These files still exist in earlier commits.
Appends an item to set_file_modes.
To override the contents of this collection use set_set_file_modes.
The file modes to update for files in this commit.
The file modes to update for files in this commit.
Consumes the builder and constructs a CreateCommitInput