Struct aws_sdk_codecommit::input::create_pull_request_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for CreatePullRequestInput
Implementations
The title of the pull request. This title is used to identify the pull request to other users in the repository.
The title of the pull request. This title is used to identify the pull request to other users in the repository.
A description of the pull request.
A description of the pull request.
Appends an item to targets.
To override the contents of this collection use set_targets.
The targets for the pull request, including the source of the code to be reviewed (the source branch) and the destination where the creator of the pull request intends the code to be merged after the pull request is closed (the destination branch).
The targets for the pull request, including the source of the code to be reviewed (the source branch) and the destination where the creator of the pull request intends the code to be merged after the pull request is closed (the destination branch).
A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
The AWS SDKs prepopulate client request tokens. If you are using an AWS SDK, an idempotency token is created for you.
A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
The AWS SDKs prepopulate client request tokens. If you are using an AWS SDK, an idempotency token is created for you.
Consumes the builder and constructs a CreatePullRequestInput