Struct aws_sdk_codecommit::input::create_unreferenced_merge_commit_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for CreateUnreferencedMergeCommitInput
Implementations
The name of the repository where you want to create the unreferenced merge commit.
The name of the repository where you want to create the unreferenced merge commit.
The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
The merge option or strategy you want to use to merge the code.
The merge option or strategy you want to use to merge the code.
The level of conflict detail to use. If unspecified, the default FILE_LEVEL is used, which returns a not-mergeable result if the same file has differences in both branches. If LINE_LEVEL is specified, a conflict is considered not mergeable if the same file in both branches has differences on the same line.
The level of conflict detail to use. If unspecified, the default FILE_LEVEL is used, which returns a not-mergeable result if the same file has differences in both branches. If LINE_LEVEL is specified, a conflict is considered not mergeable if the same file in both branches has differences on the same line.
Specifies which branch to use when resolving conflicts, or whether to attempt automatically merging two versions of a file. The default is NONE, which requires any conflicts to be resolved manually before the merge operation is successful.
pub fn set_conflict_resolution_strategy(
self,
input: Option<ConflictResolutionStrategyTypeEnum>
) -> Self
pub fn set_conflict_resolution_strategy(
self,
input: Option<ConflictResolutionStrategyTypeEnum>
) -> Self
Specifies which branch to use when resolving conflicts, or whether to attempt automatically merging two versions of a file. The default is NONE, which requires any conflicts to be resolved manually before the merge operation is successful.
The name of the author who created the unreferenced commit. This information is used as both the author and committer for the commit.
The name of the author who created the unreferenced commit. This information is used as both the author and committer for the commit.
The email address for the person who created the unreferenced commit.
The email address for the person who created the unreferenced commit.
The commit message for the unreferenced commit.
The commit message for the unreferenced commit.
If the commit contains deletions, whether to keep a folder or folder structure if the changes leave the folders empty. If this is specified as true, a .gitkeep file is created for empty folders. The default is false.
If the commit contains deletions, whether to keep a folder or folder structure if the changes leave the folders empty. If this is specified as true, a .gitkeep file is created for empty folders. The default is false.
If AUTOMERGE is the conflict resolution strategy, a list of inputs to use when resolving conflicts during a merge.
If AUTOMERGE is the conflict resolution strategy, a list of inputs to use when resolving conflicts during a merge.
Consumes the builder and constructs a CreateUnreferencedMergeCommitInput