Struct aws_sdk_codecommit::input::delete_pull_request_approval_rule_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for DeletePullRequestApprovalRuleInput
Implementations
The system-generated ID of the pull request that contains the approval rule you want to delete.
The system-generated ID of the pull request that contains the approval rule you want to delete.
The name of the approval rule you want to delete.
The name of the approval rule you want to delete.
Consumes the builder and constructs a DeletePullRequestApprovalRuleInput