Struct aws_sdk_codecommit::input::describe_pull_request_events_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for DescribePullRequestEventsInput
Implementations
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
Optional. The pull request event type about which you want to return information.
Optional. The pull request event type about which you want to return information.
The Amazon Resource Name (ARN) of the user whose actions resulted in the event. Examples include updating the pull request with more commits or changing the status of a pull request.
The Amazon Resource Name (ARN) of the user whose actions resulted in the event. Examples include updating the pull request with more commits or changing the status of a pull request.
An enumeration token that, when provided in a request, returns the next batch of the results.
An enumeration token that, when provided in a request, returns the next batch of the results.
A non-zero, non-negative integer used to limit the number of returned results. The default is 100 events, which is also the maximum number of events that can be returned in a result.
A non-zero, non-negative integer used to limit the number of returned results. The default is 100 events, which is also the maximum number of events that can be returned in a result.
Consumes the builder and constructs a DescribePullRequestEventsInput