Struct aws_sdk_codecommit::input::evaluate_pull_request_approval_rules_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for EvaluatePullRequestApprovalRulesInput
Implementations
The system-generated ID of the pull request you want to evaluate.
The system-generated ID of the pull request you want to evaluate.
The system-generated ID for the pull request revision. To retrieve the most recent revision ID for a pull request, use GetPullRequest.
The system-generated ID for the pull request revision. To retrieve the most recent revision ID for a pull request, use GetPullRequest.
Consumes the builder and constructs a EvaluatePullRequestApprovalRulesInput