Struct aws_sdk_codecommit::input::get_blob_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for GetBlobInput
Implementations
The name of the repository that contains the blob.
The name of the repository that contains the blob.
The ID of the blob, which is its SHA-1 pointer.
The ID of the blob, which is its SHA-1 pointer.
Consumes the builder and constructs a GetBlobInput