Struct aws_sdk_codecommit::input::get_branch_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for GetBranchInput
Implementations
The name of the repository that contains the branch for which you want to retrieve information.
The name of the repository that contains the branch for which you want to retrieve information.
The name of the branch for which you want to retrieve information.
The name of the branch for which you want to retrieve information.
Consumes the builder and constructs a GetBranchInput