Struct aws_sdk_codecommit::input::get_comment_reactions_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for GetCommentReactionsInput
Implementations
The ID of the comment for which you want to get reactions information.
The ID of the comment for which you want to get reactions information.
Optional. The Amazon Resource Name (ARN) of the user or identity for which you want to get reaction information.
Optional. The Amazon Resource Name (ARN) of the user or identity for which you want to get reaction information.
An enumeration token that, when provided in a request, returns the next batch of the results.
An enumeration token that, when provided in a request, returns the next batch of the results.
A non-zero, non-negative integer used to limit the number of returned results. The default is the same as the allowed maximum, 1,000.
A non-zero, non-negative integer used to limit the number of returned results. The default is the same as the allowed maximum, 1,000.
Consumes the builder and constructs a GetCommentReactionsInput