Struct aws_sdk_codecommit::input::get_comments_for_compared_commit_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for GetCommentsForComparedCommitInput
Implementations
The name of the repository where you want to compare commits.
The name of the repository where you want to compare commits.
To establish the directionality of the comparison, the full commit ID of the before commit.
To establish the directionality of the comparison, the full commit ID of the before commit.
To establish the directionality of the comparison, the full commit ID of the after commit.
To establish the directionality of the comparison, the full commit ID of the after commit.
An enumeration token that when provided in a request, returns the next batch of the results.
An enumeration token that when provided in a request, returns the next batch of the results.
A non-zero, non-negative integer used to limit the number of returned results. The default is 100 comments, but you can configure up to 500.
A non-zero, non-negative integer used to limit the number of returned results. The default is 100 comments, but you can configure up to 500.
Consumes the builder and constructs a GetCommentsForComparedCommitInput