Struct aws_sdk_codecommit::input::get_comments_for_pull_request_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for GetCommentsForPullRequestInput
Implementations
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
The name of the repository that contains the pull request.
The name of the repository that contains the pull request.
The full commit ID of the commit in the destination branch that was the tip of the branch at the time the pull request was created.
The full commit ID of the commit in the destination branch that was the tip of the branch at the time the pull request was created.
The full commit ID of the commit in the source branch that was the tip of the branch at the time the comment was made.
The full commit ID of the commit in the source branch that was the tip of the branch at the time the comment was made.
An enumeration token that, when provided in a request, returns the next batch of the results.
An enumeration token that, when provided in a request, returns the next batch of the results.
A non-zero, non-negative integer used to limit the number of returned results. The default is 100 comments. You can return up to 500 comments with a single request.
A non-zero, non-negative integer used to limit the number of returned results. The default is 100 comments. You can return up to 500 comments with a single request.
Consumes the builder and constructs a GetCommentsForPullRequestInput