Struct aws_sdk_codecommit::input::get_commit_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for GetCommitInput
Implementations
The name of the repository to which the commit was made.
The name of the repository to which the commit was made.
The commit ID. Commit IDs are the full SHA ID of the commit.
The commit ID. Commit IDs are the full SHA ID of the commit.
Consumes the builder and constructs a GetCommitInput