Struct aws_sdk_codecommit::input::get_merge_commit_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for GetMergeCommitInput
Implementations
The name of the repository that contains the merge commit about which you want to get information.
The name of the repository that contains the merge commit about which you want to get information.
The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
The level of conflict detail to use. If unspecified, the default FILE_LEVEL is used, which returns a not-mergeable result if the same file has differences in both branches. If LINE_LEVEL is specified, a conflict is considered not mergeable if the same file in both branches has differences on the same line.
The level of conflict detail to use. If unspecified, the default FILE_LEVEL is used, which returns a not-mergeable result if the same file has differences in both branches. If LINE_LEVEL is specified, a conflict is considered not mergeable if the same file in both branches has differences on the same line.
Specifies which branch to use when resolving conflicts, or whether to attempt automatically merging two versions of a file. The default is NONE, which requires any conflicts to be resolved manually before the merge operation is successful.
pub fn set_conflict_resolution_strategy(
self,
input: Option<ConflictResolutionStrategyTypeEnum>
) -> Self
pub fn set_conflict_resolution_strategy(
self,
input: Option<ConflictResolutionStrategyTypeEnum>
) -> Self
Specifies which branch to use when resolving conflicts, or whether to attempt automatically merging two versions of a file. The default is NONE, which requires any conflicts to be resolved manually before the merge operation is successful.
Consumes the builder and constructs a GetMergeCommitInput