Struct aws_sdk_codecommit::input::get_pull_request_override_state_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for GetPullRequestOverrideStateInput
Implementations
The ID of the pull request for which you want to get information about whether approval rules have been set aside (overridden).
The ID of the pull request for which you want to get information about whether approval rules have been set aside (overridden).
The system-generated ID of the revision for the pull request. To retrieve the most recent revision ID, use GetPullRequest.
The system-generated ID of the revision for the pull request. To retrieve the most recent revision ID, use GetPullRequest.
Consumes the builder and constructs a GetPullRequestOverrideStateInput