Struct aws_sdk_codecommit::input::list_branches_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for ListBranchesInput
Implementations
The name of the repository that contains the branches.
The name of the repository that contains the branches.
An enumeration token that allows the operation to batch the results.
An enumeration token that allows the operation to batch the results.
Consumes the builder and constructs a ListBranchesInput