Struct aws_sdk_codecommit::input::list_pull_requests_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for ListPullRequestsInput
Implementations
The name of the repository for which you want to list pull requests.
The name of the repository for which you want to list pull requests.
Optional. The Amazon Resource Name (ARN) of the user who created the pull request. If used, this filters the results to pull requests created by that user.
Optional. The Amazon Resource Name (ARN) of the user who created the pull request. If used, this filters the results to pull requests created by that user.
Optional. The status of the pull request. If used, this refines the results to the pull requests that match the specified status.
Optional. The status of the pull request. If used, this refines the results to the pull requests that match the specified status.
An enumeration token that, when provided in a request, returns the next batch of the results.
An enumeration token that, when provided in a request, returns the next batch of the results.
A non-zero, non-negative integer used to limit the number of returned results.
A non-zero, non-negative integer used to limit the number of returned results.
Consumes the builder and constructs a ListPullRequestsInput