Struct aws_sdk_codecommit::input::merge_pull_request_by_squash_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for MergePullRequestBySquashInput
Implementations
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
The name of the repository where the pull request was created.
The name of the repository where the pull request was created.
The full commit ID of the original or updated commit in the pull request source branch. Pass this value if you want an exception thrown if the current commit ID of the tip of the source branch does not match this commit ID.
The full commit ID of the original or updated commit in the pull request source branch. Pass this value if you want an exception thrown if the current commit ID of the tip of the source branch does not match this commit ID.
The level of conflict detail to use. If unspecified, the default FILE_LEVEL is used, which returns a not-mergeable result if the same file has differences in both branches. If LINE_LEVEL is specified, a conflict is considered not mergeable if the same file in both branches has differences on the same line.
The level of conflict detail to use. If unspecified, the default FILE_LEVEL is used, which returns a not-mergeable result if the same file has differences in both branches. If LINE_LEVEL is specified, a conflict is considered not mergeable if the same file in both branches has differences on the same line.
Specifies which branch to use when resolving conflicts, or whether to attempt automatically merging two versions of a file. The default is NONE, which requires any conflicts to be resolved manually before the merge operation is successful.
pub fn set_conflict_resolution_strategy(
self,
input: Option<ConflictResolutionStrategyTypeEnum>
) -> Self
pub fn set_conflict_resolution_strategy(
self,
input: Option<ConflictResolutionStrategyTypeEnum>
) -> Self
Specifies which branch to use when resolving conflicts, or whether to attempt automatically merging two versions of a file. The default is NONE, which requires any conflicts to be resolved manually before the merge operation is successful.
The commit message to include in the commit information for the merge.
The commit message to include in the commit information for the merge.
The name of the author who created the commit. This information is used as both the author and committer for the commit.
The name of the author who created the commit. This information is used as both the author and committer for the commit.
The email address of the person merging the branches. This information is used in the commit information for the merge.
The email address of the person merging the branches. This information is used in the commit information for the merge.
If the commit contains deletions, whether to keep a folder or folder structure if the changes leave the folders empty. If true, a .gitkeep file is created for empty folders. The default is false.
If the commit contains deletions, whether to keep a folder or folder structure if the changes leave the folders empty. If true, a .gitkeep file is created for empty folders. The default is false.
If AUTOMERGE is the conflict resolution strategy, a list of inputs to use when resolving conflicts during a merge.
If AUTOMERGE is the conflict resolution strategy, a list of inputs to use when resolving conflicts during a merge.
Consumes the builder and constructs a MergePullRequestBySquashInput