Struct aws_sdk_codecommit::input::override_pull_request_approval_rules_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for OverridePullRequestApprovalRulesInput
Implementations
The system-generated ID of the pull request for which you want to override all approval rule requirements. To get this information, use GetPullRequest.
The system-generated ID of the pull request for which you want to override all approval rule requirements. To get this information, use GetPullRequest.
The system-generated ID of the most recent revision of the pull request. You cannot override approval rules for anything but the most recent revision of a pull request. To get the revision ID, use GetPullRequest.
The system-generated ID of the most recent revision of the pull request. You cannot override approval rules for anything but the most recent revision of a pull request. To get the revision ID, use GetPullRequest.
Whether you want to set aside approval rule requirements for the pull request (OVERRIDE) or revoke a previous override and apply approval rule requirements (REVOKE). REVOKE status is not stored.
Whether you want to set aside approval rule requirements for the pull request (OVERRIDE) or revoke a previous override and apply approval rule requirements (REVOKE). REVOKE status is not stored.
Consumes the builder and constructs a OverridePullRequestApprovalRulesInput