Struct aws_sdk_codecommit::input::post_comment_for_compared_commit_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for PostCommentForComparedCommitInput
Implementations
The name of the repository where you want to post a comment on the comparison between commits.
The name of the repository where you want to post a comment on the comparison between commits.
To establish the directionality of the comparison, the full commit ID of the before commit. Required for commenting on any commit unless that commit is the initial commit.
To establish the directionality of the comparison, the full commit ID of the before commit. Required for commenting on any commit unless that commit is the initial commit.
To establish the directionality of the comparison, the full commit ID of the after commit.
To establish the directionality of the comparison, the full commit ID of the after commit.
The location of the comparison where you want to comment.
The location of the comparison where you want to comment.
The content of the comment you want to make.
The content of the comment you want to make.
A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
Consumes the builder and constructs a PostCommentForComparedCommitInput