#[non_exhaustive]pub struct Builder { /* private fields */ }Expand description
A builder for PostCommentForPullRequestInput
Implementations
sourceimpl Builder
impl Builder
sourcepub fn pull_request_id(self, input: impl Into<String>) -> Self
pub fn pull_request_id(self, input: impl Into<String>) -> Self
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
sourcepub fn set_pull_request_id(self, input: Option<String>) -> Self
pub fn set_pull_request_id(self, input: Option<String>) -> Self
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
sourcepub fn repository_name(self, input: impl Into<String>) -> Self
pub fn repository_name(self, input: impl Into<String>) -> Self
The name of the repository where you want to post a comment on a pull request.
sourcepub fn set_repository_name(self, input: Option<String>) -> Self
pub fn set_repository_name(self, input: Option<String>) -> Self
The name of the repository where you want to post a comment on a pull request.
sourcepub fn before_commit_id(self, input: impl Into<String>) -> Self
pub fn before_commit_id(self, input: impl Into<String>) -> Self
The full commit ID of the commit in the destination branch that was the tip of the branch at the time the pull request was created.
sourcepub fn set_before_commit_id(self, input: Option<String>) -> Self
pub fn set_before_commit_id(self, input: Option<String>) -> Self
The full commit ID of the commit in the destination branch that was the tip of the branch at the time the pull request was created.
sourcepub fn after_commit_id(self, input: impl Into<String>) -> Self
pub fn after_commit_id(self, input: impl Into<String>) -> Self
The full commit ID of the commit in the source branch that is the current tip of the branch for the pull request when you post the comment.
sourcepub fn set_after_commit_id(self, input: Option<String>) -> Self
pub fn set_after_commit_id(self, input: Option<String>) -> Self
The full commit ID of the commit in the source branch that is the current tip of the branch for the pull request when you post the comment.
sourcepub fn location(self, input: Location) -> Self
pub fn location(self, input: Location) -> Self
The location of the change where you want to post your comment. If no location is provided, the comment is posted as a general comment on the pull request difference between the before commit ID and the after commit ID.
sourcepub fn set_location(self, input: Option<Location>) -> Self
pub fn set_location(self, input: Option<Location>) -> Self
The location of the change where you want to post your comment. If no location is provided, the comment is posted as a general comment on the pull request difference between the before commit ID and the after commit ID.
sourcepub fn content(self, input: impl Into<String>) -> Self
pub fn content(self, input: impl Into<String>) -> Self
The content of your comment on the change.
sourcepub fn set_content(self, input: Option<String>) -> Self
pub fn set_content(self, input: Option<String>) -> Self
The content of your comment on the change.
sourcepub fn client_request_token(self, input: impl Into<String>) -> Self
pub fn client_request_token(self, input: impl Into<String>) -> Self
A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
sourcepub fn set_client_request_token(self, input: Option<String>) -> Self
pub fn set_client_request_token(self, input: Option<String>) -> Self
A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
sourcepub fn build(self) -> Result<PostCommentForPullRequestInput, BuildError>
pub fn build(self) -> Result<PostCommentForPullRequestInput, BuildError>
Consumes the builder and constructs a PostCommentForPullRequestInput