Struct aws_sdk_codecommit::input::put_comment_reaction_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for PutCommentReactionInput
Implementations
The ID of the comment to which you want to add or update a reaction.
The ID of the comment to which you want to add or update a reaction.
The emoji reaction you want to add or update. To remove a reaction, provide a value of blank or null. You can also provide the value of none. For information about emoji reaction values supported in AWS CodeCommit, see the AWS CodeCommit User Guide.
The emoji reaction you want to add or update. To remove a reaction, provide a value of blank or null. You can also provide the value of none. For information about emoji reaction values supported in AWS CodeCommit, see the AWS CodeCommit User Guide.
Consumes the builder and constructs a PutCommentReactionInput