Struct aws_sdk_codecommit::input::BatchAssociateApprovalRuleTemplateWithRepositoriesInput [−][src]
#[non_exhaustive]pub struct BatchAssociateApprovalRuleTemplateWithRepositoriesInput {
pub approval_rule_template_name: Option<String>,
pub repository_names: Option<Vec<String>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.approval_rule_template_name: Option<String>The name of the template you want to associate with one or more repositories.
repository_names: Option<Vec<String>>The names of the repositories you want to associate with the template.
The length constraint limit is for each string in the array. The array itself can be empty.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<BatchAssociateApprovalRuleTemplateWithRepositories, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<BatchAssociateApprovalRuleTemplateWithRepositories, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<BatchAssociateApprovalRuleTemplateWithRepositories>
Creates a new builder-style object to manufacture BatchAssociateApprovalRuleTemplateWithRepositoriesInput