Struct aws_sdk_codecommit::input::BatchGetRepositoriesInput [−][src]
#[non_exhaustive]pub struct BatchGetRepositoriesInput {
pub repository_names: Option<Vec<String>>,
}Expand description
Represents the input of a batch get repositories operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_names: Option<Vec<String>>The names of the repositories to get information about.
The length constraint limit is for each string in the array. The array itself can be empty.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<BatchGetRepositories, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<BatchGetRepositories, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<BatchGetRepositories>
Creates a new builder-style object to manufacture BatchGetRepositoriesInput