Struct aws_sdk_codecommit::input::CreateCommitInput [−][src]
#[non_exhaustive]pub struct CreateCommitInput {
pub repository_name: Option<String>,
pub branch_name: Option<String>,
pub parent_commit_id: Option<String>,
pub author_name: Option<String>,
pub email: Option<String>,
pub commit_message: Option<String>,
pub keep_empty_folders: bool,
pub put_files: Option<Vec<PutFileEntry>>,
pub delete_files: Option<Vec<DeleteFileEntry>>,
pub set_file_modes: Option<Vec<SetFileModeEntry>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository where you create the commit.
branch_name: Option<String>The name of the branch where you create the commit.
parent_commit_id: Option<String>The ID of the commit that is the parent of the commit you create. Not required if this is an empty repository.
The name of the author who created the commit. This information is used as both the author and committer for the commit.
email: Option<String>The email address of the person who created the commit.
commit_message: Option<String>The commit message you want to include in the commit. Commit messages are limited to 256 KB. If no message is specified, a default message is used.
keep_empty_folders: boolIf the commit contains deletions, whether to keep a folder or folder structure if the changes leave the folders empty. If true, a ..gitkeep file is created for empty folders. The default is false.
put_files: Option<Vec<PutFileEntry>>The files to add or update in this commit.
delete_files: Option<Vec<DeleteFileEntry>>The files to delete in this commit. These files still exist in earlier commits.
set_file_modes: Option<Vec<SetFileModeEntry>>The file modes to update for files in this commit.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<CreateCommit, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<CreateCommit, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<CreateCommit>
Creates a new builder-style object to manufacture CreateCommitInput
The name of the repository where you create the commit.
The name of the branch where you create the commit.
The ID of the commit that is the parent of the commit you create. Not required if this is an empty repository.
The name of the author who created the commit. This information is used as both the author and committer for the commit.
The commit message you want to include in the commit. Commit messages are limited to 256 KB. If no message is specified, a default message is used.
If the commit contains deletions, whether to keep a folder or folder structure if the changes leave the folders empty. If true, a ..gitkeep file is created for empty folders. The default is false.
The files to delete in this commit. These files still exist in earlier commits.
The file modes to update for files in this commit.