Struct aws_sdk_codecommit::input::CreatePullRequestInput [−][src]
#[non_exhaustive]pub struct CreatePullRequestInput {
pub title: Option<String>,
pub description: Option<String>,
pub targets: Option<Vec<Target>>,
pub client_request_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.title: Option<String>The title of the pull request. This title is used to identify the pull request to other users in the repository.
description: Option<String>A description of the pull request.
targets: Option<Vec<Target>>The targets for the pull request, including the source of the code to be reviewed (the source branch) and the destination where the creator of the pull request intends the code to be merged after the pull request is closed (the destination branch).
client_request_token: Option<String>A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
The AWS SDKs prepopulate client request tokens. If you are using an AWS SDK, an idempotency token is created for you.
Implementations
pub async fn make_operation(
self,
_config: &Config
) -> Result<Operation<CreatePullRequest, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
self,
_config: &Config
) -> Result<Operation<CreatePullRequest, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<CreatePullRequest>
Creates a new builder-style object to manufacture CreatePullRequestInput
The title of the pull request. This title is used to identify the pull request to other users in the repository.
A description of the pull request.
The targets for the pull request, including the source of the code to be reviewed (the source branch) and the destination where the creator of the pull request intends the code to be merged after the pull request is closed (the destination branch).
A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
The AWS SDKs prepopulate client request tokens. If you are using an AWS SDK, an idempotency token is created for you.