Struct aws_sdk_codecommit::input::CreateRepositoryInput [−][src]
#[non_exhaustive]pub struct CreateRepositoryInput {
pub repository_name: Option<String>,
pub repository_description: Option<String>,
pub tags: Option<HashMap<String, String>>,
}Expand description
Represents the input of a create repository operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the new repository to be created.
The repository name must be unique across the calling AWS account. Repository names are limited to 100 alphanumeric, dash, and underscore characters, and cannot include certain characters. For more information about the limits on repository names, see Limits in the AWS CodeCommit User Guide. The suffix .git is prohibited.
repository_description: Option<String>A comment or description about the new repository.
The description field for a repository accepts all HTML characters and all valid Unicode characters. Applications that do not HTML-encode the description and display it in a webpage can expose users to potentially malicious code. Make sure that you HTML-encode the description field in any application that uses this API to display the repository description on a webpage.
One or more tag key-value pairs to use when tagging this repository.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<CreateRepository, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<CreateRepository, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<CreateRepository>
Creates a new builder-style object to manufacture CreateRepositoryInput