Struct aws_sdk_codecommit::input::CreateUnreferencedMergeCommitInput [−][src]
#[non_exhaustive]pub struct CreateUnreferencedMergeCommitInput {
pub repository_name: Option<String>,
pub source_commit_specifier: Option<String>,
pub destination_commit_specifier: Option<String>,
pub merge_option: Option<MergeOptionTypeEnum>,
pub conflict_detail_level: Option<ConflictDetailLevelTypeEnum>,
pub conflict_resolution_strategy: Option<ConflictResolutionStrategyTypeEnum>,
pub author_name: Option<String>,
pub email: Option<String>,
pub commit_message: Option<String>,
pub keep_empty_folders: bool,
pub conflict_resolution: Option<ConflictResolution>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository where you want to create the unreferenced merge commit.
source_commit_specifier: Option<String>The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
destination_commit_specifier: Option<String>The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
merge_option: Option<MergeOptionTypeEnum>The merge option or strategy you want to use to merge the code.
conflict_detail_level: Option<ConflictDetailLevelTypeEnum>The level of conflict detail to use. If unspecified, the default FILE_LEVEL is used, which returns a not-mergeable result if the same file has differences in both branches. If LINE_LEVEL is specified, a conflict is considered not mergeable if the same file in both branches has differences on the same line.
conflict_resolution_strategy: Option<ConflictResolutionStrategyTypeEnum>Specifies which branch to use when resolving conflicts, or whether to attempt automatically merging two versions of a file. The default is NONE, which requires any conflicts to be resolved manually before the merge operation is successful.
The name of the author who created the unreferenced commit. This information is used as both the author and committer for the commit.
email: Option<String>The email address for the person who created the unreferenced commit.
commit_message: Option<String>The commit message for the unreferenced commit.
keep_empty_folders: boolIf the commit contains deletions, whether to keep a folder or folder structure if the changes leave the folders empty. If this is specified as true, a .gitkeep file is created for empty folders. The default is false.
conflict_resolution: Option<ConflictResolution>If AUTOMERGE is the conflict resolution strategy, a list of inputs to use when resolving conflicts during a merge.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<CreateUnreferencedMergeCommit, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<CreateUnreferencedMergeCommit, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<CreateUnreferencedMergeCommit>
Creates a new builder-style object to manufacture CreateUnreferencedMergeCommitInput