Struct aws_sdk_codecommit::input::DeleteFileInput [−][src]
#[non_exhaustive]pub struct DeleteFileInput {
pub repository_name: Option<String>,
pub branch_name: Option<String>,
pub file_path: Option<String>,
pub parent_commit_id: Option<String>,
pub keep_empty_folders: bool,
pub commit_message: Option<String>,
pub name: Option<String>,
pub email: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository that contains the file to delete.
branch_name: Option<String>The name of the branch where the commit that deletes the file is made.
file_path: Option<String>The fully qualified path to the file that to be deleted, including the full name and extension of that file. For example, /examples/file.md is a fully qualified path to a file named file.md in a folder named examples.
parent_commit_id: Option<String>The ID of the commit that is the tip of the branch where you want to create the commit that deletes the file. This must be the HEAD commit for the branch. The commit that deletes the file is created from this commit ID.
keep_empty_folders: boolIf a file is the only object in the folder or directory, specifies whether to delete the folder or directory that contains the file. By default, empty folders are deleted. This includes empty folders that are part of the directory structure. For example, if the path to a file is dir1/dir2/dir3/dir4, and dir2 and dir3 are empty, deleting the last file in dir4 also deletes the empty folders dir4, dir3, and dir2.
commit_message: Option<String>The commit message you want to include as part of deleting the file. Commit messages are limited to 256 KB. If no message is specified, a default message is used.
name: Option<String>The name of the author of the commit that deletes the file. If no name is specified, the user's ARN is used as the author name and committer name.
email: Option<String>The email address for the commit that deletes the file. If no email address is specified, the email address is left blank.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DeleteFile, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DeleteFile, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<DeleteFile>
Creates a new builder-style object to manufacture DeleteFileInput