Struct aws_sdk_codecommit::input::DeletePullRequestApprovalRuleInput [−][src]
#[non_exhaustive]pub struct DeletePullRequestApprovalRuleInput {
pub pull_request_id: Option<String>,
pub approval_rule_name: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pull_request_id: Option<String>The system-generated ID of the pull request that contains the approval rule you want to delete.
approval_rule_name: Option<String>The name of the approval rule you want to delete.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DeletePullRequestApprovalRule, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DeletePullRequestApprovalRule, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<DeletePullRequestApprovalRule>
Creates a new builder-style object to manufacture DeletePullRequestApprovalRuleInput
The system-generated ID of the pull request that contains the approval rule you want to delete.
The name of the approval rule you want to delete.