Struct aws_sdk_codecommit::input::DescribeMergeConflictsInput [−][src]
#[non_exhaustive]pub struct DescribeMergeConflictsInput {
pub repository_name: Option<String>,
pub destination_commit_specifier: Option<String>,
pub source_commit_specifier: Option<String>,
pub merge_option: Option<MergeOptionTypeEnum>,
pub max_merge_hunks: Option<i32>,
pub file_path: Option<String>,
pub conflict_detail_level: Option<ConflictDetailLevelTypeEnum>,
pub conflict_resolution_strategy: Option<ConflictResolutionStrategyTypeEnum>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository where you want to get information about a merge conflict.
destination_commit_specifier: Option<String>The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
source_commit_specifier: Option<String>The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
merge_option: Option<MergeOptionTypeEnum>The merge option or strategy you want to use to merge the code.
max_merge_hunks: Option<i32>The maximum number of merge hunks to include in the output.
file_path: Option<String>The path of the target files used to describe the conflicts.
conflict_detail_level: Option<ConflictDetailLevelTypeEnum>The level of conflict detail to use. If unspecified, the default FILE_LEVEL is used, which returns a not-mergeable result if the same file has differences in both branches. If LINE_LEVEL is specified, a conflict is considered not mergeable if the same file in both branches has differences on the same line.
conflict_resolution_strategy: Option<ConflictResolutionStrategyTypeEnum>Specifies which branch to use when resolving conflicts, or whether to attempt automatically merging two versions of a file. The default is NONE, which requires any conflicts to be resolved manually before the merge operation is successful.
next_token: Option<String>An enumeration token that, when provided in a request, returns the next batch of the results.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DescribeMergeConflicts, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DescribeMergeConflicts, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<DescribeMergeConflicts>
Creates a new builder-style object to manufacture DescribeMergeConflictsInput