Struct aws_sdk_codecommit::input::DescribePullRequestEventsInput [−][src]
#[non_exhaustive]pub struct DescribePullRequestEventsInput {
pub pull_request_id: Option<String>,
pub pull_request_event_type: Option<PullRequestEventType>,
pub actor_arn: Option<String>,
pub next_token: Option<String>,
pub max_results: Option<i32>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pull_request_id: Option<String>The system-generated ID of the pull request. To get this ID, use ListPullRequests.
pull_request_event_type: Option<PullRequestEventType>Optional. The pull request event type about which you want to return information.
actor_arn: Option<String>The Amazon Resource Name (ARN) of the user whose actions resulted in the event. Examples include updating the pull request with more commits or changing the status of a pull request.
next_token: Option<String>An enumeration token that, when provided in a request, returns the next batch of the results.
max_results: Option<i32>A non-zero, non-negative integer used to limit the number of returned results. The default is 100 events, which is also the maximum number of events that can be returned in a result.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DescribePullRequestEvents, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<DescribePullRequestEvents, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<DescribePullRequestEvents>
Creates a new builder-style object to manufacture DescribePullRequestEventsInput