Struct aws_sdk_codecommit::input::GetApprovalRuleTemplateInput [−][src]
#[non_exhaustive]pub struct GetApprovalRuleTemplateInput {
pub approval_rule_template_name: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.approval_rule_template_name: Option<String>The name of the approval rule template for which you want to get information.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetApprovalRuleTemplate, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetApprovalRuleTemplate, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<GetApprovalRuleTemplate>
Creates a new builder-style object to manufacture GetApprovalRuleTemplateInput
The name of the approval rule template for which you want to get information.