Struct aws_sdk_codecommit::input::GetBranchInput [−][src]
#[non_exhaustive]pub struct GetBranchInput {
pub repository_name: Option<String>,
pub branch_name: Option<String>,
}Expand description
Represents the input of a get branch operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository that contains the branch for which you want to retrieve information.
branch_name: Option<String>The name of the branch for which you want to retrieve information.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetBranch, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetBranch, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<GetBranch>
Creates a new builder-style object to manufacture GetBranchInput
The name of the repository that contains the branch for which you want to retrieve information.
The name of the branch for which you want to retrieve information.