Struct aws_sdk_codecommit::input::GetCommentsForComparedCommitInput [−][src]
#[non_exhaustive]pub struct GetCommentsForComparedCommitInput {
pub repository_name: Option<String>,
pub before_commit_id: Option<String>,
pub after_commit_id: Option<String>,
pub next_token: Option<String>,
pub max_results: Option<i32>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository where you want to compare commits.
before_commit_id: Option<String>To establish the directionality of the comparison, the full commit ID of the before commit.
after_commit_id: Option<String>To establish the directionality of the comparison, the full commit ID of the after commit.
next_token: Option<String>An enumeration token that when provided in a request, returns the next batch of the results.
max_results: Option<i32>A non-zero, non-negative integer used to limit the number of returned results. The default is 100 comments, but you can configure up to 500.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetCommentsForComparedCommit, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetCommentsForComparedCommit, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<GetCommentsForComparedCommit>
Creates a new builder-style object to manufacture GetCommentsForComparedCommitInput
The name of the repository where you want to compare commits.
To establish the directionality of the comparison, the full commit ID of the before commit.
To establish the directionality of the comparison, the full commit ID of the after commit.
An enumeration token that when provided in a request, returns the next batch of the results.
A non-zero, non-negative integer used to limit the number of returned results. The default is 100 comments, but you can configure up to 500.