Struct aws_sdk_codecommit::input::GetCommentsForPullRequestInput [−][src]
#[non_exhaustive]pub struct GetCommentsForPullRequestInput {
pub pull_request_id: Option<String>,
pub repository_name: Option<String>,
pub before_commit_id: Option<String>,
pub after_commit_id: Option<String>,
pub next_token: Option<String>,
pub max_results: Option<i32>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pull_request_id: Option<String>The system-generated ID of the pull request. To get this ID, use ListPullRequests.
repository_name: Option<String>The name of the repository that contains the pull request.
before_commit_id: Option<String>The full commit ID of the commit in the destination branch that was the tip of the branch at the time the pull request was created.
after_commit_id: Option<String>The full commit ID of the commit in the source branch that was the tip of the branch at the time the comment was made.
next_token: Option<String>An enumeration token that, when provided in a request, returns the next batch of the results.
max_results: Option<i32>A non-zero, non-negative integer used to limit the number of returned results. The default is 100 comments. You can return up to 500 comments with a single request.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetCommentsForPullRequest, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetCommentsForPullRequest, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<GetCommentsForPullRequest>
Creates a new builder-style object to manufacture GetCommentsForPullRequestInput
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
The name of the repository that contains the pull request.
The full commit ID of the commit in the destination branch that was the tip of the branch at the time the pull request was created.
The full commit ID of the commit in the source branch that was the tip of the branch at the time the comment was made.
An enumeration token that, when provided in a request, returns the next batch of the results.
A non-zero, non-negative integer used to limit the number of returned results. The default is 100 comments. You can return up to 500 comments with a single request.