Struct aws_sdk_codecommit::input::GetDifferencesInput [−][src]
#[non_exhaustive]pub struct GetDifferencesInput {
pub repository_name: Option<String>,
pub before_commit_specifier: Option<String>,
pub after_commit_specifier: Option<String>,
pub before_path: Option<String>,
pub after_path: Option<String>,
pub max_results: Option<i32>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository where you want to get differences.
before_commit_specifier: Option<String>The branch, tag, HEAD, or other fully qualified reference used to identify a commit
(for example, the full commit ID). Optional. If not specified, all changes before the
afterCommitSpecifier value are shown. If you do not use
beforeCommitSpecifier in your request, consider limiting the results
with maxResults.
after_commit_specifier: Option<String>The branch, tag, HEAD, or other fully qualified reference used to identify a commit.
before_path: Option<String>The file path in which to check for differences. Limits the results to this path. Can
also be used to specify the previous name of a directory or folder. If
beforePath and afterPath are not specified, differences
are shown for all paths.
after_path: Option<String>The file path in which to check differences. Limits the results to this path. Can also be used to specify the changed name of a directory or folder, if it has changed. If not specified, differences are shown for all paths.
max_results: Option<i32>A non-zero, non-negative integer used to limit the number of returned results.
next_token: Option<String>An enumeration token that, when provided in a request, returns the next batch of the results.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetDifferences, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetDifferences, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<GetDifferences>
Creates a new builder-style object to manufacture GetDifferencesInput
The name of the repository where you want to get differences.
The branch, tag, HEAD, or other fully qualified reference used to identify a commit
(for example, the full commit ID). Optional. If not specified, all changes before the
afterCommitSpecifier value are shown. If you do not use
beforeCommitSpecifier in your request, consider limiting the results
with maxResults.
The branch, tag, HEAD, or other fully qualified reference used to identify a commit.
The file path in which to check for differences. Limits the results to this path. Can
also be used to specify the previous name of a directory or folder. If
beforePath and afterPath are not specified, differences
are shown for all paths.
The file path in which to check differences. Limits the results to this path. Can also be used to specify the changed name of a directory or folder, if it has changed. If not specified, differences are shown for all paths.
A non-zero, non-negative integer used to limit the number of returned results.
An enumeration token that, when provided in a request, returns the next batch of the results.