Struct aws_sdk_codecommit::input::GetFileInput [−][src]
#[non_exhaustive]pub struct GetFileInput {
pub repository_name: Option<String>,
pub commit_specifier: Option<String>,
pub file_path: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository that contains the file.
commit_specifier: Option<String>The fully quaified reference that identifies the commit that contains the file. For example, you can specify a full commit ID, a tag, a branch name, or a reference such as refs/heads/master. If none is provided, the head commit is used.
file_path: Option<String>The fully qualified path to the file, including the full name and extension of the file. For example, /examples/file.md is the fully qualified path to a file named file.md in a folder named examples.
Implementations
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetFile, AwsErrorRetryPolicy>, BuildError>
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetFile, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<GetFile>
Creates a new builder-style object to manufacture GetFileInput