Struct aws_sdk_codecommit::input::GetFolderInput [−][src]
#[non_exhaustive]pub struct GetFolderInput {
pub repository_name: Option<String>,
pub commit_specifier: Option<String>,
pub folder_path: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository.
commit_specifier: Option<String>A fully qualified reference used to identify a commit that contains the version of the folder's content to return. A fully qualified reference can be a commit ID, branch name, tag, or reference such as HEAD. If no specifier is provided, the folder content is returned as it exists in the HEAD commit.
folder_path: Option<String>The fully qualified path to the folder whose contents are returned, including the folder name. For example, /examples is a fully-qualified path to a folder named examples that was created off of the root directory (/) of a repository.
Implementations
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetFolder, AwsErrorRetryPolicy>, BuildError>
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetFolder, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<GetFolder>
Creates a new builder-style object to manufacture GetFolderInput