Struct aws_sdk_codecommit::input::GetMergeCommitInput [−][src]
#[non_exhaustive]pub struct GetMergeCommitInput {
pub repository_name: Option<String>,
pub source_commit_specifier: Option<String>,
pub destination_commit_specifier: Option<String>,
pub conflict_detail_level: Option<ConflictDetailLevelTypeEnum>,
pub conflict_resolution_strategy: Option<ConflictResolutionStrategyTypeEnum>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository that contains the merge commit about which you want to get information.
source_commit_specifier: Option<String>The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
destination_commit_specifier: Option<String>The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
conflict_detail_level: Option<ConflictDetailLevelTypeEnum>The level of conflict detail to use. If unspecified, the default FILE_LEVEL is used, which returns a not-mergeable result if the same file has differences in both branches. If LINE_LEVEL is specified, a conflict is considered not mergeable if the same file in both branches has differences on the same line.
conflict_resolution_strategy: Option<ConflictResolutionStrategyTypeEnum>Specifies which branch to use when resolving conflicts, or whether to attempt automatically merging two versions of a file. The default is NONE, which requires any conflicts to be resolved manually before the merge operation is successful.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetMergeCommit, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetMergeCommit, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<GetMergeCommit>
Creates a new builder-style object to manufacture GetMergeCommitInput