Struct aws_sdk_codecommit::input::GetPullRequestOverrideStateInput [−][src]
#[non_exhaustive]pub struct GetPullRequestOverrideStateInput {
pub pull_request_id: Option<String>,
pub revision_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pull_request_id: Option<String>The ID of the pull request for which you want to get information about whether approval rules have been set aside (overridden).
revision_id: Option<String>The system-generated ID of the revision for the pull request. To retrieve the most recent revision ID, use GetPullRequest.
Implementations
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetPullRequestOverrideState, AwsErrorRetryPolicy>, BuildError>
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<GetPullRequestOverrideState, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<GetPullRequestOverrideState>
Creates a new builder-style object to manufacture GetPullRequestOverrideStateInput