Struct aws_sdk_codecommit::input::ListApprovalRuleTemplatesInput [−][src]
#[non_exhaustive]pub struct ListApprovalRuleTemplatesInput {
pub next_token: Option<String>,
pub max_results: Option<i32>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_token: Option<String>An enumeration token that, when provided in a request, returns the next batch of the results.
max_results: Option<i32>A non-zero, non-negative integer used to limit the number of returned results.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListApprovalRuleTemplates, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListApprovalRuleTemplates, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<ListApprovalRuleTemplates>
Creates a new builder-style object to manufacture ListApprovalRuleTemplatesInput
An enumeration token that, when provided in a request, returns the next batch of the results.
A non-zero, non-negative integer used to limit the number of returned results.