Struct aws_sdk_codecommit::input::ListBranchesInput [−][src]
#[non_exhaustive]pub struct ListBranchesInput {
pub repository_name: Option<String>,
pub next_token: Option<String>,
}Expand description
Represents the input of a list branches operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository that contains the branches.
next_token: Option<String>An enumeration token that allows the operation to batch the results.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListBranches, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListBranches, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<ListBranches>
Creates a new builder-style object to manufacture ListBranchesInput