Struct aws_sdk_codecommit::input::ListPullRequestsInput [−][src]
#[non_exhaustive]pub struct ListPullRequestsInput {
pub repository_name: Option<String>,
pub author_arn: Option<String>,
pub pull_request_status: Option<PullRequestStatusEnum>,
pub next_token: Option<String>,
pub max_results: Option<i32>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository for which you want to list pull requests.
Optional. The Amazon Resource Name (ARN) of the user who created the pull request. If used, this filters the results to pull requests created by that user.
pull_request_status: Option<PullRequestStatusEnum>Optional. The status of the pull request. If used, this refines the results to the pull requests that match the specified status.
next_token: Option<String>An enumeration token that, when provided in a request, returns the next batch of the results.
max_results: Option<i32>A non-zero, non-negative integer used to limit the number of returned results.
Implementations
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListPullRequests, AwsErrorRetryPolicy>, BuildError>
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListPullRequests, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<ListPullRequests>
Creates a new builder-style object to manufacture ListPullRequestsInput