Struct aws_sdk_codecommit::input::ListRepositoriesInput [−][src]
#[non_exhaustive]pub struct ListRepositoriesInput {
pub next_token: Option<String>,
pub sort_by: Option<SortByEnum>,
pub order: Option<OrderEnum>,
}Expand description
Represents the input of a list repositories operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.next_token: Option<String>An enumeration token that allows the operation to batch the results of the operation. Batch sizes are 1,000 for list repository operations. When the client sends the token back to AWS CodeCommit, another page of 1,000 records is retrieved.
sort_by: Option<SortByEnum>The criteria used to sort the results of a list repositories operation.
order: Option<OrderEnum>The order in which to sort the results of a list repositories operation.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListRepositories, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListRepositories, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<ListRepositories>
Creates a new builder-style object to manufacture ListRepositoriesInput
An enumeration token that allows the operation to batch the results of the operation. Batch sizes are 1,000 for list repository operations. When the client sends the token back to AWS CodeCommit, another page of 1,000 records is retrieved.
The criteria used to sort the results of a list repositories operation.