Struct aws_sdk_codecommit::input::MergeBranchesByFastForwardInput [−][src]
#[non_exhaustive]pub struct MergeBranchesByFastForwardInput {
pub repository_name: Option<String>,
pub source_commit_specifier: Option<String>,
pub destination_commit_specifier: Option<String>,
pub target_branch: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository where you want to merge two branches.
source_commit_specifier: Option<String>The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
destination_commit_specifier: Option<String>The branch, tag, HEAD, or other fully qualified reference used to identify a commit (for example, a branch name or a full commit ID).
target_branch: Option<String>The branch where the merge is applied.
Implementations
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<MergeBranchesByFastForward, AwsErrorRetryPolicy>, BuildError>
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<MergeBranchesByFastForward, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<MergeBranchesByFastForward>
Creates a new builder-style object to manufacture MergeBranchesByFastForwardInput