Struct aws_sdk_codecommit::input::MergePullRequestByFastForwardInput [−][src]
#[non_exhaustive]pub struct MergePullRequestByFastForwardInput {
pub pull_request_id: Option<String>,
pub repository_name: Option<String>,
pub source_commit_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pull_request_id: Option<String>The system-generated ID of the pull request. To get this ID, use ListPullRequests.
repository_name: Option<String>The name of the repository where the pull request was created.
source_commit_id: Option<String>The full commit ID of the original or updated commit in the pull request source branch. Pass this value if you want an exception thrown if the current commit ID of the tip of the source branch does not match this commit ID.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<MergePullRequestByFastForward, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<MergePullRequestByFastForward, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<MergePullRequestByFastForward>
Creates a new builder-style object to manufacture MergePullRequestByFastForwardInput