Struct aws_sdk_codecommit::input::MergePullRequestBySquashInput [−][src]
#[non_exhaustive]pub struct MergePullRequestBySquashInput {
pub pull_request_id: Option<String>,
pub repository_name: Option<String>,
pub source_commit_id: Option<String>,
pub conflict_detail_level: Option<ConflictDetailLevelTypeEnum>,
pub conflict_resolution_strategy: Option<ConflictResolutionStrategyTypeEnum>,
pub commit_message: Option<String>,
pub author_name: Option<String>,
pub email: Option<String>,
pub keep_empty_folders: bool,
pub conflict_resolution: Option<ConflictResolution>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pull_request_id: Option<String>The system-generated ID of the pull request. To get this ID, use ListPullRequests.
repository_name: Option<String>The name of the repository where the pull request was created.
source_commit_id: Option<String>The full commit ID of the original or updated commit in the pull request source branch. Pass this value if you want an exception thrown if the current commit ID of the tip of the source branch does not match this commit ID.
conflict_detail_level: Option<ConflictDetailLevelTypeEnum>The level of conflict detail to use. If unspecified, the default FILE_LEVEL is used, which returns a not-mergeable result if the same file has differences in both branches. If LINE_LEVEL is specified, a conflict is considered not mergeable if the same file in both branches has differences on the same line.
conflict_resolution_strategy: Option<ConflictResolutionStrategyTypeEnum>Specifies which branch to use when resolving conflicts, or whether to attempt automatically merging two versions of a file. The default is NONE, which requires any conflicts to be resolved manually before the merge operation is successful.
commit_message: Option<String>The commit message to include in the commit information for the merge.
The name of the author who created the commit. This information is used as both the author and committer for the commit.
email: Option<String>The email address of the person merging the branches. This information is used in the commit information for the merge.
keep_empty_folders: boolIf the commit contains deletions, whether to keep a folder or folder structure if the changes leave the folders empty. If true, a .gitkeep file is created for empty folders. The default is false.
conflict_resolution: Option<ConflictResolution>If AUTOMERGE is the conflict resolution strategy, a list of inputs to use when resolving conflicts during a merge.
Implementations
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<MergePullRequestBySquash, AwsErrorRetryPolicy>, BuildError>
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<MergePullRequestBySquash, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<MergePullRequestBySquash>
Creates a new builder-style object to manufacture MergePullRequestBySquashInput