Struct aws_sdk_codecommit::input::OverridePullRequestApprovalRulesInput [−][src]
#[non_exhaustive]pub struct OverridePullRequestApprovalRulesInput {
pub pull_request_id: Option<String>,
pub revision_id: Option<String>,
pub override_status: Option<OverrideStatus>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pull_request_id: Option<String>The system-generated ID of the pull request for which you want to override all approval rule requirements. To get this information, use GetPullRequest.
revision_id: Option<String>The system-generated ID of the most recent revision of the pull request. You cannot override approval rules for anything but the most recent revision of a pull request. To get the revision ID, use GetPullRequest.
override_status: Option<OverrideStatus>Whether you want to set aside approval rule requirements for the pull request (OVERRIDE) or revoke a previous override and apply approval rule requirements (REVOKE). REVOKE status is not stored.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<OverridePullRequestApprovalRules, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<OverridePullRequestApprovalRules, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<OverridePullRequestApprovalRules>
Creates a new builder-style object to manufacture OverridePullRequestApprovalRulesInput