Struct aws_sdk_codecommit::input::PostCommentForComparedCommitInput [−][src]
#[non_exhaustive]pub struct PostCommentForComparedCommitInput {
pub repository_name: Option<String>,
pub before_commit_id: Option<String>,
pub after_commit_id: Option<String>,
pub location: Option<Location>,
pub content: Option<String>,
pub client_request_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository where you want to post a comment on the comparison between commits.
before_commit_id: Option<String>To establish the directionality of the comparison, the full commit ID of the before commit. Required for commenting on any commit unless that commit is the initial commit.
after_commit_id: Option<String>To establish the directionality of the comparison, the full commit ID of the after commit.
location: Option<Location>The location of the comparison where you want to comment.
content: Option<String>The content of the comment you want to make.
client_request_token: Option<String>A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
Implementations
pub fn make_operation(
self,
_config: &Config
) -> Result<Operation<PostCommentForComparedCommit, AwsErrorRetryPolicy>, BuildError>
pub fn make_operation(
self,
_config: &Config
) -> Result<Operation<PostCommentForComparedCommit, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<PostCommentForComparedCommit>
Creates a new builder-style object to manufacture PostCommentForComparedCommitInput