Struct aws_sdk_codecommit::input::PostCommentForPullRequestInput [−][src]
#[non_exhaustive]pub struct PostCommentForPullRequestInput {
pub pull_request_id: Option<String>,
pub repository_name: Option<String>,
pub before_commit_id: Option<String>,
pub after_commit_id: Option<String>,
pub location: Option<Location>,
pub content: Option<String>,
pub client_request_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pull_request_id: Option<String>The system-generated ID of the pull request. To get this ID, use ListPullRequests.
repository_name: Option<String>The name of the repository where you want to post a comment on a pull request.
before_commit_id: Option<String>The full commit ID of the commit in the destination branch that was the tip of the branch at the time the pull request was created.
after_commit_id: Option<String>The full commit ID of the commit in the source branch that is the current tip of the branch for the pull request when you post the comment.
location: Option<Location>The location of the change where you want to post your comment. If no location is provided, the comment is posted as a general comment on the pull request difference between the before commit ID and the after commit ID.
content: Option<String>The content of your comment on the change.
client_request_token: Option<String>A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
Implementations
pub fn make_operation(
self,
_config: &Config
) -> Result<Operation<PostCommentForPullRequest, AwsErrorRetryPolicy>, BuildError>
pub fn make_operation(
self,
_config: &Config
) -> Result<Operation<PostCommentForPullRequest, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<PostCommentForPullRequest>
Creates a new builder-style object to manufacture PostCommentForPullRequestInput