Struct aws_sdk_codecommit::input::PostCommentReplyInput [−][src]
#[non_exhaustive]pub struct PostCommentReplyInput {
pub in_reply_to: Option<String>,
pub client_request_token: Option<String>,
pub content: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.in_reply_to: Option<String>The system-generated ID of the comment to which you want to reply. To get this ID, use GetCommentsForComparedCommit or GetCommentsForPullRequest.
client_request_token: Option<String>A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
content: Option<String>The contents of your reply to a comment.
Implementations
pub async fn make_operation(
self,
_config: &Config
) -> Result<Operation<PostCommentReply, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
self,
_config: &Config
) -> Result<Operation<PostCommentReply, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<PostCommentReply>
Creates a new builder-style object to manufacture PostCommentReplyInput
The system-generated ID of the comment to which you want to reply. To get this ID, use GetCommentsForComparedCommit or GetCommentsForPullRequest.
A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.