Struct aws_sdk_codecommit::input::PutCommentReactionInput [−][src]
#[non_exhaustive]pub struct PutCommentReactionInput {
pub comment_id: Option<String>,
pub reaction_value: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.comment_id: Option<String>The ID of the comment to which you want to add or update a reaction.
reaction_value: Option<String>The emoji reaction you want to add or update. To remove a reaction, provide a value of blank or null. You can also provide the value of none. For information about emoji reaction values supported in AWS CodeCommit, see the AWS CodeCommit User Guide.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<PutCommentReaction, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<PutCommentReaction, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<PutCommentReaction>
Creates a new builder-style object to manufacture PutCommentReactionInput
The ID of the comment to which you want to add or update a reaction.
The emoji reaction you want to add or update. To remove a reaction, provide a value of blank or null. You can also provide the value of none. For information about emoji reaction values supported in AWS CodeCommit, see the AWS CodeCommit User Guide.