Struct aws_sdk_codecommit::input::PutFileInput [−][src]
#[non_exhaustive]pub struct PutFileInput {
pub repository_name: Option<String>,
pub branch_name: Option<String>,
pub file_content: Option<Blob>,
pub file_path: Option<String>,
pub file_mode: Option<FileModeTypeEnum>,
pub parent_commit_id: Option<String>,
pub commit_message: Option<String>,
pub name: Option<String>,
pub email: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository where you want to add or update the file.
branch_name: Option<String>The name of the branch where you want to add or update the file. If this is an empty repository, this branch is created.
file_content: Option<Blob>The content of the file, in binary object format.
file_path: Option<String>The name of the file you want to add or update, including the relative path to the file in the repository.
If the path does not currently exist in the repository, the path is created as part of adding the file.
file_mode: Option<FileModeTypeEnum>The file mode permissions of the blob. Valid file mode permissions are listed here.
parent_commit_id: Option<String>The full commit ID of the head commit in the branch where you want to add or update the file. If this is an empty repository, no commit ID is required. If this is not an empty repository, a commit ID is required.
The commit ID must match the ID of the head commit at the time of the operation. Otherwise, an error occurs, and the file is not added or updated.
commit_message: Option<String>A message about why this file was added or updated. Although it is optional, a message makes the commit history for your repository more useful.
name: Option<String>The name of the person adding or updating the file. Although it is optional, a name makes the commit history for your repository more useful.
email: Option<String>An email address for the person adding or updating the file.
Implementations
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<PutFile, AwsErrorRetryPolicy>, BuildError>
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<PutFile, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<PutFile>
Creates a new builder-style object to manufacture PutFileInput