Struct aws_sdk_codecommit::input::TestRepositoryTriggersInput [−][src]
#[non_exhaustive]pub struct TestRepositoryTriggersInput {
pub repository_name: Option<String>,
pub triggers: Option<Vec<RepositoryTrigger>>,
}Expand description
Represents the input of a test repository triggers operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository in which to test the triggers.
triggers: Option<Vec<RepositoryTrigger>>The list of triggers to test.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<TestRepositoryTriggers, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<TestRepositoryTriggers, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<TestRepositoryTriggers>
Creates a new builder-style object to manufacture TestRepositoryTriggersInput
The name of the repository in which to test the triggers.