Struct aws_sdk_codecommit::input::UpdateApprovalRuleTemplateDescriptionInput [−][src]
#[non_exhaustive]pub struct UpdateApprovalRuleTemplateDescriptionInput {
pub approval_rule_template_name: Option<String>,
pub approval_rule_template_description: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.approval_rule_template_name: Option<String>The name of the template for which you want to update the description.
approval_rule_template_description: Option<String>The updated description of the approval rule template.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateApprovalRuleTemplateDescription, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateApprovalRuleTemplateDescription, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<UpdateApprovalRuleTemplateDescription>
Creates a new builder-style object to manufacture UpdateApprovalRuleTemplateDescriptionInput
The name of the template for which you want to update the description.
The updated description of the approval rule template.