Struct aws_sdk_codecommit::input::UpdateDefaultBranchInput [−][src]
#[non_exhaustive]pub struct UpdateDefaultBranchInput {
pub repository_name: Option<String>,
pub default_branch_name: Option<String>,
}Expand description
Represents the input of an update default branch operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository to set or change the default branch for.
default_branch_name: Option<String>The name of the branch to set as the default.
Implementations
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateDefaultBranch, AwsErrorRetryPolicy>, BuildError>
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateDefaultBranch, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<UpdateDefaultBranch>
Creates a new builder-style object to manufacture UpdateDefaultBranchInput