Struct aws_sdk_codecommit::input::UpdatePullRequestDescriptionInput [−][src]
#[non_exhaustive]pub struct UpdatePullRequestDescriptionInput {
pub pull_request_id: Option<String>,
pub description: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pull_request_id: Option<String>The system-generated ID of the pull request. To get this ID, use ListPullRequests.
description: Option<String>The updated content of the description for the pull request. This content replaces the existing description.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdatePullRequestDescription, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdatePullRequestDescription, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<UpdatePullRequestDescription>
Creates a new builder-style object to manufacture UpdatePullRequestDescriptionInput
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
The updated content of the description for the pull request. This content replaces the existing description.