Struct aws_sdk_codecommit::input::UpdatePullRequestStatusInput [−][src]
#[non_exhaustive]pub struct UpdatePullRequestStatusInput {
pub pull_request_id: Option<String>,
pub pull_request_status: Option<PullRequestStatusEnum>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pull_request_id: Option<String>The system-generated ID of the pull request. To get this ID, use ListPullRequests.
pull_request_status: Option<PullRequestStatusEnum>The status of the pull request. The only valid operations are to update the status
from OPEN to OPEN, OPEN to CLOSED or
from CLOSED to CLOSED.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdatePullRequestStatus, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdatePullRequestStatus, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<UpdatePullRequestStatus>
Creates a new builder-style object to manufacture UpdatePullRequestStatusInput
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
The status of the pull request. The only valid operations are to update the status
from OPEN to OPEN, OPEN to CLOSED or
from CLOSED to CLOSED.