Struct aws_sdk_codecommit::input::UpdateRepositoryDescriptionInput [−][src]
#[non_exhaustive]pub struct UpdateRepositoryDescriptionInput {
pub repository_name: Option<String>,
pub repository_description: Option<String>,
}Expand description
Represents the input of an update repository description operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository to set or change the comment or description for.
repository_description: Option<String>The new comment or description for the specified repository. Repository descriptions are limited to 1,000 characters.
Implementations
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateRepositoryDescription, AwsErrorRetryPolicy>, BuildError>
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateRepositoryDescription, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<UpdateRepositoryDescription>
Creates a new builder-style object to manufacture UpdateRepositoryDescriptionInput