Struct aws_sdk_codecommit::input::update_comment_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for UpdateCommentInput
Implementations
The system-generated ID of the comment you want to update. To get this ID, use GetCommentsForComparedCommit or GetCommentsForPullRequest.
The system-generated ID of the comment you want to update. To get this ID, use GetCommentsForComparedCommit or GetCommentsForPullRequest.
The updated content to replace the existing content of the comment.
The updated content to replace the existing content of the comment.
Consumes the builder and constructs a UpdateCommentInput