Struct aws_sdk_codecommit::input::update_default_branch_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for UpdateDefaultBranchInput
Implementations
The name of the repository to set or change the default branch for.
The name of the repository to set or change the default branch for.
The name of the branch to set as the default.
The name of the branch to set as the default.
Consumes the builder and constructs a UpdateDefaultBranchInput