Struct aws_sdk_codecommit::input::update_pull_request_approval_state_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for UpdatePullRequestApprovalStateInput
Implementations
The system-generated ID of the pull request.
The system-generated ID of the pull request.
The system-generated ID of the revision.
The system-generated ID of the revision.
The approval state to associate with the user on the pull request.
The approval state to associate with the user on the pull request.
Consumes the builder and constructs a UpdatePullRequestApprovalStateInput