Struct aws_sdk_codecommit::input::update_pull_request_description_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for UpdatePullRequestDescriptionInput
Implementations
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
The updated content of the description for the pull request. This content replaces the existing description.
The updated content of the description for the pull request. This content replaces the existing description.
Consumes the builder and constructs a UpdatePullRequestDescriptionInput