Struct aws_sdk_codecommit::input::update_pull_request_status_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for UpdatePullRequestStatusInput
Implementations
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
The status of the pull request. The only valid operations are to update the status
from OPEN to OPEN, OPEN to CLOSED or
from CLOSED to CLOSED.
The status of the pull request. The only valid operations are to update the status
from OPEN to OPEN, OPEN to CLOSED or
from CLOSED to CLOSED.
Consumes the builder and constructs a UpdatePullRequestStatusInput