Struct aws_sdk_codecommit::model::batch_get_commits_error::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for BatchGetCommitsError
Implementations
A commit ID that either could not be found or was not in a valid format.
A commit ID that either could not be found or was not in a valid format.
An error code that specifies whether the commit ID was not valid or not found.
An error code that specifies whether the commit ID was not valid or not found.
An error message that provides detail about why the commit ID either was not found or was not valid.
An error message that provides detail about why the commit ID either was not found or was not valid.
Consumes the builder and constructs a BatchGetCommitsError