Struct aws_sdk_codecommit::model::comment::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for Comment
Implementations
The system-generated comment ID.
The system-generated comment ID.
The content of the comment.
The ID of the comment for which this comment is a reply, if any.
The ID of the comment for which this comment is a reply, if any.
The date and time the comment was created, in timestamp format.
The date and time the comment was created, in timestamp format.
The date and time the comment was most recently modified, in timestamp format.
The date and time the comment was most recently modified, in timestamp format.
The Amazon Resource Name (ARN) of the person who posted the comment.
The Amazon Resource Name (ARN) of the person who posted the comment.
A Boolean value indicating whether the comment has been deleted.
A Boolean value indicating whether the comment has been deleted.
A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
Appends an item to caller_reactions.
To override the contents of this collection use set_caller_reactions.
The emoji reactions to a comment, if any, submitted by the user whose credentials are associated with the call to the API.
The emoji reactions to a comment, if any, submitted by the user whose credentials are associated with the call to the API.
Adds a key-value pair to reaction_counts.
To override the contents of this collection use set_reaction_counts.
A string to integer map that represents the number of individual users who have responded to a comment with the specified reactions.
A string to integer map that represents the number of individual users who have responded to a comment with the specified reactions.