Struct aws_sdk_codecommit::model::comments_for_compared_commit::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for CommentsForComparedCommit
Implementations
The name of the repository that contains the compared commits.
The name of the repository that contains the compared commits.
The full commit ID of the commit used to establish the before of the comparison.
The full commit ID of the commit used to establish the before of the comparison.
The full commit ID of the commit used to establish the after of the comparison.
The full commit ID of the commit used to establish the after of the comparison.
The full blob ID of the commit used to establish the before of the comparison.
The full blob ID of the commit used to establish the before of the comparison.
The full blob ID of the commit used to establish the after of the comparison.
The full blob ID of the commit used to establish the after of the comparison.
Location information about the comment on the comparison, including the file name, line number, and whether the version of the file where the comment was made is BEFORE or AFTER.
Location information about the comment on the comparison, including the file name, line number, and whether the version of the file where the comment was made is BEFORE or AFTER.
Appends an item to comments.
To override the contents of this collection use set_comments.
An array of comment objects. Each comment object contains information about a comment on the comparison between commits.
An array of comment objects. Each comment object contains information about a comment on the comparison between commits.
Consumes the builder and constructs a CommentsForComparedCommit