Struct aws_sdk_codecommit::model::commit::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for Commit
Implementations
The full SHA ID of the specified commit.
The full SHA ID of the specified commit.
Tree information for the specified commit.
Tree information for the specified commit.
Appends an item to parents.
To override the contents of this collection use set_parents.
A list of parent commits for the specified commit. Each parent commit ID is the full commit ID.
A list of parent commits for the specified commit. Each parent commit ID is the full commit ID.
The commit message associated with the specified commit.
The commit message associated with the specified commit.
Information about the author of the specified commit. Information includes the date in timestamp format with GMT offset, the name of the author, and the email address for the author, as configured in Git.
Information about the author of the specified commit. Information includes the date in timestamp format with GMT offset, the name of the author, and the email address for the author, as configured in Git.
Information about the person who committed the specified commit, also known as the committer. Information includes the date in timestamp format with GMT offset, the name of the committer, and the email address for the committer, as configured in Git.
For more information about the difference between an author and a committer in Git, see Viewing the Commit History in Pro Git by Scott Chacon and Ben Straub.
Information about the person who committed the specified commit, also known as the committer. Information includes the date in timestamp format with GMT offset, the name of the committer, and the email address for the committer, as configured in Git.
For more information about the difference between an author and a committer in Git, see Viewing the Commit History in Pro Git by Scott Chacon and Ben Straub.
Any other data associated with the specified commit.
Any other data associated with the specified commit.