Struct aws_sdk_codecommit::model::delete_file_entry::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for DeleteFileEntry
Implementations
The full path of the file to be deleted, including the name of the file.
The full path of the file to be deleted, including the name of the file.
Consumes the builder and constructs a DeleteFileEntry