Struct aws_sdk_codecommit::model::difference::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for Difference
Implementations
Information about a beforeBlob data type object, including the ID,
the file mode permission code, and the path.
Information about a beforeBlob data type object, including the ID,
the file mode permission code, and the path.
Information about an afterBlob data type object, including the ID,
the file mode permission code, and the path.
Information about an afterBlob data type object, including the ID,
the file mode permission code, and the path.
Whether the change type of the difference is an addition (A), deletion (D), or modification (M).
Whether the change type of the difference is an addition (A), deletion (D), or modification (M).
Consumes the builder and constructs a Difference