Struct aws_sdk_codecommit::model::evaluation::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for Evaluation
Implementations
Whether the state of the pull request is approved.
Whether the approval rule requirements for the pull request have been overridden and no longer need to be met.
Whether the approval rule requirements for the pull request have been overridden and no longer need to be met.
Appends an item to approval_rules_satisfied.
To override the contents of this collection use set_approval_rules_satisfied.
The names of the approval rules that have had their conditions met.
The names of the approval rules that have had their conditions met.
Appends an item to approval_rules_not_satisfied.
To override the contents of this collection use set_approval_rules_not_satisfied.
The names of the approval rules that have not had their conditions met.
The names of the approval rules that have not had their conditions met.
Consumes the builder and constructs a Evaluation