Struct aws_sdk_codecommit::model::file::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for File
Implementations
The blob ID that contains the file information.
The blob ID that contains the file information.
The fully qualified path to the file in the repository.
The fully qualified path to the file in the repository.
The relative path of the file from the folder where the query originated.
The relative path of the file from the folder where the query originated.
The extrapolated file mode permissions for the file. Valid values include EXECUTABLE and NORMAL.
The extrapolated file mode permissions for the file. Valid values include EXECUTABLE and NORMAL.