Struct aws_sdk_codecommit::model::file_metadata::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for FileMetadata
Implementations
The full path to the file to be added or updated, including the name of the file.
The full path to the file to be added or updated, including the name of the file.
The blob ID that contains the file information.
The blob ID that contains the file information.
The extrapolated file mode permissions for the file. Valid values include EXECUTABLE and NORMAL.
The extrapolated file mode permissions for the file. Valid values include EXECUTABLE and NORMAL.
Consumes the builder and constructs a FileMetadata