Struct aws_sdk_codecommit::model::file_modes::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for FileModes
Implementations
The file mode of a file in the source of a merge or pull request.
The file mode of a file in the source of a merge or pull request.
The file mode of a file in the destination of a merge or pull request.
The file mode of a file in the destination of a merge or pull request.
The file mode of a file in the base of a merge or pull request.
The file mode of a file in the base of a merge or pull request.