Struct aws_sdk_codecommit::model::folder::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for Folder
Implementations
The full SHA-1 pointer of the tree information for the commit that contains the folder.
The full SHA-1 pointer of the tree information for the commit that contains the folder.
The fully qualified path of the folder in the repository.
The fully qualified path of the folder in the repository.
The relative path of the specified folder from the folder where the query originated.
The relative path of the specified folder from the folder where the query originated.