Struct aws_sdk_codecommit::model::is_binary_file::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for IsBinaryFile
Implementations
The binary or non-binary status of file in the source of a merge or pull request.
The binary or non-binary status of file in the source of a merge or pull request.
The binary or non-binary status of a file in the destination of a merge or pull request.
The binary or non-binary status of a file in the destination of a merge or pull request.
The binary or non-binary status of a file in the base of a merge or pull request.
The binary or non-binary status of a file in the base of a merge or pull request.
Consumes the builder and constructs a IsBinaryFile