Struct aws_sdk_codecommit::model::location::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for Location
Implementations
The name of the file being compared, including its extension and subdirectory, if any.
The name of the file being compared, including its extension and subdirectory, if any.
The position of a change in a compared file, in line number format.
The position of a change in a compared file, in line number format.
In a comparison of commits or a pull request, whether the change is in the before or after of that comparison.
In a comparison of commits or a pull request, whether the change is in the before or after of that comparison.