Struct aws_sdk_codecommit::model::pull_request::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for PullRequest
Implementations
The system-generated ID of the pull request.
The system-generated ID of the pull request.
The user-defined title of the pull request. This title is displayed in the list of pull requests to other repository users.
The user-defined title of the pull request. This title is displayed in the list of pull requests to other repository users.
The user-defined description of the pull request. This description can be used to clarify what should be reviewed and other details of the request.
The user-defined description of the pull request. This description can be used to clarify what should be reviewed and other details of the request.
The day and time of the last user or system activity on the pull request, in timestamp format.
The day and time of the last user or system activity on the pull request, in timestamp format.
The date and time the pull request was originally created, in timestamp format.
The date and time the pull request was originally created, in timestamp format.
The status of the pull request. Pull request status can only change from OPEN to CLOSED.
The status of the pull request. Pull request status can only change from OPEN to CLOSED.
The Amazon Resource Name (ARN) of the user who created the pull request.
The Amazon Resource Name (ARN) of the user who created the pull request.
Appends an item to pull_request_targets.
To override the contents of this collection use set_pull_request_targets.
The targets of the pull request, including the source branch and destination branch for the pull request.
The targets of the pull request, including the source branch and destination branch for the pull request.
A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
The system-generated revision ID for the pull request.
The system-generated revision ID for the pull request.
Appends an item to approval_rules.
To override the contents of this collection use set_approval_rules.
The approval rules applied to the pull request.
The approval rules applied to the pull request.
Consumes the builder and constructs a PullRequest