Struct aws_sdk_codecommit::model::pull_request_created_event_metadata::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for PullRequestCreatedEventMetadata
Implementations
The name of the repository where the pull request was created.
The name of the repository where the pull request was created.
The commit ID on the source branch used when the pull request was created.
The commit ID on the source branch used when the pull request was created.
The commit ID of the tip of the branch specified as the destination branch when the pull request was created.
The commit ID of the tip of the branch specified as the destination branch when the pull request was created.
The commit ID of the most recent commit that the source branch and the destination branch have in common.
The commit ID of the most recent commit that the source branch and the destination branch have in common.
Consumes the builder and constructs a PullRequestCreatedEventMetadata