Struct aws_sdk_codecommit::model::pull_request_event::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for PullRequestEvent
Implementations
The system-generated ID of the pull request.
The system-generated ID of the pull request.
The day and time of the pull request event, in timestamp format.
The day and time of the pull request event, in timestamp format.
The type of the pull request event (for example, a status change event (PULL_REQUEST_STATUS_CHANGED) or update event (PULL_REQUEST_SOURCE_REFERENCE_UPDATED)).
The type of the pull request event (for example, a status change event (PULL_REQUEST_STATUS_CHANGED) or update event (PULL_REQUEST_SOURCE_REFERENCE_UPDATED)).
The Amazon Resource Name (ARN) of the user whose actions resulted in the event. Examples include updating the pull request with more commits or changing the status of a pull request.
The Amazon Resource Name (ARN) of the user whose actions resulted in the event. Examples include updating the pull request with more commits or changing the status of a pull request.
pub fn pull_request_created_event_metadata(
self,
input: PullRequestCreatedEventMetadata
) -> Self
pub fn pull_request_created_event_metadata(
self,
input: PullRequestCreatedEventMetadata
) -> Self
Information about the source and destination branches for the pull request.
pub fn set_pull_request_created_event_metadata(
self,
input: Option<PullRequestCreatedEventMetadata>
) -> Self
pub fn set_pull_request_created_event_metadata(
self,
input: Option<PullRequestCreatedEventMetadata>
) -> Self
Information about the source and destination branches for the pull request.
pub fn pull_request_status_changed_event_metadata(
self,
input: PullRequestStatusChangedEventMetadata
) -> Self
pub fn pull_request_status_changed_event_metadata(
self,
input: PullRequestStatusChangedEventMetadata
) -> Self
Information about the change in status for the pull request event.
pub fn set_pull_request_status_changed_event_metadata(
self,
input: Option<PullRequestStatusChangedEventMetadata>
) -> Self
pub fn set_pull_request_status_changed_event_metadata(
self,
input: Option<PullRequestStatusChangedEventMetadata>
) -> Self
Information about the change in status for the pull request event.
pub fn pull_request_source_reference_updated_event_metadata(
self,
input: PullRequestSourceReferenceUpdatedEventMetadata
) -> Self
pub fn pull_request_source_reference_updated_event_metadata(
self,
input: PullRequestSourceReferenceUpdatedEventMetadata
) -> Self
Information about the updated source branch for the pull request event.
pub fn set_pull_request_source_reference_updated_event_metadata(
self,
input: Option<PullRequestSourceReferenceUpdatedEventMetadata>
) -> Self
pub fn set_pull_request_source_reference_updated_event_metadata(
self,
input: Option<PullRequestSourceReferenceUpdatedEventMetadata>
) -> Self
Information about the updated source branch for the pull request event.
pub fn pull_request_merged_state_changed_event_metadata(
self,
input: PullRequestMergedStateChangedEventMetadata
) -> Self
pub fn pull_request_merged_state_changed_event_metadata(
self,
input: PullRequestMergedStateChangedEventMetadata
) -> Self
Information about the change in mergability state for the pull request event.
pub fn set_pull_request_merged_state_changed_event_metadata(
self,
input: Option<PullRequestMergedStateChangedEventMetadata>
) -> Self
pub fn set_pull_request_merged_state_changed_event_metadata(
self,
input: Option<PullRequestMergedStateChangedEventMetadata>
) -> Self
Information about the change in mergability state for the pull request event.
Information about a pull request event.
pub fn set_approval_rule_event_metadata(
self,
input: Option<ApprovalRuleEventMetadata>
) -> Self
pub fn set_approval_rule_event_metadata(
self,
input: Option<ApprovalRuleEventMetadata>
) -> Self
Information about a pull request event.
pub fn approval_state_changed_event_metadata(
self,
input: ApprovalStateChangedEventMetadata
) -> Self
pub fn approval_state_changed_event_metadata(
self,
input: ApprovalStateChangedEventMetadata
) -> Self
Information about an approval state change for a pull request.
pub fn set_approval_state_changed_event_metadata(
self,
input: Option<ApprovalStateChangedEventMetadata>
) -> Self
pub fn set_approval_state_changed_event_metadata(
self,
input: Option<ApprovalStateChangedEventMetadata>
) -> Self
Information about an approval state change for a pull request.
pub fn approval_rule_overridden_event_metadata(
self,
input: ApprovalRuleOverriddenEventMetadata
) -> Self
pub fn approval_rule_overridden_event_metadata(
self,
input: ApprovalRuleOverriddenEventMetadata
) -> Self
Information about an approval rule override event for a pull request.
pub fn set_approval_rule_overridden_event_metadata(
self,
input: Option<ApprovalRuleOverriddenEventMetadata>
) -> Self
pub fn set_approval_rule_overridden_event_metadata(
self,
input: Option<ApprovalRuleOverriddenEventMetadata>
) -> Self
Information about an approval rule override event for a pull request.
Consumes the builder and constructs a PullRequestEvent