Struct aws_sdk_codecommit::model::pull_request_source_reference_updated_event_metadata::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for PullRequestSourceReferenceUpdatedEventMetadata
Implementations
The name of the repository where the pull request was updated.
The name of the repository where the pull request was updated.
The full commit ID of the commit in the destination branch that was the tip of the branch at the time the pull request was updated.
The full commit ID of the commit in the destination branch that was the tip of the branch at the time the pull request was updated.
The full commit ID of the commit in the source branch that was the tip of the branch at the time the pull request was updated.
The full commit ID of the commit in the source branch that was the tip of the branch at the time the pull request was updated.
The commit ID of the most recent commit that the source branch and the destination branch have in common.
The commit ID of the most recent commit that the source branch and the destination branch have in common.
Consumes the builder and constructs a PullRequestSourceReferenceUpdatedEventMetadata