Struct aws_sdk_codecommit::model::pull_request_target::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for PullRequestTarget
Implementations
The name of the repository that contains the pull request source and destination branches.
The name of the repository that contains the pull request source and destination branches.
The branch of the repository that contains the changes for the pull request. Also known as the source branch.
The branch of the repository that contains the changes for the pull request. Also known as the source branch.
The branch of the repository where the pull request changes are merged. Also known as the destination branch.
The branch of the repository where the pull request changes are merged. Also known as the destination branch.
The full commit ID that is the tip of the destination branch. This is the commit where the pull request was or will be merged.
The full commit ID that is the tip of the destination branch. This is the commit where the pull request was or will be merged.
The full commit ID of the tip of the source branch used to create the pull request. If the pull request branch is updated by a push while the pull request is open, the commit ID changes to reflect the new tip of the branch.
The full commit ID of the tip of the source branch used to create the pull request. If the pull request branch is updated by a push while the pull request is open, the commit ID changes to reflect the new tip of the branch.
The commit ID of the most recent commit that the source branch and the destination branch have in common.
The commit ID of the most recent commit that the source branch and the destination branch have in common.
Returns metadata about the state of the merge, including whether the merge has been made.
Returns metadata about the state of the merge, including whether the merge has been made.
Consumes the builder and constructs a PullRequestTarget