Struct aws_sdk_codecommit::model::put_file_entry::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for PutFileEntry
Implementations
The full path to the file in the repository, including the name of the file.
The full path to the file in the repository, including the name of the file.
The extrapolated file mode permissions for the file. Valid values include EXECUTABLE and NORMAL.
The extrapolated file mode permissions for the file. Valid values include EXECUTABLE and NORMAL.
The content of the file, if a source file is not specified.
The content of the file, if a source file is not specified.
The name and full path of the file that contains the changes you want to make as part of the commit, if you are not providing the file content directly.
The name and full path of the file that contains the changes you want to make as part of the commit, if you are not providing the file content directly.
Consumes the builder and constructs a PutFileEntry