Struct aws_sdk_codecommit::model::replace_content_entry::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for ReplaceContentEntry
Implementations
The path of the conflicting file.
The replacement type to use when determining how to resolve the conflict.
The replacement type to use when determining how to resolve the conflict.
The base-64 encoded content to use when the replacement type is USE_NEW_CONTENT.
The base-64 encoded content to use when the replacement type is USE_NEW_CONTENT.
The file mode to apply during conflict resoltion.
The file mode to apply during conflict resoltion.
Consumes the builder and constructs a ReplaceContentEntry