Struct aws_sdk_codecommit::model::repository_trigger::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for RepositoryTrigger
Implementations
The ARN of the resource that is the target for a trigger (for example, the ARN of a topic in Amazon SNS).
The ARN of the resource that is the target for a trigger (for example, the ARN of a topic in Amazon SNS).
Any custom data associated with the trigger to be included in the information sent to the target of the trigger.
Any custom data associated with the trigger to be included in the information sent to the target of the trigger.
Appends an item to branches.
To override the contents of this collection use set_branches.
The branches to be included in the trigger configuration. If you specify an empty array, the trigger applies to all branches.
Although no content is required in the array, you must include the array itself.
The branches to be included in the trigger configuration. If you specify an empty array, the trigger applies to all branches.
Although no content is required in the array, you must include the array itself.
Appends an item to events.
To override the contents of this collection use set_events.
The repository events that cause the trigger to run actions in another service, such as sending a notification through Amazon SNS.
The valid value "all" cannot be used with any other values.
The repository events that cause the trigger to run actions in another service, such as sending a notification through Amazon SNS.
The valid value "all" cannot be used with any other values.
Consumes the builder and constructs a RepositoryTrigger