Struct aws_sdk_codecommit::model::repository_trigger_execution_failure::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for RepositoryTriggerExecutionFailure
Implementations
The name of the trigger that did not run.
The name of the trigger that did not run.
Message information about the trigger that did not run.
Message information about the trigger that did not run.
Consumes the builder and constructs a RepositoryTriggerExecutionFailure