Struct aws_sdk_codecommit::model::source_file_specifier::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for SourceFileSpecifier
Implementations
The full path to the file, including the name of the file.
The full path to the file, including the name of the file.
Whether to remove the source file from the parent commit.
Whether to remove the source file from the parent commit.
Consumes the builder and constructs a SourceFileSpecifier