Struct aws_sdk_codecommit::model::ApprovalRule [−][src]
#[non_exhaustive]pub struct ApprovalRule {
pub approval_rule_id: Option<String>,
pub approval_rule_name: Option<String>,
pub approval_rule_content: Option<String>,
pub rule_content_sha256: Option<String>,
pub last_modified_date: Option<DateTime>,
pub creation_date: Option<DateTime>,
pub last_modified_user: Option<String>,
pub origin_approval_rule_template: Option<OriginApprovalRuleTemplate>,
}Expand description
Returns information about an approval rule.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.approval_rule_id: Option<String>The system-generated ID of the approval rule.
approval_rule_name: Option<String>The name of the approval rule.
approval_rule_content: Option<String>The content of the approval rule.
rule_content_sha256: Option<String>The SHA-256 hash signature for the content of the approval rule.
last_modified_date: Option<DateTime>The date the approval rule was most recently changed, in timestamp format.
creation_date: Option<DateTime>The date the approval rule was created, in timestamp format.
last_modified_user: Option<String>The Amazon Resource Name (ARN) of the user who made the most recent changes to the approval rule.
origin_approval_rule_template: Option<OriginApprovalRuleTemplate>The approval rule template used to create the rule.
Implementations
The system-generated ID of the approval rule.
The name of the approval rule.
The content of the approval rule.
The SHA-256 hash signature for the content of the approval rule.
The date the approval rule was most recently changed, in timestamp format.
The date the approval rule was created, in timestamp format.
The Amazon Resource Name (ARN) of the user who made the most recent changes to the approval rule.
The approval rule template used to create the rule.
Creates a new builder-style object to manufacture ApprovalRule