Struct aws_sdk_codecommit::model::ApprovalRuleOverriddenEventMetadata [−][src]
#[non_exhaustive]pub struct ApprovalRuleOverriddenEventMetadata {
pub revision_id: Option<String>,
pub override_status: Option<OverrideStatus>,
}Expand description
Returns information about an override event for approval rules for a pull request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.revision_id: Option<String>The revision ID of the pull request when the override event occurred.
override_status: Option<OverrideStatus>The status of the override event.
Implementations
The revision ID of the pull request when the override event occurred.
The status of the override event.
Creates a new builder-style object to manufacture ApprovalRuleOverriddenEventMetadata