Struct aws_sdk_codecommit::model::ApprovalRuleTemplate [−][src]
#[non_exhaustive]pub struct ApprovalRuleTemplate {
pub approval_rule_template_id: Option<String>,
pub approval_rule_template_name: Option<String>,
pub approval_rule_template_description: Option<String>,
pub approval_rule_template_content: Option<String>,
pub rule_content_sha256: Option<String>,
pub last_modified_date: Option<DateTime>,
pub creation_date: Option<DateTime>,
pub last_modified_user: Option<String>,
}Expand description
Returns information about an approval rule template.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.approval_rule_template_id: Option<String>The system-generated ID of the approval rule template.
approval_rule_template_name: Option<String>The name of the approval rule template.
approval_rule_template_description: Option<String>The description of the approval rule template.
approval_rule_template_content: Option<String>The content of the approval rule template.
rule_content_sha256: Option<String>The SHA-256 hash signature for the content of the approval rule template.
last_modified_date: Option<DateTime>The date the approval rule template was most recently changed, in timestamp format.
creation_date: Option<DateTime>The date the approval rule template was created, in timestamp format.
last_modified_user: Option<String>The Amazon Resource Name (ARN) of the user who made the most recent changes to the approval rule template.
Implementations
The system-generated ID of the approval rule template.
The name of the approval rule template.
The description of the approval rule template.
The content of the approval rule template.
The SHA-256 hash signature for the content of the approval rule template.
The date the approval rule template was most recently changed, in timestamp format.
The date the approval rule template was created, in timestamp format.
The Amazon Resource Name (ARN) of the user who made the most recent changes to the approval rule template.
Creates a new builder-style object to manufacture ApprovalRuleTemplate