Struct aws_sdk_codecommit::model::BatchGetCommitsError [−][src]
#[non_exhaustive]pub struct BatchGetCommitsError {
pub commit_id: Option<String>,
pub error_code: Option<String>,
pub error_message: Option<String>,
}Expand description
Returns information about errors in a BatchGetCommits operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.commit_id: Option<String>A commit ID that either could not be found or was not in a valid format.
error_code: Option<String>An error code that specifies whether the commit ID was not valid or not found.
error_message: Option<String>An error message that provides detail about why the commit ID either was not found or was not valid.
Implementations
A commit ID that either could not be found or was not in a valid format.
An error code that specifies whether the commit ID was not valid or not found.
An error message that provides detail about why the commit ID either was not found or was not valid.
Creates a new builder-style object to manufacture BatchGetCommitsError