Struct aws_sdk_codecommit::model::CommentsForComparedCommit [−][src]
#[non_exhaustive]pub struct CommentsForComparedCommit {
pub repository_name: Option<String>,
pub before_commit_id: Option<String>,
pub after_commit_id: Option<String>,
pub before_blob_id: Option<String>,
pub after_blob_id: Option<String>,
pub location: Option<Location>,
pub comments: Option<Vec<Comment>>,
}Expand description
Returns information about comments on the comparison between two commits.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository that contains the compared commits.
before_commit_id: Option<String>The full commit ID of the commit used to establish the before of the comparison.
after_commit_id: Option<String>The full commit ID of the commit used to establish the after of the comparison.
before_blob_id: Option<String>The full blob ID of the commit used to establish the before of the comparison.
after_blob_id: Option<String>The full blob ID of the commit used to establish the after of the comparison.
location: Option<Location>Location information about the comment on the comparison, including the file name, line number, and whether the version of the file where the comment was made is BEFORE or AFTER.
comments: Option<Vec<Comment>>An array of comment objects. Each comment object contains information about a comment on the comparison between commits.
Implementations
The name of the repository that contains the compared commits.
The full commit ID of the commit used to establish the before of the comparison.
The full commit ID of the commit used to establish the after of the comparison.
The full blob ID of the commit used to establish the before of the comparison.
The full blob ID of the commit used to establish the after of the comparison.
Location information about the comment on the comparison, including the file name, line number, and whether the version of the file where the comment was made is BEFORE or AFTER.
Creates a new builder-style object to manufacture CommentsForComparedCommit