Struct aws_sdk_codecommit::model::CommentsForPullRequest [−][src]
#[non_exhaustive]pub struct CommentsForPullRequest {
pub pull_request_id: Option<String>,
pub repository_name: Option<String>,
pub before_commit_id: Option<String>,
pub after_commit_id: Option<String>,
pub before_blob_id: Option<String>,
pub after_blob_id: Option<String>,
pub location: Option<Location>,
pub comments: Option<Vec<Comment>>,
}Expand description
Returns information about comments on a pull request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pull_request_id: Option<String>The system-generated ID of the pull request.
repository_name: Option<String>The name of the repository that contains the pull request.
before_commit_id: Option<String>The full commit ID of the commit that was the tip of the destination branch when the pull request was created. This commit is superceded by the after commit in the source branch when and if you merge the source branch into the destination branch.
after_commit_id: Option<String>The full commit ID of the commit that was the tip of the source branch at the time the comment was made.
before_blob_id: Option<String>The full blob ID of the file on which you want to comment on the destination commit.
after_blob_id: Option<String>The full blob ID of the file on which you want to comment on the source commit.
location: Option<Location>Location information about the comment on the pull request, including the file name, line number, and whether the version of the file where the comment was made is BEFORE (destination branch) or AFTER (source branch).
comments: Option<Vec<Comment>>An array of comment objects. Each comment object contains information about a comment on the pull request.
Implementations
Creates a new builder-style object to manufacture CommentsForPullRequest