Struct aws_sdk_codecommit::model::ConflictMetadata [−][src]
#[non_exhaustive]pub struct ConflictMetadata {
pub file_path: Option<String>,
pub file_sizes: Option<FileSizes>,
pub file_modes: Option<FileModes>,
pub object_types: Option<ObjectTypes>,
pub number_of_conflicts: i32,
pub is_binary_file: Option<IsBinaryFile>,
pub content_conflict: bool,
pub file_mode_conflict: bool,
pub object_type_conflict: bool,
pub merge_operations: Option<MergeOperations>,
}Expand description
Information about the metadata for a conflict in a merge operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.file_path: Option<String>The path of the file that contains conflicts.
file_sizes: Option<FileSizes>The file sizes of the file in the source, destination, and base of the merge.
file_modes: Option<FileModes>The file modes of the file in the source, destination, and base of the merge.
object_types: Option<ObjectTypes>Information about any object type conflicts in a merge operation.
number_of_conflicts: i32The number of conflicts, including both hunk conflicts and metadata conflicts.
is_binary_file: Option<IsBinaryFile>A boolean value (true or false) indicating whether the file is binary or textual in the source, destination, and base of the merge.
content_conflict: boolA boolean value indicating whether there are conflicts in the content of a file.
file_mode_conflict: boolA boolean value indicating whether there are conflicts in the file mode of a file.
object_type_conflict: boolA boolean value (true or false) indicating whether there are conflicts between the branches in the object type of a file, folder, or submodule.
merge_operations: Option<MergeOperations>Whether an add, modify, or delete operation caused the conflict between the source and destination of the merge.
Implementations
The file sizes of the file in the source, destination, and base of the merge.
The file modes of the file in the source, destination, and base of the merge.
Information about any object type conflicts in a merge operation.
The number of conflicts, including both hunk conflicts and metadata conflicts.
A boolean value (true or false) indicating whether the file is binary or textual in the source, destination, and base of the merge.
A boolean value indicating whether there are conflicts in the content of a file.
A boolean value indicating whether there are conflicts in the file mode of a file.
A boolean value (true or false) indicating whether there are conflicts between the branches in the object type of a file, folder, or submodule.
Whether an add, modify, or delete operation caused the conflict between the source and destination of the merge.
Creates a new builder-style object to manufacture ConflictMetadata