Struct aws_sdk_codecommit::model::ConflictResolution [−][src]
#[non_exhaustive]pub struct ConflictResolution {
pub replace_contents: Option<Vec<ReplaceContentEntry>>,
pub delete_files: Option<Vec<DeleteFileEntry>>,
pub set_file_modes: Option<Vec<SetFileModeEntry>>,
}Expand description
If AUTOMERGE is the conflict resolution strategy, a list of inputs to use when resolving conflicts during a merge.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.replace_contents: Option<Vec<ReplaceContentEntry>>Files to have content replaced as part of the merge conflict resolution.
delete_files: Option<Vec<DeleteFileEntry>>Files to be deleted as part of the merge conflict resolution.
set_file_modes: Option<Vec<SetFileModeEntry>>File modes that are set as part of the merge conflict resolution.
Implementations
Creates a new builder-style object to manufacture ConflictResolution