Struct aws_sdk_codecommit::model::Difference [−][src]
#[non_exhaustive]pub struct Difference {
pub before_blob: Option<BlobMetadata>,
pub after_blob: Option<BlobMetadata>,
pub change_type: Option<ChangeTypeEnum>,
}Expand description
Returns information about a set of differences for a commit specifier.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.before_blob: Option<BlobMetadata>Information about a beforeBlob data type object, including the ID,
the file mode permission code, and the path.
after_blob: Option<BlobMetadata>Information about an afterBlob data type object, including the ID,
the file mode permission code, and the path.
change_type: Option<ChangeTypeEnum>Whether the change type of the difference is an addition (A), deletion (D), or modification (M).
Implementations
Creates a new builder-style object to manufacture Difference