Struct aws_sdk_codecommit::model::Evaluation [−][src]
#[non_exhaustive]pub struct Evaluation {
pub approved: bool,
pub overridden: bool,
pub approval_rules_satisfied: Option<Vec<String>>,
pub approval_rules_not_satisfied: Option<Vec<String>>,
}Expand description
Returns information about the approval rules applied to a pull request and whether conditions have been met.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.approved: boolWhether the state of the pull request is approved.
overridden: boolWhether the approval rule requirements for the pull request have been overridden and no longer need to be met.
approval_rules_satisfied: Option<Vec<String>>The names of the approval rules that have had their conditions met.
approval_rules_not_satisfied: Option<Vec<String>>The names of the approval rules that have not had their conditions met.
Implementations
Whether the approval rule requirements for the pull request have been overridden and no longer need to be met.
The names of the approval rules that have had their conditions met.
Creates a new builder-style object to manufacture Evaluation