Struct aws_sdk_codecommit::model::FileModes [−][src]
#[non_exhaustive]pub struct FileModes {
pub source: Option<FileModeTypeEnum>,
pub destination: Option<FileModeTypeEnum>,
pub base: Option<FileModeTypeEnum>,
}Expand description
Information about file modes in a merge or pull request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source: Option<FileModeTypeEnum>The file mode of a file in the source of a merge or pull request.
destination: Option<FileModeTypeEnum>The file mode of a file in the destination of a merge or pull request.
base: Option<FileModeTypeEnum>The file mode of a file in the base of a merge or pull request.
Implementations
The file mode of a file in the source of a merge or pull request.
The file mode of a file in the destination of a merge or pull request.
The file mode of a file in the base of a merge or pull request.