Struct aws_sdk_codecommit::model::FileSizes [−][src]
Information about the size of files in a merge or pull request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source: i64The size of a file in the source of a merge or pull request.
destination: i64The size of a file in the destination of a merge or pull request.
base: i64The size of a file in the base of a merge or pull request.
Implementations