Struct aws_sdk_codecommit::model::Folder [−][src]
#[non_exhaustive]pub struct Folder {
pub tree_id: Option<String>,
pub absolute_path: Option<String>,
pub relative_path: Option<String>,
}Expand description
Returns information about a folder in a repository.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.tree_id: Option<String>The full SHA-1 pointer of the tree information for the commit that contains the folder.
absolute_path: Option<String>The fully qualified path of the folder in the repository.
relative_path: Option<String>The relative path of the specified folder from the folder where the query originated.
Implementations
The full SHA-1 pointer of the tree information for the commit that contains the folder.
The fully qualified path of the folder in the repository.
The relative path of the specified folder from the folder where the query originated.