Struct aws_sdk_codecommit::model::Location [−][src]
#[non_exhaustive]pub struct Location {
pub file_path: Option<String>,
pub file_position: Option<i64>,
pub relative_file_version: Option<RelativeFileVersionEnum>,
}Expand description
Returns information about the location of a change or comment in the comparison between two commits or a pull request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.file_path: Option<String>The name of the file being compared, including its extension and subdirectory, if any.
file_position: Option<i64>The position of a change in a compared file, in line number format.
relative_file_version: Option<RelativeFileVersionEnum>In a comparison of commits or a pull request, whether the change is in the before or after of that comparison.
Implementations