Struct aws_sdk_codecommit::model::MergeHunk [−][src]
#[non_exhaustive]pub struct MergeHunk {
pub is_conflict: bool,
pub source: Option<MergeHunkDetail>,
pub destination: Option<MergeHunkDetail>,
pub base: Option<MergeHunkDetail>,
}Expand description
Information about merge hunks in a merge or pull request operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.is_conflict: boolA Boolean value indicating whether a combination of hunks contains a conflict. Conflicts occur when the same file or the same lines in a file were modified in both the source and destination of a merge or pull request. Valid values include true, false, and null. True when the hunk represents a conflict and one or more files contains a line conflict. File mode conflicts in a merge do not set this to true.
source: Option<MergeHunkDetail>Information about the merge hunk in the source of a merge or pull request.
destination: Option<MergeHunkDetail>Information about the merge hunk in the destination of a merge or pull request.
base: Option<MergeHunkDetail>Information about the merge hunk in the base of a merge or pull request.
Implementations
A Boolean value indicating whether a combination of hunks contains a conflict. Conflicts occur when the same file or the same lines in a file were modified in both the source and destination of a merge or pull request. Valid values include true, false, and null. True when the hunk represents a conflict and one or more files contains a line conflict. File mode conflicts in a merge do not set this to true.
Information about the merge hunk in the source of a merge or pull request.
Information about the merge hunk in the destination of a merge or pull request.
Information about the merge hunk in the base of a merge or pull request.