Struct aws_sdk_codecommit::model::MergeHunkDetail [−][src]
#[non_exhaustive]pub struct MergeHunkDetail {
pub start_line: Option<i32>,
pub end_line: Option<i32>,
pub hunk_content: Option<String>,
}Expand description
Information about the details of a merge hunk that contains a conflict in a merge or pull request operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.start_line: Option<i32>The start position of the hunk in the merge result.
end_line: Option<i32>The end position of the hunk in the merge result.
hunk_content: Option<String>The base-64 encoded content of the hunk merged region that might contain a conflict.
Implementations
Creates a new builder-style object to manufacture MergeHunkDetail