Struct aws_sdk_codecommit::model::MergeOperations [−][src]
#[non_exhaustive]pub struct MergeOperations {
pub source: Option<ChangeTypeEnum>,
pub destination: Option<ChangeTypeEnum>,
}Expand description
Information about the file operation conflicts in a merge operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source: Option<ChangeTypeEnum>The operation (add, modify, or delete) on a file in the source of a merge or pull request.
destination: Option<ChangeTypeEnum>The operation on a file in the destination of a merge or pull request.
Implementations
The operation (add, modify, or delete) on a file in the source of a merge or pull request.
The operation on a file in the destination of a merge or pull request.
Creates a new builder-style object to manufacture MergeOperations