Struct aws_sdk_codecommit::model::ObjectTypes [−][src]
#[non_exhaustive]pub struct ObjectTypes {
pub source: Option<ObjectTypeEnum>,
pub destination: Option<ObjectTypeEnum>,
pub base: Option<ObjectTypeEnum>,
}Expand description
Information about the type of an object in a merge operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source: Option<ObjectTypeEnum>The type of the object in the source branch.
destination: Option<ObjectTypeEnum>The type of the object in the destination branch.
base: Option<ObjectTypeEnum>The type of the object in the base commit of the merge.
Implementations
Creates a new builder-style object to manufacture ObjectTypes