Struct aws_sdk_codecommit::model::OriginApprovalRuleTemplate [−][src]
#[non_exhaustive]pub struct OriginApprovalRuleTemplate {
pub approval_rule_template_id: Option<String>,
pub approval_rule_template_name: Option<String>,
}Expand description
Returns information about the template that created the approval rule for a pull request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.approval_rule_template_id: Option<String>The ID of the template that created the approval rule.
approval_rule_template_name: Option<String>The name of the template that created the approval rule.
Implementations
The ID of the template that created the approval rule.
The name of the template that created the approval rule.
Creates a new builder-style object to manufacture OriginApprovalRuleTemplate