Struct aws_sdk_codecommit::model::PullRequest [−][src]
#[non_exhaustive]pub struct PullRequest {
pub pull_request_id: Option<String>,
pub title: Option<String>,
pub description: Option<String>,
pub last_activity_date: Option<DateTime>,
pub creation_date: Option<DateTime>,
pub pull_request_status: Option<PullRequestStatusEnum>,
pub author_arn: Option<String>,
pub pull_request_targets: Option<Vec<PullRequestTarget>>,
pub client_request_token: Option<String>,
pub revision_id: Option<String>,
pub approval_rules: Option<Vec<ApprovalRule>>,
}Expand description
Returns information about a pull request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pull_request_id: Option<String>The system-generated ID of the pull request.
title: Option<String>The user-defined title of the pull request. This title is displayed in the list of pull requests to other repository users.
description: Option<String>The user-defined description of the pull request. This description can be used to clarify what should be reviewed and other details of the request.
last_activity_date: Option<DateTime>The day and time of the last user or system activity on the pull request, in timestamp format.
creation_date: Option<DateTime>The date and time the pull request was originally created, in timestamp format.
pull_request_status: Option<PullRequestStatusEnum>The status of the pull request. Pull request status can only change from OPEN to CLOSED.
The Amazon Resource Name (ARN) of the user who created the pull request.
pull_request_targets: Option<Vec<PullRequestTarget>>The targets of the pull request, including the source branch and destination branch for the pull request.
client_request_token: Option<String>A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
revision_id: Option<String>The system-generated revision ID for the pull request.
approval_rules: Option<Vec<ApprovalRule>>The approval rules applied to the pull request.
Implementations
The system-generated ID of the pull request.
The user-defined title of the pull request. This title is displayed in the list of pull requests to other repository users.
The user-defined description of the pull request. This description can be used to clarify what should be reviewed and other details of the request.
The day and time of the last user or system activity on the pull request, in timestamp format.
The date and time the pull request was originally created, in timestamp format.
The status of the pull request. Pull request status can only change from OPEN to CLOSED.
The Amazon Resource Name (ARN) of the user who created the pull request.
The targets of the pull request, including the source branch and destination branch for the pull request.
A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
The system-generated revision ID for the pull request.
The approval rules applied to the pull request.
Creates a new builder-style object to manufacture PullRequest