Struct aws_sdk_codecommit::model::PullRequestCreatedEventMetadata [−][src]
#[non_exhaustive]pub struct PullRequestCreatedEventMetadata {
pub repository_name: Option<String>,
pub source_commit_id: Option<String>,
pub destination_commit_id: Option<String>,
pub merge_base: Option<String>,
}Expand description
Metadata about the pull request that is used when comparing the pull request source with its destination.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository where the pull request was created.
source_commit_id: Option<String>The commit ID on the source branch used when the pull request was created.
destination_commit_id: Option<String>The commit ID of the tip of the branch specified as the destination branch when the pull request was created.
merge_base: Option<String>The commit ID of the most recent commit that the source branch and the destination branch have in common.
Implementations
Creates a new builder-style object to manufacture PullRequestCreatedEventMetadata