Struct aws_sdk_codecommit::model::PullRequestEvent [−][src]
#[non_exhaustive]pub struct PullRequestEvent {
pub pull_request_id: Option<String>,
pub event_date: Option<Instant>,
pub pull_request_event_type: Option<PullRequestEventType>,
pub actor_arn: Option<String>,
pub pull_request_created_event_metadata: Option<PullRequestCreatedEventMetadata>,
pub pull_request_status_changed_event_metadata: Option<PullRequestStatusChangedEventMetadata>,
pub pull_request_source_reference_updated_event_metadata: Option<PullRequestSourceReferenceUpdatedEventMetadata>,
pub pull_request_merged_state_changed_event_metadata: Option<PullRequestMergedStateChangedEventMetadata>,
pub approval_rule_event_metadata: Option<ApprovalRuleEventMetadata>,
pub approval_state_changed_event_metadata: Option<ApprovalStateChangedEventMetadata>,
pub approval_rule_overridden_event_metadata: Option<ApprovalRuleOverriddenEventMetadata>,
}Expand description
Returns information about a pull request event.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.pull_request_id: Option<String>The system-generated ID of the pull request.
event_date: Option<Instant>The day and time of the pull request event, in timestamp format.
pull_request_event_type: Option<PullRequestEventType>The type of the pull request event (for example, a status change event (PULL_REQUEST_STATUS_CHANGED) or update event (PULL_REQUEST_SOURCE_REFERENCE_UPDATED)).
actor_arn: Option<String>The Amazon Resource Name (ARN) of the user whose actions resulted in the event. Examples include updating the pull request with more commits or changing the status of a pull request.
pull_request_created_event_metadata: Option<PullRequestCreatedEventMetadata>Information about the source and destination branches for the pull request.
pull_request_status_changed_event_metadata: Option<PullRequestStatusChangedEventMetadata>Information about the change in status for the pull request event.
pull_request_source_reference_updated_event_metadata: Option<PullRequestSourceReferenceUpdatedEventMetadata>Information about the updated source branch for the pull request event.
pull_request_merged_state_changed_event_metadata: Option<PullRequestMergedStateChangedEventMetadata>Information about the change in mergability state for the pull request event.
approval_rule_event_metadata: Option<ApprovalRuleEventMetadata>Information about a pull request event.
approval_state_changed_event_metadata: Option<ApprovalStateChangedEventMetadata>Information about an approval state change for a pull request.
approval_rule_overridden_event_metadata: Option<ApprovalRuleOverriddenEventMetadata>Information about an approval rule override event for a pull request.
Implementations
Creates a new builder-style object to manufacture PullRequestEvent