Struct aws_sdk_codecommit::model::PullRequestTarget [−][src]
#[non_exhaustive]pub struct PullRequestTarget {
pub repository_name: Option<String>,
pub source_reference: Option<String>,
pub destination_reference: Option<String>,
pub destination_commit: Option<String>,
pub source_commit: Option<String>,
pub merge_base: Option<String>,
pub merge_metadata: Option<MergeMetadata>,
}Expand description
Returns information about a pull request target.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository that contains the pull request source and destination branches.
source_reference: Option<String>The branch of the repository that contains the changes for the pull request. Also known as the source branch.
destination_reference: Option<String>The branch of the repository where the pull request changes are merged. Also known as the destination branch.
destination_commit: Option<String>The full commit ID that is the tip of the destination branch. This is the commit where the pull request was or will be merged.
source_commit: Option<String>The full commit ID of the tip of the source branch used to create the pull request. If the pull request branch is updated by a push while the pull request is open, the commit ID changes to reflect the new tip of the branch.
merge_base: Option<String>The commit ID of the most recent commit that the source branch and the destination branch have in common.
merge_metadata: Option<MergeMetadata>Returns metadata about the state of the merge, including whether the merge has been made.
Implementations
The name of the repository that contains the pull request source and destination branches.
The branch of the repository that contains the changes for the pull request. Also known as the source branch.
The branch of the repository where the pull request changes are merged. Also known as the destination branch.
The full commit ID that is the tip of the destination branch. This is the commit where the pull request was or will be merged.
The full commit ID of the tip of the source branch used to create the pull request. If the pull request branch is updated by a push while the pull request is open, the commit ID changes to reflect the new tip of the branch.
The commit ID of the most recent commit that the source branch and the destination branch have in common.
Returns metadata about the state of the merge, including whether the merge has been made.
Creates a new builder-style object to manufacture PullRequestTarget