Struct aws_sdk_codecommit::model::ReactionForComment [−][src]
#[non_exhaustive]pub struct ReactionForComment {
pub reaction: Option<ReactionValueFormats>,
pub reaction_users: Option<Vec<String>>,
pub reactions_from_deleted_users_count: Option<i32>,
}Expand description
Information about the reaction values provided by users on a comment.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.reaction: Option<ReactionValueFormats>The reaction for a specified comment.
reaction_users: Option<Vec<String>>The Amazon Resource Names (ARNs) of users who have provided reactions to the comment.
reactions_from_deleted_users_count: Option<i32>A numerical count of users who reacted with the specified emoji whose identities have been subsequently deleted from IAM. While these IAM users or roles no longer exist, the reactions might still appear in total reaction counts.
Implementations
Creates a new builder-style object to manufacture ReactionForComment