Struct aws_sdk_codecommit::model::ReactionValueFormats [−][src]
#[non_exhaustive]pub struct ReactionValueFormats {
pub emoji: Option<String>,
pub short_code: Option<String>,
pub unicode: Option<String>,
}Expand description
Information about the values for reactions to a comment. AWS CodeCommit supports a limited set of reactions.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.emoji: Option<String>The Emoji Version 1.0 graphic of the reaction. These graphics are interpreted slightly differently on different operating systems.
short_code: Option<String>The emoji short code for the reaction. Short codes are interpreted slightly differently on different operating systems.
unicode: Option<String>The Unicode codepoint for the reaction.
Implementations
The Emoji Version 1.0 graphic of the reaction. These graphics are interpreted slightly differently on different operating systems.
The emoji short code for the reaction. Short codes are interpreted slightly differently on different operating systems.
Creates a new builder-style object to manufacture ReactionValueFormats