Struct aws_sdk_codecommit::model::ReplaceContentEntry [−][src]
#[non_exhaustive]pub struct ReplaceContentEntry {
pub file_path: Option<String>,
pub replacement_type: Option<ReplacementTypeEnum>,
pub content: Option<Blob>,
pub file_mode: Option<FileModeTypeEnum>,
}Expand description
Information about a replacement content entry in the conflict of a merge or pull request operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.file_path: Option<String>The path of the conflicting file.
replacement_type: Option<ReplacementTypeEnum>The replacement type to use when determining how to resolve the conflict.
content: Option<Blob>The base-64 encoded content to use when the replacement type is USE_NEW_CONTENT.
file_mode: Option<FileModeTypeEnum>The file mode to apply during conflict resoltion.
Implementations
The replacement type to use when determining how to resolve the conflict.
The base-64 encoded content to use when the replacement type is USE_NEW_CONTENT.
The file mode to apply during conflict resoltion.
Creates a new builder-style object to manufacture ReplaceContentEntry