Struct aws_sdk_codecommit::model::RepositoryTriggerExecutionFailure [−][src]
#[non_exhaustive]pub struct RepositoryTriggerExecutionFailure {
pub trigger: Option<String>,
pub failure_message: Option<String>,
}Expand description
A trigger failed to run.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.trigger: Option<String>The name of the trigger that did not run.
failure_message: Option<String>Message information about the trigger that did not run.
Implementations
Creates a new builder-style object to manufacture RepositoryTriggerExecutionFailure