Struct aws_sdk_codecommit::model::SourceFileSpecifier [−][src]
#[non_exhaustive]pub struct SourceFileSpecifier {
pub file_path: Option<String>,
pub is_move: bool,
}Expand description
Information about a source file that is part of changes made in a commit.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.file_path: Option<String>The full path to the file, including the name of the file.
is_move: boolWhether to remove the source file from the parent commit.
Implementations
Creates a new builder-style object to manufacture SourceFileSpecifier