Struct aws_sdk_codecommit::model::SubModule [−][src]
#[non_exhaustive]pub struct SubModule {
pub commit_id: Option<String>,
pub absolute_path: Option<String>,
pub relative_path: Option<String>,
}Expand description
Returns information about a submodule reference in a repository folder.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.commit_id: Option<String>The commit ID that contains the reference to the submodule.
absolute_path: Option<String>The fully qualified path to the folder that contains the reference to the submodule.
relative_path: Option<String>The relative path of the submodule from the folder where the query originated.
Implementations
The commit ID that contains the reference to the submodule.
The fully qualified path to the folder that contains the reference to the submodule.
The relative path of the submodule from the folder where the query originated.