Struct aws_sdk_codecommit::model::SymbolicLink [−][src]
#[non_exhaustive]pub struct SymbolicLink {
pub blob_id: Option<String>,
pub absolute_path: Option<String>,
pub relative_path: Option<String>,
pub file_mode: Option<FileModeTypeEnum>,
}Expand description
Returns information about a symbolic link in a repository folder.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.blob_id: Option<String>The blob ID that contains the information about the symbolic link.
absolute_path: Option<String>The fully qualified path to the folder that contains the symbolic link.
relative_path: Option<String>The relative path of the symbolic link from the folder where the query originated.
file_mode: Option<FileModeTypeEnum>The file mode permissions of the blob that cotains information about the symbolic link.
Implementations
The blob ID that contains the information about the symbolic link.
The fully qualified path to the folder that contains the symbolic link.
The relative path of the symbolic link from the folder where the query originated.
The file mode permissions of the blob that cotains information about the symbolic link.
Creates a new builder-style object to manufacture SymbolicLink