Struct aws_sdk_codecommit::model::Target [−][src]
#[non_exhaustive]pub struct Target {
pub repository_name: Option<String>,
pub source_reference: Option<String>,
pub destination_reference: Option<String>,
}Expand description
Returns information about a target for a pull request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository that contains the pull request.
source_reference: Option<String>The branch of the repository that contains the changes for the pull request. Also known as the source branch.
destination_reference: Option<String>The branch of the repository where the pull request changes are merged. Also known as the destination branch.
Implementations