Struct aws_sdk_codecommit::model::UserInfo [−][src]
#[non_exhaustive]pub struct UserInfo {
pub name: Option<String>,
pub email: Option<String>,
pub date: Option<String>,
}Expand description
Information about the user who made a specified commit.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: Option<String>The name of the user who made the specified commit.
email: Option<String>The email address associated with the user who made the commit, if any.
date: Option<String>The date when the specified commit was commited, in timestamp format with GMT offset.
Implementations
The email address associated with the user who made the commit, if any.