Struct aws_sdk_codecommit::model::sub_module::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for SubModule
Implementations
The commit ID that contains the reference to the submodule.
The commit ID that contains the reference to the submodule.
The fully qualified path to the folder that contains the reference to the submodule.
The fully qualified path to the folder that contains the reference to the submodule.
The relative path of the submodule from the folder where the query originated.
The relative path of the submodule from the folder where the query originated.