Struct aws_sdk_codecommit::model::target::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for Target
Implementations
The name of the repository that contains the pull request.
The name of the repository that contains the pull request.
The branch of the repository that contains the changes for the pull request. Also known as the source branch.
The branch of the repository that contains the changes for the pull request. Also known as the source branch.
The branch of the repository where the pull request changes are merged. Also known as the destination branch.
The branch of the repository where the pull request changes are merged. Also known as the destination branch.