Struct aws_sdk_codecommit::model::user_info::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for UserInfo
Implementations
The name of the user who made the specified commit.
The name of the user who made the specified commit.
The email address associated with the user who made the commit, if any.
The email address associated with the user who made the commit, if any.
The date when the specified commit was commited, in timestamp format with GMT offset.
The date when the specified commit was commited, in timestamp format with GMT offset.