#[non_exhaustive]pub struct DescribePullRequestEventsInputBuilder { /* private fields */ }Expand description
A builder for DescribePullRequestEventsInput.
Implementations
Sourceimpl DescribePullRequestEventsInputBuilder
impl DescribePullRequestEventsInputBuilder
Sourcepub fn pull_request_id(self, input: impl Into<String>) -> Self
pub fn pull_request_id(self, input: impl Into<String>) -> Self
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
Sourcepub fn set_pull_request_id(self, input: Option<String>) -> Self
pub fn set_pull_request_id(self, input: Option<String>) -> Self
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
Sourcepub fn get_pull_request_id(&self) -> &Option<String>
pub fn get_pull_request_id(&self) -> &Option<String>
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
Sourcepub fn pull_request_event_type(self, input: PullRequestEventType) -> Self
pub fn pull_request_event_type(self, input: PullRequestEventType) -> Self
Optional. The pull request event type about which you want to return information.
Sourcepub fn set_pull_request_event_type(
self,
input: Option<PullRequestEventType>,
) -> Self
pub fn set_pull_request_event_type( self, input: Option<PullRequestEventType>, ) -> Self
Optional. The pull request event type about which you want to return information.
Sourcepub fn get_pull_request_event_type(&self) -> &Option<PullRequestEventType>
pub fn get_pull_request_event_type(&self) -> &Option<PullRequestEventType>
Optional. The pull request event type about which you want to return information.
Sourcepub fn actor_arn(self, input: impl Into<String>) -> Self
pub fn actor_arn(self, input: impl Into<String>) -> Self
The Amazon Resource Name (ARN) of the user whose actions resulted in the event. Examples include updating the pull request with more commits or changing the status of a pull request.
Sourcepub fn set_actor_arn(self, input: Option<String>) -> Self
pub fn set_actor_arn(self, input: Option<String>) -> Self
The Amazon Resource Name (ARN) of the user whose actions resulted in the event. Examples include updating the pull request with more commits or changing the status of a pull request.
Sourcepub fn get_actor_arn(&self) -> &Option<String>
pub fn get_actor_arn(&self) -> &Option<String>
The Amazon Resource Name (ARN) of the user whose actions resulted in the event. Examples include updating the pull request with more commits or changing the status of a pull request.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
An enumeration token that, when provided in a request, returns the next batch of the results.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
An enumeration token that, when provided in a request, returns the next batch of the results.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
An enumeration token that, when provided in a request, returns the next batch of the results.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
A non-zero, non-negative integer used to limit the number of returned results. The default is 100 events, which is also the maximum number of events that can be returned in a result.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
A non-zero, non-negative integer used to limit the number of returned results. The default is 100 events, which is also the maximum number of events that can be returned in a result.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
A non-zero, non-negative integer used to limit the number of returned results. The default is 100 events, which is also the maximum number of events that can be returned in a result.
Sourcepub fn build(self) -> Result<DescribePullRequestEventsInput, BuildError>
pub fn build(self) -> Result<DescribePullRequestEventsInput, BuildError>
Consumes the builder and constructs a DescribePullRequestEventsInput.
Sourceimpl DescribePullRequestEventsInputBuilder
impl DescribePullRequestEventsInputBuilder
Sourcepub async fn send_with(
self,
client: &Client,
) -> Result<DescribePullRequestEventsOutput, SdkError<DescribePullRequestEventsError, HttpResponse>>
pub async fn send_with( self, client: &Client, ) -> Result<DescribePullRequestEventsOutput, SdkError<DescribePullRequestEventsError, HttpResponse>>
Sends a request with this input using the given client.