pub struct GetBlobDifferencesFluentBuilder { /* private fields */ }Expand description
Fluent builder constructing a request to GetBlobDifferences.
Returns a structured, line-level diff between two blob versions in a repository. The diff is returned as an ordered list of hunks, where each hunk represents a contiguous run of changed lines together with any surrounding unchanged context lines.
Results are paginated. Use MaxResults and NextToken to retrieve additional pages.
For the typical usage workflow, see GetDifferences.
Implementations
Sourceimpl GetBlobDifferencesFluentBuilder
impl GetBlobDifferencesFluentBuilder
Sourcepub fn as_input(&self) -> &GetBlobDifferencesInputBuilder
pub fn as_input(&self) -> &GetBlobDifferencesInputBuilder
Access the GetBlobDifferences as a reference.
Sourcepub async fn send(
self,
) -> Result<GetBlobDifferencesOutput, SdkError<GetBlobDifferencesError, HttpResponse>>
pub async fn send( self, ) -> Result<GetBlobDifferencesOutput, SdkError<GetBlobDifferencesError, HttpResponse>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
Sourcepub fn customize(
self,
) -> CustomizableOperation<GetBlobDifferencesOutput, GetBlobDifferencesError, Self>
pub fn customize( self, ) -> CustomizableOperation<GetBlobDifferencesOutput, GetBlobDifferencesError, Self>
Consumes this builder, creating a customizable operation that can be modified before being sent.
Sourcepub fn into_paginator(self) -> GetBlobDifferencesPaginator
pub fn into_paginator(self) -> GetBlobDifferencesPaginator
Create a paginator for this request
Paginators are used by calling send().await which returns a PaginationStream.
Sourcepub fn repository_name(self, input: impl Into<String>) -> Self
pub fn repository_name(self, input: impl Into<String>) -> Self
The name of the repository that contains the blobs to compare.
Sourcepub fn set_repository_name(self, input: Option<String>) -> Self
pub fn set_repository_name(self, input: Option<String>) -> Self
The name of the repository that contains the blobs to compare.
Sourcepub fn get_repository_name(&self) -> &Option<String>
pub fn get_repository_name(&self) -> &Option<String>
The name of the repository that contains the blobs to compare.
Sourcepub fn after_blob_id(self, input: impl Into<String>) -> Self
pub fn after_blob_id(self, input: impl Into<String>) -> Self
The ID of the "after" (destination) blob in the diff. Typically the value of afterBlob.blobId from a Difference object returned by GetDifferences.
Sourcepub fn set_after_blob_id(self, input: Option<String>) -> Self
pub fn set_after_blob_id(self, input: Option<String>) -> Self
The ID of the "after" (destination) blob in the diff. Typically the value of afterBlob.blobId from a Difference object returned by GetDifferences.
Sourcepub fn get_after_blob_id(&self) -> &Option<String>
pub fn get_after_blob_id(&self) -> &Option<String>
The ID of the "after" (destination) blob in the diff. Typically the value of afterBlob.blobId from a Difference object returned by GetDifferences.
Sourcepub fn before_blob_id(self, input: impl Into<String>) -> Self
pub fn before_blob_id(self, input: impl Into<String>) -> Self
The ID of the "before" (source) blob in the diff. Typically the value of beforeBlob.blobId from a Difference object returned by GetDifferences.
If you do not specify a value, the operation returns a diff against an empty before-state. This is equivalent to treating the file as newly added.
Sourcepub fn set_before_blob_id(self, input: Option<String>) -> Self
pub fn set_before_blob_id(self, input: Option<String>) -> Self
The ID of the "before" (source) blob in the diff. Typically the value of beforeBlob.blobId from a Difference object returned by GetDifferences.
If you do not specify a value, the operation returns a diff against an empty before-state. This is equivalent to treating the file as newly added.
Sourcepub fn get_before_blob_id(&self) -> &Option<String>
pub fn get_before_blob_id(&self) -> &Option<String>
The ID of the "before" (source) blob in the diff. Typically the value of beforeBlob.blobId from a Difference object returned by GetDifferences.
If you do not specify a value, the operation returns a diff against an empty before-state. This is equivalent to treating the file as newly added.
Sourcepub fn context_lines(self, input: i32) -> Self
pub fn context_lines(self, input: i32) -> Self
The number of unchanged lines of context to include before and after each block of changes in a hunk. Valid values are 0 through 20. Defaults to 3.
Sourcepub fn set_context_lines(self, input: Option<i32>) -> Self
pub fn set_context_lines(self, input: Option<i32>) -> Self
The number of unchanged lines of context to include before and after each block of changes in a hunk. Valid values are 0 through 20. Defaults to 3.
Sourcepub fn get_context_lines(&self) -> &Option<i32>
pub fn get_context_lines(&self) -> &Option<i32>
The number of unchanged lines of context to include before and after each block of changes in a hunk. Valid values are 0 through 20. Defaults to 3.
Sourcepub fn ignore_whitespace(self, input: bool) -> Self
pub fn ignore_whitespace(self, input: bool) -> Self
Specifies whether to ignore whitespace-only changes when computing the diff. When true, the operation treats lines that differ only in whitespace as unchanged. Defaults to false.
Sourcepub fn set_ignore_whitespace(self, input: Option<bool>) -> Self
pub fn set_ignore_whitespace(self, input: Option<bool>) -> Self
Specifies whether to ignore whitespace-only changes when computing the diff. When true, the operation treats lines that differ only in whitespace as unchanged. Defaults to false.
Sourcepub fn get_ignore_whitespace(&self) -> &Option<bool>
pub fn get_ignore_whitespace(&self) -> &Option<bool>
Specifies whether to ignore whitespace-only changes when computing the diff. When true, the operation treats lines that differ only in whitespace as unchanged. Defaults to false.
Sourcepub fn max_results(self, input: i32) -> Self
pub fn max_results(self, input: i32) -> Self
The maximum number of DiffHunk entries to return in a single response page. Defaults to 100.
Sourcepub fn set_max_results(self, input: Option<i32>) -> Self
pub fn set_max_results(self, input: Option<i32>) -> Self
The maximum number of DiffHunk entries to return in a single response page. Defaults to 100.
Sourcepub fn get_max_results(&self) -> &Option<i32>
pub fn get_max_results(&self) -> &Option<i32>
The maximum number of DiffHunk entries to return in a single response page. Defaults to 100.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
An enumeration token that returns the next batch of results when present in a request.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
An enumeration token that returns the next batch of results when present in a request.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
An enumeration token that returns the next batch of results when present in a request.