#[non_exhaustive]pub struct GetBlobDifferencesOutputBuilder { /* private fields */ }Expand description
A builder for GetBlobDifferencesOutput.
Implementations
Sourceimpl GetBlobDifferencesOutputBuilder
impl GetBlobDifferencesOutputBuilder
Sourcepub fn hunks(self, input: DiffHunk) -> Self
pub fn hunks(self, input: DiffHunk) -> Self
Appends an item to hunks.
To override the contents of this collection use set_hunks.
An ordered list of diff hunks. Each hunk represents a contiguous run of changed and adjacent context lines. The list is empty when the blobs are identical or when the content is binary. The list is also empty when a paginated request has already returned all hunks in earlier pages, in which case NextToken is also null.
Sourcepub fn set_hunks(self, input: Option<Vec<DiffHunk>>) -> Self
pub fn set_hunks(self, input: Option<Vec<DiffHunk>>) -> Self
An ordered list of diff hunks. Each hunk represents a contiguous run of changed and adjacent context lines. The list is empty when the blobs are identical or when the content is binary. The list is also empty when a paginated request has already returned all hunks in earlier pages, in which case NextToken is also null.
Sourcepub fn get_hunks(&self) -> &Option<Vec<DiffHunk>>
pub fn get_hunks(&self) -> &Option<Vec<DiffHunk>>
An ordered list of diff hunks. Each hunk represents a contiguous run of changed and adjacent context lines. The list is empty when the blobs are identical or when the content is binary. The list is also empty when a paginated request has already returned all hunks in earlier pages, in which case NextToken is also null.
Sourcepub fn is_binary(self, input: bool) -> Self
pub fn is_binary(self, input: bool) -> Self
Specifies whether the operation treated the diff content as binary. When true, the operation does not compute a line-level diff and hunks is empty.
Sourcepub fn set_is_binary(self, input: Option<bool>) -> Self
pub fn set_is_binary(self, input: Option<bool>) -> Self
Specifies whether the operation treated the diff content as binary. When true, the operation does not compute a line-level diff and hunks is empty.
Sourcepub fn get_is_binary(&self) -> &Option<bool>
pub fn get_is_binary(&self) -> &Option<bool>
Specifies whether the operation treated the diff content as binary. When true, the operation does not compute a line-level diff and hunks is empty.
Sourcepub fn before_blob_size(self, input: i64) -> Self
pub fn before_blob_size(self, input: i64) -> Self
The size, in bytes, of the blob identified by beforeBlobId. Returns 0 when you do not specify beforeBlobId.
Sourcepub fn set_before_blob_size(self, input: Option<i64>) -> Self
pub fn set_before_blob_size(self, input: Option<i64>) -> Self
The size, in bytes, of the blob identified by beforeBlobId. Returns 0 when you do not specify beforeBlobId.
Sourcepub fn get_before_blob_size(&self) -> &Option<i64>
pub fn get_before_blob_size(&self) -> &Option<i64>
The size, in bytes, of the blob identified by beforeBlobId. Returns 0 when you do not specify beforeBlobId.
Sourcepub fn after_blob_size(self, input: i64) -> Self
pub fn after_blob_size(self, input: i64) -> Self
The size, in bytes, of the blob identified by afterBlobId.
Sourcepub fn set_after_blob_size(self, input: Option<i64>) -> Self
pub fn set_after_blob_size(self, input: Option<i64>) -> Self
The size, in bytes, of the blob identified by afterBlobId.
Sourcepub fn get_after_blob_size(&self) -> &Option<i64>
pub fn get_after_blob_size(&self) -> &Option<i64>
The size, in bytes, of the blob identified by afterBlobId.
Sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
An enumeration token that can be used in a request to return the next batch of DiffHunk entries. null when the response contains the final page of the diff.
Sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
An enumeration token that can be used in a request to return the next batch of DiffHunk entries. null when the response contains the final page of the diff.
Sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
An enumeration token that can be used in a request to return the next batch of DiffHunk entries. null when the response contains the final page of the diff.
Sourcepub fn build(self) -> Result<GetBlobDifferencesOutput, BuildError>
pub fn build(self) -> Result<GetBlobDifferencesOutput, BuildError>
Consumes the builder and constructs a GetBlobDifferencesOutput.
This method will fail if any of the following fields are not set: