GetBlobDifferencesInput

Struct GetBlobDifferencesInput 

#[non_exhaustive]
pub struct GetBlobDifferencesInput { pub repository_name: Option<String>, pub after_blob_id: Option<String>, pub before_blob_id: Option<String>, pub context_lines: Option<i32>, pub ignore_whitespace: Option<bool>, pub max_results: Option<i32>, pub next_token: Option<String>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
repository_name: Option<String>

The name of the repository that contains the blobs to compare.

after_blob_id: Option<String>

The ID of the "after" (destination) blob in the diff. Typically the value of afterBlob.blobId from a Difference object returned by GetDifferences.

before_blob_id: Option<String>

The ID of the "before" (source) blob in the diff. Typically the value of beforeBlob.blobId from a Difference object returned by GetDifferences.

If you do not specify a value, the operation returns a diff against an empty before-state. This is equivalent to treating the file as newly added.

context_lines: Option<i32>

The number of unchanged lines of context to include before and after each block of changes in a hunk. Valid values are 0 through 20. Defaults to 3.

ignore_whitespace: Option<bool>

Specifies whether to ignore whitespace-only changes when computing the diff. When true, the operation treats lines that differ only in whitespace as unchanged. Defaults to false.

max_results: Option<i32>

The maximum number of DiffHunk entries to return in a single response page. Defaults to 100.

next_token: Option<String>

An enumeration token that returns the next batch of results when present in a request.

Implementations

Source

impl GetBlobDifferencesInput

pub fn repository_name(&self) -> Option<&str>

The name of the repository that contains the blobs to compare.

pub fn after_blob_id(&self) -> Option<&str>

The ID of the "after" (destination) blob in the diff. Typically the value of afterBlob.blobId from a Difference object returned by GetDifferences.

pub fn before_blob_id(&self) -> Option<&str>

The ID of the "before" (source) blob in the diff. Typically the value of beforeBlob.blobId from a Difference object returned by GetDifferences.

If you do not specify a value, the operation returns a diff against an empty before-state. This is equivalent to treating the file as newly added.

pub fn context_lines(&self) -> Option<i32>

The number of unchanged lines of context to include before and after each block of changes in a hunk. Valid values are 0 through 20. Defaults to 3.

pub fn ignore_whitespace(&self) -> Option<bool>

Specifies whether to ignore whitespace-only changes when computing the diff. When true, the operation treats lines that differ only in whitespace as unchanged. Defaults to false.

pub fn max_results(&self) -> Option<i32>

The maximum number of DiffHunk entries to return in a single response page. Defaults to 100.

pub fn next_token(&self) -> Option<&str>

An enumeration token that returns the next batch of results when present in a request.

Source

impl GetBlobDifferencesInput

pub fn builder() -> GetBlobDifferencesInputBuilder

Creates a new builder-style object to manufacture GetBlobDifferencesInput.