#[non_exhaustive]pub struct GetBlobDifferencesOutput {
pub hunks: Vec<DiffHunk>,
pub is_binary: bool,
pub before_blob_size: i64,
pub after_blob_size: i64,
pub next_token: Option<String>,
/* private fields */
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.hunks: Vec<DiffHunk>An ordered list of diff hunks. Each hunk represents a contiguous run of changed and adjacent context lines. The list is empty when the blobs are identical or when the content is binary. The list is also empty when a paginated request has already returned all hunks in earlier pages, in which case NextToken is also null.
is_binary: boolSpecifies whether the operation treated the diff content as binary. When true, the operation does not compute a line-level diff and hunks is empty.
before_blob_size: i64The size, in bytes, of the blob identified by beforeBlobId. Returns 0 when you do not specify beforeBlobId.
after_blob_size: i64The size, in bytes, of the blob identified by afterBlobId.
next_token: Option<String>An enumeration token that can be used in a request to return the next batch of DiffHunk entries. null when the response contains the final page of the diff.
Implementations
Sourceimpl GetBlobDifferencesOutput
impl GetBlobDifferencesOutput
Sourcepub fn hunks(&self) -> &[DiffHunk]
pub fn hunks(&self) -> &[DiffHunk]
An ordered list of diff hunks. Each hunk represents a contiguous run of changed and adjacent context lines. The list is empty when the blobs are identical or when the content is binary. The list is also empty when a paginated request has already returned all hunks in earlier pages, in which case NextToken is also null.
Sourcepub fn is_binary(&self) -> bool
pub fn is_binary(&self) -> bool
Specifies whether the operation treated the diff content as binary. When true, the operation does not compute a line-level diff and hunks is empty.
Sourcepub fn before_blob_size(&self) -> i64
pub fn before_blob_size(&self) -> i64
The size, in bytes, of the blob identified by beforeBlobId. Returns 0 when you do not specify beforeBlobId.
Sourcepub fn after_blob_size(&self) -> i64
pub fn after_blob_size(&self) -> i64
The size, in bytes, of the blob identified by afterBlobId.
Sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
An enumeration token that can be used in a request to return the next batch of DiffHunk entries. null when the response contains the final page of the diff.
Sourceimpl GetBlobDifferencesOutput
impl GetBlobDifferencesOutput
Sourcepub fn builder() -> GetBlobDifferencesOutputBuilder
pub fn builder() -> GetBlobDifferencesOutputBuilder
Creates a new builder-style object to manufacture GetBlobDifferencesOutput.