Struct aws_sdk_codecommit::operation::list_pull_requests::builders::ListPullRequestsOutputBuilder
source · #[non_exhaustive]pub struct ListPullRequestsOutputBuilder { /* private fields */ }Expand description
A builder for ListPullRequestsOutput.
Implementations
sourceimpl ListPullRequestsOutputBuilder
impl ListPullRequestsOutputBuilder
sourcepub fn pull_request_ids(self, input: impl Into<String>) -> Self
pub fn pull_request_ids(self, input: impl Into<String>) -> Self
Appends an item to pull_request_ids.
To override the contents of this collection use set_pull_request_ids.
The system-generated IDs of the pull requests.
sourcepub fn set_pull_request_ids(self, input: Option<Vec<String>>) -> Self
pub fn set_pull_request_ids(self, input: Option<Vec<String>>) -> Self
The system-generated IDs of the pull requests.
sourcepub fn get_pull_request_ids(&self) -> &Option<Vec<String>>
pub fn get_pull_request_ids(&self) -> &Option<Vec<String>>
The system-generated IDs of the pull requests.
sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
An enumeration token that allows the operation to batch the next results of the operation.
sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
An enumeration token that allows the operation to batch the next results of the operation.
sourcepub fn get_next_token(&self) -> &Option<String>
pub fn get_next_token(&self) -> &Option<String>
An enumeration token that allows the operation to batch the next results of the operation.
sourcepub fn build(self) -> Result<ListPullRequestsOutput, BuildError>
pub fn build(self) -> Result<ListPullRequestsOutput, BuildError>
Consumes the builder and constructs a ListPullRequestsOutput.
This method will fail if any of the following fields are not set: