Struct aws_sdk_codecommit::output::evaluate_pull_request_approval_rules_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for EvaluatePullRequestApprovalRulesOutput
Implementations
The result of the evaluation, including the names of the rules whose conditions have been met (if any), the names of the rules whose conditions have not been met (if any), whether the pull request is in the approved state, and whether the pull request approval rule has been set aside by an override.
The result of the evaluation, including the names of the rules whose conditions have been met (if any), the names of the rules whose conditions have not been met (if any), whether the pull request is in the approved state, and whether the pull request approval rule has been set aside by an override.
Consumes the builder and constructs a EvaluatePullRequestApprovalRulesOutput