Struct aws_sdk_codecommit::output::get_comments_for_compared_commit_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for GetCommentsForComparedCommitOutput
Implementations
pub fn comments_for_compared_commit_data(
self,
input: impl Into<CommentsForComparedCommit>
) -> Self
pub fn comments_for_compared_commit_data(
self,
input: impl Into<CommentsForComparedCommit>
) -> Self
Appends an item to comments_for_compared_commit_data.
To override the contents of this collection use set_comments_for_compared_commit_data.
A list of comment objects on the compared commit.
pub fn set_comments_for_compared_commit_data(
self,
input: Option<Vec<CommentsForComparedCommit>>
) -> Self
pub fn set_comments_for_compared_commit_data(
self,
input: Option<Vec<CommentsForComparedCommit>>
) -> Self
A list of comment objects on the compared commit.
An enumeration token that can be used in a request to return the next batch of the results.
An enumeration token that can be used in a request to return the next batch of the results.
Consumes the builder and constructs a GetCommentsForComparedCommitOutput