Struct aws_sdk_codecommit::output::get_comments_for_pull_request_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for GetCommentsForPullRequestOutput
Implementations
Appends an item to comments_for_pull_request_data.
To override the contents of this collection use set_comments_for_pull_request_data.
An array of comment objects on the pull request.
pub fn set_comments_for_pull_request_data(
self,
input: Option<Vec<CommentsForPullRequest>>
) -> Self
pub fn set_comments_for_pull_request_data(
self,
input: Option<Vec<CommentsForPullRequest>>
) -> Self
An array of comment objects on the pull request.
An enumeration token that can be used in a request to return the next batch of the results.
An enumeration token that can be used in a request to return the next batch of the results.
Consumes the builder and constructs a GetCommentsForPullRequestOutput