Struct aws_sdk_codecommit::output::get_commit_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for GetCommitOutput
Implementations
A commit data type object that contains information about the specified commit.
A commit data type object that contains information about the specified commit.
Consumes the builder and constructs a GetCommitOutput