Struct aws_sdk_codecommit::output::get_differences_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for GetDifferencesOutput
Implementations
Appends an item to differences.
To override the contents of this collection use set_differences.
A data type object that contains information about the differences, including whether the difference is added, modified, or deleted (A, D, M).
A data type object that contains information about the differences, including whether the difference is added, modified, or deleted (A, D, M).
An enumeration token that can be used in a request to return the next batch of the results.
An enumeration token that can be used in a request to return the next batch of the results.
Consumes the builder and constructs a GetDifferencesOutput