Struct aws_sdk_codecommit::output::get_folder_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for GetFolderOutput
Implementations
The full commit ID used as a reference for the returned version of the folder content.
The full commit ID used as a reference for the returned version of the folder content.
The fully qualified path of the folder whose contents are returned.
The fully qualified path of the folder whose contents are returned.
The full SHA-1 pointer of the tree information for the commit that contains the folder.
The full SHA-1 pointer of the tree information for the commit that contains the folder.
Appends an item to sub_folders.
To override the contents of this collection use set_sub_folders.
The list of folders that exist under the specified folder, if any.
The list of folders that exist under the specified folder, if any.
Appends an item to files.
To override the contents of this collection use set_files.
The list of files in the specified folder, if any.
The list of files in the specified folder, if any.
Appends an item to symbolic_links.
To override the contents of this collection use set_symbolic_links.
The list of symbolic links to other files and folders in the specified folder, if any.
The list of symbolic links to other files and folders in the specified folder, if any.
Appends an item to sub_modules.
To override the contents of this collection use set_sub_modules.
The list of submodules in the specified folder, if any.
The list of submodules in the specified folder, if any.
Consumes the builder and constructs a GetFolderOutput