Struct aws_sdk_codecommit::output::post_comment_for_compared_commit_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for PostCommentForComparedCommitOutput
Implementations
The name of the repository where you posted a comment on the comparison between commits.
The name of the repository where you posted a comment on the comparison between commits.
In the directionality you established, the full commit ID of the before commit.
In the directionality you established, the full commit ID of the before commit.
In the directionality you established, the full commit ID of the after commit.
In the directionality you established, the full commit ID of the after commit.
In the directionality you established, the blob ID of the before blob.
In the directionality you established, the blob ID of the before blob.
In the directionality you established, the blob ID of the after blob.
In the directionality you established, the blob ID of the after blob.
The location of the comment in the comparison between the two commits.
The location of the comment in the comparison between the two commits.
The content of the comment you posted.
Consumes the builder and constructs a PostCommentForComparedCommitOutput