Struct aws_sdk_codecommit::output::post_comment_for_pull_request_output::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for PostCommentForPullRequestOutput
Implementations
The name of the repository where you posted a comment on a pull request.
The name of the repository where you posted a comment on a pull request.
The system-generated ID of the pull request.
The system-generated ID of the pull request.
The full commit ID of the commit in the source branch used to create the pull request, or in the case of an updated pull request, the full commit ID of the commit used to update the pull request.
The full commit ID of the commit in the source branch used to create the pull request, or in the case of an updated pull request, the full commit ID of the commit used to update the pull request.
The full commit ID of the commit in the destination branch where the pull request is merged.
The full commit ID of the commit in the destination branch where the pull request is merged.
In the directionality of the pull request, the blob ID of the before blob.
In the directionality of the pull request, the blob ID of the before blob.
In the directionality of the pull request, the blob ID of the after blob.
In the directionality of the pull request, the blob ID of the after blob.
The location of the change where you posted your comment.
The location of the change where you posted your comment.
The content of the comment you posted.
Consumes the builder and constructs a PostCommentForPullRequestOutput