Struct aws_sdk_codecommit::output::BatchAssociateApprovalRuleTemplateWithRepositoriesOutput [−][src]
#[non_exhaustive]pub struct BatchAssociateApprovalRuleTemplateWithRepositoriesOutput {
pub associated_repository_names: Option<Vec<String>>,
pub errors: Option<Vec<BatchAssociateApprovalRuleTemplateWithRepositoriesError>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.associated_repository_names: Option<Vec<String>>A list of names of the repositories that have been associated with the template.
errors: Option<Vec<BatchAssociateApprovalRuleTemplateWithRepositoriesError>>A list of any errors that might have occurred while attempting to create the association between the template and the repositories.
Implementations
A list of names of the repositories that have been associated with the template.
Creates a new builder-style object to manufacture BatchAssociateApprovalRuleTemplateWithRepositoriesOutput