Struct aws_sdk_codecommit::output::BatchDescribeMergeConflictsOutput [−][src]
#[non_exhaustive]pub struct BatchDescribeMergeConflictsOutput {
pub conflicts: Option<Vec<Conflict>>,
pub next_token: Option<String>,
pub errors: Option<Vec<BatchDescribeMergeConflictsError>>,
pub destination_commit_id: Option<String>,
pub source_commit_id: Option<String>,
pub base_commit_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.conflicts: Option<Vec<Conflict>>A list of conflicts for each file, including the conflict metadata and the hunks of the differences between the files.
next_token: Option<String>An enumeration token that can be used in a request to return the next batch of the results.
errors: Option<Vec<BatchDescribeMergeConflictsError>>A list of any errors returned while describing the merge conflicts for each file.
destination_commit_id: Option<String>The commit ID of the destination commit specifier that was used in the merge evaluation.
source_commit_id: Option<String>The commit ID of the source commit specifier that was used in the merge evaluation.
base_commit_id: Option<String>The commit ID of the merge base.
Implementations
Creates a new builder-style object to manufacture BatchDescribeMergeConflictsOutput