Struct aws_sdk_codecommit::output::BatchDisassociateApprovalRuleTemplateFromRepositoriesOutput [−][src]
#[non_exhaustive]pub struct BatchDisassociateApprovalRuleTemplateFromRepositoriesOutput {
pub disassociated_repository_names: Option<Vec<String>>,
pub errors: Option<Vec<BatchDisassociateApprovalRuleTemplateFromRepositoriesError>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.disassociated_repository_names: Option<Vec<String>>A list of repository names that have had their association with the template removed.
errors: Option<Vec<BatchDisassociateApprovalRuleTemplateFromRepositoriesError>>A list of any errors that might have occurred while attempting to remove the association between the template and the repositories.
Implementations
A list of repository names that have had their association with the template removed.
Creates a new builder-style object to manufacture BatchDisassociateApprovalRuleTemplateFromRepositoriesOutput