Struct aws_sdk_codecommit::output::BatchGetCommitsOutput [−][src]
#[non_exhaustive]pub struct BatchGetCommitsOutput {
pub commits: Option<Vec<Commit>>,
pub errors: Option<Vec<BatchGetCommitsError>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.commits: Option<Vec<Commit>>An array of commit data type objects, each of which contains information about a specified commit.
errors: Option<Vec<BatchGetCommitsError>>Returns any commit IDs for which information could not be found. For example, if one of the commit IDs was a shortened SHA ID or that commit was not found in the specified repository, the ID returns an error object with more information.
Implementations
Creates a new builder-style object to manufacture BatchGetCommitsOutput