Struct aws_sdk_codecommit::output::BatchGetRepositoriesOutput [−][src]
#[non_exhaustive]pub struct BatchGetRepositoriesOutput {
pub repositories: Option<Vec<RepositoryMetadata>>,
pub repositories_not_found: Option<Vec<String>>,
}Expand description
Represents the output of a batch get repositories operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repositories: Option<Vec<RepositoryMetadata>>A list of repositories returned by the batch get repositories operation.
repositories_not_found: Option<Vec<String>>Returns a list of repository names for which information could not be found.
Implementations
Creates a new builder-style object to manufacture BatchGetRepositoriesOutput