Struct aws_sdk_codecommit::output::CreateUnreferencedMergeCommitOutput [−][src]
#[non_exhaustive]pub struct CreateUnreferencedMergeCommitOutput {
pub commit_id: Option<String>,
pub tree_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.commit_id: Option<String>The full commit ID of the commit that contains your merge results.
tree_id: Option<String>The full SHA-1 pointer of the tree information for the commit that contains the merge results.
Implementations
Creates a new builder-style object to manufacture CreateUnreferencedMergeCommitOutput