Struct aws_sdk_codecommit::output::DeleteFileOutput [−][src]
#[non_exhaustive]pub struct DeleteFileOutput {
pub commit_id: Option<String>,
pub blob_id: Option<String>,
pub tree_id: Option<String>,
pub file_path: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.commit_id: Option<String>The full commit ID of the commit that contains the change that deletes the file.
blob_id: Option<String>The blob ID removed from the tree as part of deleting the file.
tree_id: Option<String>The full SHA-1 pointer of the tree information for the commit that contains the delete file change.
file_path: Option<String>The fully qualified path to the file to be deleted, including the full name and extension of that file.
Implementations
The full commit ID of the commit that contains the change that deletes the file.
The blob ID removed from the tree as part of deleting the file.
The full SHA-1 pointer of the tree information for the commit that contains the delete file change.
Creates a new builder-style object to manufacture DeleteFileOutput