Struct aws_sdk_codecommit::output::DescribeMergeConflictsOutput [−][src]
#[non_exhaustive]pub struct DescribeMergeConflictsOutput {
pub conflict_metadata: Option<ConflictMetadata>,
pub merge_hunks: Option<Vec<MergeHunk>>,
pub next_token: Option<String>,
pub destination_commit_id: Option<String>,
pub source_commit_id: Option<String>,
pub base_commit_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.conflict_metadata: Option<ConflictMetadata>Contains metadata about the conflicts found in the merge.
merge_hunks: Option<Vec<MergeHunk>>A list of merge hunks of the differences between the files or lines.
next_token: Option<String>An enumeration token that can be used in a request to return the next batch of the results.
destination_commit_id: Option<String>The commit ID of the destination commit specifier that was used in the merge evaluation.
source_commit_id: Option<String>The commit ID of the source commit specifier that was used in the merge evaluation.
base_commit_id: Option<String>The commit ID of the merge base.
Implementations
Contains metadata about the conflicts found in the merge.
A list of merge hunks of the differences between the files or lines.
An enumeration token that can be used in a request to return the next batch of the results.
The commit ID of the destination commit specifier that was used in the merge evaluation.
The commit ID of the source commit specifier that was used in the merge evaluation.
The commit ID of the merge base.
Creates a new builder-style object to manufacture DescribeMergeConflictsOutput