Struct aws_sdk_codecommit::output::EvaluatePullRequestApprovalRulesOutput [−][src]
#[non_exhaustive]pub struct EvaluatePullRequestApprovalRulesOutput {
pub evaluation: Option<Evaluation>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.evaluation: Option<Evaluation>The result of the evaluation, including the names of the rules whose conditions have been met (if any), the names of the rules whose conditions have not been met (if any), whether the pull request is in the approved state, and whether the pull request approval rule has been set aside by an override.
Implementations
The result of the evaluation, including the names of the rules whose conditions have been met (if any), the names of the rules whose conditions have not been met (if any), whether the pull request is in the approved state, and whether the pull request approval rule has been set aside by an override.
Creates a new builder-style object to manufacture EvaluatePullRequestApprovalRulesOutput