Struct aws_sdk_codecommit::output::GetCommentReactionsOutput [−][src]
#[non_exhaustive]pub struct GetCommentReactionsOutput {
pub reactions_for_comment: Option<Vec<ReactionForComment>>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.reactions_for_comment: Option<Vec<ReactionForComment>>An array of reactions to the specified comment.
next_token: Option<String>An enumeration token that can be used in a request to return the next batch of the results.
Implementations
An array of reactions to the specified comment.
An enumeration token that can be used in a request to return the next batch of the results.
Creates a new builder-style object to manufacture GetCommentReactionsOutput