Struct aws_sdk_codecommit::output::GetCommentsForComparedCommitOutput [−][src]
#[non_exhaustive]pub struct GetCommentsForComparedCommitOutput {
pub comments_for_compared_commit_data: Option<Vec<CommentsForComparedCommit>>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.comments_for_compared_commit_data: Option<Vec<CommentsForComparedCommit>>A list of comment objects on the compared commit.
next_token: Option<String>An enumeration token that can be used in a request to return the next batch of the results.
Implementations
Creates a new builder-style object to manufacture GetCommentsForComparedCommitOutput