Struct aws_sdk_codecommit::output::GetDifferencesOutput [−][src]
#[non_exhaustive]pub struct GetDifferencesOutput {
pub differences: Option<Vec<Difference>>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.differences: Option<Vec<Difference>>A data type object that contains information about the differences, including whether the difference is added, modified, or deleted (A, D, M).
next_token: Option<String>An enumeration token that can be used in a request to return the next batch of the results.
Implementations
A data type object that contains information about the differences, including whether the difference is added, modified, or deleted (A, D, M).
An enumeration token that can be used in a request to return the next batch of the results.
Creates a new builder-style object to manufacture GetDifferencesOutput