Struct aws_sdk_codecommit::output::GetFileOutput [−][src]
#[non_exhaustive]pub struct GetFileOutput {
pub commit_id: Option<String>,
pub blob_id: Option<String>,
pub file_path: Option<String>,
pub file_mode: Option<FileModeTypeEnum>,
pub file_size: i64,
pub file_content: Option<Blob>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.commit_id: Option<String>The full commit ID of the commit that contains the content returned by GetFile.
blob_id: Option<String>The blob ID of the object that represents the file content.
file_path: Option<String>The fully qualified path to the specified file. Returns the name and extension of the file.
file_mode: Option<FileModeTypeEnum>The extrapolated file mode permissions of the blob. Valid values include strings such as EXECUTABLE and not numeric values.
The file mode permissions returned by this API are not the standard file mode permission values, such as 100644, but rather extrapolated values. See the supported return values.
file_size: i64The size of the contents of the file, in bytes.
file_content: Option<Blob>The base-64 encoded binary data object that represents the content of the file.
Implementations
The full commit ID of the commit that contains the content returned by GetFile.
The blob ID of the object that represents the file content.
The fully qualified path to the specified file. Returns the name and extension of the file.
The extrapolated file mode permissions of the blob. Valid values include strings such as EXECUTABLE and not numeric values.
The file mode permissions returned by this API are not the standard file mode permission values, such as 100644, but rather extrapolated values. See the supported return values.
The base-64 encoded binary data object that represents the content of the file.
Creates a new builder-style object to manufacture GetFileOutput