Struct aws_sdk_codecommit::output::GetFolderOutput [−][src]
#[non_exhaustive]pub struct GetFolderOutput {
pub commit_id: Option<String>,
pub folder_path: Option<String>,
pub tree_id: Option<String>,
pub sub_folders: Option<Vec<Folder>>,
pub files: Option<Vec<File>>,
pub symbolic_links: Option<Vec<SymbolicLink>>,
pub sub_modules: Option<Vec<SubModule>>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.commit_id: Option<String>The full commit ID used as a reference for the returned version of the folder content.
folder_path: Option<String>The fully qualified path of the folder whose contents are returned.
tree_id: Option<String>The full SHA-1 pointer of the tree information for the commit that contains the folder.
sub_folders: Option<Vec<Folder>>The list of folders that exist under the specified folder, if any.
files: Option<Vec<File>>The list of files in the specified folder, if any.
symbolic_links: Option<Vec<SymbolicLink>>The list of symbolic links to other files and folders in the specified folder, if any.
sub_modules: Option<Vec<SubModule>>The list of submodules in the specified folder, if any.
Implementations
The full commit ID used as a reference for the returned version of the folder content.
The fully qualified path of the folder whose contents are returned.
The full SHA-1 pointer of the tree information for the commit that contains the folder.
The list of folders that exist under the specified folder, if any.
The list of symbolic links to other files and folders in the specified folder, if any.
Creates a new builder-style object to manufacture GetFolderOutput