Struct aws_sdk_codecommit::output::GetMergeCommitOutput [−][src]
#[non_exhaustive]pub struct GetMergeCommitOutput {
pub source_commit_id: Option<String>,
pub destination_commit_id: Option<String>,
pub base_commit_id: Option<String>,
pub merged_commit_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.source_commit_id: Option<String>The commit ID of the source commit specifier that was used in the merge evaluation.
destination_commit_id: Option<String>The commit ID of the destination commit specifier that was used in the merge evaluation.
base_commit_id: Option<String>The commit ID of the merge base.
merged_commit_id: Option<String>The commit ID for the merge commit created when the source branch was merged into the destination branch. If the fast-forward merge strategy was used, there is no merge commit.
Implementations
The commit ID of the source commit specifier that was used in the merge evaluation.
The commit ID of the destination commit specifier that was used in the merge evaluation.
The commit ID of the merge base.
The commit ID for the merge commit created when the source branch was merged into the destination branch. If the fast-forward merge strategy was used, there is no merge commit.
Creates a new builder-style object to manufacture GetMergeCommitOutput