Struct aws_sdk_codecommit::output::GetMergeOptionsOutput [−][src]
#[non_exhaustive]pub struct GetMergeOptionsOutput {
pub merge_options: Option<Vec<MergeOptionTypeEnum>>,
pub source_commit_id: Option<String>,
pub destination_commit_id: Option<String>,
pub base_commit_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.merge_options: Option<Vec<MergeOptionTypeEnum>>The merge option or strategy used to merge the code.
source_commit_id: Option<String>The commit ID of the source commit specifier that was used in the merge evaluation.
destination_commit_id: Option<String>The commit ID of the destination commit specifier that was used in the merge evaluation.
base_commit_id: Option<String>The commit ID of the merge base.
Implementations
Creates a new builder-style object to manufacture GetMergeOptionsOutput