Struct aws_sdk_codecommit::output::GetPullRequestOverrideStateOutput [−][src]
#[non_exhaustive]pub struct GetPullRequestOverrideStateOutput {
pub overridden: bool,
pub overrider: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.overridden: boolA Boolean value that indicates whether a pull request has had its rules set aside (TRUE) or whether all approval rules still apply (FALSE).
overrider: Option<String>The Amazon Resource Name (ARN) of the user or identity that overrode the rules and their requirements for the pull request.
Implementations
A Boolean value that indicates whether a pull request has had its rules set aside (TRUE) or whether all approval rules still apply (FALSE).
Creates a new builder-style object to manufacture GetPullRequestOverrideStateOutput