Struct aws_sdk_codecommit::output::ListApprovalRuleTemplatesOutput [−][src]
#[non_exhaustive]pub struct ListApprovalRuleTemplatesOutput {
pub approval_rule_template_names: Option<Vec<String>>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.approval_rule_template_names: Option<Vec<String>>The names of all the approval rule templates found in the AWS Region for your AWS account.
next_token: Option<String>An enumeration token that allows the operation to batch the next results of the operation.
Implementations
The names of all the approval rule templates found in the AWS Region for your AWS account.
An enumeration token that allows the operation to batch the next results of the operation.
Creates a new builder-style object to manufacture ListApprovalRuleTemplatesOutput