Struct aws_sdk_codecommit::output::ListRepositoriesForApprovalRuleTemplateOutput [−][src]
#[non_exhaustive]pub struct ListRepositoriesForApprovalRuleTemplateOutput {
pub repository_names: Option<Vec<String>>,
pub next_token: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_names: Option<Vec<String>>A list of repository names that are associated with the specified approval rule template.
next_token: Option<String>An enumeration token that allows the operation to batch the next results of the operation.
Implementations
A list of repository names that are associated with the specified approval rule template.
An enumeration token that allows the operation to batch the next results of the operation.
Creates a new builder-style object to manufacture ListRepositoriesForApprovalRuleTemplateOutput