Struct aws_sdk_codecommit::output::ListRepositoriesOutput [−][src]
#[non_exhaustive]pub struct ListRepositoriesOutput {
pub repositories: Option<Vec<RepositoryNameIdPair>>,
pub next_token: Option<String>,
}Expand description
Represents the output of a list repositories operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repositories: Option<Vec<RepositoryNameIdPair>>Lists the repositories called by the list repositories operation.
next_token: Option<String>An enumeration token that allows the operation to batch the results of the operation. Batch sizes are 1,000 for list repository operations. When the client sends the token back to AWS CodeCommit, another page of 1,000 records is retrieved.
Implementations
Creates a new builder-style object to manufacture ListRepositoriesOutput