Struct aws_sdk_codecommit::output::MergeBranchesBySquashOutput [−][src]
#[non_exhaustive]pub struct MergeBranchesBySquashOutput {
pub commit_id: Option<String>,
pub tree_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.commit_id: Option<String>The commit ID of the merge in the destination or target branch.
tree_id: Option<String>The tree ID of the merge in the destination or target branch.
Implementations
Creates a new builder-style object to manufacture MergeBranchesBySquashOutput