Struct aws_sdk_codecommit::output::PutFileOutput [−][src]
#[non_exhaustive]pub struct PutFileOutput {
pub commit_id: Option<String>,
pub blob_id: Option<String>,
pub tree_id: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.commit_id: Option<String>The full SHA ID of the commit that contains this file change.
blob_id: Option<String>The ID of the blob, which is its SHA-1 pointer.
tree_id: Option<String>The full SHA-1 pointer of the tree information for the commit that contains this file change.
Implementations
The full SHA ID of the commit that contains this file change.
Creates a new builder-style object to manufacture PutFileOutput