Struct aws_sdk_codecommit::output::TestRepositoryTriggersOutput [−][src]
#[non_exhaustive]pub struct TestRepositoryTriggersOutput {
pub successful_executions: Option<Vec<String>>,
pub failed_executions: Option<Vec<RepositoryTriggerExecutionFailure>>,
}Expand description
Represents the output of a test repository triggers operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.successful_executions: Option<Vec<String>>The list of triggers that were successfully tested. This list provides the names of the triggers that were successfully tested, separated by commas.
failed_executions: Option<Vec<RepositoryTriggerExecutionFailure>>The list of triggers that were not tested. This list provides the names of the triggers that could not be tested, separated by commas.
Implementations
The list of triggers that were successfully tested. This list provides the names of the triggers that were successfully tested, separated by commas.
The list of triggers that were not tested. This list provides the names of the triggers that could not be tested, separated by commas.
Creates a new builder-style object to manufacture TestRepositoryTriggersOutput