DiffHunkBuilder

Struct DiffHunkBuilder 

#[non_exhaustive]
pub struct DiffHunkBuilder { /* private fields */ }
A builder for DiffHunk.

Implementations

Source

impl DiffHunkBuilder

pub fn before_start_line(self, input: i32) -> Self

The 1-based line number in the before blob where this hunk begins. When the hunk consists entirely of additions, beforeLineCount is 0.

pub fn set_before_start_line(self, input: Option<i32>) -> Self

The 1-based line number in the before blob where this hunk begins. When the hunk consists entirely of additions, beforeLineCount is 0.

pub fn get_before_start_line(&self) -> &Option<i32>

The 1-based line number in the before blob where this hunk begins. When the hunk consists entirely of additions, beforeLineCount is 0.

pub fn before_line_count(self, input: i32) -> Self

The number of lines from the before blob covered by this hunk, including any context lines.

pub fn set_before_line_count(self, input: Option<i32>) -> Self

The number of lines from the before blob covered by this hunk, including any context lines.

pub fn get_before_line_count(&self) -> &Option<i32>

The number of lines from the before blob covered by this hunk, including any context lines.

pub fn after_start_line(self, input: i32) -> Self

The 1-based line number in the after blob where this hunk begins. When the hunk consists entirely of deletions, afterLineCount is 0.

pub fn set_after_start_line(self, input: Option<i32>) -> Self

The 1-based line number in the after blob where this hunk begins. When the hunk consists entirely of deletions, afterLineCount is 0.

pub fn get_after_start_line(&self) -> &Option<i32>

The 1-based line number in the after blob where this hunk begins. When the hunk consists entirely of deletions, afterLineCount is 0.

pub fn after_line_count(self, input: i32) -> Self

The number of lines from the after blob covered by this hunk, including any context lines.

pub fn set_after_line_count(self, input: Option<i32>) -> Self

The number of lines from the after blob covered by this hunk, including any context lines.

pub fn get_after_line_count(&self) -> &Option<i32>

The number of lines from the after blob covered by this hunk, including any context lines.

pub fn changes(self, input: DiffChange) -> Self

Appends an item to changes.

To override the contents of this collection use set_changes.

An ordered list of line-level changes that make up this hunk. Each entry indicates whether the line is unchanged context, an addition, or a deletion.

pub fn set_changes(self, input: Option<Vec<DiffChange>>) -> Self

An ordered list of line-level changes that make up this hunk. Each entry indicates whether the line is unchanged context, an addition, or a deletion.

pub fn get_changes(&self) -> &Option<Vec<DiffChange>>

An ordered list of line-level changes that make up this hunk. Each entry indicates whether the line is unchanged context, an addition, or a deletion.

pub fn build(self) -> DiffHunk

Consumes the builder and constructs a DiffHunk.