DiffHunk

Struct DiffHunk 

#[non_exhaustive]
pub struct DiffHunk { pub before_start_line: Option<i32>, pub before_line_count: Option<i32>, pub after_start_line: Option<i32>, pub after_line_count: Option<i32>, pub changes: Option<Vec<DiffChange>>, }
A contiguous run of changed lines from a blob diff, together with any surrounding unchanged context lines. Hunks are returned in order from the start of the file to the end. Adjacent or overlapping hunks are merged into a single hunk in the response.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
before_start_line: Option<i32>

The 1-based line number in the before blob where this hunk begins. When the hunk consists entirely of additions, beforeLineCount is 0.

before_line_count: Option<i32>

The number of lines from the before blob covered by this hunk, including any context lines.

after_start_line: Option<i32>

The 1-based line number in the after blob where this hunk begins. When the hunk consists entirely of deletions, afterLineCount is 0.

after_line_count: Option<i32>

The number of lines from the after blob covered by this hunk, including any context lines.

changes: Option<Vec<DiffChange>>

An ordered list of line-level changes that make up this hunk. Each entry indicates whether the line is unchanged context, an addition, or a deletion.

Implementations

Source

impl DiffHunk

pub fn before_start_line(&self) -> Option<i32>

The 1-based line number in the before blob where this hunk begins. When the hunk consists entirely of additions, beforeLineCount is 0.

pub fn before_line_count(&self) -> Option<i32>

The number of lines from the before blob covered by this hunk, including any context lines.

pub fn after_start_line(&self) -> Option<i32>

The 1-based line number in the after blob where this hunk begins. When the hunk consists entirely of deletions, afterLineCount is 0.

pub fn after_line_count(&self) -> Option<i32>

The number of lines from the after blob covered by this hunk, including any context lines.

pub fn changes(&self) -> &[DiffChange]

An ordered list of line-level changes that make up this hunk. Each entry indicates whether the line is unchanged context, an addition, or a deletion.

If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .changes.is_none().

Source

impl DiffHunk

pub fn builder() -> DiffHunkBuilder

Creates a new builder-style object to manufacture DiffHunk.