Struct aws_sdk_codecommit::client::fluent_builders::GetBranch [−][src]
pub struct GetBranch<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to GetBranch.
Returns information about a repository branch, including its name and the last commit ID.
Implementations
impl<C, M, R> GetBranch<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> GetBranch<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(self) -> Result<GetBranchOutput, SdkError<GetBranchError>> where
R::Policy: SmithyRetryPolicy<GetBranchInputOperationOutputAlias, GetBranchOutput, GetBranchError, GetBranchInputOperationRetryAlias>,
pub async fn send(self) -> Result<GetBranchOutput, SdkError<GetBranchError>> where
R::Policy: SmithyRetryPolicy<GetBranchInputOperationOutputAlias, GetBranchOutput, GetBranchError, GetBranchInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The name of the repository that contains the branch for which you want to retrieve information.
The name of the repository that contains the branch for which you want to retrieve information.
The name of the branch for which you want to retrieve information.
The name of the branch for which you want to retrieve information.