Struct aws_sdk_codecommit::client::fluent_builders::OverridePullRequestApprovalRules[][src]

pub struct OverridePullRequestApprovalRules<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }
Fluent builder constructing a request to OverridePullRequestApprovalRules.

Sets aside (overrides) all approval rule requirements for a specified pull request.

Implementations

Sends the request and returns the response.

If an error occurs, an SdkError will be returned with additional details that can be matched against.

By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.

The system-generated ID of the pull request for which you want to override all approval rule requirements. To get this information, use GetPullRequest.

The system-generated ID of the pull request for which you want to override all approval rule requirements. To get this information, use GetPullRequest.

The system-generated ID of the most recent revision of the pull request. You cannot override approval rules for anything but the most recent revision of a pull request. To get the revision ID, use GetPullRequest.

The system-generated ID of the most recent revision of the pull request. You cannot override approval rules for anything but the most recent revision of a pull request. To get the revision ID, use GetPullRequest.

Whether you want to set aside approval rule requirements for the pull request (OVERRIDE) or revoke a previous override and apply approval rule requirements (REVOKE). REVOKE status is not stored.

Whether you want to set aside approval rule requirements for the pull request (OVERRIDE) or revoke a previous override and apply approval rule requirements (REVOKE). REVOKE status is not stored.