Struct aws_sdk_codecommit::client::fluent_builders::PutCommentReaction [−][src]
pub struct PutCommentReaction<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to PutCommentReaction.
Adds or updates a reaction to a specified comment for the user whose identity is used to make the request. You can only add or update a reaction for yourself. You cannot add, modify, or delete a reaction for another user.
Implementations
impl<C, M, R> PutCommentReaction<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> PutCommentReaction<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<PutCommentReactionOutput, SdkError<PutCommentReactionError>> where
R::Policy: SmithyRetryPolicy<PutCommentReactionInputOperationOutputAlias, PutCommentReactionOutput, PutCommentReactionError, PutCommentReactionInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<PutCommentReactionOutput, SdkError<PutCommentReactionError>> where
R::Policy: SmithyRetryPolicy<PutCommentReactionInputOperationOutputAlias, PutCommentReactionOutput, PutCommentReactionError, PutCommentReactionInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The ID of the comment to which you want to add or update a reaction.
The ID of the comment to which you want to add or update a reaction.
The emoji reaction you want to add or update. To remove a reaction, provide a value of blank or null. You can also provide the value of none. For information about emoji reaction values supported in AWS CodeCommit, see the AWS CodeCommit User Guide.
The emoji reaction you want to add or update. To remove a reaction, provide a value of blank or null. You can also provide the value of none. For information about emoji reaction values supported in AWS CodeCommit, see the AWS CodeCommit User Guide.