Struct aws_sdk_codecommit::client::fluent_builders::UpdateDefaultBranch [−][src]
pub struct UpdateDefaultBranch<C = DynConnector, M = AwsMiddleware, R = Standard> { /* fields omitted */ }Expand description
Fluent builder constructing a request to UpdateDefaultBranch.
Sets or changes the default branch name for the specified repository.
If you use this operation to change the default branch name to the current default branch name, a success message is returned even though the default branch did not change.
Implementations
impl<C, M, R> UpdateDefaultBranch<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
impl<C, M, R> UpdateDefaultBranch<C, M, R> where
C: SmithyConnector,
M: SmithyMiddleware<C>,
R: NewRequestPolicy,
pub async fn send(
self
) -> Result<UpdateDefaultBranchOutput, SdkError<UpdateDefaultBranchError>> where
R::Policy: SmithyRetryPolicy<UpdateDefaultBranchInputOperationOutputAlias, UpdateDefaultBranchOutput, UpdateDefaultBranchError, UpdateDefaultBranchInputOperationRetryAlias>,
pub async fn send(
self
) -> Result<UpdateDefaultBranchOutput, SdkError<UpdateDefaultBranchError>> where
R::Policy: SmithyRetryPolicy<UpdateDefaultBranchInputOperationOutputAlias, UpdateDefaultBranchOutput, UpdateDefaultBranchError, UpdateDefaultBranchInputOperationRetryAlias>,
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
The name of the repository to set or change the default branch for.
The name of the repository to set or change the default branch for.
The name of the branch to set as the default.
The name of the branch to set as the default.