Enum aws_sdk_codecommit::error::AssociateApprovalRuleTemplateWithRepositoryErrorKind [−][src]
#[non_exhaustive]
pub enum AssociateApprovalRuleTemplateWithRepositoryErrorKind {
Show 13 variants
ApprovalRuleTemplateDoesNotExistException(ApprovalRuleTemplateDoesNotExistException),
ApprovalRuleTemplateNameRequiredException(ApprovalRuleTemplateNameRequiredException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidApprovalRuleTemplateNameException(InvalidApprovalRuleTemplateNameException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
MaximumRuleTemplatesAssociatedWithRepositoryException(MaximumRuleTemplatesAssociatedWithRepositoryException),
RepositoryDoesNotExistException(RepositoryDoesNotExistException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the AssociateApprovalRuleTemplateWithRepository operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ApprovalRuleTemplateDoesNotExistException(ApprovalRuleTemplateDoesNotExistException)The specified approval rule template does not exist. Verify that the name is correct and that you are signed in to the AWS Region where the template was created, and then try again.
Tuple Fields of ApprovalRuleTemplateDoesNotExistException
ApprovalRuleTemplateNameRequiredException(ApprovalRuleTemplateNameRequiredException)An approval rule template name is required, but was not specified.
Tuple Fields of ApprovalRuleTemplateNameRequiredException
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)An encryption integrity check failed.
Tuple Fields of EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)An encryption key could not be accessed.
Tuple Fields of EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)The encryption key is disabled.
Tuple Fields of EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)No encryption key was found.
Tuple Fields of EncryptionKeyNotFoundException
The encryption key is not available.
InvalidApprovalRuleTemplateNameException(InvalidApprovalRuleTemplateNameException)The name of the approval rule template is not valid. Template names must be between 1 and 100 valid characters in length. For more information about limits in AWS CodeCommit, see AWS CodeCommit User Guide.
Tuple Fields of InvalidApprovalRuleTemplateNameException
InvalidRepositoryNameException(InvalidRepositoryNameException)A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
Tuple Fields of InvalidRepositoryNameException
MaximumRuleTemplatesAssociatedWithRepositoryException(MaximumRuleTemplatesAssociatedWithRepositoryException)The maximum number of approval rule templates for a repository has been exceeded. You cannot associate more than 25 approval rule templates with a repository.
Tuple Fields of MaximumRuleTemplatesAssociatedWithRepositoryException
RepositoryDoesNotExistException(RepositoryDoesNotExistException)The specified repository does not exist.
Tuple Fields of RepositoryDoesNotExistException
RepositoryNameRequiredException(RepositoryNameRequiredException)A repository name is required, but was not specified.
Tuple Fields of RepositoryNameRequiredException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code