Enum aws_sdk_codecommit::error::BatchGetRepositoriesErrorKind [−][src]
#[non_exhaustive]
pub enum BatchGetRepositoriesErrorKind {
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
MaximumRepositoryNamesExceededException(MaximumRepositoryNamesExceededException),
RepositoryNamesRequiredException(RepositoryNamesRequiredException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the BatchGetRepositories operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)An encryption integrity check failed.
Tuple Fields of EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)An encryption key could not be accessed.
Tuple Fields of EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)The encryption key is disabled.
Tuple Fields of EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)No encryption key was found.
Tuple Fields of EncryptionKeyNotFoundException
The encryption key is not available.
InvalidRepositoryNameException(InvalidRepositoryNameException)A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
Tuple Fields of InvalidRepositoryNameException
MaximumRepositoryNamesExceededException(MaximumRepositoryNamesExceededException)The maximum number of allowed repository names was exceeded. Currently, this number is 100.
Tuple Fields of MaximumRepositoryNamesExceededException
RepositoryNamesRequiredException(RepositoryNamesRequiredException)At least one repository name object is required, but was not specified.
Tuple Fields of RepositoryNamesRequiredException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code