Enum aws_sdk_codecommit::error::CreateRepositoryErrorKind [−][src]
#[non_exhaustive]
pub enum CreateRepositoryErrorKind {
Show 15 variants
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidRepositoryDescriptionException(InvalidRepositoryDescriptionException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
InvalidSystemTagUsageException(InvalidSystemTagUsageException),
InvalidTagsMapException(InvalidTagsMapException),
RepositoryLimitExceededException(RepositoryLimitExceededException),
RepositoryNameExistsException(RepositoryNameExistsException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
TagPolicyException(TagPolicyException),
TooManyTagsException(TooManyTagsException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the CreateRepository operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)An encryption integrity check failed.
Tuple Fields of EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)An encryption key could not be accessed.
Tuple Fields of EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)The encryption key is disabled.
Tuple Fields of EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)No encryption key was found.
Tuple Fields of EncryptionKeyNotFoundException
The encryption key is not available.
InvalidRepositoryDescriptionException(InvalidRepositoryDescriptionException)The specified repository description is not valid.
Tuple Fields of InvalidRepositoryDescriptionException
InvalidRepositoryNameException(InvalidRepositoryNameException)A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
Tuple Fields of InvalidRepositoryNameException
InvalidSystemTagUsageException(InvalidSystemTagUsageException)The specified tag is not valid. Key names cannot be prefixed with aws:.
Tuple Fields of InvalidSystemTagUsageException
InvalidTagsMapException(InvalidTagsMapException)The map of tags is not valid.
Tuple Fields of InvalidTagsMapException
RepositoryLimitExceededException(RepositoryLimitExceededException)A repository resource limit was exceeded.
Tuple Fields of RepositoryLimitExceededException
RepositoryNameExistsException(RepositoryNameExistsException)The specified repository name already exists.
Tuple Fields of RepositoryNameExistsException
RepositoryNameRequiredException(RepositoryNameRequiredException)A repository name is required, but was not specified.
Tuple Fields of RepositoryNameRequiredException
TagPolicyException(TagPolicyException)The tag policy is not valid.
Tuple Fields of TagPolicyException
TooManyTagsException(TooManyTagsException)The maximum number of tags for an AWS CodeCommit resource has been exceeded.
Tuple Fields of TooManyTagsException
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code