Enum aws_sdk_codecommit::error::DeleteFileErrorKind [−][src]
#[non_exhaustive]
pub enum DeleteFileErrorKind {
Show 23 variants
BranchDoesNotExistException(BranchDoesNotExistException),
BranchNameIsTagNameException(BranchNameIsTagNameException),
BranchNameRequiredException(BranchNameRequiredException),
CommitMessageLengthExceededException(CommitMessageLengthExceededException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
FileDoesNotExistException(FileDoesNotExistException),
InvalidBranchNameException(InvalidBranchNameException),
InvalidEmailException(InvalidEmailException),
InvalidParentCommitIdException(InvalidParentCommitIdException),
InvalidPathException(InvalidPathException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
NameLengthExceededException(NameLengthExceededException),
ParentCommitDoesNotExistException(ParentCommitDoesNotExistException),
ParentCommitIdOutdatedException(ParentCommitIdOutdatedException),
ParentCommitIdRequiredException(ParentCommitIdRequiredException),
PathRequiredException(PathRequiredException),
RepositoryDoesNotExistException(RepositoryDoesNotExistException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the DeleteFile operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BranchDoesNotExistException(BranchDoesNotExistException)The specified branch does not exist.
Tuple Fields of BranchDoesNotExistException
BranchNameIsTagNameException(BranchNameIsTagNameException)The specified branch name is not valid because it is a tag name. Enter the name of a branch in the repository. For a list of valid branch names, use ListBranches.
Tuple Fields of BranchNameIsTagNameException
BranchNameRequiredException(BranchNameRequiredException)A branch name is required, but was not specified.
Tuple Fields of BranchNameRequiredException
CommitMessageLengthExceededException(CommitMessageLengthExceededException)The commit message is too long. Provide a shorter string.
Tuple Fields of CommitMessageLengthExceededException
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)An encryption integrity check failed.
Tuple Fields of EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)An encryption key could not be accessed.
Tuple Fields of EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)The encryption key is disabled.
Tuple Fields of EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)No encryption key was found.
Tuple Fields of EncryptionKeyNotFoundException
The encryption key is not available.
FileDoesNotExistException(FileDoesNotExistException)The specified file does not exist. Verify that you have used the correct file name, full path, and extension.
Tuple Fields of FileDoesNotExistException
InvalidBranchNameException(InvalidBranchNameException)The specified reference name is not valid.
Tuple Fields of InvalidBranchNameException
InvalidEmailException(InvalidEmailException)The specified email address either contains one or more characters that are not allowed, or it exceeds the maximum number of characters allowed for an email address.
Tuple Fields of InvalidEmailException
InvalidParentCommitIdException(InvalidParentCommitIdException)The parent commit ID is not valid. The commit ID cannot be empty, and must match the head commit ID for the branch of the repository where you want to add or update a file.
Tuple Fields of InvalidParentCommitIdException
InvalidPathException(InvalidPathException)The specified path is not valid.
Tuple Fields of InvalidPathException
InvalidRepositoryNameException(InvalidRepositoryNameException)A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
Tuple Fields of InvalidRepositoryNameException
NameLengthExceededException(NameLengthExceededException)The user name is not valid because it has exceeded the character limit for author names.
Tuple Fields of NameLengthExceededException
ParentCommitDoesNotExistException(ParentCommitDoesNotExistException)The parent commit ID is not valid because it does not exist. The specified parent commit ID does not exist in the specified branch of the repository.
Tuple Fields of ParentCommitDoesNotExistException
ParentCommitIdOutdatedException(ParentCommitIdOutdatedException)The file could not be added because the provided parent commit ID is not the current tip of the specified branch. To view the full commit ID of the current head of the branch, use GetBranch.
Tuple Fields of ParentCommitIdOutdatedException
ParentCommitIdRequiredException(ParentCommitIdRequiredException)A parent commit ID is required. To view the full commit ID of a branch in a repository, use GetBranch or a Git command (for example, git pull or git log).
Tuple Fields of ParentCommitIdRequiredException
PathRequiredException(PathRequiredException)The folderPath for a location cannot be null.
Tuple Fields of PathRequiredException
RepositoryDoesNotExistException(RepositoryDoesNotExistException)The specified repository does not exist.
Tuple Fields of RepositoryDoesNotExistException
RepositoryNameRequiredException(RepositoryNameRequiredException)A repository name is required, but was not specified.
Tuple Fields of RepositoryNameRequiredException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code