Enum aws_sdk_codecommit::error::DeletePullRequestApprovalRuleErrorKind [−][src]
#[non_exhaustive]
pub enum DeletePullRequestApprovalRuleErrorKind {
Show 13 variants
ApprovalRuleNameRequiredException(ApprovalRuleNameRequiredException),
CannotDeleteApprovalRuleFromTemplateException(CannotDeleteApprovalRuleFromTemplateException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidApprovalRuleNameException(InvalidApprovalRuleNameException),
InvalidPullRequestIdException(InvalidPullRequestIdException),
PullRequestAlreadyClosedException(PullRequestAlreadyClosedException),
PullRequestDoesNotExistException(PullRequestDoesNotExistException),
PullRequestIdRequiredException(PullRequestIdRequiredException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the DeletePullRequestApprovalRule operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ApprovalRuleNameRequiredException(ApprovalRuleNameRequiredException)An approval rule name is required, but was not specified.
Tuple Fields of ApprovalRuleNameRequiredException
CannotDeleteApprovalRuleFromTemplateException(CannotDeleteApprovalRuleFromTemplateException)The approval rule cannot be deleted from the pull request because it was created by an approval rule template and applied to the pull request automatically.
Tuple Fields of CannotDeleteApprovalRuleFromTemplateException
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)An encryption integrity check failed.
Tuple Fields of EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)An encryption key could not be accessed.
Tuple Fields of EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)The encryption key is disabled.
Tuple Fields of EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)No encryption key was found.
Tuple Fields of EncryptionKeyNotFoundException
The encryption key is not available.
InvalidApprovalRuleNameException(InvalidApprovalRuleNameException)The name for the approval rule is not valid.
Tuple Fields of InvalidApprovalRuleNameException
InvalidPullRequestIdException(InvalidPullRequestIdException)The pull request ID is not valid. Make sure that you have provided the full ID and that the pull request is in the specified repository, and then try again.
Tuple Fields of InvalidPullRequestIdException
PullRequestAlreadyClosedException(PullRequestAlreadyClosedException)The pull request status cannot be updated because it is already closed.
Tuple Fields of PullRequestAlreadyClosedException
PullRequestDoesNotExistException(PullRequestDoesNotExistException)The pull request ID could not be found. Make sure that you have specified the correct repository name and pull request ID, and then try again.
Tuple Fields of PullRequestDoesNotExistException
PullRequestIdRequiredException(PullRequestIdRequiredException)A pull request ID is required, but none was provided.
Tuple Fields of PullRequestIdRequiredException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code