Enum aws_sdk_codecommit::error::GetCommentErrorKind [−][src]
#[non_exhaustive]
pub enum GetCommentErrorKind {
CommentDeletedException(CommentDeletedException),
CommentDoesNotExistException(CommentDoesNotExistException),
CommentIdRequiredException(CommentIdRequiredException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidCommentIdException(InvalidCommentIdException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the GetComment operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
CommentDeletedException(CommentDeletedException)This comment has already been deleted. You cannot edit or delete a deleted comment.
Tuple Fields of CommentDeletedException
CommentDoesNotExistException(CommentDoesNotExistException)No comment exists with the provided ID. Verify that you have used the correct ID, and then try again.
Tuple Fields of CommentDoesNotExistException
CommentIdRequiredException(CommentIdRequiredException)The comment ID is missing or null. A comment ID is required.
Tuple Fields of CommentIdRequiredException
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)An encryption integrity check failed.
Tuple Fields of EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)An encryption key could not be accessed.
Tuple Fields of EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)The encryption key is disabled.
Tuple Fields of EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)No encryption key was found.
Tuple Fields of EncryptionKeyNotFoundException
The encryption key is not available.
InvalidCommentIdException(InvalidCommentIdException)The comment ID is not in a valid format. Make sure that you have provided the full comment ID.
Tuple Fields of InvalidCommentIdException
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code