Enum aws_sdk_codecommit::error::GetCommentsForPullRequestErrorKind[][src]

#[non_exhaustive]
pub enum GetCommentsForPullRequestErrorKind {
Show 18 variants CommitDoesNotExistException(CommitDoesNotExistException), CommitIdRequiredException(CommitIdRequiredException), EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException), EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException), EncryptionKeyDisabledException(EncryptionKeyDisabledException), EncryptionKeyNotFoundException(EncryptionKeyNotFoundException), EncryptionKeyUnavailableException(EncryptionKeyUnavailableException), InvalidCommitIdException(InvalidCommitIdException), InvalidContinuationTokenException(InvalidContinuationTokenException), InvalidMaxResultsException(InvalidMaxResultsException), InvalidPullRequestIdException(InvalidPullRequestIdException), InvalidRepositoryNameException(InvalidRepositoryNameException), PullRequestDoesNotExistException(PullRequestDoesNotExistException), PullRequestIdRequiredException(PullRequestIdRequiredException), RepositoryDoesNotExistException(RepositoryDoesNotExistException), RepositoryNameRequiredException(RepositoryNameRequiredException), RepositoryNotAssociatedWithPullRequestException(RepositoryNotAssociatedWithPullRequestException), Unhandled(Box<dyn Error + Send + Sync + 'static>),
}
Types of errors that can occur for the GetCommentsForPullRequest operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CommitDoesNotExistException(CommitDoesNotExistException)

The specified commit does not exist or no commit was specified, and the specified repository has no default branch.

Tuple Fields of CommitDoesNotExistException

0: CommitDoesNotExistException
CommitIdRequiredException(CommitIdRequiredException)

A commit ID was not specified.

Tuple Fields of CommitIdRequiredException

0: CommitIdRequiredException
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)

An encryption integrity check failed.

Tuple Fields of EncryptionIntegrityChecksFailedException

0: EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)

An encryption key could not be accessed.

Tuple Fields of EncryptionKeyAccessDeniedException

0: EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)

The encryption key is disabled.

Tuple Fields of EncryptionKeyDisabledException

0: EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)

No encryption key was found.

Tuple Fields of EncryptionKeyNotFoundException

0: EncryptionKeyNotFoundException
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)

The encryption key is not available.

Tuple Fields of EncryptionKeyUnavailableException

0: EncryptionKeyUnavailableException
InvalidCommitIdException(InvalidCommitIdException)

The specified commit ID is not valid.

Tuple Fields of InvalidCommitIdException

0: InvalidCommitIdException
InvalidContinuationTokenException(InvalidContinuationTokenException)

The specified continuation token is not valid.

Tuple Fields of InvalidContinuationTokenException

0: InvalidContinuationTokenException
InvalidMaxResultsException(InvalidMaxResultsException)

The specified number of maximum results is not valid.

Tuple Fields of InvalidMaxResultsException

0: InvalidMaxResultsException
InvalidPullRequestIdException(InvalidPullRequestIdException)

The pull request ID is not valid. Make sure that you have provided the full ID and that the pull request is in the specified repository, and then try again.

Tuple Fields of InvalidPullRequestIdException

0: InvalidPullRequestIdException
InvalidRepositoryNameException(InvalidRepositoryNameException)

A specified repository name is not valid.

This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.

Tuple Fields of InvalidRepositoryNameException

0: InvalidRepositoryNameException
PullRequestDoesNotExistException(PullRequestDoesNotExistException)

The pull request ID could not be found. Make sure that you have specified the correct repository name and pull request ID, and then try again.

Tuple Fields of PullRequestDoesNotExistException

0: PullRequestDoesNotExistException
PullRequestIdRequiredException(PullRequestIdRequiredException)

A pull request ID is required, but none was provided.

Tuple Fields of PullRequestIdRequiredException

0: PullRequestIdRequiredException
RepositoryDoesNotExistException(RepositoryDoesNotExistException)

The specified repository does not exist.

Tuple Fields of RepositoryDoesNotExistException

0: RepositoryDoesNotExistException
RepositoryNameRequiredException(RepositoryNameRequiredException)

A repository name is required, but was not specified.

Tuple Fields of RepositoryNameRequiredException

0: RepositoryNameRequiredException
RepositoryNotAssociatedWithPullRequestException(RepositoryNotAssociatedWithPullRequestException)

The repository does not contain any pull requests with that pull request ID. Use GetPullRequest to verify the correct repository name for the pull request ID.

Tuple Fields of RepositoryNotAssociatedWithPullRequestException

0: RepositoryNotAssociatedWithPullRequestException
Unhandled(Box<dyn Error + Send + Sync + 'static>)

An unexpected error, e.g. invalid JSON returned by the service or an unknown error code

Tuple Fields of Unhandled

0: Box<dyn Error + Send + Sync + 'static>