Enum aws_sdk_codecommit::error::MergeBranchesByFastForwardErrorKind[][src]

#[non_exhaustive]
pub enum MergeBranchesByFastForwardErrorKind {
Show 20 variants BranchDoesNotExistException(BranchDoesNotExistException), BranchNameIsTagNameException(BranchNameIsTagNameException), BranchNameRequiredException(BranchNameRequiredException), CommitDoesNotExistException(CommitDoesNotExistException), CommitRequiredException(CommitRequiredException), ConcurrentReferenceUpdateException(ConcurrentReferenceUpdateException), EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException), EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException), EncryptionKeyDisabledException(EncryptionKeyDisabledException), EncryptionKeyNotFoundException(EncryptionKeyNotFoundException), EncryptionKeyUnavailableException(EncryptionKeyUnavailableException), InvalidBranchNameException(InvalidBranchNameException), InvalidCommitException(InvalidCommitException), InvalidRepositoryNameException(InvalidRepositoryNameException), InvalidTargetBranchException(InvalidTargetBranchException), ManualMergeRequiredException(ManualMergeRequiredException), RepositoryDoesNotExistException(RepositoryDoesNotExistException), RepositoryNameRequiredException(RepositoryNameRequiredException), TipsDivergenceExceededException(TipsDivergenceExceededException), Unhandled(Box<dyn Error + Send + Sync + 'static>),
}
Types of errors that can occur for the MergeBranchesByFastForward operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BranchDoesNotExistException(BranchDoesNotExistException)

The specified branch does not exist.

Tuple Fields of BranchDoesNotExistException

0: BranchDoesNotExistException
BranchNameIsTagNameException(BranchNameIsTagNameException)

The specified branch name is not valid because it is a tag name. Enter the name of a branch in the repository. For a list of valid branch names, use ListBranches.

Tuple Fields of BranchNameIsTagNameException

0: BranchNameIsTagNameException
BranchNameRequiredException(BranchNameRequiredException)

A branch name is required, but was not specified.

Tuple Fields of BranchNameRequiredException

0: BranchNameRequiredException
CommitDoesNotExistException(CommitDoesNotExistException)

The specified commit does not exist or no commit was specified, and the specified repository has no default branch.

Tuple Fields of CommitDoesNotExistException

0: CommitDoesNotExistException
CommitRequiredException(CommitRequiredException)

A commit was not specified.

Tuple Fields of CommitRequiredException

0: CommitRequiredException
ConcurrentReferenceUpdateException(ConcurrentReferenceUpdateException)

The merge cannot be completed because the target branch has been modified. Another user might have modified the target branch while the merge was in progress. Wait a few minutes, and then try again.

Tuple Fields of ConcurrentReferenceUpdateException

0: ConcurrentReferenceUpdateException
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)

An encryption integrity check failed.

Tuple Fields of EncryptionIntegrityChecksFailedException

0: EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)

An encryption key could not be accessed.

Tuple Fields of EncryptionKeyAccessDeniedException

0: EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)

The encryption key is disabled.

Tuple Fields of EncryptionKeyDisabledException

0: EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)

No encryption key was found.

Tuple Fields of EncryptionKeyNotFoundException

0: EncryptionKeyNotFoundException
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)

The encryption key is not available.

Tuple Fields of EncryptionKeyUnavailableException

0: EncryptionKeyUnavailableException
InvalidBranchNameException(InvalidBranchNameException)

The specified reference name is not valid.

Tuple Fields of InvalidBranchNameException

0: InvalidBranchNameException
InvalidCommitException(InvalidCommitException)

The specified commit is not valid.

Tuple Fields of InvalidCommitException

0: InvalidCommitException
InvalidRepositoryNameException(InvalidRepositoryNameException)

A specified repository name is not valid.

This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.

Tuple Fields of InvalidRepositoryNameException

0: InvalidRepositoryNameException
InvalidTargetBranchException(InvalidTargetBranchException)

The specified target branch is not valid.

Tuple Fields of InvalidTargetBranchException

0: InvalidTargetBranchException
ManualMergeRequiredException(ManualMergeRequiredException)

The pull request cannot be merged automatically into the destination branch. You must manually merge the branches and resolve any conflicts.

Tuple Fields of ManualMergeRequiredException

0: ManualMergeRequiredException
RepositoryDoesNotExistException(RepositoryDoesNotExistException)

The specified repository does not exist.

Tuple Fields of RepositoryDoesNotExistException

0: RepositoryDoesNotExistException
RepositoryNameRequiredException(RepositoryNameRequiredException)

A repository name is required, but was not specified.

Tuple Fields of RepositoryNameRequiredException

0: RepositoryNameRequiredException
TipsDivergenceExceededException(TipsDivergenceExceededException)

The divergence between the tips of the provided commit specifiers is too great to determine whether there might be any merge conflicts. Locally compare the specifiers using git diff or a diff tool.

Tuple Fields of TipsDivergenceExceededException

0: TipsDivergenceExceededException
Unhandled(Box<dyn Error + Send + Sync + 'static>)

An unexpected error, e.g. invalid JSON returned by the service or an unknown error code

Tuple Fields of Unhandled

0: Box<dyn Error + Send + Sync + 'static>