Enum aws_sdk_codecommit::error::MergeBranchesByFastForwardErrorKind [−][src]
#[non_exhaustive]
pub enum MergeBranchesByFastForwardErrorKind {
Show 20 variants
BranchDoesNotExistException(BranchDoesNotExistException),
BranchNameIsTagNameException(BranchNameIsTagNameException),
BranchNameRequiredException(BranchNameRequiredException),
CommitDoesNotExistException(CommitDoesNotExistException),
CommitRequiredException(CommitRequiredException),
ConcurrentReferenceUpdateException(ConcurrentReferenceUpdateException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidBranchNameException(InvalidBranchNameException),
InvalidCommitException(InvalidCommitException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
InvalidTargetBranchException(InvalidTargetBranchException),
ManualMergeRequiredException(ManualMergeRequiredException),
RepositoryDoesNotExistException(RepositoryDoesNotExistException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
TipsDivergenceExceededException(TipsDivergenceExceededException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the MergeBranchesByFastForward operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BranchDoesNotExistException(BranchDoesNotExistException)The specified branch does not exist.
Tuple Fields of BranchDoesNotExistException
BranchNameIsTagNameException(BranchNameIsTagNameException)The specified branch name is not valid because it is a tag name. Enter the name of a branch in the repository. For a list of valid branch names, use ListBranches.
Tuple Fields of BranchNameIsTagNameException
BranchNameRequiredException(BranchNameRequiredException)A branch name is required, but was not specified.
Tuple Fields of BranchNameRequiredException
CommitDoesNotExistException(CommitDoesNotExistException)The specified commit does not exist or no commit was specified, and the specified repository has no default branch.
Tuple Fields of CommitDoesNotExistException
CommitRequiredException(CommitRequiredException)A commit was not specified.
Tuple Fields of CommitRequiredException
ConcurrentReferenceUpdateException(ConcurrentReferenceUpdateException)The merge cannot be completed because the target branch has been modified. Another user might have modified the target branch while the merge was in progress. Wait a few minutes, and then try again.
Tuple Fields of ConcurrentReferenceUpdateException
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)An encryption integrity check failed.
Tuple Fields of EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)An encryption key could not be accessed.
Tuple Fields of EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)The encryption key is disabled.
Tuple Fields of EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)No encryption key was found.
Tuple Fields of EncryptionKeyNotFoundException
The encryption key is not available.
InvalidBranchNameException(InvalidBranchNameException)The specified reference name is not valid.
Tuple Fields of InvalidBranchNameException
InvalidCommitException(InvalidCommitException)The specified commit is not valid.
Tuple Fields of InvalidCommitException
InvalidRepositoryNameException(InvalidRepositoryNameException)A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
Tuple Fields of InvalidRepositoryNameException
InvalidTargetBranchException(InvalidTargetBranchException)The specified target branch is not valid.
Tuple Fields of InvalidTargetBranchException
ManualMergeRequiredException(ManualMergeRequiredException)The pull request cannot be merged automatically into the destination branch. You must manually merge the branches and resolve any conflicts.
Tuple Fields of ManualMergeRequiredException
RepositoryDoesNotExistException(RepositoryDoesNotExistException)The specified repository does not exist.
Tuple Fields of RepositoryDoesNotExistException
RepositoryNameRequiredException(RepositoryNameRequiredException)A repository name is required, but was not specified.
Tuple Fields of RepositoryNameRequiredException
TipsDivergenceExceededException(TipsDivergenceExceededException)The divergence between the tips of the provided commit specifiers is too great to determine whether there might be
any merge conflicts. Locally compare the specifiers using git diff or a diff tool.
Tuple Fields of TipsDivergenceExceededException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code