Enum aws_sdk_codecommit::error::MergeBranchesBySquashErrorKind [−][src]
#[non_exhaustive]
pub enum MergeBranchesBySquashErrorKind {
Show 40 variants
BranchDoesNotExistException(BranchDoesNotExistException),
BranchNameIsTagNameException(BranchNameIsTagNameException),
BranchNameRequiredException(BranchNameRequiredException),
CommitDoesNotExistException(CommitDoesNotExistException),
CommitMessageLengthExceededException(CommitMessageLengthExceededException),
CommitRequiredException(CommitRequiredException),
ConcurrentReferenceUpdateException(ConcurrentReferenceUpdateException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
FileContentSizeLimitExceededException(FileContentSizeLimitExceededException),
FileModeRequiredException(FileModeRequiredException),
FolderContentSizeLimitExceededException(FolderContentSizeLimitExceededException),
InvalidBranchNameException(InvalidBranchNameException),
InvalidCommitException(InvalidCommitException),
InvalidConflictDetailLevelException(InvalidConflictDetailLevelException),
InvalidConflictResolutionException(InvalidConflictResolutionException),
InvalidConflictResolutionStrategyException(InvalidConflictResolutionStrategyException),
InvalidEmailException(InvalidEmailException),
InvalidFileModeException(InvalidFileModeException),
InvalidPathException(InvalidPathException),
InvalidReplacementContentException(InvalidReplacementContentException),
InvalidReplacementTypeException(InvalidReplacementTypeException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
InvalidTargetBranchException(InvalidTargetBranchException),
ManualMergeRequiredException(ManualMergeRequiredException),
MaximumConflictResolutionEntriesExceededException(MaximumConflictResolutionEntriesExceededException),
MaximumFileContentToLoadExceededException(MaximumFileContentToLoadExceededException),
MaximumItemsToCompareExceededException(MaximumItemsToCompareExceededException),
MultipleConflictResolutionEntriesException(MultipleConflictResolutionEntriesException),
NameLengthExceededException(NameLengthExceededException),
PathRequiredException(PathRequiredException),
ReplacementContentRequiredException(ReplacementContentRequiredException),
ReplacementTypeRequiredException(ReplacementTypeRequiredException),
RepositoryDoesNotExistException(RepositoryDoesNotExistException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
TipsDivergenceExceededException(TipsDivergenceExceededException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the MergeBranchesBySquash operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BranchDoesNotExistException(BranchDoesNotExistException)The specified branch does not exist.
Tuple Fields of BranchDoesNotExistException
BranchNameIsTagNameException(BranchNameIsTagNameException)The specified branch name is not valid because it is a tag name. Enter the name of a branch in the repository. For a list of valid branch names, use ListBranches.
Tuple Fields of BranchNameIsTagNameException
BranchNameRequiredException(BranchNameRequiredException)A branch name is required, but was not specified.
Tuple Fields of BranchNameRequiredException
CommitDoesNotExistException(CommitDoesNotExistException)The specified commit does not exist or no commit was specified, and the specified repository has no default branch.
Tuple Fields of CommitDoesNotExistException
CommitMessageLengthExceededException(CommitMessageLengthExceededException)The commit message is too long. Provide a shorter string.
Tuple Fields of CommitMessageLengthExceededException
CommitRequiredException(CommitRequiredException)A commit was not specified.
Tuple Fields of CommitRequiredException
ConcurrentReferenceUpdateException(ConcurrentReferenceUpdateException)The merge cannot be completed because the target branch has been modified. Another user might have modified the target branch while the merge was in progress. Wait a few minutes, and then try again.
Tuple Fields of ConcurrentReferenceUpdateException
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)An encryption integrity check failed.
Tuple Fields of EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)An encryption key could not be accessed.
Tuple Fields of EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)The encryption key is disabled.
Tuple Fields of EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)No encryption key was found.
Tuple Fields of EncryptionKeyNotFoundException
The encryption key is not available.
FileContentSizeLimitExceededException(FileContentSizeLimitExceededException)The file cannot be added because it is too large. The maximum file size is 6 MB, and the combined file content change size is 7 MB. Consider making these changes using a Git client.
Tuple Fields of FileContentSizeLimitExceededException
FileModeRequiredException(FileModeRequiredException)The commit cannot be created because no file mode has been specified. A file mode is required to update mode permissions for a file.
Tuple Fields of FileModeRequiredException
FolderContentSizeLimitExceededException(FolderContentSizeLimitExceededException)The commit cannot be created because at least one of the overall changes in the commit results in a folder whose contents exceed the limit of 6 MB. Either reduce the number and size of your changes, or split the changes across multiple folders.
Tuple Fields of FolderContentSizeLimitExceededException
InvalidBranchNameException(InvalidBranchNameException)The specified reference name is not valid.
Tuple Fields of InvalidBranchNameException
InvalidCommitException(InvalidCommitException)The specified commit is not valid.
Tuple Fields of InvalidCommitException
InvalidConflictDetailLevelException(InvalidConflictDetailLevelException)The specified conflict detail level is not valid.
Tuple Fields of InvalidConflictDetailLevelException
InvalidConflictResolutionException(InvalidConflictResolutionException)The specified conflict resolution list is not valid.
Tuple Fields of InvalidConflictResolutionException
InvalidConflictResolutionStrategyException(InvalidConflictResolutionStrategyException)The specified conflict resolution strategy is not valid.
Tuple Fields of InvalidConflictResolutionStrategyException
InvalidEmailException(InvalidEmailException)The specified email address either contains one or more characters that are not allowed, or it exceeds the maximum number of characters allowed for an email address.
Tuple Fields of InvalidEmailException
InvalidFileModeException(InvalidFileModeException)The specified file mode permission is not valid. For a list of valid file mode permissions, see PutFile.
Tuple Fields of InvalidFileModeException
InvalidPathException(InvalidPathException)The specified path is not valid.
Tuple Fields of InvalidPathException
InvalidReplacementContentException(InvalidReplacementContentException)Automerge was specified for resolving the conflict, but the replacement type is not valid or content is missing.
Tuple Fields of InvalidReplacementContentException
InvalidReplacementTypeException(InvalidReplacementTypeException)Automerge was specified for resolving the conflict, but the specified replacement type is not valid.
Tuple Fields of InvalidReplacementTypeException
InvalidRepositoryNameException(InvalidRepositoryNameException)A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
Tuple Fields of InvalidRepositoryNameException
InvalidTargetBranchException(InvalidTargetBranchException)The specified target branch is not valid.
Tuple Fields of InvalidTargetBranchException
ManualMergeRequiredException(ManualMergeRequiredException)The pull request cannot be merged automatically into the destination branch. You must manually merge the branches and resolve any conflicts.
Tuple Fields of ManualMergeRequiredException
MaximumConflictResolutionEntriesExceededException(MaximumConflictResolutionEntriesExceededException)The number of allowed conflict resolution entries was exceeded.
Tuple Fields of MaximumConflictResolutionEntriesExceededException
MaximumFileContentToLoadExceededException(MaximumFileContentToLoadExceededException)The number of files to load exceeds the allowed limit.
Tuple Fields of MaximumFileContentToLoadExceededException
MaximumItemsToCompareExceededException(MaximumItemsToCompareExceededException)The number of items to compare between the source or destination branches and the merge base has exceeded the maximum allowed.
Tuple Fields of MaximumItemsToCompareExceededException
MultipleConflictResolutionEntriesException(MultipleConflictResolutionEntriesException)More than one conflict resolution entries exists for the conflict. A conflict can have only one conflict resolution entry.
Tuple Fields of MultipleConflictResolutionEntriesException
NameLengthExceededException(NameLengthExceededException)The user name is not valid because it has exceeded the character limit for author names.
Tuple Fields of NameLengthExceededException
PathRequiredException(PathRequiredException)The folderPath for a location cannot be null.
Tuple Fields of PathRequiredException
ReplacementContentRequiredException(ReplacementContentRequiredException)USE_NEW_CONTENT was specified, but no replacement content has been provided.
Tuple Fields of ReplacementContentRequiredException
ReplacementTypeRequiredException(ReplacementTypeRequiredException)A replacement type is required.
Tuple Fields of ReplacementTypeRequiredException
RepositoryDoesNotExistException(RepositoryDoesNotExistException)The specified repository does not exist.
Tuple Fields of RepositoryDoesNotExistException
RepositoryNameRequiredException(RepositoryNameRequiredException)A repository name is required, but was not specified.
Tuple Fields of RepositoryNameRequiredException
TipsDivergenceExceededException(TipsDivergenceExceededException)The divergence between the tips of the provided commit specifiers is too great to determine whether there might be
any merge conflicts. Locally compare the specifiers using git diff or a diff tool.
Tuple Fields of TipsDivergenceExceededException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code