Enum aws_sdk_codecommit::error::MergePullRequestByFastForwardErrorKind[][src]

#[non_exhaustive]
pub enum MergePullRequestByFastForwardErrorKind {
Show 20 variants ConcurrentReferenceUpdateException(ConcurrentReferenceUpdateException), EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException), EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException), EncryptionKeyDisabledException(EncryptionKeyDisabledException), EncryptionKeyNotFoundException(EncryptionKeyNotFoundException), EncryptionKeyUnavailableException(EncryptionKeyUnavailableException), InvalidCommitIdException(InvalidCommitIdException), InvalidPullRequestIdException(InvalidPullRequestIdException), InvalidRepositoryNameException(InvalidRepositoryNameException), ManualMergeRequiredException(ManualMergeRequiredException), PullRequestAlreadyClosedException(PullRequestAlreadyClosedException), PullRequestApprovalRulesNotSatisfiedException(PullRequestApprovalRulesNotSatisfiedException), PullRequestDoesNotExistException(PullRequestDoesNotExistException), PullRequestIdRequiredException(PullRequestIdRequiredException), ReferenceDoesNotExistException(ReferenceDoesNotExistException), RepositoryDoesNotExistException(RepositoryDoesNotExistException), RepositoryNameRequiredException(RepositoryNameRequiredException), RepositoryNotAssociatedWithPullRequestException(RepositoryNotAssociatedWithPullRequestException), TipOfSourceReferenceIsDifferentException(TipOfSourceReferenceIsDifferentException), Unhandled(Box<dyn Error + Send + Sync + 'static>),
}
Types of errors that can occur for the MergePullRequestByFastForward operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ConcurrentReferenceUpdateException(ConcurrentReferenceUpdateException)

The merge cannot be completed because the target branch has been modified. Another user might have modified the target branch while the merge was in progress. Wait a few minutes, and then try again.

Tuple Fields of ConcurrentReferenceUpdateException

0: ConcurrentReferenceUpdateException
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)

An encryption integrity check failed.

Tuple Fields of EncryptionIntegrityChecksFailedException

0: EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)

An encryption key could not be accessed.

Tuple Fields of EncryptionKeyAccessDeniedException

0: EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)

The encryption key is disabled.

Tuple Fields of EncryptionKeyDisabledException

0: EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)

No encryption key was found.

Tuple Fields of EncryptionKeyNotFoundException

0: EncryptionKeyNotFoundException
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException)

The encryption key is not available.

Tuple Fields of EncryptionKeyUnavailableException

0: EncryptionKeyUnavailableException
InvalidCommitIdException(InvalidCommitIdException)

The specified commit ID is not valid.

Tuple Fields of InvalidCommitIdException

0: InvalidCommitIdException
InvalidPullRequestIdException(InvalidPullRequestIdException)

The pull request ID is not valid. Make sure that you have provided the full ID and that the pull request is in the specified repository, and then try again.

Tuple Fields of InvalidPullRequestIdException

0: InvalidPullRequestIdException
InvalidRepositoryNameException(InvalidRepositoryNameException)

A specified repository name is not valid.

This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.

Tuple Fields of InvalidRepositoryNameException

0: InvalidRepositoryNameException
ManualMergeRequiredException(ManualMergeRequiredException)

The pull request cannot be merged automatically into the destination branch. You must manually merge the branches and resolve any conflicts.

Tuple Fields of ManualMergeRequiredException

0: ManualMergeRequiredException
PullRequestAlreadyClosedException(PullRequestAlreadyClosedException)

The pull request status cannot be updated because it is already closed.

Tuple Fields of PullRequestAlreadyClosedException

0: PullRequestAlreadyClosedException
PullRequestApprovalRulesNotSatisfiedException(PullRequestApprovalRulesNotSatisfiedException)

The pull request cannot be merged because one or more approval rules applied to the pull request have conditions that have not been met.

Tuple Fields of PullRequestApprovalRulesNotSatisfiedException

0: PullRequestApprovalRulesNotSatisfiedException
PullRequestDoesNotExistException(PullRequestDoesNotExistException)

The pull request ID could not be found. Make sure that you have specified the correct repository name and pull request ID, and then try again.

Tuple Fields of PullRequestDoesNotExistException

0: PullRequestDoesNotExistException
PullRequestIdRequiredException(PullRequestIdRequiredException)

A pull request ID is required, but none was provided.

Tuple Fields of PullRequestIdRequiredException

0: PullRequestIdRequiredException
ReferenceDoesNotExistException(ReferenceDoesNotExistException)

The specified reference does not exist. You must provide a full commit ID.

Tuple Fields of ReferenceDoesNotExistException

0: ReferenceDoesNotExistException
RepositoryDoesNotExistException(RepositoryDoesNotExistException)

The specified repository does not exist.

Tuple Fields of RepositoryDoesNotExistException

0: RepositoryDoesNotExistException
RepositoryNameRequiredException(RepositoryNameRequiredException)

A repository name is required, but was not specified.

Tuple Fields of RepositoryNameRequiredException

0: RepositoryNameRequiredException
RepositoryNotAssociatedWithPullRequestException(RepositoryNotAssociatedWithPullRequestException)

The repository does not contain any pull requests with that pull request ID. Use GetPullRequest to verify the correct repository name for the pull request ID.

Tuple Fields of RepositoryNotAssociatedWithPullRequestException

0: RepositoryNotAssociatedWithPullRequestException
TipOfSourceReferenceIsDifferentException(TipOfSourceReferenceIsDifferentException)

The tip of the source branch in the destination repository does not match the tip of the source branch specified in your request. The pull request might have been updated. Make sure that you have the latest changes.

Tuple Fields of TipOfSourceReferenceIsDifferentException

0: TipOfSourceReferenceIsDifferentException
Unhandled(Box<dyn Error + Send + Sync + 'static>)

An unexpected error, e.g. invalid JSON returned by the service or an unknown error code

Tuple Fields of Unhandled

0: Box<dyn Error + Send + Sync + 'static>