Enum aws_sdk_codecommit::error::MergePullRequestByFastForwardErrorKind [−][src]
#[non_exhaustive]
pub enum MergePullRequestByFastForwardErrorKind {
Show 20 variants
ConcurrentReferenceUpdateException(ConcurrentReferenceUpdateException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidCommitIdException(InvalidCommitIdException),
InvalidPullRequestIdException(InvalidPullRequestIdException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
ManualMergeRequiredException(ManualMergeRequiredException),
PullRequestAlreadyClosedException(PullRequestAlreadyClosedException),
PullRequestApprovalRulesNotSatisfiedException(PullRequestApprovalRulesNotSatisfiedException),
PullRequestDoesNotExistException(PullRequestDoesNotExistException),
PullRequestIdRequiredException(PullRequestIdRequiredException),
ReferenceDoesNotExistException(ReferenceDoesNotExistException),
RepositoryDoesNotExistException(RepositoryDoesNotExistException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
RepositoryNotAssociatedWithPullRequestException(RepositoryNotAssociatedWithPullRequestException),
TipOfSourceReferenceIsDifferentException(TipOfSourceReferenceIsDifferentException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the MergePullRequestByFastForward operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ConcurrentReferenceUpdateException(ConcurrentReferenceUpdateException)The merge cannot be completed because the target branch has been modified. Another user might have modified the target branch while the merge was in progress. Wait a few minutes, and then try again.
Tuple Fields of ConcurrentReferenceUpdateException
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)An encryption integrity check failed.
Tuple Fields of EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)An encryption key could not be accessed.
Tuple Fields of EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)The encryption key is disabled.
Tuple Fields of EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)No encryption key was found.
Tuple Fields of EncryptionKeyNotFoundException
The encryption key is not available.
InvalidCommitIdException(InvalidCommitIdException)The specified commit ID is not valid.
Tuple Fields of InvalidCommitIdException
InvalidPullRequestIdException(InvalidPullRequestIdException)The pull request ID is not valid. Make sure that you have provided the full ID and that the pull request is in the specified repository, and then try again.
Tuple Fields of InvalidPullRequestIdException
InvalidRepositoryNameException(InvalidRepositoryNameException)A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
Tuple Fields of InvalidRepositoryNameException
ManualMergeRequiredException(ManualMergeRequiredException)The pull request cannot be merged automatically into the destination branch. You must manually merge the branches and resolve any conflicts.
Tuple Fields of ManualMergeRequiredException
PullRequestAlreadyClosedException(PullRequestAlreadyClosedException)The pull request status cannot be updated because it is already closed.
Tuple Fields of PullRequestAlreadyClosedException
PullRequestApprovalRulesNotSatisfiedException(PullRequestApprovalRulesNotSatisfiedException)The pull request cannot be merged because one or more approval rules applied to the pull request have conditions that have not been met.
Tuple Fields of PullRequestApprovalRulesNotSatisfiedException
PullRequestDoesNotExistException(PullRequestDoesNotExistException)The pull request ID could not be found. Make sure that you have specified the correct repository name and pull request ID, and then try again.
Tuple Fields of PullRequestDoesNotExistException
PullRequestIdRequiredException(PullRequestIdRequiredException)A pull request ID is required, but none was provided.
Tuple Fields of PullRequestIdRequiredException
ReferenceDoesNotExistException(ReferenceDoesNotExistException)The specified reference does not exist. You must provide a full commit ID.
Tuple Fields of ReferenceDoesNotExistException
RepositoryDoesNotExistException(RepositoryDoesNotExistException)The specified repository does not exist.
Tuple Fields of RepositoryDoesNotExistException
RepositoryNameRequiredException(RepositoryNameRequiredException)A repository name is required, but was not specified.
Tuple Fields of RepositoryNameRequiredException
RepositoryNotAssociatedWithPullRequestException(RepositoryNotAssociatedWithPullRequestException)The repository does not contain any pull requests with that pull request ID. Use GetPullRequest to verify the correct repository name for the pull request ID.
Tuple Fields of RepositoryNotAssociatedWithPullRequestException
TipOfSourceReferenceIsDifferentException(TipOfSourceReferenceIsDifferentException)The tip of the source branch in the destination repository does not match the tip of the source branch specified in your request. The pull request might have been updated. Make sure that you have the latest changes.
Tuple Fields of TipOfSourceReferenceIsDifferentException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code