Enum aws_sdk_codecommit::error::PostCommentForComparedCommitErrorKind [−][src]
#[non_exhaustive]
pub enum PostCommentForComparedCommitErrorKind {
Show 24 variants
BeforeCommitIdAndAfterCommitIdAreSameException(BeforeCommitIdAndAfterCommitIdAreSameException),
ClientRequestTokenRequiredException(ClientRequestTokenRequiredException),
CommentContentRequiredException(CommentContentRequiredException),
CommentContentSizeLimitExceededException(CommentContentSizeLimitExceededException),
CommitDoesNotExistException(CommitDoesNotExistException),
CommitIdRequiredException(CommitIdRequiredException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
IdempotencyParameterMismatchException(IdempotencyParameterMismatchException),
InvalidClientRequestTokenException(InvalidClientRequestTokenException),
InvalidCommitIdException(InvalidCommitIdException),
InvalidFileLocationException(InvalidFileLocationException),
InvalidFilePositionException(InvalidFilePositionException),
InvalidPathException(InvalidPathException),
InvalidRelativeFileVersionEnumException(InvalidRelativeFileVersionEnumException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
PathDoesNotExistException(PathDoesNotExistException),
PathRequiredException(PathRequiredException),
RepositoryDoesNotExistException(RepositoryDoesNotExistException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the PostCommentForComparedCommit operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BeforeCommitIdAndAfterCommitIdAreSameException(BeforeCommitIdAndAfterCommitIdAreSameException)The before commit ID and the after commit ID are the same, which is not valid. The before commit ID and the after commit ID must be different commit IDs.
Tuple Fields of BeforeCommitIdAndAfterCommitIdAreSameException
ClientRequestTokenRequiredException(ClientRequestTokenRequiredException)A client request token is required. A client request token is an unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
Tuple Fields of ClientRequestTokenRequiredException
CommentContentRequiredException(CommentContentRequiredException)The comment is empty. You must provide some content for a comment. The content cannot be null.
Tuple Fields of CommentContentRequiredException
CommentContentSizeLimitExceededException(CommentContentSizeLimitExceededException)The comment is too large. Comments are limited to 1,000 characters.
Tuple Fields of CommentContentSizeLimitExceededException
CommitDoesNotExistException(CommitDoesNotExistException)The specified commit does not exist or no commit was specified, and the specified repository has no default branch.
Tuple Fields of CommitDoesNotExistException
CommitIdRequiredException(CommitIdRequiredException)A commit ID was not specified.
Tuple Fields of CommitIdRequiredException
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)An encryption integrity check failed.
Tuple Fields of EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)An encryption key could not be accessed.
Tuple Fields of EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)The encryption key is disabled.
Tuple Fields of EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)No encryption key was found.
Tuple Fields of EncryptionKeyNotFoundException
The encryption key is not available.
IdempotencyParameterMismatchException(IdempotencyParameterMismatchException)The client request token is not valid. Either the token is not in a valid format, or the token has been used in a previous request and cannot be reused.
Tuple Fields of IdempotencyParameterMismatchException
InvalidClientRequestTokenException(InvalidClientRequestTokenException)The client request token is not valid.
Tuple Fields of InvalidClientRequestTokenException
InvalidCommitIdException(InvalidCommitIdException)The specified commit ID is not valid.
Tuple Fields of InvalidCommitIdException
InvalidFileLocationException(InvalidFileLocationException)The location of the file is not valid. Make sure that you include the file name and extension.
Tuple Fields of InvalidFileLocationException
InvalidFilePositionException(InvalidFilePositionException)The position is not valid. Make sure that the line number exists in the version of the file you want to comment on.
Tuple Fields of InvalidFilePositionException
InvalidPathException(InvalidPathException)The specified path is not valid.
Tuple Fields of InvalidPathException
InvalidRelativeFileVersionEnumException(InvalidRelativeFileVersionEnumException)Either the enum is not in a valid format, or the specified file version enum is not valid in respect to the current file version.
Tuple Fields of InvalidRelativeFileVersionEnumException
InvalidRepositoryNameException(InvalidRepositoryNameException)A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
Tuple Fields of InvalidRepositoryNameException
PathDoesNotExistException(PathDoesNotExistException)The specified path does not exist.
Tuple Fields of PathDoesNotExistException
PathRequiredException(PathRequiredException)The folderPath for a location cannot be null.
Tuple Fields of PathRequiredException
RepositoryDoesNotExistException(RepositoryDoesNotExistException)The specified repository does not exist.
Tuple Fields of RepositoryDoesNotExistException
RepositoryNameRequiredException(RepositoryNameRequiredException)A repository name is required, but was not specified.
Tuple Fields of RepositoryNameRequiredException
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code