Enum aws_sdk_codecommit::error::PostCommentReplyErrorKind [−][src]
#[non_exhaustive]
pub enum PostCommentReplyErrorKind {
ClientRequestTokenRequiredException(ClientRequestTokenRequiredException),
CommentContentRequiredException(CommentContentRequiredException),
CommentContentSizeLimitExceededException(CommentContentSizeLimitExceededException),
CommentDoesNotExistException(CommentDoesNotExistException),
CommentIdRequiredException(CommentIdRequiredException),
IdempotencyParameterMismatchException(IdempotencyParameterMismatchException),
InvalidClientRequestTokenException(InvalidClientRequestTokenException),
InvalidCommentIdException(InvalidCommentIdException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the PostCommentReply operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ClientRequestTokenRequiredException(ClientRequestTokenRequiredException)A client request token is required. A client request token is an unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
Tuple Fields of ClientRequestTokenRequiredException
CommentContentRequiredException(CommentContentRequiredException)The comment is empty. You must provide some content for a comment. The content cannot be null.
Tuple Fields of CommentContentRequiredException
CommentContentSizeLimitExceededException(CommentContentSizeLimitExceededException)The comment is too large. Comments are limited to 1,000 characters.
Tuple Fields of CommentContentSizeLimitExceededException
CommentDoesNotExistException(CommentDoesNotExistException)No comment exists with the provided ID. Verify that you have used the correct ID, and then try again.
Tuple Fields of CommentDoesNotExistException
CommentIdRequiredException(CommentIdRequiredException)The comment ID is missing or null. A comment ID is required.
Tuple Fields of CommentIdRequiredException
IdempotencyParameterMismatchException(IdempotencyParameterMismatchException)The client request token is not valid. Either the token is not in a valid format, or the token has been used in a previous request and cannot be reused.
Tuple Fields of IdempotencyParameterMismatchException
InvalidClientRequestTokenException(InvalidClientRequestTokenException)The client request token is not valid.
Tuple Fields of InvalidClientRequestTokenException
InvalidCommentIdException(InvalidCommentIdException)The comment ID is not in a valid format. Make sure that you have provided the full comment ID.
Tuple Fields of InvalidCommentIdException
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code