Enum aws_sdk_codecommit::error::PutCommentReactionErrorKind[][src]

#[non_exhaustive]
pub enum PutCommentReactionErrorKind {
    CommentDeletedException(CommentDeletedException),
    CommentDoesNotExistException(CommentDoesNotExistException),
    CommentIdRequiredException(CommentIdRequiredException),
    InvalidCommentIdException(InvalidCommentIdException),
    InvalidReactionValueException(InvalidReactionValueException),
    ReactionLimitExceededException(ReactionLimitExceededException),
    ReactionValueRequiredException(ReactionValueRequiredException),
    Unhandled(Box<dyn Error + Send + Sync + 'static>),
}
Types of errors that can occur for the PutCommentReaction operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CommentDeletedException(CommentDeletedException)

This comment has already been deleted. You cannot edit or delete a deleted comment.

Tuple Fields of CommentDeletedException

0: CommentDeletedException
CommentDoesNotExistException(CommentDoesNotExistException)

No comment exists with the provided ID. Verify that you have used the correct ID, and then try again.

Tuple Fields of CommentDoesNotExistException

0: CommentDoesNotExistException
CommentIdRequiredException(CommentIdRequiredException)

The comment ID is missing or null. A comment ID is required.

Tuple Fields of CommentIdRequiredException

0: CommentIdRequiredException
InvalidCommentIdException(InvalidCommentIdException)

The comment ID is not in a valid format. Make sure that you have provided the full comment ID.

Tuple Fields of InvalidCommentIdException

0: InvalidCommentIdException
InvalidReactionValueException(InvalidReactionValueException)

The value of the reaction is not valid. For more information, see the AWS CodeCommit User Guide.

Tuple Fields of InvalidReactionValueException

0: InvalidReactionValueException
ReactionLimitExceededException(ReactionLimitExceededException)

The number of reactions has been exceeded. Reactions are limited to one reaction per user for each individual comment ID.

Tuple Fields of ReactionLimitExceededException

0: ReactionLimitExceededException
ReactionValueRequiredException(ReactionValueRequiredException)

A reaction value is required.

Tuple Fields of ReactionValueRequiredException

0: ReactionValueRequiredException
Unhandled(Box<dyn Error + Send + Sync + 'static>)

An unexpected error, eg. invalid JSON returned by the service or an unknown error code

Tuple Fields of Unhandled

0: Box<dyn Error + Send + Sync + 'static>