Enum aws_sdk_codecommit::error::PutFileErrorKind [−][src]
#[non_exhaustive]
pub enum PutFileErrorKind {
Show 31 variants
BranchDoesNotExistException(BranchDoesNotExistException),
BranchNameIsTagNameException(BranchNameIsTagNameException),
BranchNameRequiredException(BranchNameRequiredException),
CommitMessageLengthExceededException(CommitMessageLengthExceededException),
DirectoryNameConflictsWithFileNameException(DirectoryNameConflictsWithFileNameException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
FileContentRequiredException(FileContentRequiredException),
FileContentSizeLimitExceededException(FileContentSizeLimitExceededException),
FileNameConflictsWithDirectoryNameException(FileNameConflictsWithDirectoryNameException),
FilePathConflictsWithSubmodulePathException(FilePathConflictsWithSubmodulePathException),
FolderContentSizeLimitExceededException(FolderContentSizeLimitExceededException),
InvalidBranchNameException(InvalidBranchNameException),
InvalidDeletionParameterException(InvalidDeletionParameterException),
InvalidEmailException(InvalidEmailException),
InvalidFileModeException(InvalidFileModeException),
InvalidParentCommitIdException(InvalidParentCommitIdException),
InvalidPathException(InvalidPathException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
NameLengthExceededException(NameLengthExceededException),
ParentCommitDoesNotExistException(ParentCommitDoesNotExistException),
ParentCommitIdOutdatedException(ParentCommitIdOutdatedException),
ParentCommitIdRequiredException(ParentCommitIdRequiredException),
PathRequiredException(PathRequiredException),
RepositoryDoesNotExistException(RepositoryDoesNotExistException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
SameFileContentException(SameFileContentException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the PutFile operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BranchDoesNotExistException(BranchDoesNotExistException)The specified branch does not exist.
Tuple Fields of BranchDoesNotExistException
BranchNameIsTagNameException(BranchNameIsTagNameException)The specified branch name is not valid because it is a tag name. Enter the name of a branch in the repository. For a list of valid branch names, use ListBranches.
Tuple Fields of BranchNameIsTagNameException
BranchNameRequiredException(BranchNameRequiredException)A branch name is required, but was not specified.
Tuple Fields of BranchNameRequiredException
CommitMessageLengthExceededException(CommitMessageLengthExceededException)The commit message is too long. Provide a shorter string.
Tuple Fields of CommitMessageLengthExceededException
DirectoryNameConflictsWithFileNameException(DirectoryNameConflictsWithFileNameException)A file cannot be added to the repository because the specified path name has the same name as a file that already exists in this repository. Either provide a different name for the file, or specify a different path for the file.
Tuple Fields of DirectoryNameConflictsWithFileNameException
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)An encryption integrity check failed.
Tuple Fields of EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)An encryption key could not be accessed.
Tuple Fields of EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)The encryption key is disabled.
Tuple Fields of EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)No encryption key was found.
Tuple Fields of EncryptionKeyNotFoundException
The encryption key is not available.
FileContentRequiredException(FileContentRequiredException)The file cannot be added because it is empty. Empty files cannot be added to the repository with this API.
Tuple Fields of FileContentRequiredException
FileContentSizeLimitExceededException(FileContentSizeLimitExceededException)The file cannot be added because it is too large. The maximum file size is 6 MB, and the combined file content change size is 7 MB. Consider making these changes using a Git client.
Tuple Fields of FileContentSizeLimitExceededException
FileNameConflictsWithDirectoryNameException(FileNameConflictsWithDirectoryNameException)A file cannot be added to the repository because the specified file name has the same name as a directory in this repository. Either provide another name for the file, or add the file in a directory that does not match the file name.
Tuple Fields of FileNameConflictsWithDirectoryNameException
FilePathConflictsWithSubmodulePathException(FilePathConflictsWithSubmodulePathException)The commit cannot be created because a specified file path points to a submodule. Verify that the destination files have valid file paths that do not point to a submodule.
Tuple Fields of FilePathConflictsWithSubmodulePathException
FolderContentSizeLimitExceededException(FolderContentSizeLimitExceededException)The commit cannot be created because at least one of the overall changes in the commit results in a folder whose contents exceed the limit of 6 MB. Either reduce the number and size of your changes, or split the changes across multiple folders.
Tuple Fields of FolderContentSizeLimitExceededException
InvalidBranchNameException(InvalidBranchNameException)The specified reference name is not valid.
Tuple Fields of InvalidBranchNameException
InvalidDeletionParameterException(InvalidDeletionParameterException)The specified deletion parameter is not valid.
Tuple Fields of InvalidDeletionParameterException
InvalidEmailException(InvalidEmailException)The specified email address either contains one or more characters that are not allowed, or it exceeds the maximum number of characters allowed for an email address.
Tuple Fields of InvalidEmailException
InvalidFileModeException(InvalidFileModeException)The specified file mode permission is not valid. For a list of valid file mode permissions, see PutFile.
Tuple Fields of InvalidFileModeException
InvalidParentCommitIdException(InvalidParentCommitIdException)The parent commit ID is not valid. The commit ID cannot be empty, and must match the head commit ID for the branch of the repository where you want to add or update a file.
Tuple Fields of InvalidParentCommitIdException
InvalidPathException(InvalidPathException)The specified path is not valid.
Tuple Fields of InvalidPathException
InvalidRepositoryNameException(InvalidRepositoryNameException)A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
Tuple Fields of InvalidRepositoryNameException
NameLengthExceededException(NameLengthExceededException)The user name is not valid because it has exceeded the character limit for author names.
Tuple Fields of NameLengthExceededException
ParentCommitDoesNotExistException(ParentCommitDoesNotExistException)The parent commit ID is not valid because it does not exist. The specified parent commit ID does not exist in the specified branch of the repository.
Tuple Fields of ParentCommitDoesNotExistException
ParentCommitIdOutdatedException(ParentCommitIdOutdatedException)The file could not be added because the provided parent commit ID is not the current tip of the specified branch. To view the full commit ID of the current head of the branch, use GetBranch.
Tuple Fields of ParentCommitIdOutdatedException
ParentCommitIdRequiredException(ParentCommitIdRequiredException)A parent commit ID is required. To view the full commit ID of a branch in a repository, use GetBranch or a Git command (for example, git pull or git log).
Tuple Fields of ParentCommitIdRequiredException
PathRequiredException(PathRequiredException)The folderPath for a location cannot be null.
Tuple Fields of PathRequiredException
RepositoryDoesNotExistException(RepositoryDoesNotExistException)The specified repository does not exist.
Tuple Fields of RepositoryDoesNotExistException
RepositoryNameRequiredException(RepositoryNameRequiredException)A repository name is required, but was not specified.
Tuple Fields of RepositoryNameRequiredException
SameFileContentException(SameFileContentException)The file was not added or updated because the content of the file is exactly the same as the content of that file in the repository and branch that you specified.
Tuple Fields of SameFileContentException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code