Enum aws_sdk_codecommit::error::PutRepositoryTriggersErrorKind [−][src]
#[non_exhaustive]
pub enum PutRepositoryTriggersErrorKind {
Show 22 variants
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
InvalidRepositoryTriggerBranchNameException(InvalidRepositoryTriggerBranchNameException),
InvalidRepositoryTriggerCustomDataException(InvalidRepositoryTriggerCustomDataException),
InvalidRepositoryTriggerDestinationArnException(InvalidRepositoryTriggerDestinationArnException),
InvalidRepositoryTriggerEventsException(InvalidRepositoryTriggerEventsException),
InvalidRepositoryTriggerNameException(InvalidRepositoryTriggerNameException),
InvalidRepositoryTriggerRegionException(InvalidRepositoryTriggerRegionException),
MaximumBranchesExceededException(MaximumBranchesExceededException),
MaximumRepositoryTriggersExceededException(MaximumRepositoryTriggersExceededException),
RepositoryDoesNotExistException(RepositoryDoesNotExistException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
RepositoryTriggerBranchNameListRequiredException(RepositoryTriggerBranchNameListRequiredException),
RepositoryTriggerDestinationArnRequiredException(RepositoryTriggerDestinationArnRequiredException),
RepositoryTriggerEventsListRequiredException(RepositoryTriggerEventsListRequiredException),
RepositoryTriggerNameRequiredException(RepositoryTriggerNameRequiredException),
RepositoryTriggersListRequiredException(RepositoryTriggersListRequiredException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the PutRepositoryTriggers operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)An encryption integrity check failed.
Tuple Fields of EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)An encryption key could not be accessed.
Tuple Fields of EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)The encryption key is disabled.
Tuple Fields of EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)No encryption key was found.
Tuple Fields of EncryptionKeyNotFoundException
The encryption key is not available.
InvalidRepositoryNameException(InvalidRepositoryNameException)A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
Tuple Fields of InvalidRepositoryNameException
InvalidRepositoryTriggerBranchNameException(InvalidRepositoryTriggerBranchNameException)One or more branch names specified for the trigger is not valid.
Tuple Fields of InvalidRepositoryTriggerBranchNameException
InvalidRepositoryTriggerCustomDataException(InvalidRepositoryTriggerCustomDataException)The custom data provided for the trigger is not valid.
Tuple Fields of InvalidRepositoryTriggerCustomDataException
InvalidRepositoryTriggerDestinationArnException(InvalidRepositoryTriggerDestinationArnException)The Amazon Resource Name (ARN) for the trigger is not valid for the specified destination. The most common reason for this error is that the ARN does not meet the requirements for the service type.
Tuple Fields of InvalidRepositoryTriggerDestinationArnException
InvalidRepositoryTriggerEventsException(InvalidRepositoryTriggerEventsException)One or more events specified for the trigger is not valid. Check to make sure that all events specified match the requirements for allowed events.
Tuple Fields of InvalidRepositoryTriggerEventsException
InvalidRepositoryTriggerNameException(InvalidRepositoryTriggerNameException)The name of the trigger is not valid.
Tuple Fields of InvalidRepositoryTriggerNameException
InvalidRepositoryTriggerRegionException(InvalidRepositoryTriggerRegionException)The AWS Region for the trigger target does not match the AWS Region for the repository. Triggers must be created in the same Region as the target for the trigger.
Tuple Fields of InvalidRepositoryTriggerRegionException
MaximumBranchesExceededException(MaximumBranchesExceededException)The number of branches for the trigger was exceeded.
Tuple Fields of MaximumBranchesExceededException
MaximumRepositoryTriggersExceededException(MaximumRepositoryTriggersExceededException)The number of triggers allowed for the repository was exceeded.
Tuple Fields of MaximumRepositoryTriggersExceededException
RepositoryDoesNotExistException(RepositoryDoesNotExistException)The specified repository does not exist.
Tuple Fields of RepositoryDoesNotExistException
RepositoryNameRequiredException(RepositoryNameRequiredException)A repository name is required, but was not specified.
Tuple Fields of RepositoryNameRequiredException
RepositoryTriggerBranchNameListRequiredException(RepositoryTriggerBranchNameListRequiredException)At least one branch name is required, but was not specified in the trigger configuration.
Tuple Fields of RepositoryTriggerBranchNameListRequiredException
RepositoryTriggerDestinationArnRequiredException(RepositoryTriggerDestinationArnRequiredException)A destination ARN for the target service for the trigger is required, but was not specified.
Tuple Fields of RepositoryTriggerDestinationArnRequiredException
RepositoryTriggerEventsListRequiredException(RepositoryTriggerEventsListRequiredException)At least one event for the trigger is required, but was not specified.
Tuple Fields of RepositoryTriggerEventsListRequiredException
RepositoryTriggerNameRequiredException(RepositoryTriggerNameRequiredException)A name for the trigger is required, but was not specified.
Tuple Fields of RepositoryTriggerNameRequiredException
RepositoryTriggersListRequiredException(RepositoryTriggersListRequiredException)The list of triggers for the repository is required, but was not specified.
Tuple Fields of RepositoryTriggersListRequiredException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code