Enum aws_sdk_codecommit::error::UpdateApprovalRuleTemplateNameErrorKind[][src]

#[non_exhaustive]
pub enum UpdateApprovalRuleTemplateNameErrorKind {
    ApprovalRuleTemplateDoesNotExistException(ApprovalRuleTemplateDoesNotExistException),
    ApprovalRuleTemplateNameAlreadyExistsException(ApprovalRuleTemplateNameAlreadyExistsException),
    ApprovalRuleTemplateNameRequiredException(ApprovalRuleTemplateNameRequiredException),
    InvalidApprovalRuleTemplateNameException(InvalidApprovalRuleTemplateNameException),
    Unhandled(Box<dyn Error + Send + Sync + 'static>),
}
Types of errors that can occur for the UpdateApprovalRuleTemplateName operation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ApprovalRuleTemplateDoesNotExistException(ApprovalRuleTemplateDoesNotExistException)

The specified approval rule template does not exist. Verify that the name is correct and that you are signed in to the AWS Region where the template was created, and then try again.

Tuple Fields of ApprovalRuleTemplateDoesNotExistException

0: ApprovalRuleTemplateDoesNotExistException
ApprovalRuleTemplateNameAlreadyExistsException(ApprovalRuleTemplateNameAlreadyExistsException)

You cannot create an approval rule template with that name because a template with that name already exists in this AWS Region for your AWS account. Approval rule template names must be unique.

Tuple Fields of ApprovalRuleTemplateNameAlreadyExistsException

0: ApprovalRuleTemplateNameAlreadyExistsException
ApprovalRuleTemplateNameRequiredException(ApprovalRuleTemplateNameRequiredException)

An approval rule template name is required, but was not specified.

Tuple Fields of ApprovalRuleTemplateNameRequiredException

0: ApprovalRuleTemplateNameRequiredException
InvalidApprovalRuleTemplateNameException(InvalidApprovalRuleTemplateNameException)

The name of the approval rule template is not valid. Template names must be between 1 and 100 valid characters in length. For more information about limits in AWS CodeCommit, see AWS CodeCommit User Guide.

Tuple Fields of InvalidApprovalRuleTemplateNameException

0: InvalidApprovalRuleTemplateNameException
Unhandled(Box<dyn Error + Send + Sync + 'static>)

An unexpected error, e.g. invalid JSON returned by the service or an unknown error code

Tuple Fields of Unhandled

0: Box<dyn Error + Send + Sync + 'static>