Enum aws_sdk_codecommit::error::UpdatePullRequestApprovalRuleContentErrorKind [−][src]
#[non_exhaustive]
pub enum UpdatePullRequestApprovalRuleContentErrorKind {
Show 17 variants
ApprovalRuleContentRequiredException(ApprovalRuleContentRequiredException),
ApprovalRuleDoesNotExistException(ApprovalRuleDoesNotExistException),
ApprovalRuleNameRequiredException(ApprovalRuleNameRequiredException),
CannotModifyApprovalRuleFromTemplateException(CannotModifyApprovalRuleFromTemplateException),
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidApprovalRuleContentException(InvalidApprovalRuleContentException),
InvalidApprovalRuleNameException(InvalidApprovalRuleNameException),
InvalidPullRequestIdException(InvalidPullRequestIdException),
InvalidRuleContentSha256Exception(InvalidRuleContentSha256Exception),
PullRequestAlreadyClosedException(PullRequestAlreadyClosedException),
PullRequestDoesNotExistException(PullRequestDoesNotExistException),
PullRequestIdRequiredException(PullRequestIdRequiredException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the UpdatePullRequestApprovalRuleContent operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
ApprovalRuleContentRequiredException(ApprovalRuleContentRequiredException)The content for the approval rule is empty. You must provide some content for an approval rule. The content cannot be null.
Tuple Fields of ApprovalRuleContentRequiredException
ApprovalRuleDoesNotExistException(ApprovalRuleDoesNotExistException)The specified approval rule does not exist.
Tuple Fields of ApprovalRuleDoesNotExistException
ApprovalRuleNameRequiredException(ApprovalRuleNameRequiredException)An approval rule name is required, but was not specified.
Tuple Fields of ApprovalRuleNameRequiredException
CannotModifyApprovalRuleFromTemplateException(CannotModifyApprovalRuleFromTemplateException)The approval rule cannot be modified for the pull request because it was created by an approval rule template and applied to the pull request automatically.
Tuple Fields of CannotModifyApprovalRuleFromTemplateException
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)An encryption integrity check failed.
Tuple Fields of EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)An encryption key could not be accessed.
Tuple Fields of EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)The encryption key is disabled.
Tuple Fields of EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)No encryption key was found.
Tuple Fields of EncryptionKeyNotFoundException
The encryption key is not available.
InvalidApprovalRuleContentException(InvalidApprovalRuleContentException)The content for the approval rule is not valid.
Tuple Fields of InvalidApprovalRuleContentException
InvalidApprovalRuleNameException(InvalidApprovalRuleNameException)The name for the approval rule is not valid.
Tuple Fields of InvalidApprovalRuleNameException
InvalidPullRequestIdException(InvalidPullRequestIdException)The pull request ID is not valid. Make sure that you have provided the full ID and that the pull request is in the specified repository, and then try again.
Tuple Fields of InvalidPullRequestIdException
InvalidRuleContentSha256Exception(InvalidRuleContentSha256Exception)The SHA-256 hash signature for the rule content is not valid.
Tuple Fields of InvalidRuleContentSha256Exception
PullRequestAlreadyClosedException(PullRequestAlreadyClosedException)The pull request status cannot be updated because it is already closed.
Tuple Fields of PullRequestAlreadyClosedException
PullRequestDoesNotExistException(PullRequestDoesNotExistException)The pull request ID could not be found. Make sure that you have specified the correct repository name and pull request ID, and then try again.
Tuple Fields of PullRequestDoesNotExistException
PullRequestIdRequiredException(PullRequestIdRequiredException)A pull request ID is required, but none was provided.
Tuple Fields of PullRequestIdRequiredException
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code