Enum aws_sdk_codecommit::error::UpdatePullRequestStatusErrorKind [−][src]
#[non_exhaustive]
pub enum UpdatePullRequestStatusErrorKind {
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidPullRequestIdException(InvalidPullRequestIdException),
InvalidPullRequestStatusException(InvalidPullRequestStatusException),
InvalidPullRequestStatusUpdateException(InvalidPullRequestStatusUpdateException),
PullRequestDoesNotExistException(PullRequestDoesNotExistException),
PullRequestIdRequiredException(PullRequestIdRequiredException),
PullRequestStatusRequiredException(PullRequestStatusRequiredException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the UpdatePullRequestStatus operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)An encryption integrity check failed.
Tuple Fields of EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)An encryption key could not be accessed.
Tuple Fields of EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)The encryption key is disabled.
Tuple Fields of EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)No encryption key was found.
Tuple Fields of EncryptionKeyNotFoundException
The encryption key is not available.
InvalidPullRequestIdException(InvalidPullRequestIdException)The pull request ID is not valid. Make sure that you have provided the full ID and that the pull request is in the specified repository, and then try again.
Tuple Fields of InvalidPullRequestIdException
InvalidPullRequestStatusException(InvalidPullRequestStatusException)The pull request status is not valid. The only valid values are OPEN and CLOSED.
Tuple Fields of InvalidPullRequestStatusException
InvalidPullRequestStatusUpdateException(InvalidPullRequestStatusUpdateException)The pull request status update is not valid. The only valid update is from OPEN to CLOSED.
Tuple Fields of InvalidPullRequestStatusUpdateException
PullRequestDoesNotExistException(PullRequestDoesNotExistException)The pull request ID could not be found. Make sure that you have specified the correct repository name and pull request ID, and then try again.
Tuple Fields of PullRequestDoesNotExistException
PullRequestIdRequiredException(PullRequestIdRequiredException)A pull request ID is required, but none was provided.
Tuple Fields of PullRequestIdRequiredException
PullRequestStatusRequiredException(PullRequestStatusRequiredException)A pull request status is required, but none was provided.
Tuple Fields of PullRequestStatusRequiredException
An unexpected error, e.g. invalid JSON returned by the service or an unknown error code