Enum aws_sdk_codecommit::error::UpdateRepositoryDescriptionErrorKind [−][src]
#[non_exhaustive]
pub enum UpdateRepositoryDescriptionErrorKind {
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException),
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException),
EncryptionKeyDisabledException(EncryptionKeyDisabledException),
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException),
EncryptionKeyUnavailableException(EncryptionKeyUnavailableException),
InvalidRepositoryDescriptionException(InvalidRepositoryDescriptionException),
InvalidRepositoryNameException(InvalidRepositoryNameException),
RepositoryDoesNotExistException(RepositoryDoesNotExistException),
RepositoryNameRequiredException(RepositoryNameRequiredException),
Unhandled(Box<dyn Error + Send + Sync + 'static>),
}Expand description
Types of errors that can occur for the UpdateRepositoryDescription operation.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
EncryptionIntegrityChecksFailedException(EncryptionIntegrityChecksFailedException)An encryption integrity check failed.
Tuple Fields of EncryptionIntegrityChecksFailedException
EncryptionKeyAccessDeniedException(EncryptionKeyAccessDeniedException)An encryption key could not be accessed.
Tuple Fields of EncryptionKeyAccessDeniedException
EncryptionKeyDisabledException(EncryptionKeyDisabledException)The encryption key is disabled.
Tuple Fields of EncryptionKeyDisabledException
EncryptionKeyNotFoundException(EncryptionKeyNotFoundException)No encryption key was found.
Tuple Fields of EncryptionKeyNotFoundException
The encryption key is not available.
InvalidRepositoryDescriptionException(InvalidRepositoryDescriptionException)The specified repository description is not valid.
Tuple Fields of InvalidRepositoryDescriptionException
InvalidRepositoryNameException(InvalidRepositoryNameException)A specified repository name is not valid.
This exception occurs only when a specified repository name is not valid. Other exceptions occur when a required repository parameter is missing, or when a specified repository does not exist.
Tuple Fields of InvalidRepositoryNameException
RepositoryDoesNotExistException(RepositoryDoesNotExistException)The specified repository does not exist.
Tuple Fields of RepositoryDoesNotExistException
RepositoryNameRequiredException(RepositoryNameRequiredException)A repository name is required, but was not specified.
Tuple Fields of RepositoryNameRequiredException
An unexpected error, eg. invalid JSON returned by the service or an unknown error code