Struct aws_sdk_codecommit::input::post_comment_for_pull_request_input::Builder [−][src]
#[non_exhaustive]pub struct Builder { /* fields omitted */ }Expand description
A builder for PostCommentForPullRequestInput
Implementations
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
The system-generated ID of the pull request. To get this ID, use ListPullRequests.
The name of the repository where you want to post a comment on a pull request.
The name of the repository where you want to post a comment on a pull request.
The full commit ID of the commit in the destination branch that was the tip of the branch at the time the pull request was created.
The full commit ID of the commit in the destination branch that was the tip of the branch at the time the pull request was created.
The full commit ID of the commit in the source branch that is the current tip of the branch for the pull request when you post the comment.
The full commit ID of the commit in the source branch that is the current tip of the branch for the pull request when you post the comment.
The location of the change where you want to post your comment. If no location is provided, the comment is posted as a general comment on the pull request difference between the before commit ID and the after commit ID.
The location of the change where you want to post your comment. If no location is provided, the comment is posted as a general comment on the pull request difference between the before commit ID and the after commit ID.
The content of your comment on the change.
The content of your comment on the change.
A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
Consumes the builder and constructs a PostCommentForPullRequestInput