Struct aws_sdk_codecommit::input::ListRepositoriesForApprovalRuleTemplateInput [−][src]
#[non_exhaustive]pub struct ListRepositoriesForApprovalRuleTemplateInput {
pub approval_rule_template_name: Option<String>,
pub next_token: Option<String>,
pub max_results: Option<i32>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.approval_rule_template_name: Option<String>The name of the approval rule template for which you want to list repositories that are associated with that template.
next_token: Option<String>An enumeration token that, when provided in a request, returns the next batch of the results.
max_results: Option<i32>A non-zero, non-negative integer used to limit the number of returned results.
Implementations
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListRepositoriesForApprovalRuleTemplate, AwsErrorRetryPolicy>, BuildError>
pub fn make_operation(
&self,
_config: &Config
) -> Result<Operation<ListRepositoriesForApprovalRuleTemplate, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<ListRepositoriesForApprovalRuleTemplate>
Creates a new builder-style object to manufacture ListRepositoriesForApprovalRuleTemplateInput