Struct aws_sdk_codecommit::input::UpdateApprovalRuleTemplateContentInput [−][src]
#[non_exhaustive]pub struct UpdateApprovalRuleTemplateContentInput {
pub approval_rule_template_name: Option<String>,
pub new_rule_content: Option<String>,
pub existing_rule_content_sha256: Option<String>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.approval_rule_template_name: Option<String>The name of the approval rule template where you want to update the content of the rule.
new_rule_content: Option<String>The content that replaces the existing content of the rule. Content statements must be complete. You cannot provide only the changes.
existing_rule_content_sha256: Option<String>The SHA-256 hash signature for the content of the approval rule. You can retrieve this information by using GetPullRequest.
Implementations
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateApprovalRuleTemplateContent, AwsErrorRetryPolicy>, BuildError>
pub async fn make_operation(
&self,
_config: &Config
) -> Result<Operation<UpdateApprovalRuleTemplateContent, AwsErrorRetryPolicy>, BuildError>
Consumes the builder and constructs an Operation<UpdateApprovalRuleTemplateContent>
Creates a new builder-style object to manufacture UpdateApprovalRuleTemplateContentInput