Struct aws_sdk_codecommit::model::BatchDisassociateApprovalRuleTemplateFromRepositoriesError [−][src]
#[non_exhaustive]pub struct BatchDisassociateApprovalRuleTemplateFromRepositoriesError {
pub repository_name: Option<String>,
pub error_code: Option<String>,
pub error_message: Option<String>,
}Expand description
Returns information about errors in a BatchDisassociateApprovalRuleTemplateFromRepositories operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository where the association with the template was not able to be removed.
error_code: Option<String>An error code that specifies whether the repository name was not valid or not found.
error_message: Option<String>An error message that provides details about why the repository name was either not found or not valid.
Implementations
Creates a new builder-style object to manufacture BatchDisassociateApprovalRuleTemplateFromRepositoriesError