Struct aws_sdk_codecommit::model::File [−][src]
#[non_exhaustive]pub struct File {
pub blob_id: Option<String>,
pub absolute_path: Option<String>,
pub relative_path: Option<String>,
pub file_mode: Option<FileModeTypeEnum>,
}Expand description
Returns information about a file in a repository.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.blob_id: Option<String>The blob ID that contains the file information.
absolute_path: Option<String>The fully qualified path to the file in the repository.
relative_path: Option<String>The relative path of the file from the folder where the query originated.
file_mode: Option<FileModeTypeEnum>The extrapolated file mode permissions for the file. Valid values include EXECUTABLE and NORMAL.
Implementations