Struct aws_sdk_codecommit::model::PullRequestMergedStateChangedEventMetadata [−][src]
#[non_exhaustive]pub struct PullRequestMergedStateChangedEventMetadata {
pub repository_name: Option<String>,
pub destination_reference: Option<String>,
pub merge_metadata: Option<MergeMetadata>,
}Expand description
Returns information about the change in the merge state for a pull request event.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository where the pull request was created.
destination_reference: Option<String>The name of the branch that the pull request is merged into.
merge_metadata: Option<MergeMetadata>Information about the merge state change event.
Implementations
Creates a new builder-style object to manufacture PullRequestMergedStateChangedEventMetadata