Struct aws_sdk_codecommit::model::PullRequestSourceReferenceUpdatedEventMetadata [−][src]
#[non_exhaustive]pub struct PullRequestSourceReferenceUpdatedEventMetadata {
pub repository_name: Option<String>,
pub before_commit_id: Option<String>,
pub after_commit_id: Option<String>,
pub merge_base: Option<String>,
}Expand description
Information about an update to the source branch of a pull request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.repository_name: Option<String>The name of the repository where the pull request was updated.
before_commit_id: Option<String>The full commit ID of the commit in the destination branch that was the tip of the branch at the time the pull request was updated.
after_commit_id: Option<String>The full commit ID of the commit in the source branch that was the tip of the branch at the time the pull request was updated.
merge_base: Option<String>The commit ID of the most recent commit that the source branch and the destination branch have in common.
Implementations
Creates a new builder-style object to manufacture PullRequestSourceReferenceUpdatedEventMetadata