#[non_exhaustive]pub struct DiffHunkBuilder { /* private fields */ }Expand description
A builder for DiffHunk.
Implementations
Sourceimpl DiffHunkBuilder
impl DiffHunkBuilder
Sourcepub fn before_start_line(self, input: i32) -> Self
pub fn before_start_line(self, input: i32) -> Self
The 1-based line number in the before blob where this hunk begins. When the hunk consists entirely of additions, beforeLineCount is 0.
Sourcepub fn set_before_start_line(self, input: Option<i32>) -> Self
pub fn set_before_start_line(self, input: Option<i32>) -> Self
The 1-based line number in the before blob where this hunk begins. When the hunk consists entirely of additions, beforeLineCount is 0.
Sourcepub fn get_before_start_line(&self) -> &Option<i32>
pub fn get_before_start_line(&self) -> &Option<i32>
The 1-based line number in the before blob where this hunk begins. When the hunk consists entirely of additions, beforeLineCount is 0.
Sourcepub fn before_line_count(self, input: i32) -> Self
pub fn before_line_count(self, input: i32) -> Self
The number of lines from the before blob covered by this hunk, including any context lines.
Sourcepub fn set_before_line_count(self, input: Option<i32>) -> Self
pub fn set_before_line_count(self, input: Option<i32>) -> Self
The number of lines from the before blob covered by this hunk, including any context lines.
Sourcepub fn get_before_line_count(&self) -> &Option<i32>
pub fn get_before_line_count(&self) -> &Option<i32>
The number of lines from the before blob covered by this hunk, including any context lines.
Sourcepub fn after_start_line(self, input: i32) -> Self
pub fn after_start_line(self, input: i32) -> Self
The 1-based line number in the after blob where this hunk begins. When the hunk consists entirely of deletions, afterLineCount is 0.
Sourcepub fn set_after_start_line(self, input: Option<i32>) -> Self
pub fn set_after_start_line(self, input: Option<i32>) -> Self
The 1-based line number in the after blob where this hunk begins. When the hunk consists entirely of deletions, afterLineCount is 0.
Sourcepub fn get_after_start_line(&self) -> &Option<i32>
pub fn get_after_start_line(&self) -> &Option<i32>
The 1-based line number in the after blob where this hunk begins. When the hunk consists entirely of deletions, afterLineCount is 0.
Sourcepub fn after_line_count(self, input: i32) -> Self
pub fn after_line_count(self, input: i32) -> Self
The number of lines from the after blob covered by this hunk, including any context lines.
Sourcepub fn set_after_line_count(self, input: Option<i32>) -> Self
pub fn set_after_line_count(self, input: Option<i32>) -> Self
The number of lines from the after blob covered by this hunk, including any context lines.
Sourcepub fn get_after_line_count(&self) -> &Option<i32>
pub fn get_after_line_count(&self) -> &Option<i32>
The number of lines from the after blob covered by this hunk, including any context lines.
Sourcepub fn changes(self, input: DiffChange) -> Self
pub fn changes(self, input: DiffChange) -> Self
Appends an item to changes.
To override the contents of this collection use set_changes.
An ordered list of line-level changes that make up this hunk. Each entry indicates whether the line is unchanged context, an addition, or a deletion.
Sourcepub fn set_changes(self, input: Option<Vec<DiffChange>>) -> Self
pub fn set_changes(self, input: Option<Vec<DiffChange>>) -> Self
An ordered list of line-level changes that make up this hunk. Each entry indicates whether the line is unchanged context, an addition, or a deletion.
Sourcepub fn get_changes(&self) -> &Option<Vec<DiffChange>>
pub fn get_changes(&self) -> &Option<Vec<DiffChange>>
An ordered list of line-level changes that make up this hunk. Each entry indicates whether the line is unchanged context, an addition, or a deletion.